echoUsage()
{
	echo "$(basename "$0") [-n EDB_NS_LIST] [-c CNP_LOC] [-v CNP_VER] [-o EDB_OPER_NS_LIST] [-h]"
	echo
	echo "WHERE"
	echo "-n EDB_NS_LIST = To set namespace(s) of Postgres EDB (separate multiple namespaces with space)"
	echo "-c CNP_LOC = To set the location or directory path of CNP plugin (eg. /usr/local/bin)"
	echo "-v CNP_VER = To set version of CNP plugin to download"
	echo "-o EDB_OPER_NS_LIST = To set namespace(s) of Postgres EDB Operator (separate multiple namespaces with space)"

	exit 0
}

while getopts :c:n:o:v:h OPTION
do
	case $OPTION in
		n)  EDB_NS_LIST=$OPTARG ;;
		c)  CNP_LOC=$OPTARG ;;
		v)  CNP_VER=$OPTARG ;;
		o)  EDB_OPER_NS_LIST=$OPTARG ;;
		h)  echoUsage ;;
		\?) echo "[ERROR] Invalid option = -$OPTARG [OPTIND=$OPTIND]" >&2 ;;
	esac
done

if [ ${#CNP_LOC} -gt 0 ]
then
	echo "[$(date)] [$(basename "$0")] Setting location of KUBECTL-CNP to [$CNP_LOC]..."
	
	if [ -s $CNP_LOC/kubectl-cnp ]
	then
		export PATH=$PATH:$CNP_LOC
	else
		echo "[$(date)] [$(basename "$0")] KUBECTL-CNP [$CNP_LOC/kubectl-cnp] does not exist or is zero-sized!" >&2
		exit 1
	fi
else
	if [ ${#CNP_VER} -gt 0 ]
	then
		echo "[$(date)] [$(basename "$0")] Setting version of KUBECTL-CNP to [$CNP_VER]..."
		curl -sSfL https://github.com/EnterpriseDB/kubectl-cnp/raw/main/install.sh 2> $CMD_EXEC_ERRFILE | bash -s -- -b $CMD_EXEC_OUTPUT_DIR v$CNP_VER
	else
		curl -sSfL https://github.com/EnterpriseDB/kubectl-cnp/raw/main/install.sh 2> $CMD_EXEC_ERRFILE | bash -s -- -b $CMD_EXEC_OUTPUT_DIR
	fi
	
	if [ -s $CMD_EXEC_OUTPUT_DIR/kubectl-cnp ]
	then
		export PATH=$PATH:$CMD_EXEC_OUTPUT_DIR
	else
		echo "[$(date)] [$(basename "$0")] KUBECTL-CNP [$CMD_EXEC_OUTPUT_DIR/kubectl-cnp] does not exist or is zero-sized!" >&2
		exit 1
	fi
fi

if [ ${#EDB_NS_LIST} -eq 0 ]
then
	EDB_NS_LIST=$(getProdToNamespacesMapping aimanager)

	if [ ${#EDB_OPER_NS_LIST} -eq 0 ]
	then
		EDB_OPER_NS_LIST="ibm-common-services"
	fi
fi

echo "[$(date)] [$(basename "$0")] Setting Postgres EDB namespace(s) to [$EDB_NS_LIST]..."
echo "[$(date)] [$(basename "$0")] Setting Postgres EDB Operator namespace to [$EDB_OPER_NS_LIST]..."

for EDB_NS in $EDB_NS_LIST
do
	EDB_CLUSTER_LIST=$($OC_CMD get clusters -n $EDB_NS -o=jsonpath='{.items[*].metadata.name}')
	
	for EDB_CLUSTER in $EDB_CLUSTER_LIST
	do
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] EDB_NS = [$EDB_NS] / EDB_CLUSTER = [$EDB_CLUSTER]"
		fi
		
		if [ ${#EDB_CLUSTER} -gt 0 ]
		then
			$OC_CMD cnp status ${EDB_CLUSTER} -n $EDB_NS --verbose > $CMD_EXEC_OUTPUT_DIR/${EDB_NS}:${EDB_CLUSTER}-status.txt
		
			CMD="$OC_CMD cnp report cluster $EDB_CLUSTER -n $EDB_NS -f $CMD_EXEC_OUTPUT_DIR/${EDB_NS}:${EDB_CLUSTER}-report.zip --logs"
		
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] CMD = [$CMD]"
			fi
		
			eval "$CMD"
		else
			echo "[$(date)] [$(basename "$0")] Unable to determine Postgres EDB cluster name!" >&2
		fi
	done
done

for EDB_OPER_NS in $EDB_OPER_NS_LIST
do
	EDB_OPER=$($OC_CMD get pod -n $EDB_OPER_NS --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}' | grep "postgresql-operator-controller-manager-")
	
	if [ ${#EDB_OPER} -gt 0 ]
	then
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] EDB_OPER = [$EDB_OPER] / EDB_OPER_NS = [$EDB_OPER_NS]"
		fi
	
		CMD="$OC_CMD cnp report operator -n ${EDB_OPER_NS} -f $CMD_EXEC_OUTPUT_DIR/${EDB_OPER_NS}:${EDB_OPER}-report.zip --logs"
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] CMD = [$CMD]"
		fi
	
		eval "$CMD"
	else
		if checkUserPriv get pod all >&2
		then
			IFS=$'\n'
			for LINE in $($OC_CMD get pod -A --no-headers | grep "postgresql-operator-controller-manager-")
			do	
				NSNAME=$(echo "$LINE" | $AWK '{ print $1 }')
				PODNAME=$(echo "$LINE" | $AWK '{ print $2 }')	
		
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] NSNAME = [$NSNAME] / PODNAME = [$PODNAME]"
				fi
		
				if [[ "$PODNAME" =~ ^postgresql-operator-controller-manager- ]]
				then
					EDB_OPER_NS="$NSNAME"
					EDB_OPER="$PODNAME"
		
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [$(basename "$0")] EDB_OPER = [$EDB_OPER] / EDB_OPER_NS = [$EDB_OPER_NS]"
					fi
		
					if [ ${#EDB_OPER_NS} -gt 0 ]
					then
						CMD="$OC_CMD cnp report operator -n ${EDB_OPER_NS} -f $CMD_EXEC_OUTPUT_DIR/${EDB_OPER_NS}:${EDB_OPER}-report.zip --logs"
			
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [$(basename "$0")] CMD = [$CMD]"
						fi
			
						eval "$CMD"
					else
						echo "[$(date)] [$(basename "$0")] Unable to determine Postgres EDB Operator namespace!" >&2
					fi
				fi
			done
			IFS=$OLDIFS
		else
			echo "[$(date)] [$(basename "$0")] Unable to determine Postgres EDB Operator namespace!" >&2
		fi
	fi
done

$OC_CMD get cluster -A > $CMD_EXEC_OUTPUT_DIR/all-clusters.txt 2>&1
$OC_CMD get csv -A > $CMD_EXEC_OUTPUT_DIR/all-csv.txt 2>&1
$OC_CMD get pods -A > $CMD_EXEC_OUTPUT_DIR/all-pods.txt 2>&1

if [ -f $CMD_EXEC_OUTPUT_DIR/kubectl-cnp ]
then
	rm $CMD_EXEC_OUTPUT_DIR/kubectl-cnp
fi
