NS=$(getProdToNamespacesMapping aimanager $CMD_EXEC_PRODUCT_NSFILE)

if [ ${#NS} -eq 0 ] || [ "$NS" == "$PROD_NAMESPACES_INVALID_STR" ]
then
	echo "[$(date)] [${FUNCNAME[0]}] Unable to determine AIOps namespace! Exiting..." >&2
	exit 1
fi

AIOPS_INSTALL_NAME=$($OC_CMD get install -n $NS -o jsonpath='{.items[*].metadata.name}')
KAFKA_BROKER=$($OC_CMD get routes iaf-system-kafka-bootstrap -n $NS -o=jsonpath='{.status.ingress[0].host}{"\n"}'):443;
KAFKA_SECRET="${AIOPS_INSTALL_NAME}-kafka-secret"
KAFKA_USERNAME=$($OC_CMD get secret ${KAFKA_SECRET} -n $NS -o jsonpath='{.data.username}' | base64 --decode)
KAFKA_SASL_PASSWORD=$($OC_CMD get secret "${KAFKA_SECRET}" -n $NS -o jsonpath='{.data.password}' | base64 --decode)
KAFKA_CA_CERT=$CMD_EXEC_OUTPUT_DIR/ca.crt
$OC_CMD get secret "${KAFKA_SECRET}" -n $NS -o jsonpath='{.data.caCertificate}' | base64 --decode > $KAFKA_CA_CERT
KAFKA_POD=$(getResourceInstances pod '^iaf-system-kafka-' $NS Running | head -1)

if [ $MG_DEBUG == "true" ]
then
	echo "[$(date)] [${FUNCNAME[0]}] KAFKA_BROKER = $KAFKA_BROKER" >&2
	echo "[$(date)] [${FUNCNAME[0]}] KAFKA_USERNAME = ${#KAFKA_USERNAME} (length)" >&2
	echo "[$(date)] [${FUNCNAME[0]}] KAFKA_SASL_PASSWORD = ${#KAFKA_SASL_PASSWORD} (length)" >&2
	echo "[$(date)] [${FUNCNAME[0]}] KAFKA_CA_CERT = $(ls -l $KAFKA_CA_CERT)" >&2
	echo "[$(date)] [${FUNCNAME[0]}] KAFKA_POD = $KAFKA_POD" >&2
fi

if [ ${#KAFKA_BROKER} -gt 0 ] && [ ${#KAFKA_SASL_PASSWORD} -gt 0 ] && [ -s $KAFKA_CA_CERT ] && [ ${#KAFKA_POD} -gt 0 ]
then
	# Create configuration files needed for kafka-console-consumer.sh
	KAFKA_CONSUMER_CFGFILE=$CMD_EXEC_OUTPUT_DIR/mg_consumer.cfg
	KEYSTORE_DIR="/tmp"
	KEYSTORE_NAME="$KEYSTORE_DIR/mg_truststore.pfx"
	KEYSTORE_PASSWORD="changeme"
	KEYSTORE_CONSUMER_CFGFILE=$KEYSTORE_DIR/$(basename $KAFKA_CONSUMER_CFGFILE)
	KEYSTORE_CERT=$KEYSTORE_DIR/$(basename $KAFKA_CA_CERT)
	
	echo "bootstrap.servers=${KAFKA_BROKER}" > $KAFKA_CONSUMER_CFGFILE
	echo "security.protocol=SASL_SSL" >> $KAFKA_CONSUMER_CFGFILE
	echo "ssl.protocol=TLSv1.2" >> $KAFKA_CONSUMER_CFGFILE
	echo "ssl.enabled.protocols=TLSv1.2" >> $KAFKA_CONSUMER_CFGFILE
	echo "ssl.truststore.location=$KEYSTORE_NAME" >> $KAFKA_CONSUMER_CFGFILE
	echo "ssl.truststore.password=$KEYSTORE_PASSWORD" >> $KAFKA_CONSUMER_CFGFILE
	echo "sasl.mechanism=SCRAM-SHA-512" >> $KAFKA_CONSUMER_CFGFILE
	echo "sasl.jaas.config=org.apache.kafka.common.security.scram.ScramLoginModule required username=\"${KAFKA_USERNAME}\" password=\"${KAFKA_SASL_PASSWORD}\";" >> $KAFKA_CONSUMER_CFGFILE

	# cat $KAFKA_CONSUMER_CFGFILE
	
	# Copy config file to Kafka pod
	echo "[$(date)] [${FUNCNAME[0]}] Copying Kafka configuration file [$KAFKA_CONSUMER_CFGFILE] into pod [${KAFKA_POD}] under directory [${KEYSTORE_DIR}]..." >&2
	$OC_CMD cp -n $NS $KAFKA_CONSUMER_CFGFILE ${KAFKA_POD}:${KEYSTORE_DIR} 
	
	# Create certificate in Kafka pod
	echo "[$(date)] [${FUNCNAME[0]}] Copying Kafka certificate file [$KAFKA_CA_CERT] into pod [${KAFKA_POD}] under directory [${KEYSTORE_DIR}]..." >&2
	$OC_CMD cp -n $NS $KAFKA_CA_CERT ${KAFKA_POD}:${KEYSTORE_DIR}
	
	# Import certificate
	echo "[$(date)] [${FUNCNAME[0]}] Importing Kafka certificate..." >&2
	CMD="$OC_CMD exec -n $NS $KAFKA_POD -- bash -c 'keytool -import -keystore ${KEYSTORE_NAME} -storetype PKCS12 -alias CARoot -file ${KEYSTORE_CERT} -noprompt -storepass $KEYSTORE_PASSWORD'"
	eval "$CMD"

	if [ ${#1} -eq 0 ]
	then
		for GROUP in $($OC_CMD exec $KAFKA_POD -n $NS -- bash -c "/opt/kafka/bin/kafka-consumer-groups.sh -list -bootstrap-server $KAFKA_BROKER --command-config ${KEYSTORE_CONSUMER_CFGFILE}" | $AWK '{ print $1 }')
		do
			CMD="$OC_CMD exec $KAFKA_POD -n $NS -- bash -c '/opt/kafka/bin/kafka-consumer-groups.sh -group $GROUP -describe -bootstrap-server $KAFKA_BROKER --command-config ${KEYSTORE_CONSUMER_CFGFILE}'"
	
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CMD = [$CMD]" >&2
			fi
	
			eval "$CMD"
		done
	else
		# (1) There is no need to specify the directory to the Kafka tools - directory /opt/kafka/bin/ is appended automatically
		# (2) --bootstrap-server and --command-config are constructed automatically and can be left out by user
		CMD="$OC_CMD exec $KAFKA_POD -n $NS -- bash -c '/opt/kafka/bin/$1 --bootstrap-server $KAFKA_BROKER --command-config ${KEYSTORE_CONSUMER_CFGFILE}'"
		
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] CMD = [$CMD]" >&2
		fi

		eval "$CMD"
	fi

	# Clean up
	echo "[$(date)] [${FUNCNAME[0]}] Deleting certificate from keystore..." >&2
	CMD="$OC_CMD exec -n $NS $KAFKA_POD -- bash -c 'keytool -delete -keystore ${KEYSTORE_NAME} -storetype PKCS12 -alias CARoot -noprompt -storepass $KEYSTORE_PASSWORD'"
	eval "$CMD"
	
	echo "[$(date)] [${FUNCNAME[0]}] Deleting certificate [$KEYSTORE_CERT]..." >&2
	CMD="$OC_CMD exec -n $NS $KAFKA_POD -- bash -c 'rm $KEYSTORE_CERT'"
	eval "$CMD"
	
	echo "[$(date)] [${FUNCNAME[0]}] Deleting consumer configuration file [$KEYSTORE_CONSUMER_CFGFILE]..." >&2
	CMD="$OC_CMD exec -n $NS $KAFKA_POD -- bash -c 'rm $KEYSTORE_CONSUMER_CFGFILE'"
	eval "$CMD"
	
	rm $KAFKA_CA_CERT
	rm $KAFKA_CONSUMER_CFGFILE
else
	echo "[$(date)] [${FUNCNAME[0]}] Unable to construct Kafka conenction details! Exiting..."
	exit 1
fi

