ICS_NS=$(getProdToNamespacesMapping aimanager)

if [ ${#ICS_NS} -gt 0 ]
then
	if [ ${ICS_NS} == "$PROD_NAMESPACES_INVALID_STR" ]
	then
		echo "[$(date)] [$(basename "$0")] [1] Unable to determine namespace for AIOps! Exiting..." >&2 
		exit 1
	fi
else
	echo "[$(date)] [$(basename "$0")] [2] Unable to determine namespace for AIOps! Exiting..." >&2 
	exit 1
fi

CUR_LIBERTY_LOGLEVEL=$($OC_CMD get cm platform-auth-idp -n $ICS_NS -o=jsonpath='{.data.LIBERTY_DEBUG_ENABLED}')
CUR_AUTHSVC_LOGLEVEL=$($OC_CMD get cm platform-auth-idp -n $ICS_NS -o=jsonpath='{.data.LOG_LEVEL_AUTHSVC}')
CUR_IDMGMT_LOGLEVEL=$($OC_CMD get cm platform-auth-idp -n $ICS_NS -o=jsonpath='{.data.LOG_LEVEL_IDMGMT}')
CUR_IDPROVIDER_LOGLEVEL=$($OC_CMD get cm platform-auth-idp -n $ICS_NS -o=jsonpath='{.data.LOG_LEVEL_IDPROVIDER}')

if [ $MG_DEBUG == "true" ]
then
	echo "[$(date)] [$(basename "$0")] CUR_LIBERTY_LOGLEVEL = [$CUR_LIBERTY_LOGLEVEL] / CUR_AUTHSVC_LOGLEVEL = [$CUR_AUTHSVC_LOGLEVEL] / CUR_IDMGMT_LOGLEVEL = [$CUR_IDMGMT_LOGLEVEL] / CUR_IDPROVIDER_LOGLEVEL = [$CUR_IDPROVIDER_LOGLEVEL]" >&2
fi

if [ $# -eq 0 ]
then
	if ([ ${#CUR_LIBERTY_LOGLEVEL} -gt 0 ] && [ ${CUR_LIBERTY_LOGLEVEL} == "true" ]) && ([ ${#CUR_AUTHSVC_LOGLEVEL} -gt 0 ] && [ ${CUR_AUTHSVC_LOGLEVEL} == "debug" ]) && ([ ${#CUR_IDMGMT_LOGLEVEL} -gt 0 ] && [ ${CUR_IDMGMT_LOGLEVEL} == "debug" ]) && ([ ${#CUR_IDPROVIDER_LOGLEVEL} -gt 0 ] && [ ${CUR_IDPROVIDER_LOGLEVEL} == "debug" ])
	then
		echo "[$(date)] [$(basename "$0")] LOG_LEVEL_AUTHSVC, LOG_LEVEL_IDMGMT and LOG_LEVEL_IDPROVIDER are already on [debug] loglevel and LIBERTY_DEBUG_ENABLED is already set to [true]! Exiting..." >&2
		exit 0
	fi

	# DEFAULT behavior (script called without any option) - LOG_LEVEL_AUTHSVC,LOG_LEVEL_IDMGMT,LOG_LEVEL_IDPROVIDER (debug) and LIBERTY_DEBUG_ENABLED (true)
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] Setting LOG_LEVEL_AUTHSVC, LOG_LEVEL_IDMGMT and LOG_LEVEL_IDPROVIDER to [debug]..." >&2
		echo "[$(date)] [$(basename "$0")] Setting LIBERTY_DEBUG_ENABLED to [true]..." >&2 
	fi	

	CMD="$OC_CMD patch cm platform-auth-idp -n $ICS_NS -p '{\"data\":{\"LIBERTY_DEBUG_ENABLED\":\"true\",\"LOG_LEVEL_AUTHSVC\":\"debug\",\"LOG_LEVEL_IDMGMT\":\"debug\",\"LOG_LEVEL_IDPROVIDER\":\"debug\"}}'"
	
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] CMD = [$CMD]" >&2 
	fi

	if [ $MG_DEBUG == "true" ]
	then
		eval "$CMD" >&2
	else
		eval "$CMD" >/dev/null
	fi

	echo "[$(date)] [$(basename "$0")] [1] Restarting auth-idp pods..." >&2 

	if [ $MG_DEBUG == "true" ]
	then
		$OC_CMD delete pod -l k8s-app=auth-idp -n $ICS_NS >&2 
	else
		$OC_CMD delete pod -l k8s-app=auth-idp -n $ICS_NS >/dev/null
	fi
else
	if ([ ${#CUR_LIBERTY_LOGLEVEL} -gt 0 ] && [ ${CUR_LIBERTY_LOGLEVEL} == "false" ]) && ([ ${#CUR_AUTHSVC_LOGLEVEL} -gt 0 ] && [ ${CUR_AUTHSVC_LOGLEVEL} == "info" ]) && ([ ${#CUR_IDMGMT_LOGLEVEL} -gt 0 ] && [ ${CUR_IDMGMT_LOGLEVEL} == "info" ]) && ([ ${#CUR_IDPROVIDER_LOGLEVEL} -gt 0 ] && [ ${CUR_IDPROVIDER_LOGLEVEL} == "info" ])
	then
		echo "[$(date)] [$(basename "$0")] LOG_LEVEL_AUTHSVC, LOG_LEVEL_IDMGMT and LOG_LEVEL_IDPROVIDER are already on [info] loglevel and LIBERTY_DEBUG_ENABLED is already set to [false]! Exiting..." >&2
		exit 0
	fi

	RESET="false"

	while getopts :t:l:d:r OPTION
	do
		case $OPTION in
			t)  LOG_TARGET=$OPTARG ;;
			l)  LOG_LEVEL=$OPTARG ;;
			d)  LIBERTY_DEBUG=$OPTARG ;;
			r)  RESET="true" ;;
			\?) echo "[ERROR] Invalid option = -$OPTARG [OPTIND=$OPTIND]" >&2 ;;
		esac
	done

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] LOG_TARGET = [$LOG_TARGET] / LOG_LEVEL = [$LOG_LEVEL] / LIBERTY_DEBUG = [$LIBERTY_DEBUG] / RESET = [$RESET]" >&2
	fi

	if [ $RESET == "true" ]
	then
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] Setting LOG_LEVEL_AUTHSVC, LOG_LEVEL_IDMGMT and LOG_LEVEL_IDPROVIDER to [info]..." >&2 
			echo "[$(date)] [$(basename "$0")] Setting LIBERTY_DEBUG_ENABLED to [false]..." >&2 
		fi	

		CMD="$OC_CMD patch cm platform-auth-idp -n $ICS_NS -p '{\"data\":{\"LIBERTY_DEBUG_ENABLED\":\"false\",\"LOG_LEVEL_AUTHSVC\":\"info\",\"LOG_LEVEL_IDMGMT\":\"info\",\"LOG_LEVEL_IDPROVIDER\":\"info\"}}'"
		
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] CMD = [$CMD]" >&2 
		fi
	
		if [ $MG_DEBUG == "true" ]
		then
			eval "$CMD" >&2 
		else
			eval "$CMD" >/dev/null
		fi

		echo "[$(date)] [$(basename "$0")] [1] Restarting auth-idp pods..." >&2 

		if [ $MG_DEBUG == "true" ]
		then
			$OC_CMD delete pod -l k8s-app=platform-auth-service -n $ICS_NS >&2 
		else
			$OC_CMD delete pod -l k8s-app=platform-auth-service -n $ICS_NS >/dev/null
		fi

		exit 0
	fi

	if [ ${#LOG_TARGET} -gt 0 ]
	then
		# TODO
		echo
	fi

	if [ ${#LOG_LEVEL} -gt 0 ]
	then
		# TODO
		echo
	fi

	if [ ${#LIBERTY_DEBUG} -gt 0 ]
	then
		# TODO
		echo
	fi
fi

