urlencode() 
{
	OLD_LC_COLLATE=$LC_COLLATE
	LC_COLLATE=C

	local LENGTH="${#1}"

	for (( i = 0; i < LENGTH; i++ ))
	do
		local CHAR="${1:i:1}"
		case $CHAR in
			[a-zA-Z0-9.~_-]) printf "$CHAR" ;;
			' ') printf "%%20" ;;
			*) printf '%%%02X' "'$CHAR" ;;
		esac
	done

	LC_COLLATE=$OLD_LC_COLLATE
}

AIMGR_NS=$(getProdToNamespacesMapping aimanager $PROD_NAMESPACES_REFFILE_FINAL)
TOTAL_GROUP=0
TOTAL_METRIC=0
TOTAL_KPI_COUNT=0

if [ ${#AIMGR_NS} -gt 0 ] && [ ${AIMGR_NS} != "$PROD_NAMESPACES_INVALID_STR" ]
then
	ROUTE=$($OC_CMD get route -n $AIMGR_NS | grep ibm-nginx-svc | awk '{print $2}')
	PASS=$($OC_CMD get secret platform-auth-idp-credentials -o jsonpath='{.data.admin_password}' -n $AIMGR_NS | base64 -d)
	TOKEN=$(curl -k -X POST https://$ROUTE/icp4d-api/v1/authorize -H 'Content-Type: application/json' -d "{\"username\": \"cpadmin\",\"password\": \"$PASS\"}" 2>/dev/null|awk -F'"' '{print $(NF-1)}')
	METRIC_API_URL="https://${ROUTE}/aiops/api/app/metric-api/v1/types/groups"

	if [ $MG_DEBUG == "true" ]
	then
		echo "ROUTE = [$ROUTE] / PASS = [${#PASS} (length)] / TOKEN = [$TOKEN]" >&2
		echo "METRIC_API_URL = [$METRIC_API_URL]" >&2
	fi

	for GROUP in $(curl -vk -X GET $METRIC_API_URL --header 'Content-Type: application/json' --header "Authorization: Bearer ${TOKEN}" --header 'X-TenantID: cfd95b7e-3bc7-4006-a4a8-a73a79c71255' 2>/dev/null | sed 's/^\[//' | sed 's/]$//' | sed s/^'"'// | sed s/'"'$// | sed s/'","'/,/g | sed 's/,/\n/g' | sort | uniq)
	do
		(( TOTAL_GROUP=TOTAL_GROUP+1 ))

		if [ $IS_MACOS != "true" ] && [ $BASH_V4 == "true" ]
		then
			METRIC_CURL_CMD="curl -k -G -X GET --data-urlencode 'group=${GROUP}' https://${ROUTE}/aiops/api/app/metric-api/v1/types/metrics --header 'Content-Type: application/json' --header 'Authorization: Bearer ${TOKEN}' --header 'X-TenantID: cfd95b7e-3bc7-4006-a4a8-a73a79c71255'"
		else
			GROUP_URLENCODE=$(urlencode "$GROUP")

			if [ ${#GROUP_URLENCODE} -gt 0 ]
			then
				METRIC_CURL_CMD="curl -k -X GET 'https://${ROUTE}/aiops/api/app/metric-api/v1/types/metrics?group=${GROUP_URLENCODE}' --header 'Content-Type: application/json' --header 'Authorization: Bearer ${TOKEN}' --header 'X-TenantID: cfd95b7e-3bc7-4006-a4a8-a73a79c71255'"
			else
				echo "URL encoding error for group [$GROUP]! Skipping..."
				continue
			fi
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "> METRIC_CURL_CMD = [$METRIC_CURL_CMD]" >&2
		fi

		for METRIC in $(eval "$METRIC_CURL_CMD" 2>/dev/null | sed 's/^\[//' | sed 's/]$//' | sed s/^'"'// | sed s/'"'$// | sed s/'","'/,/g | sed 's/,/\n/g')
		do 
			(( TOTAL_METRIC=TOTAL_METRIC+1 ))

			TOTAL_RESOURCE=0

			if [ $IS_MACOS != "true" ] && [ $BASH_V4 == "true" ]
			then
				RESOURCE_CURL_CMD="curl -s -k -G -X GET --data-urlencode 'group=${GROUP}' --data-urlencode 'metric=${METRIC}' https://${ROUTE}/aiops/api/app/metric-api/v1/types/resources --header 'Content-Type: application/json' --header 'Authorization: Bearer ${TOKEN}' --header 'X-TenantID: cfd95b7e-3bc7-4006-a4a8-a73a79c71255'"
			else
				METRIC_URLENCODE=$(urlencode "$METRIC")

				if [ ${#METRIC_URLENCODE} -gt 0 ]
				then
					RESOURCE_CURL_CMD="curl -s -k -X GET 'https://${ROUTE}/aiops/api/app/metric-api/v1/types/resources?group=${GROUP_URLENCODE}&metric=${METRIC_URLENCODE}' --header 'Content-Type: application/json' --header 'Authorization: Bearer ${TOKEN}' --header 'X-TenantID: cfd95b7e-3bc7-4006-a4a8-a73a79c71255'"
				else
					echo "URL encoding error for group [$GROUP] / metric [$METRIC]! Skipping..."
					continue
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo ">>> RESOURCE_CURL_CMD = [$RESOURCE_CURL_CMD]" >&2
			fi

			for RESOURCE in $(eval "$RESOURCE_CURL_CMD" | sed 's/,/\n/g')
			do 
				(( TOTAL_RESOURCE=TOTAL_RESOURCE+1 ))
				(( TOTAL_KPI_COUNT=TOTAL_KPI_COUNT+1 ))
			done

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$TOTAL_GROUP] GROUP = [$GROUP] / METRIC = [$METRIC] / TOTAL_RESOURCE = [$TOTAL_RESOURCE]"
			fi
		done
	done

	echo
	echo "TOTAL_GROUP = [$TOTAL_GROUP]"
	echo "TOTAL_METRIC = [$TOTAL_METRIC]"
	echo "TOTAL_KPI_COUNT = [$TOTAL_KPI_COUNT]"
else
	echo "Unable to determine AI Manager namespace! Exiting..." >&2
	exit 1
fi

