AIMGR_NAMESPACE=$(getProdToNamespacesMapping aimanager $CMD_EXEC_PRODUCT_NSFILE)

# Scale down lifecycle
echo "[$(date)] [$(basename "$0")] Scaling lifecycle deployment [ir-lifecycle-operator-controller-manager] down to 0..." 
echo "[$(date)] [$(basename "$0")] Scaling lifecycle deployment [ir-lifecycle-operator-controller-manager] down to 0..." >&8
$OC_CMD scale deployment/ir-lifecycle-operator-controller-manager -n $AIMGR_NAMESPACE --replicas=0

# Delete flinkcluster
echo "[$(date)] [$(basename "$0")] Deleting flinkcluster [$($OC_CMD get flinkcluster -n $AIMGR_NAMESPACE -l app.kubernetes.io/instance=aiops,app.kubernetes.io/managed-by=ir-lifecycle-operator --no-headers | $AWK '{ print $1 }')..."
echo "[$(date)] [$(basename "$0")] Deleting flinkcluster [$($OC_CMD get flinkcluster -n $AIMGR_NAMESPACE -l app.kubernetes.io/instance=aiops,app.kubernetes.io/managed-by=ir-lifecycle-operator --no-headers | $AWK '{ print $1 }')..." >&8
$OC_CMD delete flinkcluster -n $AIMGR_NAMESPACE -l app.kubernetes.io/instance=aiops,app.kubernetes.io/managed-by=ir-lifecycle-operator --ignore-not-found=true

# Patch lifecycle
echo "[$(date)] [$(basename "$0")] Patching lifecycletrigger..."
echo "[$(date)] [$(basename "$0")] Patching lifecycletrigger..." >&8
$OC_CMD patch lifecycletrigger aiops -n $AIMGR_NAMESPACE --request-timeout 5m --type=json --patch="$($OC_CMD get lifecycletrigger aiops -n $AIMGR_NAMESPACE -o jsonpath='{"[{"}"op":"add","path":"/spec/deleteSavepoints","value":[{range .status.savepoints[*]}"{.path}",{end}]},{"{"}"op":"add","path":"/spec/cancelJobs","value":[{range .status.jobs[*]}"{.jid}",{end}]}]' | sed 's/,]/]/g')"

if [ $? -eq 0 ]
then
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] Patch succeeded..."
		echo "[$(date)] [$(basename "$0")] Patch succeeded..." >&8
		$OC_CMD get -o json lifecycletrigger aiops -n $AIMGR_NAMESPACE 
	fi
else
	echo "[$(date)] [$(basename "$0")] Patch failed! Exiting..."
	echo "[$(date)] [$(basename "$0")] Patch failed! Exiting..." >&8
	exit 1
fi

TIMEOUT_CTR=0
TIMEOUT_MAX_CTR=10
WAIT_FAILED=

while [ $($OC_CMD get po -n $AIMGR_NAMESPACE | grep aiops-ir-lifecycle-eventprocessor-ep-jobmanager- | wc -l) -gt 0 ]
do
	(( TIMEOUT_CTR=TIMEOUT_CTR+1 ))

	if [ ${TIMEOUT_CTR} -gt ${TIMEOUT_MAX_CTR} ]
	then
		WAIT_FAILED="true"
		break
	else
		echo "[$(date)] [$(basename "$0")] Waiting for 'jobmanager' to exit..."
		echo "[$(date)] [$(basename "$0")] Waiting for 'jobmanager' to exit..." >&8
		sleep 5
	fi
done

if [ ${#WAIT_FAILED} -gt 0 ] && [ ${WAIT_FAILED} == "true" ]
then
	# TODO - Reset
	echo "[$(date)] [$(basename "$0")] 'jobmanager' failed to exit completely! Exiting..."
	echo "[$(date)] [$(basename "$0")] 'jobmanager' failed to exit completely! Exiting..." >&8
	exit 1
fi

TIMEOUT_CTR=0
TIMEOUT_MAX_CTR=10
WAIT_FAILED=

while [ $($OC_CMD get po -n $AIMGR_NAMESPACE | grep aiops-ir-lifecycle-eventprocessor-ep-taskmanager- | wc -l) -gt 0 ]
do
	(( TIMEOUT_CTR=TIMEOUT_CTR+1 ))

	if [ ${TIMEOUT_CTR} -gt ${TIMEOUT_MAX_CTR} ]
	then
		WAIT_FAILED="true"
		break
	else
		echo "[$(date)] [$(basename "$0")] Waiting for 'taskmanager' to exit..."
		echo "[$(date)] [$(basename "$0")] Waiting for 'taskmanager' to exit..." >&8
		sleep 5
	fi
done

if [ ${#WAIT_FAILED} -gt 0 ] && [ ${WAIT_FAILED} == "true" ]
then
	# TODO - Reset
	echo "[$(date)] [$(basename "$0")] 'taskmanager' failed to exit completely! Exiting..."
	echo "[$(date)] [$(basename "$0")] 'taskmanager' failed to exit completely! Exiting..." >&8
	exit 1
fi

# KAFKA_POD="iaf-system-kafka-0"
KAFKA_POD=$(getResourceInstances pod '^iaf-system-kafka-' $AIMGR_NAMESPACE Running | head -1)
KAFKA_BROKER="$($OC_CMD get svc -n $AIMGR_NAMESPACE iaf-system-kafka-bootstrap --no-headers | $AWK '{ print $1 }'):9093"
KAFKA_CA_CERT=$CMD_EXEC_OUTPUT_DIR/mg_ca.crt
# KAFKA_SECRET=ibm-cp-watson-aiops-kafka-secret
KAFKA_SECRET="$($OC_CMD get installations.orchestrator.aiops.ibm.com --no-headers -n $AIMGR_NAMESPACE | $AWK '{ print $1 }')-kafka-secret"
KAFKA_USERNAME=$($OC_CMD get secret ${KAFKA_SECRET} -n $AIMGR_NAMESPACE -o jsonpath='{.data.username}' | base64 --decode)
KAFKA_SASL_PASSWORD=$($OC_CMD get secret "${KAFKA_SECRET}" -n $AIMGR_NAMESPACE -o jsonpath='{.data.password}' | base64 --decode)
	
$OC_CMD get secret $KAFKA_SECRET -n $AIMGR_NAMESPACE -o jsonpath='{.data.caCertificate}' | base64 --decode > $KAFKA_CA_CERT

if [ $MG_DEBUG == "true" ]
then
	echo "[$(date)] [$(basename "$0")] KAFKA_BROKER = $KAFKA_BROKER"
	echo "[$(date)] [$(basename "$0")] KAFKA_USERNAME = $KAFKA_USERNAME"
	echo "[$(date)] [$(basename "$0")] KAFKA_SASL_PASSWORD = ${#KAFKA_SASL_PASSWORD} (length)"
	echo "[$(date)] [$(basename "$0")] KAFKA_CA_CERT = $(ls -l $KAFKA_CA_CERT)"
fi

if [ ${#KAFKA_BROKER} -gt 0 ] && [ ${#KAFKA_SASL_PASSWORD} -gt 0 ] && [ -s $KAFKA_CA_CERT ]
then
	# Create configuration files needed for kafka-console-consumer.sh
	KAFKA_CONSUMER_CFGFILE=$CMD_EXEC_OUTPUT_DIR/mg_consumer.cfg
	KEYSTORE_DIR="/tmp"
	KEYSTORE_NAME="$KEYSTORE_DIR/mg_truststore.pfx"
	KEYSTORE_PASSWORD="changeme"
	KEYSTORE_CONSUMER_CFGFILE=$KEYSTORE_DIR/$(basename $KAFKA_CONSUMER_CFGFILE)
	KEYSTORE_CERT=$KEYSTORE_DIR/$(basename $KAFKA_CA_CERT)

	echo "bootstrap.servers=${KAFKA_BROKER}" > $KAFKA_CONSUMER_CFGFILE
	echo "security.protocol=SASL_SSL" >> $KAFKA_CONSUMER_CFGFILE
	echo "ssl.protocol=TLSv1.2" >> $KAFKA_CONSUMER_CFGFILE
	echo "ssl.enabled.protocols=TLSv1.2" >> $KAFKA_CONSUMER_CFGFILE
	echo "ssl.truststore.location=$KEYSTORE_NAME" >> $KAFKA_CONSUMER_CFGFILE
	echo "ssl.truststore.password=$KEYSTORE_PASSWORD" >> $KAFKA_CONSUMER_CFGFILE
	echo "sasl.mechanism=SCRAM-SHA-512" >> $KAFKA_CONSUMER_CFGFILE
	echo "sasl.jaas.config=org.apache.kafka.common.security.scram.ScramLoginModule required username=\"${KAFKA_USERNAME}\" password=\"${KAFKA_SASL_PASSWORD}\";" >> $KAFKA_CONSUMER_CFGFILE

	# Copy config file to Kafka pod
	echo "[$(date)] [$(basename "$0")] Copying KAFKA_CONSUMER_CFGFILE [$KAFKA_CONSUMER_CFGFILE] into pod [$KAFKA_POD] at directory [$KEYSTORE_DIR]..."
	echo "[$(date)] [$(basename "$0")] Copying KAFKA_CONSUMER_CFGFILE [$KAFKA_CONSUMER_CFGFILE] into pod [$KAFKA_POD] at directory [$KEYSTORE_DIR]..." >&8
	$OC_CMD cp $KAFKA_CONSUMER_CFGFILE -n $AIMGR_NAMESPACE ${KAFKA_POD}:${KEYSTORE_DIR}

	# Create certificate in Kafka pod
	echo "[$(date)] [$(basename "$0")] Copying KAFKA_KAFKA_CA_CERT [$KAFKA_CA_CERT] into pod [$KAFKA_POD] at directory [$KEYSTORE_DIR]..."
	echo "[$(date)] [$(basename "$0")] Copying KAFKA_KAFKA_CA_CERT [$KAFKA_CA_CERT] into pod [$KAFKA_POD] at directory [$KEYSTORE_DIR]..." >&8
	$OC_CMD cp $KAFKA_CA_CERT -n $AIMGR_NAMESPACE ${KAFKA_POD}:${KEYSTORE_DIR}
	
	# Import certificate
	# echo -n "changeme" > "${KEYSTORE_DIR}/truststore_pw.txt"
	CMD="$OC_CMD exec -n $AIMGR_NAMESPACE $KAFKA_POD -- bash -c 'keytool -import -keystore ${KEYSTORE_NAME} -storetype PKCS12 -alias CARoot -file ${KEYSTORE_CERT} -noprompt -storepass $KEYSTORE_PASSWORD'"
	
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..."
	else
		echo "[$(date)] [$(basename "$0")] Executing command '$(echo $CMD | sed "s/-storepass .*'/-storepass XXX'/")'..." 
	fi

	echo "[$(date)] [$(basename "$0")] Executing command '$(echo $CMD | sed "s/-storepass .*'/-storepass XXX'/")'..." >&8
	eval "$CMD"

	# Do Kafka stuff!!
	CMD="$OC_CMD exec -n $AIMGR_NAMESPACE $KAFKA_POD -- bash -c '/opt/kafka/bin/kafka-consumer-groups.sh --bootstrap-server $KAFKA_BROKER --command-config ${KEYSTORE_CONSUMER_CFGFILE} --list'"
	echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..."
	echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..." >&8
	eval "$CMD" > $CMD_EXEC_OUTPUT_DIR/consumer_groups.lst

	IFS=$'\n'
	for CONSUMER_GROUP in $(grep 'cp4waiops-cartridge\.aiops-ir-lifecycle\.' $CMD_EXEC_OUTPUT_DIR/consumer_groups.lst | sed 's/^/--group /')
	do
		# Delete consumer group
		CMD="$OC_CMD exec -n $AIMGR_NAMESPACE $KAFKA_POD -- bash -c '/opt/kafka/bin/kafka-consumer-groups.sh --bootstrap-server $KAFKA_BROKER --command-config ${KEYSTORE_CONSUMER_CFGFILE} -delete ${CONSUMER_GROUP}'"
		echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..."
		echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..." >&8
		eval "$CMD"
	done

	# Clean up 
	echo "[$(date)] [$(basename "$0")] Deleting certificate from keystore..."
	echo "[$(date)] [$(basename "$0")] Deleting certificate from keystore..." >&8
	CMD="$OC_CMD exec -n $AIMGR_NAMESPACE $KAFKA_POD -- bash -c 'keytool -delete -keystore ${KEYSTORE_NAME} -storetype PKCS12 -alias CARoot -noprompt -storepass $KEYSTORE_PASSWORD'"
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..."
	else
		echo "[$(date)] [$(basename "$0")] Executing command '$(echo $CMD | sed "s/-storepass .*'/-storepass XXX'/")'..." 
	fi

	echo "[$(date)] [$(basename "$0")] Executing command '$(echo $CMD | sed "s/-storepass .*'/-storepass XXX'/")'..." >&8
	eval "$CMD"

	echo "[$(date)] [$(basename "$0")] Deleting certificate [$KEYSTORE_CERT]..."
	echo "[$(date)] [$(basename "$0")] Deleting certificate [$KEYSTORE_CERT]..." >&8
	CMD="$OC_CMD exec -n $AIMGR_NAMESPACE $KAFKA_POD -- bash -c 'rm -f $KEYSTORE_CERT'"
	echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..."
	echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..." >&8
	eval "$CMD"

	echo "[$(date)] [$(basename "$0")] Deleting consumer configuration file [$KEYSTORE_CONSUMER_CFGFILE]..."
	echo "[$(date)] [$(basename "$0")] Deleting consumer configuration file [$KEYSTORE_CONSUMER_CFGFILE]..." >&8
	CMD="$OC_CMD exec -n $AIMGR_NAMESPACE $KAFKA_POD -- bash -c 'rm -f $KEYSTORE_CONSUMER_CFGFILE'"
	echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..."
	echo "[$(date)] [$(basename "$0")] Executing command '$CMD'..." >&8
	eval "$CMD"
	
	rm -f $KAFKA_CA_CERT
else
	echo "[$(date)] [${FUNCNAME[0]}] Unable to create Kafka connection..."
	echo "[$(date)] [${FUNCNAME[0]}] Unable to create Kafka connection..." >&8
fi

# Clear zookeeper
ZK_POD=$(getResourceInstances pod '^iaf-system-zookeeper-' $AIMGR_NAMESPACE Running | head -1)
echo "[$(date)] [$(basename "$0")] Clearing ir-lifecycle from Zookeeper [$ZK_POD]..."
echo "[$(date)] [$(basename "$0")] Clearing ir-lifecycle from Zookeeper [$ZK_POD]..." >&8
CMD="$OC_CMD exec -n $AIMGR_NAMESPACE $ZK_POD -- /opt/kafka/bin/zookeeper-shell.sh 127.0.0.1:12181 deleteall /flink/aiops/ir-lifecycle"
eval "$CMD"

# Restart lifecycle
# echo "[$(date)] [$(basename "$0")] Restarting lifecycle pod [aiops-ir-lifecycle-eventprocessor-ep-taskmanager-0]..."
# $OC_CMD delete po -n $AIMGR_NAMESPACE aiops-ir-lifecycle-eventprocessor-ep-taskmanager-0
# echo "[$(date)] [$(basename "$0")] Restarting lifecycle pod [aiops-ir-lifecycle-eventprocessor-ep-jobmanager-0]..."
# $OC_CMD delete po -n $AIMGR_NAMESPACE aiops-ir-lifecycle-eventprocessor-ep-jobmanager-0

# Scale lifecycle back up
echo "[$(date)] [$(basename "$0")] Scaling lifecycle deployment [ir-lifecycle-operator-controller-manager] back to 1..."
echo "[$(date)] [$(basename "$0")] Scaling lifecycle deployment [ir-lifecycle-operator-controller-manager] back to 1..." >&8
$OC_CMD scale -n $AIMGR_NAMESPACE deployment/ir-lifecycle-operator-controller-manager --replicas=1
