JOBNAME_REGEX=$1
NS=$2

EXIT_STATUS=1
WORKFILE_ARR=()

JOB_LISTING_FILE=$MISSINGOBJ_OUTDIR/isJobComplete.$NS.list

if [ ! -f $JOB_LISTING_FILE ] || [ ! -s $JOB_LISTING_FILE ]
then
	$OC_CMD get -n $NS --ignore-not-found job --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}' > $JOB_LISTING_FILE
fi

JOB_TMPFILE=$MISSINGOBJ_OUTDIR/isJobComplete.$NS.$JOBNAME_REGEX.$$.tmp
grep -E "$JOBNAME_REGEX" $JOB_LISTING_FILE > $JOB_TMPFILE

if [ -s $JOB_TMPFILE ]
then
	JOB_COUNT=$(wc -l < $JOB_TMPFILE)
	rm $JOB_TMPFILE
else
	rm $JOB_TMPFILE

	echo $EXIT_STATUS
	exit 
fi

if [ ${#JOB_COUNT} -gt 0 ] 
then
	if [ $JOB_COUNT -gt 1 ]
	then
		for JOB in $($OC_CMD get -n $NS --ignore-not-found job --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}' | grep -E "$JOBNAME_REGEX")	
		do
			WORKFILE=$MISSINGOBJ_OUTDIR/isJobComplete.$NS.$JOB.$$
			$OC_CMD describe job -n $NS $JOB > $WORKFILE 2> /dev/null
			WORKFILE_ARR[${#WORKFILE_ARR[@]}]=$WORKFILE
		done
	else
		WORKFILE=$MISSINGOBJ_OUTDIR/isJobComplete.$NS.$JOBNAME_REGEX.$$
		$OC_CMD describe job -n $NS $JOBNAME_REGEX > $WORKFILE 2> /dev/null
		WORKFILE_ARR[${#WORKFILE_ARR}]=$WORKFILE
	fi
else
	# If the job is not found, remove the config line
	echo $EXIT_STATUS
	exit 
fi

if [ $MG_DEBUG == "true" ]
then
	echo "[$(date)] [$(basename "$0")] Length WORKFILE_ARR = [${#WORKFILE_ARR[@]}]" >&2
	echo "[$(date)] [$(basename "$0")] WORKFILE_ARR = [${WORKFILE_ARR[@]}]" >&2
fi

for TMPFILE in ${WORKFILE_ARR[@]}
do
	if [ -s $TMPFILE ]
	then
		JOBNAME=$(grep -E '^Name:' $TMPFILE | $AWK '{ print $2 }')	
		JOB_COMPLETIONS=$(grep -E '^Completions:' $TMPFILE | $AWK '{ print $2 }')
		JOB_PODSTATUS=$(grep -E '^Pods Statuses:' $TMPFILE | $AWK -F: '{ print $2 }' | sed 's/^[ ]*//')

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] JOB = $JOBNAME" >&2
			echo "[$(date)] [$(basename "$0")] JOB_COMPLETIONS = $JOB_COMPLETIONS" >&2
			echo "[$(date)] [$(basename "$0")] JOB_PODSTATUS = [$JOB_PODSTATUS]" >&2
		fi
		
		if [ ${#JOB_COMPLETIONS} -gt 0 ] && [ ${#JOB_PODSTATUS} -gt 0 ]
		then
			if [ $JOB_COMPLETIONS -eq 1 ]
			then
				JOB_RUN=$(echo $JOB_PODSTATUS | $AWK -F/ '{ print $1 }' | $AWK '{ print $1 }')
				JOB_SUCC=$(echo $JOB_PODSTATUS | $AWK -F/ '{ print $2 }' | $AWK '{ print $1 }')
				JOB_FAIL=$(echo $JOB_PODSTATUS | $AWK -F/ '{ print $3 }' | $AWK '{ print $1 }')

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] JOB_RUN = [$JOB_RUN] / JOB_SUCC = [$JOB_SUCC] / JOB_FAIL = [$JOB_FAIL]" >&2
				fi

				if [ $JOB_RUN -gt 0 ] || [ $JOB_FAIL -gt 0 ]
				then
					EXIT_STATUS=0
					break
				else
					if [ $JOB_SUCC -gt 0 ]
					then
						# Job is successful - remove the config line
						EXIT_STATUS=1
					else
						EXIT_STATUS=0
						break
					fi
				fi
			else
				EXIT_STATUS=0
				break
			fi
		else
			# Unable to find the job/extract job info - remove the config line
			EXIT_STATUS=1
			break
		fi
	
		rm $TMPFILE
	else
		rm $TMPFILE
	
		# Unable to find the job - remove the config line
		EXIT_STATUS=1
		break
	fi
done

if [ $MG_DEBUG == "true" ]
then
	echo "[$(date)] [$(basename "$0")] EXIT_STATUS = [$EXIT_STATUS]" >&2
fi

if [ $EXIT_STATUS -eq 0 ]
then
	for TMPFILE in ${WORKFILE_ARR[@]}
	do
		if [ -f $TMPFILE ]
		then
			echo "[$(date)] [$(basename "$0")] Removing file [$TMPFILE]..." >&2
			rm $TMPFILE
		fi
	done
fi

echo $EXIT_STATUS
