#!/bin/bash

# Generic MustGather Framework - Version
GMGF_VERSION=0.37.5

# bash variable to count script execution duration
START_TIME=$(date +%s)

# To save default IFS
OLDIFS=$IFS
GMGF_PID=$$

# To determine the root GMGF directory
MUSTGATHER_LINK=$(readlink -f "${BASH_SOURCE[0]}")
MUSTGATHER_DIRNAME=$( dirname "$MUSTGATHER_LINK" )
MUSTGATHER_SCRIPTNAME=$( basename "$MUSTGATHER_LINK" )

NEWLINE='\n'
NEWLINE2='\n\n'
RED=$(tput setaf 1 2> /dev/null)
GREEN=$(tput setaf 2 2> /dev/null)
BLUE=$(tput setaf 4 2> /dev/null)
WHITE=$(tput setaf 7 2> /dev/null)
BOLD=$(tput bold 2> /dev/null)
NORMAL=$(tput sgr0 2> /dev/null) #reset color/bolding

if [ ${#MUSTGATHER_DIRNAME} -eq 0 ]
then
	if [ -L "${BASH_SOURCE[0]}" ]
	then
		echo "[$(date)] [$(basename "$0")] The execution [${BASH_SOURCE[0]}] is a symbolic link, but command 'readlink' was unable to determine MUSTGATHER_DIRNAME! Exiting..."
		exit 1
	else
		MUSTGATHER_DIRNAME=$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )
		MUSTGATHER_SCRIPTNAME=$( basename ${BASH_SOURCE[0]} )
	fi
fi

# Exit if MUSTGATHER_DIRNAME contains spaces
if [[ ${MUSTGATHER_DIRNAME} =~ [[:space:]] ]]
then
	echo "[$(date)] [$(basename "$0")] MUSTGATHER_DIRNAME [$MUSTGATHER_DIRNAME] cannot contain spaces! Exiting..."
	exit 1
fi

# echo "[$(date)] [$(basename "$0")] MUSTGATHER_DIRNAME = [$MUSTGATHER_DIRNAME]"
# echo "[$(date)] [$(basename "$0")] MUSTGATHER_SCRIPTNAME = [$MUSTGATHER_SCRIPTNAME]"

if [ -L "${BASH_SOURCE[0]}" ]
then
	MUSTGATHER_SYMLINK=$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )/$( basename ${BASH_SOURCE[0]})
	# echo "[$(date)] [$(basename "$0")] MUSTGATHER_SYMLINK = [$MUSTGATHER_SYMLINK]"
fi

GMGF_ENV_ARR=("GMGF_PID" "NON_CLOUD" "CLOUD_PLATFORM" "CLOUD_PLATFORM_VERSION" "OS_TYPE" "OS_ARCH" "OC_CMD" "OC_WHOAMI" "AWK" "JQ" "YQ" "OPENSSL" "OLDIFS" "MG_DEBUG" "MG_TTY" "BASH_V4" "IS_MACOS" "DETECTED_PRODVER" "PRODUCT_VERSION" "MUSTGATHER_OPT" "MUSTGATHER_DIRNAME" "MUSTGATHER_SCRIPTNAME" "OUTDIR" "GZIP_OUTFILE" "ANALYZE_OUTDIR" "ANALYZE_OUTFILE" "RUNTIME_OUTDIR" "RUNTIME_LOGFILE" "REFFILE_OUTDIR" "RES_LIST_PROCFILE" "CMD_EXEC_OUTDIR" "MANUAL_COLL_OUTDIR" "EXTRA_NAMESPACES_OUTDIR" "MISSINGOBJ_OUTDIR" "COMPLIANCE_OUTDIR" "PLUGINS_ROOT_OUTDIR" "CPFILES_ROOT_OUTDIR" "PRODUCT_DATA_OUTDIR" "PROD_NAMESPACES_REFFILE_FINAL" "PROD_VERSIONS_REFFILE_FINAL" "PROD_NAMESPACES_UNIQUE_REFFILE" "PROD_NAMESPACES_UNIQUE_STR" "PROD_VERSIONS_UNIQUE_REFFILE" "PROD_VERSIONS_UNIQUE_STR" "PROD_NAMESPACES_KEYVAL_ARR_FINALIZED" "PROD_NAMESPACES_INVALID_STR" "CLUSTER_DATA_OUTDIR" "CUSTOM_DATA_OUTDIR" "CONTEXT_SWITCH_CHECK_PERIOD" "CHECK_USER_PRIV_CTR" "CHECK_USER_PRIV_SYSGLITCH_CTR" "CHECK_USER_PRIV_SYSGLITCH_MAX" "CHECK_USER_PRIV_OLD_CONTEXT" "CHECK_USER_PRIV_CLUSTER_INFO" "IS_SENSITIVE_DATA_ALLOWED" "SENSITIVE_DATA_REFFILE" "RESTRICTED_DATA_REFFILE" "PROD_REFFILE_DELIMITER" "PROD_REFFILE_NS_DELIMITER" "-f getProdToNamespacesMapping" "-f getNamespaceToProdMapping" "-f getResourceInstances" "-f getUniqueProdNamespaces" "-f getUniqueProdVersions" "-f checkUserPriv" "-f isPodOk" "-f isPodLineOk" "-f getGenericPodName" "-f getAllProdGroups" "-f getProdGroupRefFile" "-f getProdGroupThruNamespace" "-f getProdVersionThruProdGroup" "-f isSensitiveData" "-f isRestrictedData" "-f getAllValidApiNames" "-f getPodResourceInfo")

# To source system configuration
. $MUSTGATHER_DIRNAME/system.cfg

# Product mustgather implementation
PROD_CFG="$MUSTGATHER_DIRNAME/config/product.cfg"
PROD_SH="$MUSTGATHER_DIRNAME/config/product.sh"
DEFAULT_PROD_SH="$MUSTGATHER_DIRNAME/product.sh.def"

if [ -s $PROD_CFG ]
then
	# echo "[$(date)] Loading product-implemented configuration [$PROD_CFG]..."
	. $PROD_CFG

	# Checking for mandatory variables
	if [ ${MG_VERSION}x == "x" ] 
	then
		echo "[$(date)] [$(basename "$0")] Mandatory variable MG_VERSION is not set! Exiting..."
		exit 1
	fi

	if [ ${PRODUCT_NAME}x == "x" ]
	then
		echo "[$(date)] [$(basename "$0")] Mandatory variable PRODUCT_NAME is not set! Exiting..."
		exit 1
	fi

	if [[ -z ${PRODUCT_SUPPORTED_VERSION+x} ]] || [ ${#PRODUCT_SUPPORTED_VERSION[@]} -eq 0 ]
	then
		echo "[$(date)] [$(basename "$0")] Mandatory variable PRODUCT_SUPPORTED_VERSION is not set! Exiting..."
		exit 1
	else
		# To check whether PRODUCT_SUPPORTED_VERSION is declared as a normal variable (not array)
		if [ ${#PRODUCT_SUPPORTED_VERSION[@]} -eq 1 ]
		then
			if [ ${#PRODUCT_SUPPORTED_VERSION[0]} -eq 0 ]
			then
				echo "[$(date)] [$(basename "$0")] Mandatory variable PRODUCT_SUPPORTED_VERSION is not set! Exiting..."
				exit 1
			fi
		fi
	fi

	# Checking for optional but important variable
	if [[ -z ${VALID_MODULES+x} ]] || [ ${#VALID_MODULES[@]} -eq 0 ]
	then
		VALID_MODULES=(clusterinfo productinfo storage networking)
	else
		# To check whether VALID_MODULES is declared as a normal variable (not array)
		if [ ${#VALID_MODULES[@]} -eq 1 ]
		then
			if [ ${#VALID_MODULES[0]} -eq 0 ]
			then
				VALID_MODULES=(clusterinfo productinfo storage networking)
			fi
		fi
	fi
else
	echo "[$(date)] [$(basename "$0")] Product configuration file [$PROD_CFG] is unavailable! Exiting.."	
	exit 1
fi

# To set OC_CMD (oc or kubectl)
if [ ${#OC_CMD} -eq 0 ]
then
	if command -v oc > /dev/null 2>&1 
	then
		OC_CMD="oc"
	else
		if command -v kubectl > /dev/null 2>&1
		then
			OC_CMD="kubectl"
		else
			if [ ${#NON_CLOUD} -gt 0 ] && [ $NON_CLOUD == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] Executing in 'non-cloud' mode - will not set OC_CMD!"
			else
				echo "[$(date)] [$(basename "$0")] Unable to set OC_CMD! Command 'oc' and 'kubectl' are not found! Exiting..."
				exit 1
			fi
		fi
	fi
else
	# User-defined OC_CMD
	if [ ${OC_CMD} == "oc" ] || [ ${OC_CMD} == "kubectl" ]
	then
		echo "[$(date)] [$(basename "$0")] Setting OC_CMD to user-defined [$OC_CMD]..." > /dev/null
	else
		if [ ${#NON_CLOUD} -gt 0 ] && [ $NON_CLOUD == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] Executing in 'non-cloud' mode - will not set OC_CMD!"
		else
			if [ ${#ALLOW_CUSTOM_CLIENT} -gt 0 ] && [ ${ALLOW_CUSTOM_CLIENT} == "true" ]
			then
				if which $OC_CMD > /dev/null 2>&1
				then
					printf "${BOLD}${RED}[$(date)] [$(basename "$0")] WARNING: Variable OC_CMD is set to user-defined [$OC_CMD]!${NEWLINE}${NORMAL}" 
				else
					echo "[$(date)] [$(basename "$0")] User-defined OC_CMD [$OC_CMD] is not found! Exiting..."
					exit 1
				fi
			else
				echo "[$(date)] [$(basename "$0")] User-defined OC_CMD [$OC_CMD] is not supported! Exiting..."
				exit 1
			fi
		fi
	fi
fi

if [ -s $PROD_SH ]
then
	# echo "[$(date)] Loading product-implemented functions [$PROD_SH]..."
	. $PROD_SH
else
	echo "[$(date)] [$(basename "$0")] Product script file [$PROD_SH] is unavailable! Exiting.."	
	exit 1
fi

# To check whether any user-defined function has the same name as GMGF function
if [ ${#CHECK_USER_FUNC} -gt 0 ] && [ ${CHECK_USER_FUNC} == "true" ]
then
	GMGF_SYSTEM_FUNC=$(grep -E '^[[:space:]]*[a-zA-Z0-9]+\()|^[[:space:]]*function' $MUSTGATHER_DIRNAME/$MUSTGATHER_SCRIPTNAME | sed -E 's/[[:space:]]+\{.*$//' | sed -E 's/^[[:space:]]*function[[:space:]]+//' | sed -E 's/[(|)]//g' | sed -E 's/^[[:space:]]*//' | sort | uniq)
	GMGF_RESERVED_FUNC=$(echo "$RESERVED_FUNC_NAME" | tr ' ' '\n')
	GMGF_SYSTEM_FUNC=$(echo -e "${GMGF_SYSTEM_FUNC}\n${GMGF_RESERVED_FUNC}")

	GMGF_USER_FUNC=$(declare -F | sed 's/^declare -f[a-z]*[ ]*//')

	if [ ${#GMGF_USER_FUNC} -eq 0 ]
	then
		GMGF_USER_FUNC=$(declare -f | grep -E '^[a-zA-Z0-9_+%:@!]+' | grep -E -v '^declare[ ]+' | sed 's/[ |(|)|{]//g')
	fi

	# echo "[$(date)] [$(basename "$0")] GMGF_SYSTEM_FUNC = [$GMGF_SYSTEM_FUNC]"	
	# echo "[$(date)] [$(basename "$0")] GMGF_USER_FUNC = [$GMGF_USER_FUNC]"

	if [ ${#GMGF_USER_FUNC} -gt 0 ]
	then
		for USER_FUNC in ${GMGF_USER_FUNC}
		do
			for SYSTEM_FUNC in ${GMGF_SYSTEM_FUNC}
			do
				if [ "${USER_FUNC}" == "$SYSTEM_FUNC" ]
				then
					echo "[$(date)] [$(basename "$0")] User-defined function [$USER_FUNC] in [$PROD_SH] is a reserved system function and is not allowed! Exiting.."
					exit 1
				fi
			done
		done
	fi
fi

# Load default getAll, getComprehensive, getBasic, getLimited, getSelective and getModules functions (just in case those functions are not implemented by product team)
if [ -s $DEFAULT_PROD_SH ]
then
	# echo "[$(date)] Loading default data collection functions [$DEFAULT_PROD_SH]..."
	. $DEFAULT_PROD_SH
else
	if [ ! -f $PROD_SH ]
	then
		# Impossible to reach this condition due to the IF statement above (for precaution only)
		echo "[$(date)] FATAL: Both product script files [$PROD_SH] and [$DEFAULT_PROD_SH] do not exist or are zero-sized! Exiting..."
		exit 1
	else
		if [[ $(type -t getAll) != function ]] || [[ $(type -t getComprehensive) != function ]] || [[ $(type -t getBasic) != function ]] || [[ $(type -t getLimited) != function ]] || [[ $(type -t getSelective) != function ]] || [[ $(type -t getModules) != function ]] 
		then
			echo "[$(date)] FATAL: Primary data collection functions (getAll, getComprehensive, getBasic, getLimited, getSelective and getModules) are not defined or not defined completely! Exiting..."
			exit 1
		fi
	fi
fi

# Check for existence of temporary working directory
if [ ! -d $DEFAULT_TMPDIR ]
then
	mkdir -p $DEFAULT_TMPDIR

	if [ ! -d $DEFAULT_TMPDIR ]
	then
		echo "[$(date)] [$(basename "$0")] Unable to create temporary working directory [$DEFAULT_TMPDIR]! Exiting..."
		exit 1
	fi
fi


OS_TYPE=
OS_TYPE_DEFAULT="<undetermined>"
OS_TYPE_NULL="false"
OS_ARCH=
OS_ARCH_DEFAULT="<undetermined>"
OS_ARCH_NULL="false"
IS_MACOS="false"
GDATE=
BASH_VER=
BASH_V4=
MG_TTY=
USER_TTY=
AWK=$(which gawk 2> /dev/null)
TIMEOUT=$(which timeout 2> /dev/null)
CURL=$(which curl 2> /dev/null)
JQ=$(which jq 2> /dev/null)
YQ=$(which yq 2> /dev/null)
OPENSSL=$(which openssl 2> /dev/null)
PYTHON=$(which python3 2>/dev/null || which python2 2>/dev/null || which python 2>/dev/null)
IFS=$'\n'
MUSTGATHER_ALL_OPT_ORI=$@
MUSTGATHER_ALL_OPT_ORI_POS_PARAM=
MUSTGATHER_ALL_OPT_MOD=
MUSTGATHER_ALL_OPT_MOD_POS_PARAM=
OPT_WARN="false"
AUTO_YES="false"
# MAX_OC_CALL_TIMELIMIT_MILLISECOND=1200
# MAX_OC_CALL_TIMELIMIT_SECOND=2
NON_PROD_COLLECT_AGREEMENT=
ALLNS_DATA="false"
GET_DEPENDENCY_DATA="false"

DETECTED_PRODVER=
PRODUCT_VERSION=
USERSET_MISSINGOBJ_VERSION=0
USERSET_MISSINGOBJ_CFGFILE=
USERSET_MISSINGOBJ_SCRIPTDIR=
PRODUCT_VERSION_DEFAULT="false"
MUSTGATHER_OPT=
OPTSET=0
ROOT_OUTDIR=/tmp/mg
OUTDIR=
ANALYZE_OUTDIR=
ANALYZE_OUTFILE=
GZIP_OUTFILE=
RUNTIME_OUTDIR=
RUNTIME_LOGFILE=
REFFILE_OUTDIR=
OC_DESC_ON="true"
COLLECT_YAML="false"
COLLECT_JSON="false"
GET_POD_LOGS="true"
COLL_PREV_LOGS="false"
GET_PVC_USAGE="false"
IS_SENSITIVE_DATA_ALLOWED="false"
PRIMARY_MODE_ARRAY=()
SECONDARY_MODE_ARRAY=()
PRODUCT_DATA_OUTDIR=
OTHER_NS_DATA_OUTDIR=
CLUSTER_DATA_OUTDIR=
ALL_NS_PROB_OUTDIR=
CUSTOM_DATA_OUTDIR=
CUSTOM_DATA_ENABLED="true"
SELECTIVE_RESOURCES=
MODULES=
MODULES_LISTING="false"
MODULES_CUSTOM="false"
MODULES_CUSTOM_VERIFIED="false"
MODULES_CUSTOM_DEFERRED="false"
MODULES_CUSTOM_AGREEMENT="false"
CLEAN_MODULES=()
RUNTIME_VAR=
CHECK_USER_PRIV_CACHEFILE=
CHECK_USER_PRIV_CTR=0
CHECK_USER_PRIV_SYSGLITCH_CTR=0
CHECK_USER_PRIV_OLD_CONTEXT=
CHECK_USER_PRIV_CUR_CONTEXT=
OC_WHOAMI=
OC_TOKEN=
OC_APISVR=
OC_PROXY_SUCC="false"
OC_PROXY_PID=
OC_HEADER=
OC_HEADER_FOR_ECHO=
OC_YAML_HEADER="-H 'Accept: application/yaml'"
OC_JSON_HEADER="-H 'Accept: application/json'"
OC_POSSIBLE_FIREWALL="false"
FAST_OC="false"
# FAST_OC_DESC_BIN=
RES_LIST_OUTDIR=
RES_LIST_OUTFILE=
RES_GROUP_LIST_OUTFILE=
RES_LIST_PROCFILE=
SENSITIVE_DATA_ARR=
SENSITIVE_DATA_REFFILE=
RESTRICTED_DATA_ARR=
RESTRICTED_DATA_REFFILE=
INCIDENT_REPORT_ENABLED="false"
# INCIDENT_REPORT_CTR=0
INCIDENT_REPORT_TMPFILE=
INCIDENT_REPORT_OUTFILE=
INCIDENT_REPORT_ERRFILE=
INCIDENT_REPORT_CTRFILE=
ENGINE_ANALYZE_SCRIPT_DIR=
ENGINE_FIX_SCRIPT_DIR=
ENGINE_DATA_OUTDIR=
ENGINE_TVALUE=20m
PRE_DATA_COLLECT_OUTDIR=
POST_DATA_COLLECT_OUTDIR=

# SECONDARY data collection mode - Parameters
# [clusternodes]
GET_NODES_DATA="false"
USE_OC_DEBUG=1
NODE_ADMIN_USER=
ADMUSERSET=0
JOURNAL_SIZE_DEFAULT=2000
JOURNAL_SIZE=$JOURNAL_SIZE_DEFAULT
JOURNAL_SIZE_WARN_LIMIT=100000
JOURNAL_SIZE_CUSTOM="false"
CLUSTERNODES_OUTDIR=
CLUSTERNODES_ROOT_DEBUG_OUTDIR=
ALL_NODES_ONLINE="true"
# [cmdexec]
CMD_EXEC_INPUT=
CMD_EXEC_CMD=
CMD_EXEC_FILE=
CMD_EXEC_PARAM=
CMD_EXEC_OUTDIR=
CMD_EXEC="false"
CMD_EXEC_AGREEMENT=
CMD_EXEC_TVALUE="15m"
CMD_EXEC_ENV=
CMD_EXEC_ENVFILE=
CMD_EXEC_RESULT_MCCFG_FILE=
CMD_EXEC_MC_MANUAL="false"
CMD_EXEC_RESULT_EXTRANS_FILE=
CMD_EXEC_RESULT_CPFILES_FILE=
CMD_EXEC_RESULT_MISSINGOBJ_FILE=
CMD_EXEC_MISSINGOBJ_ONLY="false"
CMD_EXEC_RESULT_PLUGINS_FILE=
CMD_EXEC_RESULT_PLUGINS_PARAM_FILE=
CMD_EXEC_RESULT_COMPLIANCE_FILE=
CMD_EXEC_COMPLIANCE_ONLY="false"
CMD_EXEC_RESULT_SNAPSHOTS_FILE=
CMD_EXEC_ROOT_DEBUG_OUTDIR=
# [manualcollect]
MANUAL_COLL=0
MANUAL_COLL_INPUTTAG=
MANUAL_COLL_INPUTFILE=
MANUAL_COLL_INPUTFILE_ARR=()
MANUAL_COLL_OUTDIR=
MANUAL_COLL_CUSTOM_DATA="false"
MANUAL_COLL_DATADIR=
MANUAL_COLL_SECRET="false"
MANUAL_COLL_ROOT_DEBUG_OUTDIR=
MANUAL_COLL_EXEC_TIMEOUT=$MANUAL_COLL_DEFAULT_EXEC_TIMEOUT
MANUAL_COLL_ENV=
MANUAL_COLL_OBJNAME=
MANUAL_COLL_OBJNAME_REFFILE=
MANUAL_COLL_EXECPREP=
MANUAL_COLL_EXECPREP_REFFILE=
MANUAL_COLL_SENSITIVE_DATA_OVERRIDE="false"
# [extra]
EXTRA_NAMESPACES=
EXTRA_NAMESPACES_OUTDIR=
EXTRA_NAMESPACES_COLL_SECRET="false"
EXTRA_NAMESPACES_ROOT_DEBUG_OUTDIR=
# [missingobj]
GET_MISS_OBJ="false"
MISSINGOBJ_OUTDIR=
MISSINGOBJ_ROOT_DEBUG_OUTDIR=
MISSINGOBJ_VERSION=
MISSINGOBJ_INPUTFILE=
# MISSINGOBJ_DIFF_MAX=30
# [compliance]
GET_COMPLIANCE="false"
# COMPLIANCE_ROOTDIR=
COMPLIANCE_USERINPUT=
COMPLIANCE_CUSTOM_INPUTFILE="false"
COMPLIANCE_INPUTTAG=
COMPLIANCE_INPUTFILE=
COMPLIANCE_INPUTFILE_ARR=()
COMPLIANCE_PROCFILE=
COMPLIANCE_REPORT=
COMPLIANCE_ROOT_DEBUG_OUTDIR=
# [plugins]
PLUGINS_USERINPUT=
PLUGINS=
PLUGINS_ROOT_OUTDIR=
PLUGINS_ROOT_DEBUG_OUTDIR=
PLUGINS_TIMEOUT=$PLUGINS_DEFAULT_TIMEOUT
PLUGINS_VALID_ACTION=(data fix)
PLUGINS_DEFAULT_ACTION="data"
PLUGINS_ENV=
# [cpfiles]
CPFILES_ENABLED="false"
CPFILES_FILES=
CPFILES_FILES_PROC=
CPFILES_FILES_FINAL=
CPFILES_ROOT_OUTDIR=
CPFILES_DATA_SCRIPTDIR=
CPFILES_PROCESSED_TAGS=()

# VIEW-ONLY mode
VIEW_ONLY="false"
VIEW_MODULE=

# ALIAS mode
ALIAS_MODE="false"
ALIAS_CFGFILE=
ALIAS_NAME=
ALIAS_EXPANDED="false"
ALIAS_MODE_TMP_OUTDIR=
ALIAS_MODE_ROOT_OUTDIR=

# DEBUG related parameters
MG_DEBUG="false"
DEBUG_OUTDIR=

# Check for update
CHECK_FOR_UPDATE="false"

# Display SUMMARY.log on screen
REPORT_ON_SCREEN="false"
REPORT_ON_SCREEN_SUMMARY_FILE=
REPORT_ON_SCREEN_COMPLIANCE_FILE=
REPORT_ON_SCREEN_SNAPSHOTS_FILE=

# GREP pattern
GREP_PATTERN=
GREP_POD_LOGS_OUTFILE=
GREP_EVENTS_OUTFILE=
GREP_NODEFILE_OUTFILE=
GREP_CPFILES_OUTFILE=
GREP_POD_LOGS_HIT=0
GREP_POD_LOGS_MISS=0
GREP_POD_LOGS_TYPE="podlog"
GREP_EVENTS_HIT=0
GREP_EVENTS_MISS=0
GREP_EVENTS_TYPE="event"
GREP_NODEFILE_HIT=0
GREP_NODEFILE_MISS=0
GREP_NODEFILE_TYPE="nodefile"
GREP_CPFILES_HIT=0
GREP_CPFILES_MISS=0
GREP_CPFILES_TYPE="cpfile"

PROD_NAMESPACES_REFFILE=
PROD_NAMESPACES_REFFILE_FINAL=
PROD_NAMESPACES_UNIQUE=()
PROD_NAMESPACES_UNIQUE_STR=
PROD_NAMESPACES_UNIQUE_REFFILE=
PROD_VERSIONS_UNIQUE=()
PROD_VERSIONS_UNIQUE_STR=
PROD_VERSIONS_UNIQUE_REFFILE=
PROD_NAMESPACES_INVALID_STR="NULL"
# PROD_NAMESPACES_LIST_ARR=
PROD_NAMESPACES_LIST_FILE=
PROD_NAMESPACES_MAP_FILE=

PROD_VERSIONS_REFFILE=
PROD_VERSIONS_REFFILE_FINAL=
PROD_VERSIONS_INVALID_STR="NULL"
PROD_VERSIONS_ARR=()
PROD_VERSIONS_SINGLE_PRODGROUP="true"

PROD_GROUPS_ARR=
PROD_GROUPS_INVALID_STR="NULL"

SNAPSHOTS_OUTDIR=
# SNAPSHOTS_CURDIR=
SNAPSHOTS_DEBUG_OUTDIR=
SNAPSHOTS_CFGFILE=
# SNAPSHOTS_CFGFILE_PROD=
SNAPSHOTS_REPORT=
DIFF_SNAPSHOTS="false"
SNAPSHOTS_ONLY="false"



if [ ${#AWK} -eq 0 ]
then
	AWK=$(which awk)
fi

# Build system.cfg variables list
SYSTEM_CFG_ARR=($(grep -E -v ^$ $MUSTGATHER_DIRNAME/system.cfg | sort | $AWK -F= '{ print $1 }' | uniq))

echoUsage()
{
	printf "${BOLD}${RED}[ MustGather Version = $MG_VERSION / GMGF Version = $GMGF_VERSION ]${NEWLINE}${NORMAL}"
	echo
	printf "${BOLD}USAGE: $(basename $0) -[a|b|c|l] [-k resourcename/resourcefile] [-z module] [-d] [-L numlines] [-C cmdexec-file:cmdexec-env] [-E cmdexec-envvar] [-T timeout-value] [-m manual-collection-param] [-n manual-collection-envvar] [-j objname] [-B execprep] [-w manual-collection-exec-timeout] [-e extra-namespaces:extra-resources] [-x product-version/path-to-config-file] [-A compliance-param] [-P plugins] [-Z plugins-envvar] [-Q plugins-timeout] [-F cpfiles-param] [-K] [-V view-only-module] [-O alias-module] [-y] [-J] [-p] [-t] [-g] [-f] [-R] [-S] [-s] [-u node-admin-username] [-i path-to-sshkey] [-o output-directory] [-G filename-regex:pattern] [-W primary-mode-var] [-N] [-I] [-X] [-Y] [-H] [-U] [-M] [-D] [-v] [-h]${NEWLINE}${NORMAL}"
	echo
	echo "WHERE"
	printf "${BOLD}${RED}[PRIMARY modes]${NEWLINE}${NORMAL}"
	printf "${BOLD}${GREEN}<ALL mode>${NEWLINE}${NORMAL}"
	echo "-a = get all data (data volume = high)"
	printf "${BOLD}${GREEN}<COMPREHENSIVE mode>${NEWLINE}${NORMAL}"
	echo "-c = get comprehensive data (data volume = slightly high)" 
	printf "${BOLD}${GREEN}<BASIC mode>${NEWLINE}${NORMAL}"
	echo "-b = get basic data (data volume = moderate)"
	printf "${BOLD}${GREEN}<LIMITED mode>${NEWLINE}${NORMAL}"
	echo "-l = get limited data (data volume = low)"
	printf "${BOLD}${GREEN}<SELECTIVE mode>${NEWLINE}${NORMAL}"
	echo "-k = get data for selective resources (data volume = vary)"
	echo "     WHERE"
	echo "     <resourcename> = resource names separated by commas - Eg. pod,deployment,secrets" 
	echo "     <resourcefile> = absolute/full path to file containing resource names (one resource per line) - Eg. /tmp/selective.cfg"
	echo "     NOTE: To get cluster-wide (all-namespaces) data for namespace-scoped resource (Eg. pod), you can use special keyword 'allns' (Eg. pod/allns,ingress,cm/allns)"
	echo "     NOTE: To get resource data for specific namespace(s) (keyword NS4PROD=<prodname> is allowed), specify the namespace(s) (delimit multiple namespaces with @@) like this - 'pod/openshift-etcd@@openshift-dns'"
	echo "     NOTE: 'allns' data is available in the CLUSTER_DATA directory / namespaced data is available in the PROD_NAMESPACES or OTHER_NAMESPACES directory"
	printf "${BOLD}${GREEN}<MODULE mode>${NEWLINE}${NORMAL}"
	echo "-z = get data based on predefined modules (${VALID_MODULES[@]}) (data volume = vary)"
	echo "     WHERE"
	echo "     <module> = One of the predefined modules OR absolute/full path to the custom module script (for custom module implemented by end user) OR CUSTOM:<module> (where <module> is the custom module shipped under config/modules directory). Custom module script must implement the getCustomModule() function"
	echo "     NOTE: To list all available modules, use '-z .listmodules'"
	echo
	printf "${BOLD}${RED}[SECONDARY modes]${NEWLINE}${NORMAL}"
	printf "${BOLD}${GREEN}<CLUSTERNODES mode>${NEWLINE}${NORMAL}"
	echo "-d = get logs and data from all cluster nodes using $OC_CMD debug or SSH (if -i or -u is used)"
	echo "-L = number of lines of journal to collect from cluster nodes (default = $JOURNAL_SIZE_DEFAULT)"
	printf "${BOLD}${GREEN}<CMDEXEC mode>${NEWLINE}${NORMAL}"
	echo "-C = [script file]##[environment file] WHERE [environment file] is optional"
	echo "     Format of [environment file] is KEY=VALUE with one keyvalue pair per line (similar to variable definition format in shell script)"
	echo "     NOTE: Use keyword '.listcmd' to list all official scripts and '.listcmd_custom' to list all user custom scripts in 'data/cmdexec/<product-version>' directory"
	echo "-E = environment variables for the cmdexec script - Eg. VAR1=VAL1##VAR2=VAL2##..."
	echo "     NOTE: Please enclose the entire input string with SINGLE quotes (Eg. 'VAR1=hello##VAR2=uname -a')"
	echo "-T = timeout value for cmdexec [-C] (default = $CMD_EXEC_TVALUE) - Eg. 10s where s=second; m=minute; h=hour"
	printf "${BOLD}${GREEN}<MANUALCOLLECT mode>${NEWLINE}${NORMAL}"
	echo "-m = <manual-collection-param> = [TAGS]:<input file> for the getManualCollection() function where TAGS is optional (set <input file> to 'mc.cfg' for official config lines or 'mc_custom.cfg' for user custom config lines / if no TAGS is provided, default to ALL config lines / separate multiple tags with comma / use keyword '.listmc' to list all official config lines or '.listmc_custom' to list all user custom config lines in 'data/manualcollect/<product-version>/config/' directory)"
	echo "-n = environment variables for the 'manualcollect' EXECCMD command - Eg. TAG1~>VAR1=VAL1##VAR2=VAL2^^TAG2~>VAR3=VAL3... (Symbol ^^ to separate envvar for different tags / Symbol ~> to define envvar for a tag / Symbol ## to separate multiple envvars)"
	echo "     NOTE: Please enclose the entire input string with SINGLE quotes, but there is no need to enclose the variable values (Eg. 'VAR1=hello##VAR2=uname -a')"
	echo "     NOTE: Please enclose the entire input string with DOUBLE quotes only if variable value contains single quote (Eg. \"VAR1=abc'def##VAR2=uname -a\")"
	echo "-B = <execprep> in the format of tag~><sourcefile>:<targetfile> will be used to substitute the EXECPREP keyword in the EXECPREP column - Eg. TAG1~>/tmp/source:/tmp/target OR TAG2~>bash:/tmp/myscript.sh (separate multiple tags with ##)"
	echo "     NOTE: TAG2~>bash:/tmp/myscript.sh = to execute /tmp/myscript.sh and export all script output in the format of "VAR=VAL" to EXECCMD command"
	echo "-j = provided string [tag:<objname>##tag:<objname>##...] will be used to subtitute the OBJNAME keyword in OBJNAME column based on tagname in the manual-collect input configuration file - Eg. tag1:pod-abc##tag2:pod-xyz"
	echo "     NOTE: Use keyword ALL to specify OBJNAME value applicable to all selected tags/config lines (Eg. tag1:pod-abc##ALL:pod-xyz)"
	echo "-w = timeout value for manualcollect [-m] (default = $MANUAL_COLL_DEFAULT_EXEC_TIMEOUT) - Eg. 10s where s=second; m=minute; h=hour"
	printf "${BOLD}${GREEN}<EXTRA namespace mode>${NEWLINE}${NORMAL}"
	echo "-e = get data for extra namespaces ($OC_CMD get all,pvc,configmap,secret,serviceaccount / $OC_CMD describe / $OC_CMD logs) - separate namespaces with comma(,) / special keywords of NS4PROD=<prodname> and ALLNS (all namespaces) are allowed"
	echo "     NOTE: The [:extra-resources] is optional and is full path to a file that contains additional resource types (Eg. catalogsources, operandconfigs, etc) - specify one resource type per line in the file"
	echo "     NOTE: Set [:extra-resources] to keyword 'ALL' to collect data for all resource types associated with the namespace (Eg. -e openshift-dns:ALL or ALLNS:ALL)"
	printf "${BOLD}${GREEN}<MISSINGOBJ mode>${NEWLINE}${NORMAL}"
	echo "-x = product version to use for 'getMissingObj' function (Eg. -x 3.2.0 or -x X to auto-detect) OR absolute path of an input config file (Eg. -x /tmp/myfile.cfg) for the 'getMissingObj' function to use"
	printf "${BOLD}${GREEN}<COMPLIANCE mode>${NEWLINE}${NORMAL}"
	echo "-A = <compliance-param> = TAGS:[input file for the getCompliance() function] where 'input file' is optional and defaulted to 'config/compliance/<prod-version>/compliance.cfg' (use keyword ALL as TAGS to select all config lines / separate multiple tags with comma)"
	echo "     NOTE(1): Set <input file> to 'custom' for user custom config lines in 'data/compliance/<product-version>/config/compliance_custom.cfg' file"
	echo "     NOTE(2): Use keyword '.listcompliance' to list all official compliance rules or '.listcompliance_custom' to list all user custom compliance rules"
	printf "${BOLD}${GREEN}<PLUGINS mode>${NEWLINE}${NORMAL}"
	echo "-P = product plugin [supported=${PLUGINS_VALID[@]}]:action [supported=${PLUGINS_VALID_ACTION[@]}] (default action = data) (Eg. aimanager or aimanager:data or aimanager:fix) - separate plugins with comma(,)"
	echo "     NOTE: Use '.listparams' to list all defined paramaeters [Eg. -P .listparams]"
	echo "-Z = environment variables for the plugins script - Eg. PLUGIN1~>VAR1=VAL1##VAR2=VAL2^^PLUGIN2~>VAR3=VAL3... (Symbol ^^ to separate envvar for different plugins / Symbol ~> to define envvar for a plugin / Symbol ## to separate multiple envvars)"
	echo "     NOTE: PLUGIN is optional when there is only one plugin specified through -P option (Eg. -Z 'VAR1=VAL1##VAR2=VAL2')"
	echo "     NOTE: Please enclose the entire input string with SINGLE quotes (Eg. 'VAR1=hello##VAR2=uname -a')"
	echo "-Q = timeout value for plugins [-P] (default = $PLUGINS_DEFAULT_TIMEOUT) - Eg. 10s where s=second; m=minute; h=hour"
	printf "${BOLD}${GREEN}<CPFILES mode>${NEWLINE}${NORMAL}"
	echo "-F = to copy files in a pod -> cpfiles-param = TAGS or NAMESPACE##PODNAME##CONTAINER##FILES##LIMITS where multiple TAGS can be delimited by @@, CONTAINER is optional and FILES can be delimited by colon"
	echo "     Eg. -F aimanager = will refer to config/cpfiles/cpfiles-<prodname>-<version>.cfg and copy all the files configured as TAG=aimanager"
	echo "         -F NS4PROD=aimanager##^iaf-system-kafka-####/tmp/mydir##head -3 = manual command to copy file the newest 3 files in the target directory (LIMITS can be 'head -X' or 'tail -X'"
	echo "     NOTE(1): You can use keyword 'NS4PROD=<prodname>' in the NAMESPACE column to obtain namespace for those products automatically"
	echo "     NOTE(2): You can use keyword 'bash <script>' in the FILES column to create file list dynamically"
	echo "     NOTE(3): You can use keyword '.listcpfiles' to list all official config lines or '.listcpfiles_custom' to list all user custom config lines"
	echo "     NOTE(4): You can use asterisk(*), square brackets([]), question mark(?) and curly brackets({}) wildcards in FILES"
	echo "     NOTE(5): Since 'tar' (needed by '$OC_CMD cp') command may not be available in the target pod/container, it is advisable to only use this option for text file ('$OC_CMD exec/cat' will be used as secondary option)"
	printf "${BOLD}${GREEN}<SNAPSHOTS mode>${NEWLINE}${NORMAL}"
	echo "-K = to perform snapshots comparison" 
	echo 
	printf "${BOLD}${RED}[VIEW mode]${NEWLINE}${NORMAL}"
	echo "-V = <view-only-module> is a script that can be created under the <mustgather-install-dir>/config/view/<PRODUCT_VERSION> (precedence) or <mustgather-install-dir>/view directory"
	echo "     NOTE(1): You can use '-V .listviews' to list all official view-only-modules or '-V .listviews_custom' to list all user custom view-only-modules"
	echo "     NOTE(2): Options '-W' and '-Y' can be used together with '-V'"
	echo	
	printf "${BOLD}${RED}[ALIAS mode]${NEWLINE}${NORMAL}"
	echo "-O = <alias-module> is an alias name configured as ALIAS_NAME in config file <mustgather-install-dir>/alias/<PRODUCT_VERSION>/alias.cfg"
	echo "     NOTE(1): The 'alias' mode is used as shortcut for longer mustgather commad (Eg. -O aimgr => -cypDf -P aimanager)"
	echo "     NOTE(2): You can use '-O .listalias' to list all official aliases or '-O .listalias_custom' to list all user custom aliases"
	echo "     NOTE(3): Options '-o', '-W', '-Y' and '-D' can be used together with '-O', but their usage (except '-o' which is preserved) is limited during command expansion only"
	echo	
	printf "${BOLD}${RED}[Supporting Options]${NEWLINE}${NORMAL}"
	echo "-D = to increase log level to DEBUG"
	echo "-f = collect PVC usage data (df -h) - NOTE: Only available with option -a, -c, -b, -l, -z (productinfo/storage/pvcusage), -k (pvc) and -e"
	echo "-g = do NOT collect pod logs ($OC_CMD logs and $OC_CMD logs -p)"
	echo "-G = filename regex and pattern (delimited by colon) to grep for (applicable to pod logs, events, cpfiles and node-related data files)"
	echo "     separate patterns with double asperands(@@) and separate FILENAME_REGEX:PATTERNS keyvalue pairs with double hashes(##)"
	echo "     use keyword ALL as filename regex as instruction to grep for all detected files"
	echo "     use tilde(~) to perform piping grep (i.e. grep A <file> | grep B | grep C)"
	echo "     escape tilde(~) with backward slash(\) for its literal value, but there is no need to escape colon(:)"
	echo "     Eg. ALL:error@@failure or ^aimanager:error~fail or ^aimanager:error##ALL:failure or ALL:error\~fail##ALL:error\/fail"
	echo "-h = help"
	echo "-H = get pod dependency data [EXPERIMENTAL]"
	echo "-i = path to SSH key (needed for cluster on cloud (AWS, GKE, etc) [EXPERIMENTAL]"
	echo "-I = enable incident reporting [EXPERIMENTAL]"
	echo "-J = collect JSON output ($OC_CMD get -o json)"
	echo "-M = disable auto upgrade"
	echo "-N = turn on data collection for problematic non-product namespaces (data collection for problematic Openshift namespaces is enabled always)"
	echo "-o = full path of output directory (default = /tmp/mg)"
	echo "-p = collect logs for the previous instance of the container in a pod if it exists"
	echo "-R = enable report-on-screen where SUMMARY.log will be printed on display"
	echo "-s = to use SSH to collect logs and data from all cluster nodes (but do not have common admin username across the cluster)"
	echo "-S = allow collection of sensitive data (secrets, certs, etc) explicitly"
	echo "-t = do NOT collect '$OC_CMD describe'"
	echo "-u = to provide the admin username that will be used to SSH to all clusder nodes for data collection purpose (passwordless SSH is needed)"
	echo "-U = check for upgrade"
	echo "-v = version"
	echo "-W = to set global environment variables or system.cfg variables that the mustgather functions can use for further processing - Eg. -W 'VAR1=123##VAR2=456##VAR3=789' (delimit multiple variables with ## / all variables will be suffixed with string RTVAR_ when used internally - Eg. VAR1 => RTVAR_VAR1)"

	if [ -s $MUSTGATHER_DIRNAME/rtvar.help ] && [ -s $MUSTGATHER_DIRNAME/config/rtvar.help ]
	then
		cat $MUSTGATHER_DIRNAME/rtvar.help $MUSTGATHER_DIRNAME/config/rtvar.help | sort | $AWK -F${RTVAR_HELP_DELIMITER} '!/^[ \t]*'${RTVAR_HELP_COMMENT}'|^[ \t]*$/ { for (i=3;i<=NF;i++) { if (length(LASTCOL) > 0) { LASTCOL=LASTCOL "'${RTVAR_HELP_DELIMITER}'" $i } else { LASTCOL=$i } }; print "     [" $1 "] - " $2 " [Eg. " LASTCOL "]"; LASTCOL="" }'
	else
		if [ -s $MUSTGATHER_DIRNAME/rtvar.help ]
		then
			$AWK -F${RTVAR_HELP_DELIMITER} '!/^[ \t]*'${RTVAR_HELP_COMMENT}'|^[ \t]*$/ { for (i=3;i<=NF;i++) { if (length(LASTCOL) > 0) { LASTCOL=LASTCOL "'${RTVAR_HELP_DELIMITER}'" $i } else { LASTCOL=$i } }; print "     [" $1 "] - " $2 " [Eg. " LASTCOL "]"; LASTCOL="" }' $MUSTGATHER_DIRNAME/rtvar.help | sort 
		fi

		if [ -s $MUSTGATHER_DIRNAME/config/rtvar.help ]
		then
			$AWK -F${RTVAR_HELP_DELIMITER} '!/^[ \t]*'${RTVAR_HELP_COMMENT}'|^[ \t]*$/ { for (i=3;i<=NF;i++) { if (length(LASTCOL) > 0) { LASTCOL=LASTCOL "'${RTVAR_HELP_DELIMITER}'" $i } else { LASTCOL=$i } }; print "     [" $1 "] - " $2 " [Eg. " LASTCOL "]"; LASTCOL="" }' $MUSTGATHER_DIRNAME/config/rtvar.help | sort 
		fi
	fi

	echo "-X = turn off custom data collection"
	echo "-y = collect YAML output ($OC_CMD get -o yaml)"
	echo "-Y = auto-answer YES to question prompted"
	echo
	printf "${BOLD}${RED}[RULES]${NEWLINE}${NORMAL}"
	echo "(1) User can select ZERO or ONE 'primary' mode."
	echo "(2) User can select ZERO, SOME OR ALL 'secondary' modes."
	echo "(3) User can combine ONE "primary" mode with ZERO, SOME or ALL 'secondary' modes."
	echo "(4) 'Secondary' modes can run independently without any 'primary' mode"
	echo "(5) 'Secondary' modes selected (independently or with any primary mode) will be executed in the following precedence:"
	echo "    [ clusternodes -> cmdexec -> manualcollect -> extra -> missingobj -> compliance -> plugins -> cpfiles -> snapshots ]"
	echo
}

echoAllWarning()
{
	echo "IMPORTANT: "
	echo "You have selected the '-a' (collect all data) option."
	echo "If you have provided -u or -i options, the tool will attempt to SSH to all nodes to collect the data needed."
	echo "Otherwise, '$OC_CMD debug' is used for data collection."
	echo "If you are on AWS, GKE or any cloud provider, please use the '-i' option to provide the SSH key."
	echo -n "Are you sure you want to continue? [y/n] >>> "
}

echoSSHWarning()
{
	echo "WARNING: "
	echo "Tool option '-i' is experimental!"
}

echoJournalSizeWarning()
{
	echo "[$(date)] [${FUNCNAME[0]}] WARNING: You have set JOURNAL_SIZE [$JOURNAL_SIZE] to a value larger than $JOURNAL_SIZE_WARN_LIMIT lines." 
	echo "[$(date)] [${FUNCNAME[0]}] WARNING: It will increase the execution duration and output file size."
	echo "[$(date)] [${FUNCNAME[0]}] WARNING: It might also impact the data collection causing it to hang or terminate!"
	echo -n "Are you sure you want to continue? [y/n] >>> "
}

echoVersion()
{
	echo "[${PRODUCT_NAME}] MustGather Tool: $MG_VERSION"
	echo "Generic MustGather Framework: $GMGF_VERSION"
}

echoVersionToFile()
{
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "MUSTGATHER VERSION INFO" >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "MustGather Version: $MG_VERSION" >> $ANALYZE_OUTFILE
	echo "GMGF Version: $GMGF_VERSION" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE
}

echoProdInfoToFile()
{
	local PG_CTR=1

	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "PRODUCT INFO [$PRODUCT_NAME]" >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE
	
	if [ ${#DETECTED_PRODVER} -gt 0 ] && [ $DETECTED_PRODVER != $PRODUCT_VERSION ]
	then
		echo "Detected Product Version: $DETECTED_PRODVER" >> $ANALYZE_OUTFILE
	fi

	echo "Product Version (GENERAL): $PRODUCT_VERSION" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE

	while read PROD_VER_LINE 
	do
		local PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
		local PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
		local PROD_NS=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $3 }')
		
		echo "[$PG_CTR] Product Group Name: ${PROD_GROUP}" >> $ANALYZE_OUTFILE
		echo "    Product Group Version: ${PROD_VER}" >> $ANALYZE_OUTFILE
		echo "    Product Group Namespaces:" >> $ANALYZE_OUTFILE	

		IFS=$OLDIFS
		local COMP_CTR=1
		for PROD_NS_LINE in $(echo "$PROD_NS" | sed 's#'${PROD_REFFILE_NS_DELIMITER}'# #g')
		do
			local PROD_NAME=$(echo "$PROD_NS_LINE" | $AWK -F= '{ print $1 }')
			local PROD_NS_LIST=$(echo "$PROD_NS_LINE" | $AWK -F= '{ print $2 }')

			for PROD_NS_LIST_LINE in $(echo "$PROD_NS_LIST" | sed 's/,/ /g')
			do
				echo "    >> (${COMP_CTR}) PROD=$PROD_NAME / NAMESPACE=$PROD_NS_LIST_LINE" >> $ANALYZE_OUTFILE
				(( COMP_CTR=COMP_CTR+1 ))
			done
		done
		
		IFS=$'\n'
		echo >> $ANALYZE_OUTFILE
	
		(( PG_CTR=PG_CTR+1 ))	
	done < $PROD_VERSIONS_REFFILE_FINAL

	if [ ${#RTVAR_EXCL_PROD_NS} -gt 0 ]
	then
		echo "    Excluded Namespaces: ${RTVAR_EXCL_PROD_NS}" >> $ANALYZE_OUTFILE
		echo >> $ANALYZE_OUTFILE
	fi
}

echoProdVersion()
{
	if [ $PRODUCT_VERSION_DEFAULT == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Product '${PRODUCT_NAME}' installed version = $PRODUCT_VERSION (default)" 
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product '${PRODUCT_NAME}' installed version = $PRODUCT_VERSION (mustgather)" 
	fi
}

setupDataDir()
{
	MG_TIMESTAMP=$(date +'%d%m%Y-%H%M%S')
	
	OUTDIR=$ROOT_OUTDIR/$(echo "$PRODUCT_NAME" | $AWK '{ print tolower($0) }')-$MUSTGATHER_OPT-$MG_TIMESTAMP

	ANALYZE_OUTDIR=$OUTDIR/0-README-FIRST
	ANALYZE_OUTFILE=$ANALYZE_OUTDIR/SUMMARY.log
	RUNTIME_OUTDIR=$OUTDIR/1-RUNTIME-DATA
	RUNTIME_LOGFILE=$RUNTIME_OUTDIR/runtime.log
	REFFILE_OUTDIR=$RUNTIME_OUTDIR/reffile
	CLUSTERNODES_OUTDIR=$OUTDIR/2-CLUSTERNODES
	CMD_EXEC_OUTDIR=$OUTDIR/3-CMDEXEC
	MANUAL_COLL_OUTDIR=$OUTDIR/4-MANUALCOLLECT
	EXTRA_NAMESPACES_OUTDIR=$OUTDIR/5-EXTRA
	MISSINGOBJ_OUTDIR=$OUTDIR/6-MISSINGOBJ
	COMPLIANCE_OUTDIR=$OUTDIR/7-COMPLIANCE
	PLUGINS_ROOT_OUTDIR=$OUTDIR/8-PLUGIN-DATA
	CPFILES_ROOT_OUTDIR=$OUTDIR/9-CPFILES
	PRODUCT_DATA_OUTDIR=$OUTDIR/PROD_NAMESPACES
	OTHER_NS_DATA_OUTDIR=$OUTDIR/OTHER_NAMESPACES
	CLUSTER_DATA_OUTDIR=$OUTDIR/CLUSTER_DATA
	ALL_NS_PROB_OUTDIR=$CLUSTER_DATA_OUTDIR/0_PROBLEMATIC_NAMESPACES
	CUSTOM_DATA_OUTDIR=$OUTDIR/CUSTOM_DATA
	GREP_POD_LOGS_OUTFILE=$ANALYZE_OUTDIR/GREP_POD_LOGS.out
	GREP_EVENTS_OUTFILE=$ANALYZE_OUTDIR/GREP_EVENTS.out
	GREP_NODEFILE_OUTFILE=$ANALYZE_OUTDIR/GREP_NODE_FILE.out
	GREP_CPFILES_OUTFILE=$ANALYZE_OUTDIR/GREP_CP_FILE.out
	RES_LIST_OUTDIR=$RUNTIME_OUTDIR/resource-list
	RES_LIST_OUTFILE=$RES_LIST_OUTDIR/oc_apiresources.out
	RES_GROUP_LIST_OUTFILE=$RES_LIST_OUTDIR/oc_apigroups.out
	RES_LIST_PROCFILE=$RES_LIST_OUTDIR/api_is_namespaced.out
	SENSITIVE_DATA_REFFILE=$RUNTIME_OUTDIR/sensitive-data.final
	RESTRICTED_DATA_REFFILE=$RUNTIME_OUTDIR/restricted-data.final
	INCIDENT_REPORT_TMPFILE=$OUTDIR/0-README-FIRST/incident.rep.tmp
	INCIDENT_REPORT_OUTFILE=$OUTDIR/0-README-FIRST/INCIDENT_ANALYSIS.log
	INCIDENT_REPORT_ERRFILE=$OUTDIR/0-README-FIRST/INCIDENT_ANALYSIS.err
	INCIDENT_REPORT_CTRFILE=$OUTDIR/0-README-FIRST/INCIDENT_ANALYSIS.ctr
	ENGINE_ANALYZE_SCRIPT_DIR=$MUSTGATHER_DIRNAME/config/engine/analyze
	ENGINE_FIX_SCRIPT_DIR=$MUSTGATHER_DIRNAME/config/engine/fix
	ENGINE_DATA_OUTDIR=$RUNTIME_OUTDIR/engine
	PRE_DATA_COLLECT_OUTDIR=$OUTDIR/_PRE_DATA_COLLECT
	POST_DATA_COLLECT_OUTDIR=$OUTDIR/_POST_DATA_COLLECT
	
	if [ -d $OUTDIR ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Output directory [$OUTDIR] exists. Exiting..." 
		cleanUpDataDir
		exit 1
	else
		mkdir -p $OUTDIR 
	fi

	if [ ! -d $OUTDIR ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Error creating directory [$OUTDIR]. Exiting..." 
		cleanUpDataDir
		exit 255
	else
		mkdir -p $ANALYZE_OUTDIR
		mkdir -p $RUNTIME_OUTDIR
		mkdir -p $REFFILE_OUTDIR
		mkdir -p $PRODUCT_DATA_OUTDIR
		mkdir -p $OTHER_NS_DATA_OUTDIR
		mkdir -p $CLUSTER_DATA_OUTDIR
		mkdir -p $CUSTOM_DATA_OUTDIR

		if [ $INCIDENT_REPORT_ENABLED == "true" ]
		then
			mkdir -p $ENGINE_DATA_OUTDIR
		fi

		if [ -f $TMP_LOGFILE ]
		then
			cat $TMP_LOGFILE >> $RUNTIME_LOGFILE
			echo "[$(date)] [$(basename "$0")] Temp logfile [$TMP_LOGFILE] merged into new runtime logfile [$RUNTIME_LOGFILE]..." | tee -a $RUNTIME_LOGFILE
			echo "[$(date)] [$(basename "$0")] Deleting temp logfile [$TMP_LOGFILE]..." | tee -a $RUNTIME_LOGFILE
			rm $TMP_LOGFILE
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Output directory [$OUTDIR] created." | tee -a $RUNTIME_LOGFILE 
	fi

	if [ ${GET_COMPLIANCE} == "true" ]
	then
		mkdir -p $COMPLIANCE_OUTDIR
		COMPLIANCE_REPORT=$ANALYZE_OUTDIR/COMPLIANCE_REPORT.log
	fi

	if [ $DIFF_SNAPSHOTS == "true" ]
	then
		SNAPSHOTS_OUTDIR=$MUSTGATHER_DIRNAME/data/snapshots
		SNAPSHOTS_CFGFILE=$MUSTGATHER_DIRNAME/snapshots/.snapshots.cfg	
		SNAPSHOTS_REPORT=$ANALYZE_OUTDIR/SNAPSHOTS_REPORT.log
	fi

	if [ $MG_DEBUG == "true" ]
	then
		DEBUG_OUTDIR=$OUTDIR/_DEBUG
		MAIN_ROOT_DEBUG_OUTDIR=$DEBUG_OUTDIR/main
		CLUSTERNODES_ROOT_DEBUG_OUTDIR=$DEBUG_OUTDIR/clusternodes
		CMD_EXEC_ROOT_DEBUG_OUTDIR=$DEBUG_OUTDIR/cmdexec
		MANUAL_COLL_ROOT_DEBUG_OUTDIR=$DEBUG_OUTDIR/manualcollect
		EXTRA_NAMESPACES_ROOT_DEBUG_OUTDIR=$DEBUG_OUTDIR/extra
		MISSINGOBJ_ROOT_DEBUG_OUTDIR=$DEBUG_OUTDIR/missingobj
		COMPLIANCE_ROOT_DEBUG_OUTDIR=$DEBUG_OUTDIR/compliance
		PLUGINS_ROOT_DEBUG_OUTDIR=$DEBUG_OUTDIR/plugins
		CPFILES_DEBUG_OUTDIR=$DEBUG_OUTDIR/cpfiles
		SNAPSHOTS_DEBUG_OUTDIR=$DEBUG_OUTDIR/snapshots

		mkdir -p $MAIN_ROOT_DEBUG_OUTDIR
		mkdir -p $CLUSTERNODES_ROOT_DEBUG_OUTDIR
		mkdir -p $CMD_EXEC_ROOT_DEBUG_OUTDIR
		mkdir -p $MANUAL_COLL_ROOT_DEBUG_OUTDIR
		mkdir -p $EXTRA_NAMESPACES_ROOT_DEBUG_OUTDIR
		mkdir -p $MISSINGOBJ_ROOT_DEBUG_OUTDIR
		mkdir -p $COMPLIANCE_ROOT_DEBUG_OUTDIR
		mkdir -p $PLUGINS_ROOT_DEBUG_OUTDIR
		mkdir -p $CPFILES_DEBUG_OUTDIR
		mkdir -p $SNAPSHOTS_DEBUG_OUTDIR
	fi

	if [ $REPORT_ON_SCREEN == "true" ]
	then
		REPORT_ON_SCREEN_SUMMARY_FILE=$ROOT_OUTDIR/${ANALYZE_OUTFILE##*/}.$$

		if [ ${#COMPLIANCE_REPORT} -gt 0 ]
		then
			REPORT_ON_SCREEN_COMPLIANCE_FILE=$ROOT_OUTDIR/${COMPLIANCE_REPORT##*/}.$$
		fi

		if [ ${#SNAPSHOTS_REPORT} -gt 0 ]
		then
			REPORT_ON_SCREEN_SNAPSHOTS_FILE=$ROOT_OUTDIR/${SNAPSHOTS_REPORT##*/}.$$
		fi
	fi

	PROD_NAMESPACES_REFFILE=$REFFILE_OUTDIR/prod-ns.ref
	PROD_NAMESPACES_REFFILE_FINAL=${PROD_NAMESPACES_REFFILE}.final
	PROD_NAMESPACES_UNIQUE_REFFILE=$REFFILE_OUTDIR/prod-ns.uniq
	PROD_VERSIONS_REFFILE=$REFFILE_OUTDIR/prod-ver.ref
	PROD_VERSIONS_REFFILE_FINAL=${PROD_VERSIONS_REFFILE}.final
	PROD_VERSIONS_UNIQUE_REFFILE=$REFFILE_OUTDIR/prod-ver.uniq
}

backupMainScripts()
{
	if [ $MG_DEBUG == "false" ]
	then
		return 1
	fi

	local BACKUP_DIR=$RUNTIME_OUTDIR/backup

	if [ ! -d $BACKUP_DIR ]
	then
		mkdir -p $BACKUP_DIR
	fi

	local GMGF_SCRIPT="$MUSTGATHER_DIRNAME/$(basename $0)"
	local SYSTEM_CONFFILE=$MUSTGATHER_DIRNAME/system.cfg
	local PRODUCT_CONFFILE="$MUSTGATHER_DIRNAME/config/product.cfg"
	local PRODUCT_SCRIPT="$MUSTGATHER_DIRNAME/config/product.sh"
	local DEFAULT_PROD_SH="$MUSTGATHER_DIRNAME/product.sh.def"
	local FILE=

	IFS=$OLDIFS
	
	for FILE in $GMGF_SCRIPT $SYSTEM_CONFFILE $PRODUCT_CONFFILE $PRODUCT_SCRIPT $DEFAULT_PROD_SH
	do
		echo "[$(date)] [${FUNCNAME[0]}] Backing up critical script [$FILE] to directory [$BACKUP_DIR]..."
		cp -p $FILE $BACKUP_DIR	
	done
}

logUserInput()
{
	echo "mustgather_version = $MG_VERSION"
	echo "gmgf_version = $GMGF_VERSION"
	echo "mustgather_dirname = $MUSTGATHER_DIRNAME"
	echo "mustgather_scriptname = $MUSTGATHER_SCRIPTNAME"

	if [ ${#MUSTGATHER_SYMLINK} -gt 0 ]
	then
		echo "mustgather_symlink = $MUSTGATHER_SYMLINK"
	fi

	local CHECK_IS_SENSITIVE_CMD=$(echo "$MUSTGATHER_ALL_OPT_ORI" | grep -E -i "$SENSITIVE_DATA_REGEX" | $AWK '{ LEN=length($0) } END{ if (length(LEN)==0) { print 0 } else { print LEN } }')

	if [ ${CHECK_IS_SENSITIVE_CMD} -gt 0 ]
	then
		local IS_SENSITIVE_CMD="true"
	else
		local IS_SENSITIVE_CMD="false"
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "check_is_sensitive_cmd = $CHECK_IS_SENSITIVE_CMD"
		echo "is_sensitive_cmd = $IS_SENSITIVE_CMD"
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "mustgather_all_opt (original) = $MUSTGATHER_ALL_OPT_ORI"
		echo "mustgather_all_opt (original - positional params) = $MUSTGATHER_ALL_OPT_ORI_POS_PARAM"
		echo "mustgather_all_opt (expanded) = $MUSTGATHER_ALL_OPT_MOD"
		echo "mustgather_all_opt (expanded - positional params) = $MUSTGATHER_ALL_OPT_MOD_POS_PARAM"
	else
		if [ ${IS_SENSITIVE_CMD} == "false" ] 
		then
			echo "mustgather_all_opt (original) = $MUSTGATHER_ALL_OPT_ORI"
			echo "mustgather_all_opt (original - positional params) = $MUSTGATHER_ALL_OPT_ORI_POS_PARAM"
			echo "mustgather_all_opt (expanded) = $MUSTGATHER_ALL_OPT_MOD"
			echo "mustgather_all_opt (expanded - positional params) = $MUSTGATHER_ALL_OPT_MOD_POS_PARAM"
		else
			echo "mustgather_all_opt (original) = <contains sensitive data>"
			echo "mustgather_all_opt (original - positional params) = <contains sensitive data>"
			echo "mustgather_all_opt (expanded) = <contains sensitive data>"
			echo "mustgather_all_opt (expanded - positional params) = <contains sensitive data>"
		fi
	fi

	echo "mustgather_mode = $MUSTGATHER_OPT"
	echo "alias_mode_only = $ALIAS_MODE_ONLY"
	echo "root_outdir = $ROOT_OUTDIR"
	echo "oc_cmd = $OC_CMD"
	echo "oc_whoami = $OC_WHOAMI"
	echo "oc_token = length(${#OC_TOKEN})"
	echo "oc_apisvr = $OC_APISVR"
	echo "oc_proxy_succ = $OC_PROXY_SUCC"
	echo "oc_proxy_pid = $OC_PROXY_PID"
	echo "fast_oc = $FAST_OC"
	echo "fast_oc_desc = $FAST_OC_DESC"
	echo "fast_oc_yaml = $FAST_OC_YAML"
	echo "curl_timeout = $CURL_TIMEOUT"
	echo "force_slow_oc = $FORCE_SLOW_OC"
	echo "oc_possible_firewall = $OC_POSSIBLE_FIREWALL"
	echo "prod_groups_arr = ${PROD_GROUPS_ARR[@]}"
	echo "prod_versions_single_prodgroup = $PROD_VERSIONS_SINGLE_PRODGROUP"
	echo "detected_product_version = $DETECTED_PRODVER"

	if [ $PRODUCT_VERSION_DEFAULT == "true" ]
	then
		echo "product_version = $PRODUCT_VERSION (default)"
	else
		echo "product_version = $PRODUCT_VERSION (mustgather)"
	fi

	if [ $USERSET_MISSINGOBJ_VERSION -eq 1 ]
	then
		echo "missingobj_version = $MISSINGOBJ_VERSION (userinput)"
	else
		echo "missingobj_version = $MISSINGOBJ_VERSION (mustgather)"
	fi

	echo "prod_namespaces_reffile = $PROD_NAMESPACES_REFFILE [$(if [ -s $PROD_NAMESPACES_REFFILE ]; then echo "OK"; else echo "NOK"; fi)]"
	echo "prod_namespaces_reffile_final = $PROD_NAMESPACES_REFFILE_FINAL [$(if [ -s $PROD_NAMESPACES_REFFILE_FINAL ]; then echo "OK"; else echo "NOK"; fi)]"
	echo "prod_namespaces_unique_reffile = $PROD_NAMESPACES_UNIQUE_REFFILE [$(if [ -s $PROD_NAMESPACES_UNIQUE_REFFILE ]; then echo "OK"; else echo "NOK"; fi)]"
	echo "prod_namespaces_unique = [${PROD_NAMESPACES_UNIQUE[@]}]"
	echo "prod_versions_reffile = $PROD_VERSIONS_REFFILE [$(if [ -s $PROD_VERSIONS_REFFILE ]; then echo "OK"; else echo "NOK"; fi)]"
	echo "prod_versions_reffile_final = $PROD_VERSIONS_REFFILE_FINAL [$(if [ -s $PROD_VERSIONS_REFFILE_FINAL ]; then echo "OK"; else echo "NOK"; fi)]"
	echo "prod_versions_unique_reffile = $PROD_VERSIONS_UNIQUE_REFFILE [$(if [ -s $PROD_VERSIONS_UNIQUE_REFFILE ]; then echo "OK"; else echo "NOK"; fi)]"
	echo "prod_versions_unique = [${PROD_VERSIONS_UNIQUE[@]}]"
	echo "selective_resources = $SELECTIVE_RESOURCES"
	echo "modules = $MODULES"
	echo "modules_custom = $MODULES_CUSTOM"
	echo "modules_custom_agreement = $MODULES_CUSTOM_AGREEMENT"
	echo "extra_namespaces = $EXTRA_NAMESPACES"
	echo "oc_desc_on = $OC_DESC_ON"
	echo "collect_yaml = $COLLECT_YAML"
	echo "collect_json = $COLLECT_JSON"
	echo "show_managed_fields = $SHOW_MANAGED_FIELDS"
	echo "get_pod_logs = $GET_POD_LOGS"
	echo "collect_prev_logs = $COLL_PREV_LOGS"
	echo "pog_log_taillines = $POD_LOG_TAILLINES"
	echo "get_nodes_data = $GET_NODES_DATA"
	echo "journal_size = $JOURNAL_SIZE"
	echo "cmd_exec_input = $CMD_EXEC_INPUT"
	echo "cmd_exec_cmd = $CMD_EXEC_CMD"
	echo "cmd_exec_param = $CMD_EXEC_PARAM"
	echo "cmd_exec_file = $CMD_EXEC_FILE"
	echo "cmd_exec_envfile = $CMD_EXEC_ENVFILE"
	echo "cmd_exec_timeout = $CMD_EXEC_TVALUE"
	echo "cmd_exec_env = $CMD_EXEC_ENV"
	echo "cmd_exec_agree = $CMD_EXEC_AGREEMENT"
	echo "manual_collection_inputtag = $MANUAL_COLL_INPUTTAG"
	echo "manual_collection_inputfile = $MANUAL_COLL_INPUTFILE"
	echo "manual_collection_inputfile_arr = ${MANUAL_COLL_INPUTFILE_ARR[@]}"

	if [ $MG_DEBUG == "true" ]
	then
		echo "manual_collection_env = $MANUAL_COLL_ENV"
	else
		if [ ${IS_SENSITIVE_CMD} == "false" ]
		then	
			echo "manual_collection_env = $MANUAL_COLL_ENV"
		else
			echo "manual_collection_env = <contains sensitive data>"
		fi
	fi

	echo "manual_collection_objname = $MANUAL_COLL_OBJNAME"
	echo "manual_collection_execprep = $MANUAL_COLL_EXECPREP"
	echo "manual_collection_secret = $MANUAL_COLL_SECRET"
	echo "manual_collection_timeout = $MANUAL_COLL_EXEC_TIMEOUT"
	# echo "compliance_rootdir = $COMPLIANCE_ROOTDIR"
	echo "compliance_userinput = $COMPLIANCE_USERINPUT"
	echo "compliance_inputtag = $COMPLIANCE_INPUTTAG"
	echo "compliance_inputfile = $COMPLIANCE_INPUTFILE"
	echo "plugins = $PLUGINS"
	echo "plugins_env = $PLUGINS_ENV"
	echo "plugins_timeout = $PLUGINS_TIMEOUT"
	echo "cpfiles_files = $CPFILES_FILES"
	echo "get_pvc_usage = $GET_PVC_USAGE"
	echo "node_admin_user = $NODE_ADMIN_USER"
	echo "sshkey = $SSHKEY"
	echo "is_sensitive_data_allowed = $IS_SENSITIVE_DATA_ALLOWED"
	echo "grep_pattern = $GREP_PATTERN"
	echo "runtime_var = $RUNTIME_VAR"
	echo "allns_data = $ALLNS_DATA"
	echo "custom_data_enabled = $CUSTOM_DATA_ENABLED"
	echo "exclude_product_namespaces = $RTVAR_EXCL_PROD_NS"
	echo "check_for_update = $CHECK_FOR_UPDATE"
	echo "auto_check_update = $AUTO_CHECK_UPDATE"
	echo "report_on_screen = $REPORT_ON_SCREEN"
	echo "view_only = $VIEW_ONLY"
	echo "auto_yes = $AUTO_YES"
	echo "non_product_collect_agreement = $NON_PROD_COLLECT_AGREEMENT"
	echo "snapshots_cfgfile = $SNAPSHOTS_CFGFILE"
	# echo "snapshots_cfgfile_prod = $SNAPSHOTS_CFGFILE_PROD"
	echo "diff_snapshots = $DIFF_SNAPSHOTS"
	echo "snaphosts_only = $SNAPSHOTS_ONLY"
	echo "incident_report_enabled = $INCIDENT_REPORT_ENABLED"
	echo "engine_analyze_dir = $ENGINE_ANALYZE_SCRIPT_DIR"
	echo "engine_fix_dir = $ENGINE_FIX_SCRIPT_DIR"
	echo "engine_tvalue = $ENGINE_TVALUE"
	echo "get_dependency_data = $GET_DEPENDENCY_DATA"
	echo "os_type = $OS_TYPE"
	echo "os_arch = $OS_ARCH"
	echo "is_macos = $IS_MACOS"
	echo "gdate = $GDATE"
	echo "bash_v4 = $BASH_V4"
	echo "mg_tty = $MG_TTY [$USER_TTY]"
	echo "debug = $MG_DEBUG"
}

logUserEnv()
{
	echo "[USER_OS_VERSION]"
	echo "$(uname -av)"
	echo
	echo "========================================================="
	echo "[USER_BASH_VERSION]"
	echo "$(bash --version)"
	echo
	echo "========================================================="
	echo "[USER_AWK_VERSION]"
	echo "$($AWK -V)"
	echo
	echo "========================================================="
	echo "[USER_GREP_VERSION]"
	echo "$(grep -V)"
	echo
	echo "========================================================="
	echo "[USER_DATE_VERSION]" 
	echo "$(date --version)"
	echo
	echo "========================================================="
	echo "[USER_CURL_VERSION]"
	echo "$($CURL -V)"
	echo
	echo "========================================================="
	echo "[USER_PYTHON_VERSION]"
	
	if [ ${#PYTHON} -gt 0 ]
	then
		echo "$($PYTHON -V)"
	else
		echo "<Python is not available!>"
	fi

	echo
	echo "========================================================="
	echo "[USER_OPENSSL_VERSION]"

	if [ ${#OPENSSL} -gt 0 ]
	then
		echo "$($OPENSSL version)"
	else
		echo "<OpenSSL is not available!>"
	fi

	echo
}

logUserScriptDir()
{
	local SCRIPTDIR=$MUSTGATHER_DIRNAME

	if [ -d $SCRIPTDIR ]
	then
		echo "SCRIPT DIRECTORY = $SCRIPTDIR"
		echo
		ls -l $SCRIPTDIR
	else
		echo "[$(date)] [${FUNCNAME[0]}] Script directory [$SCRIPTDIR] does not exist!"
	fi
}

checkOSArch()
{
	local CHECK_OS="false"

	if [ ${#OS_TYPE} -eq 0 ]
	then
		local CHECK_OS="true"
		OS_TYPE=$(uname -s)

		if [[ "$OS_TYPE" =~ Darwin ]] || [[ "$OS_TYPE" =~ darwin ]]
		then
			IS_MACOS="true"
			GDATE=$(which gdate 2>/dev/null)
		fi
	fi

	if [ ${#OS_ARCH} -eq 0 ]
	then
		local CHECK_OS="true"
		OS_ARCH=$(uname -m)	
	fi

	if [ ${#OS_TYPE} -eq 0 ]
	then	
		OS_TYPE=$OS_TYPE_DEFAULT
		OS_TYPE_NULL="true"
		printf "[$(date)] [${FUNCNAME[0]}] ${BOLD}${RED}WARNING: Unable to determine OS type!${NORMAL}${NEWLINE}"
		sleep $DEFAULT_SLEEP_SEC
	fi

	if [ ${#OS_ARCH} -eq 0 ]
	then	
		OS_ARCH=$OS_ARCH_DEFAULT
		OS_ARCH_NULL="true"
		printf "[$(date)] [${FUNCNAME[0]}] ${BOLD}${RED}WARNING: Unable to determine OS architecture!${NORMAL}${NEWLINE}"
		sleep $DEFAULT_SLEEP_SEC
	fi

	if [ ${CHECK_OS} == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] INFO: OS = [$OS_TYPE] / ARCH = [$OS_ARCH]"
	fi
}

checkBashVersion()
{
	if [ ${#BASH_VER} -eq 0 ]
	then
		BASH_VER=$(/bin/bash -c "echo \$BASH_VERSION")
	fi

	if [ ${#BASH_V4} -gt 0 ]
	then
		if [ ${BASH_V4} == "true" ]
		then
			return 0
		fi

		if [ ${BASH_V4} == "false" ]
		then
			return 1
		fi
	fi

	if [ $(echo "$BASH_VER" | $AWK '{ if ($0 ~ /^4|^5/) { print "OK " } else { print "NOK" }}') == "NOK" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] WARNING: Bash version [$BASH_VER] lower than version 4 is detected!"
		echo "[$(date)] [${FUNCNAME[0]}] Setting BASH_V4 to [false]..."
		BASH_V4="false"

		return 1
	else
		echo "[$(date)] [${FUNCNAME[0]}] INFO: Bash version [$BASH_VER] equal to or high than version 4 is detected!"
		echo "[$(date)] [${FUNCNAME[0]}] Setting BASH_V4 to [true]..."
		BASH_V4="true"

		return 0
	fi
}

checkBashVersionAgain()
{
	# Created to set BASH_V4 to user-defined value (true/false)
	if [ ${#RTVAR_IS_BASH_V4} -gt 0 ] 
	then
		case "$RTVAR_IS_BASH_V4" in
			true)	echo "[$(date)] [${FUNCNAME[0]}] WARNING: BASH_V4 variable is now set to user-defined value [$RTVAR_IS_BASH_V4]!"
					BASH_V4="true"
					;;
			false)	echo "[$(date)] [${FUNCNAME[0]}] WARNING: BASH_V4 variable is now set to user-defined value [$RTVAR_IS_BASH_V4]!"
					BASH_V4="false"
					;;
			*)		echo "[$(date)] [${FUNCNAME[0]}] ERROR: Invalid BASH_NON_V4 value [$RTVAR_BASH_NON_V4]! Ignoring..."
					;;
		esac
	fi
}

checkAssociativeArray()
{
	# IMPORTANT: The success/failure of this function depends on the "echo" statement and not the return code

	declare -gA TEST_ME_ASSC_ARR 2> /dev/null
	TEST_ME_ASSC_ARR["test.me"]="abc123" 
	TEST_ME_EXIT_CODE=$?
	unset TEST_ME_ASSC_ARR
	
	if [ ${#TEST_ME_EXIT_CODE} -gt 0 ]
	then
		if [ $TEST_ME_EXIT_CODE -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] INFO: Associative array test passed!"
			return 0
		else
			# echo "[$(date)] [${FUNCNAME[0]}] WARNING: Associative array test failed!"
			return $TEST_ME_EXIT_CODE
		fi
	else
		# echo "[$(date)] [${FUNCNAME[0]}] WARNING: Associative array test failed!"
		return 1
	fi		
}

checkTty()
{
	USER_TTY=$(tty)

	if [ ${#USER_TTY} -gt 0 ]
	then
		if [ $USER_TTY == "not a tty" ] 
		then
			MG_TTY="false"
		else
			if [[ $USER_TTY =~ ^/dev/ ]]
			then
				MG_TTY="true"
			else
				MG_TTY="false"
			fi
		fi
	else
		MG_TTY="false"
	fi
}

checkOcCmd()
{
	if ! $OC_CMD version > /dev/null
	then 
		echo "[$(date)] [${FUNCNAME[0]}] Error running '$OC_CMD version' command' - client check failed! Exiting..." 
		return 1
	fi
}

checkMissingObjVersion()
{
	local IS_SUPPORTED=1
	local VER=

	IFS=$OLDIFS
	
	for VER in ${PRODUCT_SUPPORTED_VERSION[@]} 
	do
		if [ $VER == $MISSINGOBJ_VERSION ]
		then	
			local IS_SUPPORTED=0
			break
		fi
	done

	return $IS_SUPPORTED
}

checkApiCallSpeed()
{
	local CMD="$OC_CMD api-resources"
	echo "[$(date)] [${FUNCNAME[0]}] Testing API call speed with command = [$CMD]..." | tee -a $RUNTIME_LOGFILE

	local DATE_MILLISECOND="true"

	local TEST_START_TIME=$(date +%s%N | cut -b1-13)	
	eval "$CMD" > /dev/null 2>&1
	TEST_EXITSTATUS=$?
	local TEST_END_TIME=$(date +%s%N | cut -b1-13)

	if [[ $TEST_START_TIME =~ N$ ]] && [[ $TEST_END_TIME =~ N$ ]] 
	then
		local DATE_MILLISECOND="false"

		local TEST_START_TIME=$(echo "$TEST_START_TIME" | sed 's/N$//')
		local TEST_END_TIME=$(echo "$TEST_END_TIME" | sed 's/N$//')
	fi

	if [ $TEST_EXITSTATUS -ne 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] WARNING: The API call speed test failed!" | tee -a $RUNTIME_LOGFILE
		return 2
	else
		(( TEST_TOTAL_TIME=TEST_END_TIME-TEST_START_TIME ))

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] MAX_OC_CALL_TIMELIMIT_MILLISECOND = [$MAX_OC_CALL_TIMELIMIT_MILLISECOND]" | tee -a $RUNTIME_LOGFILE
		fi

		if [ $DATE_MILLISECOND == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Test API call took [$TEST_TOTAL_TIME]ms" | tee -a $RUNTIME_LOGFILE
		else
			echo "[$(date)] [${FUNCNAME[0]}] Test API call took [$TEST_TOTAL_TIME]s" | tee -a $RUNTIME_LOGFILE
		fi
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] TEST_START_TIME = [$TEST_START_TIME] / TEST_END_TIME = [$TEST_END_TIME]" | tee -a $RUNTIME_LOGFILE
		fi

		if [ $DATE_MILLISECOND == "true" ]
		then
			if [ $TEST_TOTAL_TIME -ge $MAX_OC_CALL_TIMELIMIT_MILLISECOND ]
			then
				return 1
			else
				return 0
			fi
		else
			if [ $TEST_TOTAL_TIME -ge $MAX_OC_CALL_TIMELIMIT_SECOND ]
			then
				return 1
			else
				return 0
			fi
		fi
	fi
}

checkOcClientCompat()
{
	# To check 'oc' client features compatibility

	if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
	then
		local OC_COMPAT_CHECK_RESOURCE="route"
		local OC_COMPACT_CHECK_OUTFILE=$DEFAULT_TMPDIR/checkOcClientCompat.$$

		if ! $OC_CMD get -o yaml --show-managed-fields $OC_COMPAT_CHECK_RESOURCE > /dev/null 2> $OC_COMPACT_CHECK_OUTFILE 
		then
			if [ -s $OC_COMPACT_CHECK_OUTFILE ]
			then
				local OC_COMPACT_CHECK_ERROR_COUNT=$(grep -E show-managed-fields $OC_COMPACT_CHECK_OUTFILE | wc -c)	

				if [ ${#OC_COMPACT_CHECK_ERROR_COUNT} -gt 0 ]
				then
					if [ $OC_COMPACT_CHECK_ERROR_COUNT -gt 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] The 'oc' client does not support '--show-managed-fields' flag! Setting SHOW_MANAGED_FIELDS to [false]!"
						SHOW_MANAGED_FIELDS="false"
					else
						local OC_COMPACT_CHECK_ERROR_COUNT=$(grep -E '^Error from server.*cannot list resource' $OC_COMPACT_CHECK_OUTFILE | wc -c)
	
						if [ $OC_COMPACT_CHECK_ERROR_COUNT -gt 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have permission to list resource [$OC_COMPAT_CHECK_RESOURCE]! Setting SHOW_MANAGED_FIELDS to [false]!"
							SHOW_MANAGED_FIELDS="false"
						else
							echo "[$(date)] [${FUNCNAME[0]}] [1] Unable to determine error! Setting SHOW_MANAGED_FIELDS to [false]!"
							SHOW_MANAGED_FIELDS="false"
						fi
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] [2] Unable to determine error! Setting SHOW_MANAGED_FIELDS to [false]!"
					SHOW_MANAGED_FIELDS="false"
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] [3] Unable to determine error! Setting SHOW_MANAGED_FIELDS to [false]!"
				SHOW_MANAGED_FIELDS="false"
			fi
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] The 'oc' client supports '--show-managed-fields' flag!"
			fi
		fi

		if [ -f $OC_COMPACT_CHECK_OUTFILE ]
		then
			rm $OC_COMPACT_CHECK_OUTFILE
		fi
	fi
}

checkUserPriv()
{
	# Return 0 = user has privilege
	# Return 1 = user has no privilege
	# Return 8 = user should terminate (for scripts executed in subshell)

	local IN_VERB=$1
	local IN_RESOURCE=$2
	local IN_NS=$3

	local VERB=
	local NS=

	(( CHECK_USER_PRIV_CTR=CHECK_USER_PRIV_CTR+1 ))

	if [ ${#OC_WHOAMI} -eq 0 ]
	then
		if [ $OC_CMD == "oc" ]
		then
			OC_WHOAMI=$($OC_CMD whoami)
		else
			if [ $OC_CMD == "kubectl" ]
			then
				OC_WHOAMI=$($OC_CMD config current-context | $AWK -F/ '{ print $NF }')
			else
				return 1
			fi
		fi
	fi

	# Setting whoami & cluster/context initial value
	if [ ${CHECK_USER_PRIV_CTR} == 1 ]
	then
		if [ $OC_CMD == "oc" ]
		then
			local CUR_OC_WHOAMI=$($OC_CMD whoami)
		else
			if [ $OC_CMD == "kubectl" ]
			then
				local CUR_OC_WHOAMI=$($OC_CMD config current-context | $AWK -F/ '{ print $NF }')
			else
				return 1
			fi
		fi

		local CUR_CLUSTER_INFO=$($OC_CMD cluster-info | grep -v '^$' | grep 'http' | head -1 | sed -r 's/\x1B\[([0-9]{1,3}(;[0-9]{1,2};?)?)?[mGK]//g')

		if [ ${#CUR_CLUSTER_INFO} -eq 0 ]
		then
			CHECK_USER_PRIV_CLUSTER_INFO="false"
			echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Setting CHECK_USER_PRIV_CLUSTER_INFO to [$CHECK_USER_PRIV_CLUSTER_INFO]..."

			local CUR_CLUSTER_INFO=$($OC_CMD config current-context)
		else
			echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Setting CHECK_USER_PRIV_CLUSTER_INFO to [$CHECK_USER_PRIV_CLUSTER_INFO]..."
		fi

		echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Current cluster info = [$CUR_CLUSTER_INFO] / Current user = [$CUR_OC_WHOAMI]"

		if [ ${#CHECK_USER_PRIV_OLD_CONTEXT} -eq 0 ]
		then
			CHECK_USER_PRIV_OLD_CONTEXT="$CUR_CLUSTER_INFO / $CUR_OC_WHOAMI"
		fi
	else
		# Periodic user context check (to pickup debugging details if user switch context in midst of data collection)
		if [ $(expr $CHECK_USER_PRIV_CTR % $CONTEXT_SWITCH_CHECK_PERIOD) == "0" ]
		then
			if [ $OC_CMD == "oc" ]
			then
				local CUR_OC_WHOAMI=$($OC_CMD whoami)
			else
				if [ $OC_CMD == "kubectl" ]
				then
					local CUR_OC_WHOAMI=$($OC_CMD config current-context | $AWK -F/ '{ print $NF }')
				else
					return 1
				fi
			fi

			if [ $CHECK_USER_PRIV_CLUSTER_INFO == "true" ]
			then
				local CUR_CLUSTER_INFO=$($OC_CMD cluster-info | grep -v '^$' | grep 'http' | head -1 | sed -r 's/\x1B\[([0-9]{1,3}(;[0-9]{1,2};?)?)?[mGK]//g')
			else
				local CUR_CLUSTER_INFO=$($OC_CMD config current-context)
			fi

			echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Current cluster info = [$CUR_CLUSTER_INFO] / Current user = [$CUR_OC_WHOAMI]"

			if [ ${#CHECK_USER_PRIV_OLD_CONTEXT} -eq 0 ]
			then
				CHECK_USER_PRIV_OLD_CONTEXT="$CUR_CLUSTER_INFO / $CUR_OC_WHOAMI"
			else
				CHECK_USER_PRIV_CUR_CONTEXT="$CUR_CLUSTER_INFO / $CUR_OC_WHOAMI"

				if [ "$CHECK_USER_PRIV_OLD_CONTEXT" != "$CHECK_USER_PRIV_CUR_CONTEXT" ]
				then
					if [ $GMGF_PID == $$ ]
					then
						printf "[$(date)] [${FUNCNAME[0]}] ${BOLD}${RED}CHECK_USER_PRIV_CUR_CONTEXT = ${NORMAL}[$CHECK_USER_PRIV_CUR_CONTEXT]${NORMAL}${NEWLINE}"
						printf "[$(date)] [${FUNCNAME[0]}] ${BOLD}${RED}CHECK_USER_PRIV_OLD_CONTEXT = ${NORMAL}[$CHECK_USER_PRIV_OLD_CONTEXT]${NORMAL}${NEWLINE}"

						if ( [ ${#CUR_CLUSTER_INFO} -eq 0 ] || [ ${#CUR_OC_WHOAMI} -eq 0 ] ) && [ ${CHECK_USER_PRIV_SYSGLITCH_CTR} -lt ${CHECK_USER_PRIV_SYSGLITCH_MAX} ]
						then
							printf "[$(date)] [${FUNCNAME[0]}] ${BOLD}${RED}[WARNING] CUR_CLUSTER_INFO [$CUR_CLUSTER_INFO] and/or CUR_OC_WHOAMI [$CUR_OC_WHOAMI] is empty/null! Assuming temporary system glitch! Proceeding...${NORMAL}${NEWLINE}"

							(( CHECK_USER_PRIV_SYSGLITCH_CTR=CHECK_USER_PRIV_SYSGLITCH_CTR+1 ))
							echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] [CHECK_USER_PRIV_SYSGLITCH_MAX=$CHECK_USER_PRIV_SYSGLITCH_MAX] Increasing counter CHECK_USER_PRIV_SYSGLITCH_CTR to [$CHECK_USER_PRIV_SYSGLITCH_CTR]..." 
						else
							printf "[$(date)] [${FUNCNAME[0]}] ${BOLD}${RED}[FATAL] A change in context/cluster is detected! Data is assumed to be corrupted! Exiting...${NORMAL}${NEWLINE}"
							cleanUpDataDir	
							exit 1
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] CHECK_USER_PRIV_CUR_CONTEXT = [$CHECK_USER_PRIV_CUR_CONTEXT]" >&2
						echo "[$(date)] [${FUNCNAME[0]}] CHECK_USER_PRIV_OLD_CONTEXT = [$CHECK_USER_PRIV_OLD_CONTEXT]" >&2

						if ( [ ${#CUR_CLUSTER_INFO} -eq 0 ] || [ ${#CUR_OC_WHOAMI} -eq 0 ] ) && [ ${CHECK_USER_PRIV_SYSGLITCH_CTR} -lt $CHECK_USER_PRIV_SYSGLITCH_MAX ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [WARNING] CUR_CLUSTER_INFO [$CUR_CLUSTER_INFO] and/or CUR_OC_WHOAMI [$CUR_OC_WHOAMI] is empty/null! Assuming temporary system glitch! Proceeding..." >&2

							(( CHECK_USER_PRIV_SYSGLITCH_CTR=CHECK_USER_PRIV_SYSGLITCH_CTR+1 ))
							echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] [CHECK_USER_PRIV_SYSGLITCH_MAX=$CHECK_USER_PRIV_SYSGLITCH_MAX] Increasing counter CHECK_USER_PRIV_SYSGLITCH_CTR to [$CHECK_USER_PRIV_SYSGLITCH_CTR]..." >&2
						else
							echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] [FATAL] A change in context/cluster is detected! Data is assumed to be corrupted!" >&2
							return 8
						fi
					fi
				fi
			fi
		fi
	fi

	if [ ${#IN_NS} -gt 0 ]
	then
		IFS=$OLDIFS
		for VERB in $(echo "$IN_VERB" | sed 's/,/ /g')
		do
			local USER_PRIV_ARR_KEY="${VERB}_${IN_RESOURCE}_${IN_NS}"

			# The USER_PRIV_ARR is not supported in CMDEXEC script which is executed on a subshell
			if [ $BASH_V4 == "true" ] && [ $GMGF_PID == $$ ]
			then
				if [ ${#USER_PRIV_ARR[@]} -gt 0 ]
				then
					if [ "${USER_PRIV_ARR[$USER_PRIV_ARR_KEY]+abc}" ]
					then
						local USER_PRIV_ARR_CACHE=${USER_PRIV_ARR[$USER_PRIV_ARR_KEY]}

						if [[ "${USER_PRIV_ARR_CACHE}" =~ yes ]]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Returning cached user privilege [$USER_PRIV_ARR_KEY] => [$USER_PRIV_ARR_CACHE]..."
							IFS=$'\n'
							return 0
						else
							if [[ "${USER_PRIV_ARR_CACHE}" =~ ^no ]]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Returning cached user privilege [$USER_PRIV_ARR_KEY] => [$USER_PRIV_ARR_CACHE]..."
								IFS=$'\n'
								return 1
							fi		
						fi 
					fi
				fi
			else
				CHECK_USER_PRIV_CACHEFILE=$RUNTIME_OUTDIR/can-i/user_priv.cache

				if [ -s $CHECK_USER_PRIV_CACHEFILE ]
				then
					local USER_PRIV_FILE_CACHE=$($AWK -F= '$1 ~ /^'$(echo "$USER_PRIV_ARR_KEY" | sed 's#/#\\/#g')'$/ { print $2 }' $CHECK_USER_PRIV_CACHEFILE)

					if [ ${#USER_PRIV_FILE_CACHE} -gt 0 ]
					then
						if [[ "${USER_PRIV_FILE_CACHE}" =~ yes ]]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Returning cached user privilege [$USER_PRIV_ARR_KEY] => [$USER_PRIV_FILE_CACHE]..."
							IFS=$'\n'
							return 0
						else
							if [[ "${USER_PRIV_FILE_CACHE}" =~ ^no ]]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Returning cached user privilege [$USER_PRIV_ARR_KEY] => [$USER_PRIV_FILE_CACHE]..."
								IFS=$'\n'
								return 1
							fi		
						fi
					fi
				fi
			fi

			if [ $IN_RESOURCE == "all" ]
			then
				if [ $IN_NS == "all" ]
				then
					local CAN_I_CMD="$OC_CMD auth can-i $VERB '*' --all-namespaces"
				else
					if [ $IN_NS == "allmynamespaces" ]
					then
						local CAN_I_CMD="$OC_CMD auth can-i $VERB '*'"
					else
						local CAN_I_CMD="$OC_CMD auth can-i $VERB '*' -n $IN_NS"
					fi
				fi
			else
				if [ $IN_NS == "all" ]
				then
					local CAN_I_CMD="$OC_CMD auth can-i $VERB $IN_RESOURCE --all-namespaces"
				else
					if [ $IN_NS == "allmynamespaces" ]
					then
						local CAN_I_CMD="$OC_CMD auth can-i $VERB $IN_RESOURCE"
					else
						local CAN_I_CMD="$OC_CMD auth can-i $VERB $IN_RESOURCE -n $IN_NS"
					fi
				fi
			fi
	
			echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] CAN_I_CMD = [$CAN_I_CMD]"
	
			local CAN_I_RESULT=$(eval "$CAN_I_CMD")
	
			echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Can user [$OC_WHOAMI] perform verb [$VERB] on resource [$IN_RESOURCE] in namespace [$IN_NS]? [$CAN_I_RESULT]" 

			# The USER_PRIV_ARR is not supported in CMDEXEC script which is executed on a subshell
			if [ $BASH_V4 == "true" ] && [ $GMGF_PID == $$ ]
			then
				if [ "${USER_PRIV_ARR[$USER_PRIV_ARR_KEY]+abc}" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] USER_PRIV_ARR_KEY [$USER_PRIV_ARR_KEY] exists => [${USER_PRIV_ARR[$USER_PRIV_ARR_KEY]}] [SIZE=${#USER_PRIV_ARR[@]}]..."
				else
					USER_PRIV_ARR[$USER_PRIV_ARR_KEY]=$CAN_I_RESULT
					echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Privilege check result [$CAN_I_RESULT] for [$USER_PRIV_ARR_KEY] is added into USER_PRIV_ARR [SIZE=${#USER_PRIV_ARR[@]}]..."

					if [ $MG_DEBUG == "true" ]
					then
						for X in "${!USER_PRIV_ARR[@]}"
						do
							echo "[KEY = $X] / [VAL = ${USER_PRIV_ARR[$X]}]"
						done
					fi
				fi
			else
				CHECK_USER_PRIV_CACHEFILE=$RUNTIME_OUTDIR/can-i/user_priv.cache
				local CACHEFILE_BASEDIR=$(dirname $CHECK_USER_PRIV_CACHEFILE)

				if [ ! -d $CACHEFILE_BASEDIR ]
				then
					mkdir -p $CACHEFILE_BASEDIR
				fi	

				if [ -s $CHECK_USER_PRIV_CACHEFILE ]
				then
					local USER_PRIV_FILE_CACHE=$($AWK -F= '$1 ~ /^'$(echo "$USER_PRIV_ARR_KEY" | sed 's#/#\\/#g')'$/ { print $2 }' $CHECK_USER_PRIV_CACHEFILE)
		
					if [ ${#USER_PRIV_FILE_CACHE} -gt 0 ]
					then
						local CHECK_USER_PRIV_CACHEFILE_SIZE=$(wc -l $CHECK_USER_PRIV_CACHEFILE | $AWK '{ print $1 }')
						echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] USER_PRIV_ARR_KEY [$USER_PRIV_ARR_KEY] exists => [${USER_PRIV_FILE_CACHE}] [SIZE=$CHECK_USER_PRIV_CACHEFILE_SIZE]..."
					else	
						echo "${USER_PRIV_ARR_KEY}=${CAN_I_RESULT}" >> $CHECK_USER_PRIV_CACHEFILE

						local CHECK_USER_PRIV_CACHEFILE_SIZE=$(wc -l $CHECK_USER_PRIV_CACHEFILE | $AWK '{ print $1 }')
						
						echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Privilege check result [$CAN_I_RESULT] for [$USER_PRIV_ARR_KEY] is added into CHECK_USER_PRIV_CACHEFILE [SIZE=$CHECK_USER_PRIV_CACHEFILE_SIZE]..."
	
						if [ $MG_DEBUG == "true" ]
						then
							$AWK -F= '{ print "[KEY = " $1 "] / [VAL = " $2 "]" }' $CHECK_USER_PRIV_CACHEFILE
						fi	
					fi
				else
					echo "${USER_PRIV_ARR_KEY}=${CAN_I_RESULT}" >> $CHECK_USER_PRIV_CACHEFILE

					local CHECK_USER_PRIV_CACHEFILE_SIZE=$(wc -l $CHECK_USER_PRIV_CACHEFILE | $AWK '{ print $1 }')
						
					echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Privilege check result [$CAN_I_RESULT] for [$USER_PRIV_ARR_KEY] is added into CHECK_USER_PRIV_CACHEFILE [SIZE=$CHECK_USER_PRIV_CACHEFILE_SIZE]..."
	
					if [ $MG_DEBUG == "true" ]
					then
						$AWK -F= '{ print "[KEY = " $1 "] / [VAL = " $2 "]" }' $CHECK_USER_PRIV_CACHEFILE
					fi	
				fi
			fi
	
			if [ ${#CAN_I_RESULT} -gt 0 ] && [[ "$CAN_I_RESULT" =~ ^no ]]
			then
				IFS=$'\n'
				return 1
			fi
		done

		IFS=$'\n'
		return 0
	else
		local F_OUTDIR=$RUNTIME_OUTDIR/can-i

		if [ ! -d $F_OUTDIR ]
		then	
			mkdir -p $F_OUTDIR
		fi

		echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Checking user privileges..." | tee -a $RUNTIME_LOGFILE
	
		# Current context
		$OC_CMD config current-context > $F_OUTDIR/current-context.out
		$OC_CMD cluster-info | grep -v '^$' | grep 'http' | head -1 | sed -r 's/\x1B\[([0-9]{1,3}(;[0-9]{1,2};?)?)?[mGK]//g' > $F_OUTDIR/cluster-info.out

		for NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Executing command [$OC_CMD auth can-i --list --namespace=$NS] to output file [$F_OUTDIR/can-i.$NS]" | tee -a $RUNTIME_LOGFILE
			$OC_CMD auth can-i --list --namespace=$NS > $F_OUTDIR/can-i.$NS 2>&1
		done

		# All namespaces
		$OC_CMD auth can-i get "*" --all-namespaces > $F_OUTDIR/can-i.get.all.allns
		echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Can user [$OC_WHOAMI] perform verb [get] on resource [all] in all namespaces? [$(cat $F_OUTDIR/can-i.get.all.allns)]" | tee -a $RUNTIME_LOGFILE
		$OC_CMD auth can-i list "*" --all-namespaces > $F_OUTDIR/can-i.list.all.allns
		echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Can user [$OC_WHOAMI] perform verb [list] on resource [all] in all namespaces? [$(cat $F_OUTDIR/can-i.list.all.allns)]" | tee -a $RUNTIME_LOGFILE
		$OC_CMD auth can-i create pods/exec --all-namespaces > $F_OUTDIR/can-i.create.podexec.allns
		echo "[$(date)] [${FUNCNAME[0]}] [$CHECK_USER_PRIV_CTR] Can user [$OC_WHOAMI] perform verb [create] on resource [pod/exec] in all namespace? [$(cat $F_OUTDIR/can-i.create.podexec.allns)]" | tee -a $RUNTIME_LOGFILE
	fi	
}

echoProductSupportedVersions()
{
	echo "Product '${PRODUCT_NAME}' Supported Versions: ${PRODUCT_SUPPORTED_VERSION[@]}"
}

echoProductCorrectiveActions()
{
	echo "ACTION: Please correct the product '${PRODUCT_NAME}' installed version provided OR use the '-x X' option to auto detect '${PRODUCT_NAME}' version OR remove the -x option!"
}

setupDeferRtvarStruc()
{
	if [ $BASH_V4 == "true" ]
	then
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Declaring DEFER_RTVAR_ARR..."
		fi

		declare -gA DEFER_RTVAR_ARR
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Setting DEFER_RTVAR_INFILE to [$DEFAULT_TMPDIR/defer-rtvar.ref.$$]..."
		fi

		DEFER_RTVAR_INFILE=$DEFAULT_TMPDIR/defer-rtvar.ref.$$
	fi
}

processRuntimeVar()
{
	local RTVAR=

	IFS=##

	for RTVAR in $RUNTIME_VAR
	do
		local KEY=$(echo "$RTVAR" | $AWK -F= '{ print $1 }')
		local VAL=$(echo "$RTVAR" | cut -f 2- -d =) 
	
		# Allowing VAL to be empty
		if [ ${#KEY} -gt 0 ]
		then
			local KEY_IS_SYSTEM_CFG="false"

			for SKEY in ${SYSTEM_CFG_ARR[@]}
			do
				if [ "$KEY" == "$SKEY" ]
				then
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] User provided variable [$KEY] is a system variable! Setting value to [$VAL]..."
					fi

					KEY_IS_SYSTEM_CFG="true"

					# By default, user is allowed to override system variables defined in system.cfg (unless they are also global variables - GMGF_ENV_ARR). 
					# The 'checkSysVar' function can be used to provide further processing/checking (to allow/deny override) for the target system variables.
					if checkSysVar "$KEY" "$VAL"
					then
						eval "$KEY=$VAL"
					else
						echo "[$(date)] [${FUNCNAME[0]}] User provided variable [$KEY = $VAL] failed system variable check! Maintaining original value of [$(echo ${!KEY})]..."
					fi

					break
				fi
			done

			if [ $KEY_IS_SYSTEM_CFG == "false" ]
			then
				if [[ "$VAL" =~ ^\$\( ]] && [[ "$VAL" =~ \)$ ]]
				then
					local PROC_VAL=$(echo "$VAL" | sed 's/^\$(//; s/)$//')
					local CMD=$(echo "$PROC_VAL" | $AWK '{ print $1 }')
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] PROC_VAL = [$PROC_VAL] / CMD = [$CMD]"
					fi

					if [[ $CMD =~ ^/ ]] || [[ $CMD =~ ^./ ]]
					then
						if [ -f "$CMD" ]
						then
							local FINAL_VAL=$(eval "$PROC_VAL")

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Declaring runtime variable [RTVAR_$KEY] with value [$FINAL_VAL]..."
							fi

							eval "RTVAR_$KEY=$FINAL_VAL"
						else
							echo "[$(date)] [${FUNCNAME[0]}] Unable to locate command [$CMD]! Skipping declaration of runtime variable [RTVAR_$KEY]..."
						fi
					else
						if which "$CMD" > /dev/null 2>&1
						then
							local FINAL_VAL=$(eval "$PROC_VAL")

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Declaring runtime variable [RTVAR_$KEY] with value [$FINAL_VAL]..."
							fi

							eval "RTVAR_$KEY=\"$FINAL_VAL\""
						else
							echo "[$(date)] [${FUNCNAME[0]}] Deferring declaration of runtime variable [RTVAR_$KEY] with value [$VAL]..."
	
							if [ $BASH_V4 == "true" ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Adding key [RTVAR_$KEY] with value [$VAL] into DEFER_RTVAR_ARR..."
								fi

								DEFER_RTVAR_ARR[RTVAR_$KEY]="$VAL"
							else
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Adding key [RTVAR_$KEY] with value [$VAL] into DEFER_RTVAR_INFILE [$DEFER_RTVAR_INFILE]..."
								fi

								echo "RTVAR_$KEY" >> $DEFER_RTVAR_INFILE
								echo "$VAL" >> $DEFER_RTVAR_INFILE
							fi
						fi
					fi
				else
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Declaring runtime variable [RTVAR_$KEY] with value [$VAL]..."
					fi

					eval "RTVAR_$KEY=$VAL"
				fi
			fi
		fi
	done	

	IFS=$'\n'
}

checkSysVar()
{
	local SYSVAR_KEY=$1
	local SYSVAR_VAL=$2

	case "$SYSVAR_KEY" in
		OC_CMD)	
			if which "$SYSVAR_VAL" > /dev/null 2>&1
			then
				return 0
			else
				echo "[$(date)] [${FUNCNAME[0]}] Unable to locate OC_CMD [$SYSVAR_VAL] set by user!" >&2
				return 1
			fi
			;;
		*)	return 0 ;;
	esac
}

deferRuntimeVar()
{
	if [ $BASH_V4 == "true" ]
	then
		if [ ${#DEFER_RTVAR_ARR[@]} -gt 0 ]
		then
			# Duplicating stdin, stdout and stderr for subshell to write to
			echo "[$(date)] [${FUNCNAME[0]}] Duplicating stdin(7), stdout(8) and stderr(9) for subshell to write to..." | tee -a $RUNTIME_LOGFILE
			exec 7>&0
			exec 8>&1
			exec 9>&2

			local RTVAR_CTR=0
			
			for KEY in "${!DEFER_RTVAR_ARR[@]}"
			do
				(( RTVAR_CTR=RTVAR_CTR+1 ))

				local VAL=${DEFER_RTVAR_ARR[$KEY]}

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] KEY = [$KEY] / VAL = [$VAL]" | tee -a $RUNTIME_LOGFILE
				fi

				local PROC_VAL=$(echo "$VAL" | sed 's/^\$(//; s/)$//')
				local CMD=$(echo "$PROC_VAL" | $AWK '{ print $1 }')

				if [ $(echo "$PROC_VAL" | $AWK '{ print NF }') -gt 1 ]
				then
					local CMD_PARAM=$(echo "$PROC_VAL" | $AWK '{ $1=""; print }' | sed 's/^[ ]*//')
				else
					local CMD_PARAM=""
				fi
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] PROC_VAL = [$PROC_VAL] / CMD = [$CMD] / CMD_PARAM = [$CMD_PARAM]" | tee -a $RUNTIME_LOGFILE
				fi

				# Check CMD in CMDEXEC dirs
				if [ ${#RTVAR_DEFER_FORCE_DEFAULT} -gt 0 ] && [ ${RTVAR_DEFER_FORCE_DEFAULT} == "true" ]
				then
					local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/cmdexec
					local DEFER_PROD_VERSION=$PRODUCT_VERSION
				else
					# Deferred RTVAR only support single product group for now!
					if [ ${#RTVAR_DEFER_PRODVER} -gt 0 ]
					then
						local DEFER_PRODVER_VALID="false"
		
						for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
						do
							if [ $RTVAR_DEFER_PRODVER == $VALID_PROD_VERSION ]
							then
								local DEFER_PRODVER_VALID="true"
								break
							fi
						done	
		
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] RTVAR_DEFER_PRODVER = [$RTVAR_DEFER_PRODVER] / DEFER_PRODVER_VALID = [$DEFER_PRODVER_VALID]" | tee -a $RUNTIME_LOGFILE
						fi
		
						if [ $DEFER_PRODVER_VALID == "true" ]
						then
							local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/cmdexec/$RTVAR_DEFER_PRODVER
							local DEFER_PROD_VERSION=$RTVAR_DEFER_PRODVER
						else
							local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION
							local DEFER_PROD_VERSION=$PRODUCT_VERSION
						fi
					else
						local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION
						local DEFER_PROD_VERSION=$PRODUCT_VERSION
					fi
				fi

				if [ ! -s $DEFER_DEFAULT_DIR/$CMD ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] CMD [$DEFER_DEFAULT_DIR/$CMD] does not exist or is zero-sized! Proceed to check in directory [$MUSTGATHER_DIRNAME/cmdexec]..." | tee -a $RUNTIME_LOGFILE

					local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/cmdexec

					if [ ! -s $DEFER_DEFAULT_DIR/$CMD ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] CMD [$DEFER_DEFAULT_DIR/$CMD] does not exist or is zero-sized! Skipping declaration of runtime variable [$KEY]..." | tee -a $RUNTIME_LOGFILE
			
						local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/data/cmdexec/$DEFER_PROD_VERSION

						if [ ! -s $DEFER_DEFAULT_DIR/$CMD ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] CMD [$DEFER_DEFAULT_DIR/$CMD] does not exist or is zero-sized! Skipping declaration of runtime variable [$KEY]..." | tee -a $RUNTIME_LOGFILE
			
							local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/data/cmdexec

							if [ ! -s $DEFER_DEFAULT_DIR/$CMD ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] CMD [$DEFER_DEFAULT_DIR/$CMD] does not exist or is zero-sized! Skipping declaration of runtime variable [$KEY]..." | tee -a $RUNTIME_LOGFILE

								continue
							fi
						fi
					fi
				fi

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] DEFER_DEFAULT_DIR = [$DEFER_DEFAULT_DIR]" | tee -a $RUNTIME_LOGFILE
				fi

				if [ ${#CMD_PARAM} -gt 0 ]
				then
					local FINAL_VAL=$(eval "$DEFER_DEFAULT_DIR/$CMD $CMD_PARAM" 2> >(tee -a $RUNTIME_LOGFILE >&2))
				else
					local FINAL_VAL=$(eval "$DEFER_DEFAULT_DIR/$CMD" 2> >(tee -a $RUNTIME_LOGFILE >&2))
				fi

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] Declaring runtime variable [$KEY] with value [$FINAL_VAL]..." | tee -a $RUNTIME_LOGFILE
				fi

				eval "$KEY=\"$FINAL_VAL\""
			done

			echo "[$(date)] [${FUNCNAME[0]}] Closing duplicated stdin(7), stdout(8) and stderr(9)..." | tee -a $RUNTIME_LOGFILE
			exec 7>&-
			exec 8>&-
			exec 9>&-
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] There isn't any deferred runtime variable declaration..." | tee -a $RUNTIME_LOGFILE
			fi
		fi
	else
		if [ -s $DEFER_RTVAR_INFILE ]
		then
			# Duplicating stdin, stdout and stderr for subshell to write to
			echo "[$(date)] [${FUNCNAME[0]}] Duplicating stdin(7), stdout(8) and stderr(9) for subshell to write to..." | tee -a $RUNTIME_LOGFILE
			exec 7>&0
			exec 8>&1
			exec 9>&2

			local RTVAR_CTR=0

			while read KEY
			do
				read VAL	

				(( RTVAR_CTR=RTVAR_CTR+1 ))
					
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] KEY = [$KEY] / VAL = [$VAL]" | tee -a $RUNTIME_LOGFILE
				fi

				local PROC_VAL=$(echo "$VAL" | sed 's/^\$(//; s/)$//')
				local CMD=$(echo "$PROC_VAL" | $AWK '{ print $1 }')

				if [ $(echo "$PROC_VAL" | $AWK '{ print NF }') -gt 1 ]
				then
					local CMD_PARAM=$(echo "$PROC_VAL" | $AWK '{ $1=""; print }' | sed 's/^[ ]*//')
				else
					local CMD_PARAM=""
				fi
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] PROC_VAL = [$PROC_VAL] / CMD = [$CMD] / CMD_PARAM = [$CMD_PARAM]" | tee -a $RUNTIME_LOGFILE
				fi

				# Check CMD in CMDEXEC dirs
				if [ ${#RTVAR_DEFER_FORCE_DEFAULT} -gt 0 ] && [ ${RTVAR_DEFER_FORCE_DEFAULT} == "true" ]
				then
					local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/cmdexec
				else
					# Deferred RTVAR only support single product group for now!
					if [ ${#RTVAR_DEFER_PRODVER} -gt 0 ]
					then
						local DEFER_PRODVER_VALID="false"
		
						for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
						do
							if [ $RTVAR_DEFER_PRODVER == $VALID_PROD_VERSION ]
							then
								local DEFER_PRODVER_VALID="true"
								break
							fi
						done	
		
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] RTVAR_DEFER_PRODVER = [$RTVAR_DEFER_PRODVER] / DEFER_PRODVER_VALID = [$DEFER_PRODVER_VALID]" | tee -a $RUNTIME_LOGFILE
						fi
		
						if [ $DEFER_PRODVER_VALID == "true" ]
						then
							local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/cmdexec/$RTVAR_DEFER_PRODVER
						else
							local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION
						fi
					else
						local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION
					fi
				fi

				if [ ! -s $DEFER_DEFAULT_DIR/$CMD ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] CMD [$DEFER_DEFAULT_DIR/$CMD] does not exist or is zero-sized! Proceed to check in directory [$MUSTGATHER_DIRNAME/cmdexec]..." | tee -a $RUNTIME_LOGFILE

					local DEFER_DEFAULT_DIR=$MUSTGATHER_DIRNAME/cmdexec

					if [ ! -s $DEFER_DEFAULT_DIR/$CMD ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] CMD [$DEFER_DEFAULT_DIR/$CMD] does not exist or is zero-sized! Skipping declaration of runtime variable [$KEY]..." | tee -a $RUNTIME_LOGFILE

						continue
					fi
				fi

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] DEFER_DEFAULT_DIR = [$DEFER_DEFAULT_DIR]" | tee -a $RUNTIME_LOGFILE
				fi

				if [ ${#CMD_PARAM} -gt 0 ]
				then
					local FINAL_VAL=$(eval "$DEFER_DEFAULT_DIR/$CMD $CMD_PARAM" 2> >(tee -a $RUNTIME_LOGFILE >&2))
				else
					local FINAL_VAL=$(eval "$DEFER_DEFAULT_DIR/$CMD" 2> >(tee -a $RUNTIME_LOGFILE >&2))
				fi

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$RTVAR_CTR] Declaring runtime variable [$KEY] with value [$FINAL_VAL]..." | tee -a $RUNTIME_LOGFILE
				fi

				eval "$KEY=\"$FINAL_VAL\""
			done < $DEFER_RTVAR_INFILE

			echo "[$(date)] [${FUNCNAME[0]}] Closing duplicated stdin(7), stdout(8) and stderr(9)..." | tee -a $RUNTIME_LOGFILE
			exec 7>&-
			exec 8>&-
			exec 9>&-

			echo "[$(date)] [${FUNCNAME[0]}] Removing DEFER_RTVAR_INFILE [$DEFER_RTVAR_INFILE]..." | tee -a $RUNTIME_LOGFILE
			rm $DEFER_RTVAR_INFILE
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] There isn't any deferred runtime variable declaration..." | tee -a $RUNTIME_LOGFILE
			fi
		fi
	fi
}

getOcVersion()
{
	local OC_VER_OUTFILE=$1

	if [ ${#OC_VER_OUTFILE} -eq 0 ]
	then
		# local OC_VER_OUTFILE=$CLUSTER_DATA_OUTDIR/oc_version.out
		echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD version' to set CLOUD_PLATFORM_VERSION variable..."

		CLOUD_PLATFORM_VERSION=$($OC_CMD version | grep '^Server Version:' | cut -f 2- -d : | xargs)

		if [[ ${CLOUD_PLATFORM_VERSION} =~ GitVersion ]] && [ $OC_CMD == "kubectl" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD version --short' to set CLOUD_PLATFORM_VERSION variable..."
			CLOUD_PLATFORM_VERSION=$($OC_CMD version --short | grep '^Server Version:' | cut -f 2- -d : | xargs)
		fi

		echo "[$(date)] [${FUNCNAME[0]}] CLOUD_PLATFORM_VERSION = [$CLOUD_PLATFORM_VERSION]"
	else
		if [ ! -d $(dirname $OC_VER_OUTFILE) ]
		then
			mkdir -p $(dirname $OC_VER_OUTFILE)
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD version' => $OC_VER_OUTFILE"
		$OC_CMD version > $OC_VER_OUTFILE 2>&1
	
		echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD version' => $ANALYZE_OUTFILE"
		echo "===================================================" >> $ANALYZE_OUTFILE
		echo "OPENSHIFT VERSION INFO" >> $ANALYZE_OUTFILE
		echo "===================================================" >> $ANALYZE_OUTFILE
		cat $OC_VER_OUTFILE >> $ANALYZE_OUTFILE 
		echo >> $ANALYZE_OUTFILE
	fi
}

getOcWhoAmI()
{
	local OC_WHOAMI_OUTFILE=$1

	if [ ${#OC_WHOAMI_OUTFILE} -eq 0 ]
	then
		local OC_WHOAMI_OUTFILE=$CLUSTER_DATA_OUTDIR/oc_whoami.out
	else
		if [ ! -d $(dirname $OC_WHOAMI_OUTFILE) ]
		then
			mkdir -p $(dirname $OC_WHOAMI_OUTFILE)
		fi
	fi
	
	if [ $OC_CMD == "oc" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD whoami' => $OC_WHOAMI_OUTFILE"
		$OC_CMD whoami > $OC_WHOAMI_OUTFILE 2>&1
	else
		if [ $OC_CMD == "kubectl" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD config current-context | $AWK -F/ '{ print $NF }'' => $OC_WHOAMI_OUTFILE"
			$OC_CMD config current-context | $AWK -F/ '{ print $NF }' > $OC_WHOAMI_OUTFILE 2>&1
		else
			echo "[$(date)] [${FUNCNAME[0]}] Unsupported OC_CMD [$OC_CMD]! Returning..."
			return 1
		fi
	fi

	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "OPENSHIFT WHOAMI & CONTEXT/CLUSTER INFO" >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "[WHOAMI] $(cat $OC_WHOAMI_OUTFILE)" >> $ANALYZE_OUTFILE 
	echo "[CONTEXT] $($OC_CMD config current-context)" >> $ANALYZE_OUTFILE
	echo "[CLUSTER-INFO] $($OC_CMD cluster-info | grep -v '^$' | grep http | head -1 | sed -r 's/\x1B\[([0-9]{1,3}(;[0-9]{1,2};?)?)?[mGK]//g')" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE
}

getOcAdmTopNode()
{
	local OC_TOP_NODE_OUTFILE=$1

	if ! checkUserPriv get,list nodes all
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have verb [get,list] permission on resource [nodes] in all namespaces! Skipping..."
		return 1
	fi

	if [ ${#OC_TOP_NODE_OUTFILE} -eq 0 ]
	then
		local OC_TOP_NODE_OUTFILE=$CLUSTER_DATA_OUTDIR/oc_top_node.out
	else
		if [ ! -d $(dirname $OC_TOP_NODE_OUTFILE) ]
		then
			mkdir -p $(dirname $OC_TOP_NODE_OUTFILE)
		fi
	fi

	if [ $OC_CMD == "oc" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD adm top node --use-protocol-buffers' => $OC_TOP_NODE_OUTFILE"
		$OC_CMD adm top node --use-protocol-buffers > $OC_TOP_NODE_OUTFILE 

		if [ $? -ne 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD adm top node' => $OC_TOP_NODE_OUTFILE"
			$OC_CMD adm top node > $OC_TOP_NODE_OUTFILE 
		fi
	else
		if [ $OC_CMD == "kubectl" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD top node --use-protocol-buffers' => $OC_TOP_NODE_OUTFILE"
			$OC_CMD top node --use-protocol-buffers > $OC_TOP_NODE_OUTFILE

			if [ $? -ne 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD top node' => $OC_TOP_NODE_OUTFILE"
				$OC_CMD top node > $OC_TOP_NODE_OUTFILE 
			fi
		fi
	fi
}

getOcAdmTopMemPod()
{
	local NAMESPACE=$1
	local OC_TOP_MEM_POD_OUTFILE=$2

	if ! checkUserPriv get,list pod $NAMESPACE
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have verb [get,list] permission on resource [pod] in namespace [$NAMESPACE]! Skipping..."
		return 1
	fi

	if [ ! -d $(dirname $OC_TOP_MEM_POD_OUTFILE) ]
	then
		mkdir -p $(dirname $OC_TOP_MEM_POD_OUTFILE)
	fi

	if [ $OC_CMD == "oc" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD adm top pod --sort-by="memory" -n ${NAMESPACE}' => $OC_TOP_MEM_POD_OUTFILE"
		$OC_CMD adm top pod --sort-by='memory' -n ${NAMESPACE} >> $OC_TOP_MEM_POD_OUTFILE 2>&1
	else
		if [ $OC_CMD == "kubectl" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD top pod --sort-by="memory" -n ${NAMESPACE}' => $OC_TOP_MEM_POD_OUTFILE"
			$OC_CMD top pod --sort-by='memory' -n ${NAMESPACE} >> $OC_TOP_MEM_POD_OUTFILE 2>&1
		fi
	fi
}

getOcAdmTopCpuPod()
{
	local NAMESPACE=$1
	local OC_TOP_CPU_POD_OUTFILE=$2

	if [ ! -d $(dirname $OC_TOP_CPU_POD_OUTFILE) ]
	then
		mkdir -p $(dirname $OC_TOP_CPU_POD_OUTFILE)
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD adm top pod --sort-by="cpu" -n ${NAMESPACE}' => $OC_TOP_CPU_POD_OUTFILE"
	$OC_CMD adm top pod --sort-by='cpu' -n ${NAMESPACE} >> $OC_TOP_CPU_POD_OUTFILE 2>&1
}

getPodResourceInfo()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	# IN_FILE is output of "oc adm top pod"
	local NAMESPACE=$1
	local IN_FILE=$2
	local OUT_FILE=$3
	local SORT_BY=$4

	if [ ! -s $IN_FILE ]
	then
		# If IN_FILE does not exist or empty, attempt to create the content
		echo "[$(date)] [${FUNCNAME[0]}] IN_FILE [$IN_FILE] does not exist or is zero-sized! Attempt to create..."
		$OC_CMD adm top pod --sort-by='memory' -n ${NAMESPACE} > $IN_FILE 
	fi

	if [ -s $IN_FILE ]
	then
		if ! checkUserPriv get pod $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'pod' in namespace [$NAMESPACE]!"
			return 1
		fi

		if [ ! -d $(dirname $OUT_FILE) ]
		then
			mkdir -p $(dirname $OUT_FILE)
		fi	

		local TMP_FILE=$(dirname $OUT_FILE)/podrsrc.tmp
		local WORK_FILE=$(dirname $OUT_FILE)/podrsrc.txt

		local TOTAL_CPU=0
		local TOTAL_CPU_REQ=0
		local TOTAL_CPU_LMT=0
		local TOTAL_MEM=0
		local TOTAL_MEM_REQ=0
		local TOTAL_MEM_LMT=0

		local TOTAL_LINE=0

		local COL_WIDTH=12

		local LONGEST_LINE_LEN=$($AWK 'length > max_length { max_length = length; longest_line = $0 } END { print length(longest_line) }' $IN_FILE)
		local EXTENDED_LINE_LEN=$(( $LONGEST_LINE_LEN+$COL_WIDTH+$COL_WIDTH+$COL_WIDTH+$COL_WIDTH+$COL_WIDTH+$COL_WIDTH ))
		IFS=$OLDIFS
		local TMP_FIELDWIDTHS_ARR=( $(head -1 $IN_FILE | grep -E -o '[A-Za-z(\)]+\s*' | $AWK '{printf "%d ", length($0)}' | sed 's/^[ ]*//;s/[ ]*$//') )
		IFS=$'\n'

		# Default length for first 3 columns
		if [ ${#TMP_FIELDWIDTHS_ARR[@]} -eq 0 ]
		then
			TMP_FIELDWIDTHS_ARR[0]=40
			TMP_FIELDWIDTHS_ARR[1]=$COL_WIDTH
			TMP_FIELDWIDTHS_ARR[2]=$COL_WIDTH
		fi
		
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Processing IN_FILE [$IN_FILE]..."
			echo "[$(date)] [${FUNCNAME[0]}] LONGEST_LINE_LEN = [$LONGEST_LINE_LEN]"
			echo "[$(date)] [${FUNCNAME[0]}] EXTENDED_LINE_LEN = [$EXTENDED_LINE_LEN]"
			echo "[$(date)] [${FUNCNAME[0]}] TMP_FIELDWIDTHS_ARR = [${TMP_FIELDWIDTHS_ARR[@]}] [LEN=${#TMP_FIELDWIDTHS_ARR[@]}]"
		fi

		# Create border line
		printf -v border '%*s' $((EXTENDED_LINE_LEN+5)) ''

		# Create CPU and MEMORY request/limit file
		$OC_CMD get pods -n $NAMESPACE -o=jsonpath='{range .items[*]}{.metadata.name}{"##"}{.spec.containers[*].resources.requests.cpu}{"##"}{.spec.containers[*].resources.limits.cpu}{"##"}{.spec.containers[*].resources.requests.memory}{"##"}{.spec.containers[*].resources.limits.memory}{"\n"}{end}' > $WORK_FILE

		if [ ! -s $WORK_FILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] WORK_FILE [$WORK_FILE] does not exist or is zero-sized! Unable to process further..."
			return 1
		fi

		local SORT_BY_COL=

		case $SORT_BY in
			podname)	SORT_BY_COL=1; SORT_BY_ORDER="" ;;
			cpucores)	SORT_BY_COL=2; SORT_BY_ORDER=-r"" ;;
			membytes)	SORT_BY_COL=3; SORT_BY_ORDER=-r"" ;;
			cpureq)	SORT_BY_COL=4; SORT_BY_ORDER=-r"" ;;
			cpulimit)	SORT_BY_COL=5; SORT_BY_ORDER=-r"" ;;
			memreq)	SORT_BY_COL=6; SORT_BY_ORDER=-r"" ;;
			memlimit)	SORT_BY_COL=7; SORT_BY_ORDER=-r"" ;;
			\*)		SORT_BY_COL=1; SORT_BY_ORDER="" ;;
			"")		SORT_BY_COL=1; SORT_BY_ORDER="" ;;
		esac

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] SORT_BY [$SORT_BY] / SORT_BY_COL = [$SORT_BY_COL]"
		fi

		while read LINE
		do
			if [ $MG_DEBUG == "true" ]
			then
				local CUR_LINE_LEN=${#LINE}
				echo "[$(date)] [${FUNCNAME[0]}] CUR_LINE_LEN [$LINE] = [$CUR_LINE_LEN]"
			fi

			if [[ $LINE =~ ^NAME ]]
			then
				local HEADER_LINE=$(echo "$LINE" | sed 's/cores/top/g; s/bytes/top/g; s/MEMORY/MEM/g')

				# Only make this replacement to re-align the columns if strings 'cores' and 'bytes' from the header are replaced with 'top'
				if [[ "$HEADER_LINE" =~ top ]]
				then
					local HEADER_LINE=$(echo "$HEADER_LINE" | sed 's/)/)  /g')
				fi

				if [[ "$HEADER_LINE" =~ MEM\( ]]
				then
					local HEADER_LINE=$(echo "$HEADER_LINE" | sed 's/$/   /')
				fi

				continue
			else
				(( TOTAL_LINE=TOTAL_LINE+1 ))

				if [ $(echo "$LINE" | $AWK '{ print NF }') -eq 3 ]
				then
					local LINE_POD=$(echo "$LINE" | $AWK '{ print $1 }')	
					local LINE_CPU=$(echo "$LINE" | $AWK '{ if ( $2 !~ /m$/ ) { print $2 * 1000 } else { gsub(/m/, "", $2); print $2 } }')	
					local LINE_MEM=$(echo "$LINE" | $AWK '{ if ( $3 ~ /Gi$/ ) { print $3 * 1024 } else { if ( $3 ~ /G$/ ) { print int($3 * 953.674) } else { if ( $3 ~ /M$/ ) { print int($3 * 0.953) } else { gsub(/Mi/, "", $3); print $3 } } } }')	

					(( TOTAL_CPU=TOTAL_CPU+$LINE_CPU ))
					(( TOTAL_MEM=TOTAL_MEM+$LINE_MEM ))

					# MEMORY: Only support Mi and conversion of Gi, G and M to Mi
					local LINE_CPU_REQ=$($AWK -F## '$1 ~ /^'$LINE_POD'$/ { print $2 }' $WORK_FILE | $AWK '{ for (i=1; i<=NF; i++) { if ( $i !~ /m$/ ) { TOTAL=TOTAL+($i*1000) } else { gsub(/m/,"",$i); TOTAL=TOTAL+$i } } } END { print TOTAL }')
					local LINE_CPU_LMT=$($AWK -F## '$1 ~ /^'$LINE_POD'$/ { print $3 }' $WORK_FILE | $AWK '{ for (i=1; i<=NF; i++) { if ( $i !~ /m$/ ) { TOTAL=TOTAL+($i*1000) } else { gsub(/m/,"",$i); TOTAL=TOTAL+$i } } } END { print TOTAL }')
					local LINE_MEM_REQ=$($AWK -F## '$1 ~ /^'$LINE_POD'$/ { print $4 }' $WORK_FILE | $AWK '{ for (i=1; i<=NF; i++) { if ( $i ~ /Gi$/ ) { TOTAL=TOTAL+($i*1024) } else { if ( $i ~ /G$/ ) { TOTAL=TOTAL+int($i*953.674) } else { if ( $i ~ /M$/ ) { TOTAL=TOTAL+int($i*0.953) } else { gsub(/Mi/,"",$i); TOTAL=TOTAL+$i } } } } } END { print TOTAL }')
					local LINE_MEM_LMT=$($AWK -F## '$1 ~ /^'$LINE_POD'$/ { print $5 }' $WORK_FILE | $AWK '{ for (i=1; i<=NF; i++) { if ( $i ~ /Gi$/ ) { TOTAL=TOTAL+($i*1024) } else { if ( $i ~ /G$/ ) { TOTAL=TOTAL+int($i*953.674) } else { if ( $i ~ /M$/ ) { TOTAL=TOTAL+int($i*0.953) } else { gsub(/Mi/,"",$i); TOTAL=TOTAL+$i } } } } } END { print TOTAL }')

					# Usage percentage columns
					if [ ${#LINE_CPU_REQ} -gt 0 ] && [ $LINE_CPU_REQ -gt 0 ]
					then
						local LINE_CPU_PCT=$(echo | $AWK -v CPU_TOP=$(echo "$LINE_CPU" | sed 's/m$//') -v CPU_REQ=$LINE_CPU_REQ '{ printf "%d",CPU_TOP/CPU_REQ*100 }')
					else
						local LINE_CPU_PCT=0
					fi

					if [ ${#LINE_MEM_REQ} -gt 0 ] && [ $LINE_MEM_REQ -gt 0 ]
					then
						local LINE_MEM_PCT=$(echo | $AWK -v MEM_TOP=$(echo "$LINE_MEM" | sed 's/Mi$//') -v MEM_REQ=$LINE_MEM_REQ '{ printf "%d",MEM_TOP/MEM_REQ*100 }')
					else
						local LINE_MEM_PCT=0
					fi

					(( TOTAL_CPU_REQ=TOTAL_CPU_REQ+${LINE_CPU_REQ:=0} ))
					(( TOTAL_CPU_LMT=TOTAL_CPU_LMT+${LINE_CPU_LMT:=0} ))
					(( TOTAL_MEM_REQ=TOTAL_MEM_REQ+${LINE_MEM_REQ:=0} ))
					(( TOTAL_MEM_LMT=TOTAL_MEM_LMT+${LINE_MEM_LMT:=0} ))

					printf "%s%-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s\n" "$LINE" "${LINE_CPU_REQ:=0}m" "${LINE_CPU_LMT:=0}m" "${LINE_CPU_PCT:=0}%" "${LINE_MEM_REQ:=0}Mi" "${LINE_MEM_LMT:=0}Mi" "${LINE_MEM_PCT:=0}%" >> $TMP_FILE

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] MATCHED_LINE = [$($AWK -F## '$1 ~ /^'$LINE_POD'$/ { print }' $WORK_FILE)]"
						echo "[$(date)] [${FUNCNAME[0]}] LINE_CPU = [$LINE_CPU] / LINE_MEM = [$LINE_MEM] / LINE_CPU_REQ = [$LINE_CPU_REQ] / LINE_CPU_LMT = [$LINE_CPU_LMT] / LINE_MEM_REQ = [$LINE_MEM_REQ] / LINE_MEM_LMT = [$LINE_MEM_LMT]"
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] LINE [$LINE] is invalid (not 3 columns)! Skipping..." >&2
					echo "[ERROR] $LINE" >> $TMP_FILE
					continue
				fi
			fi
		done < $IN_FILE	

		if [ ! -s $TMP_FILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] TMP_FILE [$TMP_FILE] does not exist or is zero-sized! Returning..."
			return 1
		else
			local SORT_CMD="sort $SORT_BY_ORDER -n -k$SORT_BY_COL $TMP_FILE"

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Writing output to file [$OUT_FILE]..."
				echo "[$(date)] [${FUNCNAME[0]}] SORT_CMD = [$SORT_CMD]"
			fi

			local TITLE_LINE="POD RESOURCE UTILIZATION REPORT (namespace = $NAMESPACE)"
			printf -v title '%*s' $((${#TITLE_LINE})) ''

			echo "${title// /=}" >> $OUT_FILE
			echo "$TITLE_LINE" >> $OUT_FILE
			echo "${title// /=}" >> $OUT_FILE
			printf "%s%-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s\n" "$HEADER_LINE" "CPU(request)" "CPU(limit)" "CPU(top/req)" "MEM(request)" "MEM(limit)" "MEM(top/req)" >> $OUT_FILE

			eval "$SORT_CMD" >> $OUT_FILE

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Removing TMP_FILE [$TMP_FILE]..."
			fi

			rm $TMP_FILE
		fi	

		echo "${border// /=}" >> $OUT_FILE
		printf "%-$(( TMP_FIELDWIDTHS_ARR[0] ))s%-$(( TMP_FIELDWIDTHS_ARR[1] ))s%-$(( TMP_FIELDWIDTHS_ARR[2] ))s%-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s %-${COL_WIDTH}s\n" "TOTAL ($TOTAL_LINE PODS)" "${TOTAL_CPU}m" "${TOTAL_MEM}Mi" "${TOTAL_CPU_REQ}m" "${TOTAL_CPU_LMT}m" "" "${TOTAL_MEM_REQ}Mi" "${TOTAL_MEM_LMT}Mi" "" >> $OUT_FILE
		echo "${border// /=}" >> $OUT_FILE
		echo >> $OUT_FILE
		echo >> $OUT_FILE

		if [ -f $WORK_FILE ]
		then
			if [ $MG_DEBUG == "true" ]
			then
				if [ ${#MAIN_ROOT_DEBUG_OUTDIR} -gt 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Backing up WORK_FILE [$WORK_FILE] to directory MAIN_ROOT_DEBUG_OUTDIR [$MAIN_ROOT_DEBUG_OUTDIR]..."
					mv $WORK_FILE $MAIN_ROOT_DEBUG_OUTDIR
				fi
			else
				rm $WORK_FILE
			fi
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Input file [$IN_FILE] does not exist or is zero-sized! Returning..."
		return 1
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [NS=$NAMESPACE]"
	fi
}

getOcNode()
{
	local OC_NODE_OUTFILE=$1

	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

	if ! checkUserPriv get node all
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to access cluster nodes data! Skipping..."
		return 1
	fi

	if [ ${#OC_NODE_OUTFILE} -eq 0 ]
	then
		local OC_NODE_OUTFILE=$CLUSTER_DATA_OUTDIR/oc_node.out
	else
		if [ ! -d $(dirname $OC_NODE_OUTFILE) ]
		then
			mkdir -p $(dirname $OC_NODE_OUTFILE)
		fi
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get node -o wide' => $OC_NODE_OUTFILE"
	$OC_CMD get node -o wide > $OC_NODE_OUTFILE 2>&1
}

descNodeSSH()
{
	local NODE=$1
	local NODE_IP=$2

	# IMPORTANT: Not sure whether all OCP cluster (baremetal, AWS, etc) will be SSH passwordless!
	if [ $ADMUSERSET -eq 0 ]
	then	
		if [ $MG_TTY == "false" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [FATAL] SSH administrative USERNAME must be provided through '-u' option in a non-TTY mode!"
			return 1
		fi

		echo "[ECHO] Please enter the administrative USERNAME (eg. core or root) for node [$NODE / $NODE_IP]"
		echo -n ">>> "
		read -t $DEFAULT_USERINPUT_TIMEOUT NODE_ADMIN_USER
		local EXIT_STATUS=$?

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [INFO] EXIT_STATUS = [$EXIT_STATUS]"
		fi

		if [ $EXIT_STATUS -gt 128 ]
		then
			echo
			echo "[$(date)] [${FUNCNAME[0]}] [FATAL] Timeout waiting for user input. Returning..." 
			return 1
		else	
			echo "$NODE_ADMIN_USER" 
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] [INFO] User input admin user = [$NODE_ADMIN_USER]"	
	fi

	# echo "[ECHO] Please enter the PASSWORD for node [$NODE / $NODE_IP]"	
	# read NODE_PASSWORD
	
	if [ ! -d $CLUSTERNODES_OUTDIR ]
	then
		mkdir -p $CLUSTERNODES_OUTDIR
	fi

	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting OS version from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP 'cat /etc/os-release' > $CLUSTERNODES_OUTDIR/$NODE.os-release"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP 'cat /etc/os-release' > $CLUSTERNODES_OUTDIR/$NODE.os-release 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting CPU info from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "cat /proc/cpuinfo" > $CLUSTERNODES_OUTDIR/$NODE.cpuinfo"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "cat /proc/cpuinfo" > $CLUSTERNODES_OUTDIR/$NODE.cpuinfo 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting MEMORY info from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "cat /proc/meminfo" > $CLUSTERNODES_OUTDIR/$NODE.meminfo"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "cat /proc/meminfo" > $CLUSTERNODES_OUTDIR/$NODE.meminfo 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'df -h' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP df -h > $CLUSTERNODES_OUTDIR/$NODE.df"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP df -h > $CLUSTERNODES_OUTDIR/$NODE.df 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'systemctl status kubelet' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP systemctl status kubelet > $CLUSTERNODES_OUTDIR/$NODE.kubelet"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP systemctl status kubelet > $CLUSTERNODES_OUTDIR/$NODE.kubelet 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'dmseg' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP dmesg > $CLUSTERNODES_OUTDIR/$NODE.dmesg"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP dmesg > $CLUSTERNODES_OUTDIR/$NODE.dmesg 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'journalctl -b 1 --no-pager -n $JOURNAL_SIZE' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"journalctl -b 1 --no-pager -n $JOURNAL_SIZE\" > $CLUSTERNODES_OUTDIR/$NODE.journalctl-$JOURNAL_SIZE"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "journalctl -b 1 --no-pager -n $JOURNAL_SIZE" > $CLUSTERNODES_OUTDIR/$NODE.journalctl-$JOURNAL_SIZE 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Determining container runtime from node [$NODE / $NODE_IP]"
	NODE_CONTAINER_RUNTIME_PS=$(ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "ps -ef | grep kubelet | grep container-runtime-endpoint | grep -v 'ps -ef'")
	echo "$NODE_CONTAINER_RUNTIME_PS" >> $CLUSTERNODES_OUTDIR/$NODE.cri
	NODE_CONTAINER_RUNTIME=$(echo "$NODE_CONTAINER_RUNTIME_PS" | $AWK '{ for (i=1; i<NF; i++) { if ($i ~ /container-runtime-endpoint/) { CRI=$i } } } END { if (CRI ~ /crio/) { print "crictl" } else { if ( CRI ~ /docker/) { print "docker" } else { print "unknown" } } }') 
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting '$NODE_CONTAINER_RUNTIME images' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"sudo $NODE_CONTAINER_RUNTIME images\" > $CLUSTERNODES_OUTDIR/$NODE.${NODE_CONTAINER_RUNTIME}-images"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "sudo $NODE_CONTAINER_RUNTIME images" > $CLUSTERNODES_OUTDIR/$NODE.${NODE_CONTAINER_RUNTIME}-images 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting '$NODE_CONTAINER_RUNTIME ps -a' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"sudo $NODE_CONTAINER_RUNTIME ps -a\" > $CLUSTERNODES_OUTDIR/$NODE.${NODE_CONTAINER_RUNTIME}-ps"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "sudo $NODE_CONTAINER_RUNTIME ps -a" > $CLUSTERNODES_OUTDIR/$NODE.${NODE_CONTAINER_RUNTIME}-ps 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'timedatectl' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"timedatectl\" > $CLUSTERNODES_OUTDIR/$NODE.timedatectl"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "timedatectl" > $CLUSTERNODES_OUTDIR/$NODE.timedatectl 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'ps -auxww' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"ps -auxww\" > $CLUSTERNODES_OUTDIR/$NODE.ps"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "ps -auxww" > $CLUSTERNODES_OUTDIR/$NODE.ps 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'ifconfig -a' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"sudo ifconfig -a\" > $CLUSTERNODES_OUTDIR/$NODE.ifconfig"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "sudo ifconfig -a" > $CLUSTERNODES_OUTDIR/$NODE.ifconfig 2>&1
	echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'ls -lR /var/lib/kubelet' from node [$NODE / $NODE_IP]"
	echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"sudo ls -lR /var/lib/kubelet/\" > $CLUSTERNODES_OUTDIR/$NODE.varlib"
	ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "sudo ls -lR /var/lib/kubelet/" > $CLUSTERNODES_OUTDIR/$NODE.varlib 2>&1

	if [ ${IS_SENSITIVE_DATA_ALLOWED} == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'iptables -L -nv --line-number' from node [$NODE / $NODE_IP]"
		echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"sudo iptables -L -nv --line-number\" > $CLUSTERNODES_OUTDIR/$NODE.iptables"
		ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "sudo iptables -L -nv --line-number" > $CLUSTERNODES_OUTDIR/$NODE.iptables 2>&1
		echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'find /etc/cni' from node [$NODE / $NODE_IP]"
		echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"sudo find /etc/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;\" > $CLUSTERNODES_OUTDIR/$NODE.cni"
		ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "sudo find /etc/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;" > $CLUSTERNODES_OUTDIR/$NODE.cni 2>&1
		echo "[$(date)] [${FUNCNAME[0]}] [INFO] Collecting 'find /etc/kubernetes/cni' from node [$NODE / $NODE_IP]"
		echo "[$(date)] [${FUNCNAME[0]}] [CMD] = ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP \"sudo find /etc/kubernetes/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;\" > $CLUSTERNODES_OUTDIR/$NODE.cni"
		ssh $SSHKEY $NODE_ADMIN_USER@$NODE_IP "sudo find /etc/kubernetes/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;" >> $CLUSTERNODES_OUTDIR/$NODE.cni 2>&1
	fi
}


descNodeOcDebug()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	#IMPORTANT: Hard coded 'crictl' as container runtime 

	local NODE=$1
	local NODE_IP=$2
	local DEBUG_COMPLETE=1
	local RETRY=0

	if [ ! -d $CLUSTERNODES_OUTDIR ]
	then
		mkdir -p $CLUSTERNODES_OUTDIR
	fi
	
	while [ $DEBUG_COMPLETE -ne 0 ]
	do
		if [ $RETRY -gt 3 ]
		then
			return 1
		fi
	
    		local TMP_OC_DEBUG_LOG=$CLUSTERNODES_OUTDIR/$NODE.ocdebug.tmp
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] CLOUD_PLATFORM = [$CLOUD_PLATFORM]"
		fi

		if [ ${IS_SENSITIVE_DATA_ALLOWED} == "true" ]
		then
			case "$CLOUD_PLATFORM" in
				ocp|OCP)
						echo "[$(date)] [${FUNCNAME[0]}] Collecting 'cat /etc/os-release', 'cat /proc/cpuinfo', 'cat /proc/meminfo', 'df -h', 'systemctl status kubelet', 'dmesg', 'journalctl -b 1 --no-pager -n $JOURNAL_SIZE', 'iptables -L -nv --line-number', 'iptables -L -nv -t nat --line-number', 'crictl images', 'crictl ps -a', 'ps -auxww', 'ifconfig -a', 'ls -lR /var/lib/kubelet, 'find /etc/cni/ -type f', 'find /etc/kubernetes/cni/ -type f', 'vmstat', 'cat /etc/node-sizing-enabled.env', 'cat /etc/node-sizing.env' from node [$NODE / $NODE_IP]"
			
		    				# Execute commands using '$OC_CMD debug'
						$OC_CMD debug node/$NODE -- chroot /host sh -c "sleep 3; echo '#OS-START'; cat /etc/os-release; echo '#OS-END'; echo '#CPUINFO-START'; cat /proc/cpuinfo; echo '#CPUINFO-END'; echo '#MEMINFO-START'; cat /proc/meminfo; echo '#MEMINFO-END'; echo '#DF-START'; df -h; echo '#DF-END'; echo '#KUBELET-START'; systemctl status kubelet --no-pager -l; echo '#KUBELET-END'; echo '#DMESG-START'; dmesg; echo '#DMESG-END'; echo '#JOURNALCTL-START'; journalctl -b 1 --no-pager -n "$JOURNAL_SIZE"; echo '#JOURNALCTL-END'; echo '#IPTABLES-START'; iptables -L -nv --line-number; echo '#IPTABLES-END'; echo '#NAT-START'; iptables -L -nv -t nat --line-number; echo '#NAT-END'; echo '#CRICTL-IMAGES-START'; crictl images; echo '#CRICTL-IMAGES-END'; echo '#CRICTL-PS-START'; crictl ps -a; echo '#CRICTL-PS-END'; echo '#PS-START'; ps -auxww; echo '#PS-END'; echo '#IFCONFIG-START'; ifconfig -a; echo '#IFCONFIG-END'; echo '#VARLIB-START'; ls -lR /var/lib/kubelet; echo '#VARLIB-END'; echo '#CNI-START'; find /etc/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;; echo ''; find /etc/kubernetes/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;; echo '#CNI-END'; echo '#VMSTAT-START'; vmstat; echo '#VMSTAT-END'; echo '#NODESIZING1-START'; cat /etc/node-sizing-enabled.env; echo; echo '#NODESIZING1-END'; echo '#NODESIZING2-START'; cat /etc/node-sizing.env; echo; echo '#NODESIZING2-END'" > $TMP_OC_DEBUG_LOG
						;;
				k3s|K3S)	
						echo "[$(date)] [${FUNCNAME[0]}] Collecting 'cat /etc/os-release', 'cat /proc/cpuinfo', 'cat /proc/meminfo', 'df -h', 'systemctl status k3s', 'dmesg', 'journalctl -u k3s', 'iptables -L -nv --line-number', 'iptables -L -nv -t nat --line-number', 'crictl images', 'crictl ps -a', 'ps -auxww', 'ifconfig -a', 'ls -lR /var/lib/kubelet, 'find /etc/cni/ -type f', 'find /etc/kubernetes/cni/ -type f', 'vmstat', 'cat /var/log/k3s.log' from node [$NODE / $NODE_IP]"

    							# Execute commands using '$OC_CMD debug'
						$OC_CMD debug -i node/$NODE --image=$KUBECTL_DEBUG_IMAGE -- chroot /host sh -c "sleep 3; echo '#OS-START'; cat /etc/os-release; echo '#OS-END'; echo '#CPUINFO-START'; cat /proc/cpuinfo; echo '#CPUINFO-END'; echo '#MEMINFO-START'; cat /proc/meminfo; echo '#MEMINFO-END'; echo '#DF-START'; df -h; echo '#DF-END'; echo '#KUBELET-START'; systemctl status k3s --no-pager -l; echo '#KUBELET-END'; echo '#DMESG-START'; dmesg; echo '#DMESG-END'; echo '#JOURNALCTL-START'; journalctl -u k3s; echo '#JOURNALCTL-END'; echo '#IPTABLES-START'; iptables -L -nv --line-number; echo '#IPTABLES-END'; echo '#NAT-START'; iptables -L -nv -t nat --line-number; echo '#NAT-END'; echo '#CRICTL-IMAGES-START'; crictl images; echo '#CRICTL-IMAGES-END'; echo '#CRICTL-PS-START'; crictl ps -a; echo '#CRICTL-PS-END'; echo '#PS-START'; ps -auxww; echo '#PS-END'; echo '#IFCONFIG-START'; ifconfig -a; echo '#IFCONFIG-END'; echo '#VARLIB-START'; ls -lR /var/lib/kubelet; echo '#VARLIB-END'; echo '#CNI-START'; find /etc/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;; echo ''; find /etc/kubernetes/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;; echo '#CNI-END'; echo '#VMSTAT-START'; vmstat; echo '#VMSTAT-END'; echo '#K3SLOG-START'; cat /var/log/k3s.log; echo '#K3SLOG-END'" > $TMP_OC_DEBUG_LOG
						;;	
				k8s|K8S)
						echo "[$(date)] [${FUNCNAME[0]}] Collecting 'cat /etc/os-release', 'cat /proc/cpuinfo', 'cat /proc/meminfo', 'df -h', 'systemctl status kubelet', 'dmesg', 'journalctl -b 1 --no-pager -n $JOURNAL_SIZE', 'iptables -L -nv --line-number', 'iptables -L -nv -t nat --line-number', 'crictl images', 'crictl ps -a', 'ps -auxww', 'ifconfig -a', 'ls -lR /var/lib/kubelet, 'find /etc/cni/ -type f', 'find /etc/kubernetes/cni/ -type f', 'vmstat' from node [$NODE / $NODE_IP]"
			
		    				# Execute commands using '$OC_CMD debug'
						$OC_CMD debug -i node/$NODE --image=$KUBECTL_DEBUG_IMAGE -- chroot /host sh -c "sleep 3; echo '#OS-START'; cat /etc/os-release; echo '#OS-END'; echo '#CPUINFO-START'; cat /proc/cpuinfo; echo '#CPUINFO-END'; echo '#MEMINFO-START'; cat /proc/meminfo; echo '#MEMINFO-END'; echo '#DF-START'; df -h; echo '#DF-END'; echo '#KUBELET-START'; systemctl status kubelet --no-pager -l; echo '#KUBELET-END'; echo '#DMESG-START'; dmesg; echo '#DMESG-END'; echo '#JOURNALCTL-START'; journalctl -b 1 --no-pager -n "$JOURNAL_SIZE"; echo '#JOURNALCTL-END'; echo '#IPTABLES-START'; iptables -L -nv --line-number; echo '#IPTABLES-END'; echo '#NAT-START'; iptables -L -nv -t nat --line-number; echo '#NAT-END'; echo '#CRICTL-IMAGES-START'; crictl images; echo '#CRICTL-IMAGES-END'; echo '#CRICTL-PS-START'; crictl ps -a; echo '#CRICTL-PS-END'; echo '#PS-START'; ps -auxww; echo '#PS-END'; echo '#IFCONFIG-START'; ifconfig -a; echo '#IFCONFIG-END'; echo '#VARLIB-START'; ls -lR /var/lib/kubelet; echo '#VARLIB-END'; echo '#CNI-START'; find /etc/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;; echo ''; find /etc/kubernetes/cni/ -type f -exec echo '[{}]' \; -exec cat {} \; -exec echo ''\;; echo '#CNI-END'; echo '#VMSTAT-START'; vmstat; echo '#VMSTAT-END'" > $TMP_OC_DEBUG_LOG
						;;
				*)		echo "[$(date)] [${FUNCNAME[0]}] User provided runtime variable CLOUD_PLATFORM = [$CLOUD_PLATFORM] is not supported! Returning..."
						return 1
						;;
			esac
		else
			case "$CLOUD_PLATFORM" in
				ocp|OCP)
						echo "[$(date)] [${FUNCNAME[0]}] Collecting 'cat /etc/os-release', 'cat /proc/cpuinfo', 'cat /proc/meminfo', 'df -h', 'systemctl status kubelet', 'dmesg', 'journalctl -b 1 --no-pager -n $JOURNAL_SIZE', 'crictl images', 'crictl ps -a', 'ps -auxww', 'ifconfig -a', 'ls -lR /var/lib/kubelet', 'vmstat', 'cat /etc/node-sizing-enabled.env', 'cat /etc/node-sizing.env' from node [$NODE / $NODE_IP]"
			
		    				# Execute commands using '$OC_CMD debug'
						$OC_CMD debug node/$NODE -- chroot /host sh -c "sleep 3; echo '#OS-START'; cat /etc/os-release; echo '#OS-END'; echo '#CPUINFO-START'; cat /proc/cpuinfo; echo '#CPUINFO-END'; echo '#MEMINFO-START'; cat /proc/meminfo; echo '#MEMINFO-END'; echo '#DF-START'; df -h; echo '#DF-END'; echo '#KUBELET-START'; systemctl status kubelet --no-pager -l; echo '#KUBELET-END'; echo '#DMESG-START'; dmesg; echo '#DMESG-END'; echo '#JOURNALCTL-START'; journalctl -b 1 --no-pager -n "$JOURNAL_SIZE"; echo '#JOURNALCTL-END'; echo '#CRICTL-IMAGES-START'; crictl images; echo '#CRICTL-IMAGES-END'; echo '#CRICTL-PS-START'; crictl ps -a; echo '#CRICTL-PS-END'; echo '#PS-START'; ps -auxww; echo '#PS-END'; echo '#IFCONFIG-START'; ifconfig -a; echo '#IFCONFIG-END'; echo '#VARLIB-START'; ls -lR /var/lib/kubelet; echo '#VARLIB-END'; echo '#VMSTAT-START'; vmstat; echo '#VMSTAT-END'; echo '#NODESIZING1-START'; cat /etc/node-sizing-enabled.env; echo; echo '#NODESIZING1-END'; echo '#NODESIZING2-START'; cat /etc/node-sizing.env; echo; echo '#NODESIZING2-END'" > $TMP_OC_DEBUG_LOG
						;;
				k3s|K3S)	
						echo "[$(date)] [${FUNCNAME[0]}] Collecting 'cat /etc/os-release', 'cat /proc/cpuinfo', 'cat /proc/meminfo', 'df -h', 'systemctl status k3s', 'dmesg', 'journalctl -u k3s', 'crictl images', 'crictl ps -a', 'ps -auxww', 'ifconfig -a', 'ls -lR /var/lib/kubelet', 'vmstat', 'cat /var/log/k3s.log' from node [$NODE / $NODE_IP]"

    						# Execute commands using '$OC_CMD debug'
						$OC_CMD debug -i node/$NODE --image=$KUBECTL_DEBUG_IMAGE -- chroot /host sh -c "sleep 3; echo '#OS-START'; cat /etc/os-release; echo '#OS-END'; echo '#CPUINFO-START'; cat /proc/cpuinfo; echo '#CPUINFO-END'; echo '#MEMINFO-START'; cat /proc/meminfo; echo '#MEMINFO-END'; echo '#DF-START'; df -h; echo '#DF-END'; echo '#KUBELET-START'; systemctl status k3s --no-pager -l; echo '#KUBELET-END'; echo '#DMESG-START'; dmesg; echo '#DMESG-END'; echo '#JOURNALCTL-START'; journalctl -u k3s; echo '#JOURNALCTL-END'; echo '#CRICTL-IMAGES-START'; crictl images; echo '#CRICTL-IMAGES-END'; echo '#CRICTL-PS-START'; crictl ps -a; echo '#CRICTL-PS-END'; echo '#PS-START'; ps -auxww; echo '#PS-END'; echo '#IFCONFIG-START'; ifconfig -a; echo '#IFCONFIG-END'; echo '#VARLIB-START'; ls -lR /var/lib/kubelet; echo '#VARLIB-END'; echo '#VMSTAT-START'; vmstat; echo '#VMSTAT-END'; echo '#K3SLOG-START'; cat /var/log/k3s.log; echo '#K3SLOG-END'" > $TMP_OC_DEBUG_LOG
						;;	
				k8s|K8S)
						echo "[$(date)] [${FUNCNAME[0]}] Collecting 'cat /etc/os-release', 'cat /proc/cpuinfo', 'cat /proc/meminfo', 'df -h', 'systemctl status kubelet', 'dmesg', 'journalctl -b 1 --no-pager -n $JOURNAL_SIZE', 'crictl images', 'crictl ps -a', 'ps -auxww', 'ifconfig -a', 'ls -lR /var/lib/kubelet', 'vmstat' from node [$NODE / $NODE_IP]"
			
		    				# Execute commands using '$OC_CMD debug'
						$OC_CMD debug -i node/$NODE --image=$KUBECTL_DEBUG_IMAGE -- chroot /host sh -c "sleep 3; echo '#OS-START'; cat /etc/os-release; echo '#OS-END'; echo '#CPUINFO-START'; cat /proc/cpuinfo; echo '#CPUINFO-END'; echo '#MEMINFO-START'; cat /proc/meminfo; echo '#MEMINFO-END'; echo '#DF-START'; df -h; echo '#DF-END'; echo '#KUBELET-START'; systemctl status kubelet --no-pager -l; echo '#KUBELET-END'; echo '#DMESG-START'; dmesg; echo '#DMESG-END'; echo '#JOURNALCTL-START'; journalctl -b 1 --no-pager -n "$JOURNAL_SIZE"; echo '#JOURNALCTL-END'; echo '#CRICTL-IMAGES-START'; crictl images; echo '#CRICTL-IMAGES-END'; echo '#CRICTL-PS-START'; crictl ps -a; echo '#CRICTL-PS-END'; echo '#PS-START'; ps -auxww; echo '#PS-END'; echo '#IFCONFIG-START'; ifconfig -a; echo '#IFCONFIG-END'; echo '#VARLIB-START'; ls -lR /var/lib/kubelet; echo '#VARLIB-END'; echo '#VMSTAT-START'; vmstat; echo '#VMSTAT-END'" > $TMP_OC_DEBUG_LOG
						;;
				*)		echo "[$(date)] [${FUNCNAME[0]}] User provided runtime variable CLOUD_PLATFORM = [$CLOUD_PLATFORM] is not supported! Returning..."
						return 1
						;;
			esac
		fi

		if [ -s $TMP_OC_DEBUG_LOG ]
		then	
			local DEBUG_COMPLETE=0
		else
			echo "[WARNING] Previous attempt of '$OC_CMD debug' failed. Retrying..."
			(( RETRY=RETRY+1 ))
			sleep $DEFAULT_SLEEP_SEC
		fi
	done

    	#extract command outputs from log file
	case "$CLOUD_PLATFORM" in
		ocp|OCP) 	local JOURNALCTL_OUTPUT_FILE=$CLUSTERNODES_OUTDIR/$NODE.journalctl-$JOURNAL_SIZE
				local KUBELET_OUTPUT_FILE=$CLUSTERNODES_OUTDIR/$NODE.kubelet
				;;	
		k3s|K3S) 	local JOURNALCTL_OUTPUT_FILE=$CLUSTERNODES_OUTDIR/$NODE.journalctl-$CLOUD_PLATFORM
				local KUBELET_OUTPUT_FILE=$CLUSTERNODES_OUTDIR/$NODE.k3s-service
				;;
		k8s|K8S) 	local JOURNALCTL_OUTPUT_FILE=$CLUSTERNODES_OUTDIR/$NODE.journalctl-$CLOUD_PLATFORM
				local KUBELET_OUTPUT_FILE=$CLUSTERNODES_OUTDIR/$NODE.kubelet
				;;
	esac

	$AWK '/^#OS-END/&&--f||f||/^#OS-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.os-release
	$AWK '/^#CPUINFO-END/&&--f||f||/^#CPUINFO-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.cpuinfo
	$AWK '/^#MEMINFO-END/&&--f||f||/^#MEMINFO-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.meminfo
	$AWK '/^#DF-END/&&--f||f||/^#DF-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.df
	$AWK '/^#KUBELET-END/&&--f||f||/^#KUBELET-START/&&f++' $TMP_OC_DEBUG_LOG > $KUBELET_OUTPUT_FILE
	$AWK '/^#DMESG-END/&&--f||f||/^#DMESG-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.dmesg
	$AWK '/^#JOURNALCTL-END/&&--f||f||/^#JOURNALCTL-START/&&f++' $TMP_OC_DEBUG_LOG > $JOURNALCTL_OUTPUT_FILE
	$AWK '/^#CRICTL-IMAGES-END/&&--f||f||/^#CRICTL-IMAGES-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.crictl-images
	$AWK '/^#CRICTL-PS-END/&&--f||f||/^#CRICTL-PS-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.crictl-ps
	# $AWK '/^#TIMEDATECTL-END/&&--f||f||/^#TIMEDATECTL-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.timedatectl
	$AWK '/^#PS-END/&&--f||f||/^#PS-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.ps
	$AWK '/^#IFCONFIG-END/&&--f||f||/^#IFCONFIG-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.ifconfig
	$AWK '/^#VARLIB-END/&&--f||f||/^#VARLIB-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.varlib
	$AWK '/^#VMSTAT-END/&&--f||f||/^#VMSTAT-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.vmstat

	if [ ${IS_SENSITIVE_DATA_ALLOWED} == "true" ]
	then
		$AWK '/^#IPTABLES-END/&&--f||f||/^#IPTABLES-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.iptables-filter
		$AWK '/^#NAT-END/&&--f||f||/^#NAT-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.iptables-nat
		$AWK '/^#CNI-END/&&--f||f||/^#CNI-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.cni
	fi

	case "$CLOUD_PLATFORM" in
		ocp|OCP)	$AWK '/^#NODESIZING1-END/&&--f||f||/^#NODESIZING1-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.nodesizing-enabled
				$AWK '/^#NODESIZING2-END/&&--f||f||/^#NODESIZING2-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.nodesizing
				;;
		k3s|K3S)	$AWK '/^#K3SLOG-END/&&--f||f||/^#K3SLOG-START/&&f++' $TMP_OC_DEBUG_LOG > $CLUSTERNODES_OUTDIR/$NODE.k3slog
				;;
	esac

	if [ $MG_DEBUG == "false" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMP_OC_DEBUG_LOG]..."
		rm $TMP_OC_DEBUG_LOG
	fi

	case "$CLOUD_PLATFORM" in
		k3s|K3S)	# Sleep to wait for debug pod to go into "Completed" state
				echo "[$(date)] [${FUNCNAME[0]}] Sleeping for $DEFAULT_SLEEP_SEC seconds to wait for debug pod to complete...."
				sleep $DEFAULT_SLEEP_SEC				

				local CUR_NS=$($OC_CMD config view --minify -o jsonpath='{..namespace}')
				local KUBECTL_DEBUG_POD=$(getResourceInstances "pod" "node-debugger-$NODE" "$CUR_NS" "Succeeded")

				for DEBUG_POD in $KUBECTL_DEBUG_POD
				do
					echo "[$(date)] [${FUNCNAME[0]}] Deleting debug pod [$DEBUG_POD]..."
					$OC_CMD delete pod $DEBUG_POD --now -n $CUR_NS
				done

				;;
		k8s|K8S)	#TODO ;;
	esac

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" ""
	fi
}

descNode()
{
	if isRestrictedData "node"
	then
		echo "[$(date)] [${FUNCNAME[0]}] Resource type [node] is restricteded! Returning..."
		return 1
	fi

	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local F_OUTDIR=$1

	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

	if ! checkUserPriv get node all
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to access cluster nodes data! Skipping..."
		return 1
	fi

	if [ ${#F_OUTDIR} -eq 0 ]
	then
		local F_OUTDIR=$CLUSTER_DATA_OUTDIR/nodes
	fi

	if [ ! -d $F_OUTDIR ]
	then
		mkdir -p $F_OUTDIR
	fi

	local TOTAL_NODES=$($OC_CMD get node | grep -v '^NAME' | wc -l)	
	local TOTAL_NOTREADY_NODE=0
	local NODE_LINE=

	IFS=$'\n'

	local TMP_WORKFILE=$CLUSTER_DATA_OUTDIR/nodes/oc_nodes.out
	$OC_CMD get node -o wide > $TMP_WORKFILE

	if [ -s $TMP_WORKFILE ]
	then
		if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ]
		then
			local TO_PROCEED_YAML="false"
			local TO_PROCEED_JSON="false"
	
			if isSensitiveData "node"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] descNode() function does not support '$OC_CMD get -o yaml/json' of [node] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [node]!"
					local TO_PROCEED_YAML="true"
					local TO_PROCEED_JSON="true"
				fi
			else
				local TO_PROCEED_YAML="true"
				local TO_PROCEED_JSON="true"
			fi
		fi

		for NODE_LINE in $(grep -v '^NAME' $TMP_WORKFILE)
		do
			local NODE=$(echo "$NODE_LINE" | $AWK '{ print $1 }')
			local NODE_IP=$(echo "$NODE_LINE" | $AWK '{ print $6 }')
			local NODE_STATUS=$(echo "$NODE_LINE" | $AWK '{ print tolower($2) }')
	
			if [ $OC_DESC_ON == "true" ] || [ $REPORT_ON_SCREEN == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe node $NODE' => $F_OUTDIR/$NODE.desc"
				$OC_CMD describe node $NODE > $F_OUTDIR/$NODE.desc 2>&1
			fi
	
			if [ $COLLECT_YAML == "true" ]
			then
				if [ $TO_PROCEED_YAML == "true" ]
				then
					if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields node $NODE' => $F_OUTDIR/$NODE.yaml"
						$OC_CMD get -o yaml --show-managed-fields node $NODE > $F_OUTDIR/$NODE.yaml 2>&1
					else
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml node $NODE' => $F_OUTDIR/$NODE.yaml"
						$OC_CMD get -o yaml node $NODE > $F_OUTDIR/$NODE.yaml 2>&1
					fi
				fi
			fi
	
			if [ $COLLECT_JSON == "true" ]
			then
				if [ $TO_PROCEED_JSON == "true" ]
				then
					if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields node $NODE' => $F_OUTDIR/$NODE.json"
						$OC_CMD get -o json --show-managed-fields node $NODE > $F_OUTDIR/$NODE.json 2>&1
					else
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json node $NODE' => $F_OUTDIR/$NODE.json"
						$OC_CMD get -o json node $NODE > $F_OUTDIR/$NODE.json 2>&1
					fi
				fi
			fi
		done

		rm $TMP_WORKFILE

		if [ $TOTAL_NODES -eq $TOTAL_NOTREADY_NODE ]
		then
			ALL_NODES_ONLINE="false"
			echo "[$(date)] [${FUNCNAME[0]}] All cluster nodes are not ready or offline! Exiting..."
			cleanUpDataDir	
			exit 1
		fi
	else
		CAN_I_GET_NODES=$($OC_CMD auth can-i get node --all-namespaces)

		if [ $CAN_I_GET_NODES == "yes" ]
		then
			ALL_NODES_ONLINE="false"
			echo "[$(date)] [${FUNCNAME[0]}] Unable to obtain nodes data. Exiting..."
			cleanUpDataDir
			exit 1
		else
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI)] has not privilege to get/list nodes. Skipping..."
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" ""
	fi
}

getNodesData()
{
	if [ $GET_NODES_DATA == "true" ]
	then	
		IFS=$'\n'

		for NODE_LINE in $($OC_CMD get node -o wide --no-headers)
		do
			local NODE=$(echo "$NODE_LINE" | $AWK '{ print $1 }')
			local NODE_IP=$(echo "$NODE_LINE" | $AWK '{ print $6 }')
			local NODE_STATUS=$(echo "$NODE_LINE" | $AWK '{ print tolower($2) }')
	
			if [[ $NODE_STATUS =~ "notready" ]]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Node [$NODE / $NODE_IP] is in '$NODE_STATUS' state! Skipping..."
				(( TOTAL_NOTREADY_NODE=TOTAL_NOTREADY_NODE+1 ))
				continue
			fi
	
			echo "[$(date)] [${FUNCNAME[0]}] Collecting system information from node [$NODE / $NODE_IP]"
	
			if [ $USE_OC_DEBUG -eq 1 ]
			then	
				case "$CLOUD_PLATFORM" in
					ocp|OCP)	descNodeOcDebug $NODE $NODE_IP ;;
					k3s|K3S)	
							case "$OC_CMD" in
								oc)		echo "[$(date)] [${FUNCNAME[0]}] ERROR: Unable to execute "$OC_CMD debug" on a k3s platform! Skipping..."
										continue
										;;	
								kubectl)
										if [ ${#KUBECTL_DEBUG_IMAGE} -eq 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] ERROR: KUBECTL_DEBUG_IMAGE cannot be empty/null! Skipping..."
											continue
										else
											descNodeOcDebug $NODE $NODE_IP 
										fi
										;;
							esac
							;;
					*)
							echo "[$(date)] [${FUNCNAME[0]}] [$NODE / $NODE_IP] OC_CMD = [$OC_CMD]. Command 'oc debug' is not supported on non-Openshift platform. Failing back to SSH..." 
							USE_OC_DEBUG=0
							descNodeSSH $NODE $NODE_IP
							;;
				esac
			else
				descNodeSSH $NODE $NODE_IP
			fi
		done
	else
		echo "[$(date)] [${FUNCNAME[0]}] GET_NODES_DATA [-d] is set to [$GET_NODES_DATA]! Skipping..."
	fi
}

analyzeOcNode()
{
	if isRestrictedData "node" 
	then
		echo "[$(date)] [${FUNCNAME[0]}] Resource type [node] is restricteded! Returning..."
		return 1
	fi

	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local OC_NODE_OUTFILE=$1
	local OC_TOP_NODE_OUTFILE=$2

	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

	# User privilege check
	if ! checkUserPriv get node all
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to access cluster nodes data! Skipping..."
		return 1
	fi

	if [ ${#OC_NODE_OUTFILE} -eq 0 ]
	then
		local OC_NODE_OUTFILE=$CLUSTER_DATA_OUTDIR/oc_node.out
	fi

	if [ ! -d $(dirname $OC_NODE_OUTFILE) ]
	then
		mkdir -p $(dirname $OC_NODE_OUTFILE)
	fi

	if [ ${#OC_TOP_NODE_OUTFILE} -eq 0 ]
	then
		local OC_TOP_NODE_OUTFILE=$CLUSTER_DATA_OUTDIR/oc_top_node.out
	fi

	if [ ! -d $(dirname $OC_TOP_NODE_OUTFILE) ]
	then
		mkdir -p $(dirname $OC_TOP_NODE_OUTFILE)
	fi

	# Prereqs
	if [ ! -f $OC_NODE_OUTFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] OC_NODE_OUTFILE [$OC_NODE_OUTFILE] does not exist or is zero-sized! Executing '$OC_CMD get node -o wide => $OC_NODE_OUTFILE'..."	
		$OC_CMD get node -o wide > $OC_NODE_OUTFILE
	fi

	if [ ! -f $OC_TOP_NODE_OUTFILE ]
	then
		if [ $OC_CMD == "oc" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] OC_TOP_NODE_OUTFILE [$OC_TOP_NODE_OUTFILE] does not exist or is zero-sized! Executing '$OC_CMD adm top node --use-protocol-buffers => $OC_TOP_NODE_OUTFILE'..."	
			$OC_CMD adm top node --use-protocol-buffers > $OC_TOP_NODE_OUTFILE	

			if [ $? -ne 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD adm top node' => $OC_TOP_NODE_OUTFILE"
				$OC_CMD adm top node > $OC_TOP_NODE_OUTFILE 
			fi
		else
			if [ $OC_CMD == "kubectl" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] OC_TOP_NODE_OUTFILE [$OC_TOP_NODE_OUTFILE] does not exist or is zero-sized! Executing '$OC_CMD top node --use-protocol-buffers => $OC_TOP_NODE_OUTFILE'..."	
				$OC_CMD top node --use-protocol-buffers > $OC_TOP_NODE_OUTFILE	

				if [ $? -ne 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD top node' => $OC_TOP_NODE_OUTFILE"
					$OC_CMD top node > $OC_TOP_NODE_OUTFILE 
				fi
			fi
		fi
	fi
	
	local CPU_WORKFILE=$CLUSTER_DATA_OUTDIR/oc_node.cpu
	local MEM_WORKFILE=$CLUSTER_DATA_OUTDIR/oc_node.mem

	local TOTAL_CPU=0
	local TOTAL_MEM=0

	local TOTALCTR=0
	local BADCTR=0
	local GOODCTR=0
	local WARNCTR=0

	local NODE_LINE=

	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "HEALTH REPORT OF NODES" >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing '$OC_CMD get node -o wide' => $OC_NODE_OUTFILE"

	if [ -s $OC_NODE_OUTFILE ]
	then
		printf "%-60s %-12s %-32s %-18s %-32s %-8s %-20s %-35s \n" "NODENAME" "CPU_COUNT" "CPU_USAGE" "MEM_SIZE" "MEM_USAGE" "AGE" "ROLES" "STATUS" >> $ANALYZE_OUTFILE		

		IFS=$'\n'

		for NODE_LINE in $(grep -v '^NAME' $OC_NODE_OUTFILE)
		do
			local NODENAME=$(echo "$NODE_LINE" | $AWK '{ print $1 }')
			local STATUS=$(echo "$NODE_LINE" | $AWK '{ print $2 }')
			local ROLES=$(echo "$NODE_LINE" | $AWK '{ print $3 }')
			local AGE=$(echo "$NODE_LINE" | $AWK '{ print $4 }')
			local CPU_COUNT=$($OC_CMD get node $NODENAME -o=jsonpath='{.status.capacity.cpu}')
			local MEM_SIZE=$($OC_CMD get node $NODENAME -o=jsonpath='{.status.capacity.memory}')

			if [ ${#CPU_COUNT} -gt 0 ] && [[ $CPU_COUNT =~ ^[0-9]+$ ]]
			then
				(( TOTAL_CPU=TOTAL_CPU+CPU_COUNT ))
			fi
	
			if [ ${#MEM_SIZE} -gt -0 ] && [[ $MEM_SIZE =~ ^[0-9]+ ]]
			then
				local MEM_VAL=$(echo "$MEM_SIZE" | tr -dc '0-9')
				
				if [ ${#MEM_VAL} -gt 0 ] && [[ $MEM_VAL =~ ^[0-9]+$ ]]
				then
					(( TOTAL_MEM=TOTAL_MEM+MEM_VAL ))
				fi
			fi
	
			if [ -s $OC_TOP_NODE_OUTFILE ]
			then
				local TOP_LINE=$($AWK '$1 ~ /^'$NODENAME'$/' $OC_TOP_NODE_OUTFILE)
		
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] TOP_LINE = [$TOP_LINE]"
				fi
	
				local CPU_TOP=$(echo "$TOP_LINE" | $AWK '{ print $3 }' 2> /dev/null)
				local MEM_TOP=$(echo "$TOP_LINE" | $AWK '{ print $5 }' 2> /dev/null) 
	
				if [ ${#CPU_TOP} -gt 0 ] && [[ ${CPU_TOP} =~ ^[0-9] ]]
				then
					local CPU_TOP="top=$CPU_TOP"
				else
					local CPU_TOP="top=N/A"	
				fi
	
				if [ ${#MEM_TOP} -gt 0 ] && [[ ${MEM_TOP} =~ ^[0-9] ]]
				then
					local MEM_TOP="top=$MEM_TOP"
				else
					local MEM_TOP="top=N/A"
				fi
			fi
	
			if [ ! -f $CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc ]
			then
				if [ ! -d $CLUSTER_DATA_OUTDIR/nodes ]
				then
					mkdir -p $CLUSTER_DATA_OUTDIR/nodes
				fi
	
				echo "[$(date)] [${FUNCNAME[0]}] File [$CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc] does not exist or is zero-sized! Executing '$OC_CMD describe node $NODENAME => $CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc'..."
				$OC_CMD describe node $NODENAME > $CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc
			fi
	
			if [ -s $CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc ]
			then
				local CPU_REQ=$(grep -A 2 -e "Resource.*Requests.*Limits" $CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc | grep -E "^[ ]*cpu[ ]+" | $AWK '{ print $3 }' | sed 's/[()]//g')
				local CPU_LIMIT=$(grep -A 2 -e "Resource.*Requests.*Limits" $CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc | grep -E "^[ ]*cpu[ ]+" | $AWK '{ print $5 }' | sed 's/[()]//g')
	
				local MEM_REQ=$(grep -A 3 -e "Resource.*Requests.*Limits" $CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc | grep -E "^[ ]*memory[ ]+" | $AWK '{ print $3 }' | sed 's/[()]//g')
				local MEM_LIMIT=$(grep -A 3 -e "Resource.*Requests.*Limits" $CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc | grep -E "^[ ]*memory[ ]+" | $AWK '{ print $5 }' | sed 's/[()]//g')
	
	
				if [ ${#CPU_REQ} -gt 0 ] && [[ ${CPU_REQ} =~ ^[0-9] ]]
				then
					local CPU_REQ="req=$CPU_REQ"
				else
					local CPU_REQ="req=N/A"
				fi
	
				if [ ${#CPU_LIMIT} -gt 0 ] && [[ ${CPU_LIMIT} =~ ^[0-9] ]]
				then
					local CPU_LIMIT="limit=$CPU_LIMIT"
				else
					local CPU_LIMIT="limit=N/A"
				fi
	
				if [ ${#MEM_REQ} -gt 0 ] && [[ ${MEM_REQ} =~ ^[0-9] ]]
				then
					local MEM_REQ="req=$MEM_REQ"
				else
					local MEM_REQ="req=N/A"
				fi
	
				if [ ${#MEM_LIMIT} -gt 0 ] && [[ ${MEM_LIMIT} =~ ^[0-9] ]]
				then
					local MEM_LIMIT="limit=$MEM_LIMIT"
				else
					local MEM_LIMIT="limit=N/A"
				fi
	
				if [ $CPU_REQ != "req=N/A" ]
				then
					if [ $(echo "$CPU_REQ" | sed 's/^req=//' | sed 's/%$//') -ge $CPU_WARNING ]
					then
						echo "${NODENAME}: ${CPU_REQ}" >> $CPU_WORKFILE
					fi
				fi
	
				if [ $MEM_REQ != "req=N/A" ]
				then
					if [ $(echo "$MEM_REQ" | sed 's/^req=//' | sed 's/%$//') -ge $MEM_WARNING ]
					then
						echo "${NODENAME}: ${MEM_REQ}" >> $MEM_WORKFILE
					fi
				fi
	
				if [ $VIEW_ONLY == "true" ]
				then
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [VIEW-ONLY] Deleting temporary node data files [$CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc]..."
					fi
					
					rm $CLUSTER_DATA_OUTDIR/nodes/$NODENAME.desc
				fi
			else
				local CPU_REQ="req=N/A"
				local CPU_LIMIT="limit=N/A"
				local MEM_REQ="req=N/A"
				local MEM_LIMIT="limit=N/A"
			fi
	
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$NODENAME] CPU_TOP=[$CPU_TOP] / CPU_REQ=[$CPU_REQ] / CPU_LIMIT=[$CPU_LIMIT]"
				echo "[$(date)] [${FUNCNAME[0]}] [$NODENAME] MEM_TOP=[$MEM_TOP] / MEM_REQ=[$MEM_REQ] / MEM_LIMIT=[$MEM_LIMIT]"
			fi
	
			local CPU_USAGE="$CPU_TOP $CPU_REQ $CPU_LIMIT"
			local MEM_USAGE="$MEM_TOP $MEM_REQ $MEM_LIMIT"
	
			printf "%-60s %-12s %-32s %-18s %-32s %-8s %-20s %-35s \n" $NODENAME $CPU_COUNT $CPU_USAGE $MEM_SIZE $MEM_USAGE $AGE $ROLES $STATUS >> $ANALYZE_OUTFILE
		done	
	
		# ASSUMPTION: k8s will always show memory in Ki (kibibyte)
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] TOTAL_MEM = [${TOTAL_MEM}Ki]"
		fi
	
		# Convert memory from Ki (kibibyte) to GB (gigabyte) or MB (megabyte)
		if [ ${#TOTAL_MEM} -gt 0 ] && [[ $TOTAL_MEM =~ ^[0-9]+$ ]]
		then
			if [ ${TOTAL_MEM} -ge 976563 ]
			then
				TOTAL_MEM=$(echo "$TOTAL_MEM" | $AWK '{$1=$1*0.000001024;printf "%.2fGB",$1}')
			else
				TOTAL_MEM=$(echo "$TOTAL_MEM" | $AWK '{$1=$1*0.001024;printf "%.2fMB",$1}')
			fi	
		fi
	
		echo "-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------" >> $ANALYZE_OUTFILE
		printf "%-60s %-12s %-32s %-18s %-32s %-8s %-20s %-35s \n" "TOTAL" $TOTAL_CPU "" $TOTAL_MEM "" "" "" "" >> $ANALYZE_OUTFILE
		echo "-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------" >> $ANALYZE_OUTFILE
		echo >> $ANALYZE_OUTFILE
	
		for NODE_LINE in $(sed '1d' $OC_NODE_OUTFILE)
		do
			(( TOTALCTR=TOTALCTR+1 ))
	
			local NODE=$(echo "$NODE_LINE" | $AWK '{ print $1 }')
			local N_STATUS=$(echo "$NODE_LINE" | $AWK '{ print $2 }')
		
			if [ $N_STATUS != "Ready" ] 
			then	
				if [ $INCIDENT_REPORT_ENABLED == "true" ]
				then
					setIncident "ocp" "$NODE" "oc_get_node" "RESOURCE_TYPE=node" "$NODE_LINE"
				fi
	
				if [[ $N_STATUS =~ ^Ready, ]]
				then
					(( WARNCTR=WARNCTR+1 ))
					echo "[WARN #${WARNCTR}] [NODENAME = $NODE] [STATUS = $N_STATUS]" >> $ANALYZE_OUTFILE
				else	
					(( BADCTR=BADCTR+1 ))
					echo "[BAD #${BADCTR}] [NODENAME = $NODE] [STATUS = $N_STATUS]" >> $ANALYZE_OUTFILE
				fi
	
				if [ $OC_DESC_ON == "true" ]
				then
					$AWK '/^Events:/{f=1}f' $CLUSTER_DATA_OUTDIR/nodes/$NODE.desc | sed '/^[ \t]*$/d' >> $ANALYZE_OUTFILE 2>&1
				else
					$OC_CMD describe node $NODE | $AWK '/^Events:/{f=1}f' | sed '/^[ \t]*$/d' >> $ANALYZE_OUTFILE 2>&1
				fi
	
				echo >> $ANALYZE_OUTFILE
	
				if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" ) && ! -d $ANALYZE_OUTDIR/nodes ]]
				then
					mkdir -p $ANALYZE_OUTDIR/nodes
				fi
	
				if [ $OC_DESC_ON == "true" ] && [ -s $CLUSTER_DATA_OUTDIR/nodes/$NODE.desc ]
				then
					cp -p $CLUSTER_DATA_OUTDIR/nodes/$NODE.desc $ANALYZE_OUTDIR/nodes
				fi
	
				if [ $COLLECT_YAML == "true" ] && [ -s $CLUSTER_DATA_OUTDIR/nodes/$NODE.yaml ]
				then
					cp -p $CLUSTER_DATA_OUTDIR/nodes/$NODE.yaml $ANALYZE_OUTDIR/nodes
				fi
	
				if [ $COLLECT_JSON == "true" ] && [ -s $CLUSTER_DATA_OUTDIR/nodes/$NODE.json ]
				then
					cp -p $CLUSTER_DATA_OUTDIR/nodes/$NODE.json $ANALYZE_OUTDIR/nodes
				fi
			else
				(( GOODCTR=GOODCTR+1 ))
			fi
		done
	
		if [ $BADCTR -eq 0 ] && [ $WARNCTR -eq 0 ]
		then
			echo ">>> [TOTAL OK] Running = $GOODCTR" >> $ANALYZE_OUTFILE
		else
			echo ">>> [TOTAL OK] Node = $GOODCTR" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL NOK] Node = $BADCTR" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL WARN] Node = $WARNCTR" >> $ANALYZE_OUTFILE
		fi
	
		echo ">>> [GRAND TOTAL] Node = $TOTALCTR" >> $ANALYZE_OUTFILE
	
		if [ -s $CPU_WORKFILE ]
		then
			echo ">>> [CPU WARNING >=${CPU_WARNING}%]" >> $ANALYZE_OUTFILE
			cat $CPU_WORKFILE >> $ANALYZE_OUTFILE
	
			rm $CPU_WORKFILE
		fi
	 
		if [ -s $MEM_WORKFILE ]
		then
			echo ">>> [MEM WARNING >=${MEM_WARNING}%]" >> $ANALYZE_OUTFILE
			cat $MEM_WORKFILE >> $ANALYZE_OUTFILE
	
			rm $MEM_WORKFILE
		fi
	 
		if [ $BADCTR -eq 0 ] && [ $WARNCTR -eq 0 ]
		then
			echo "[$(date)] All nodes are up and running!" >> $ANALYZE_OUTFILE
		fi
	
		echo >> $ANALYZE_OUTFILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] OC_NODE_OUTFILE [$OC_NODE_OUTFILE] does not exist or is zero-sized! Exiting..."
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" ""
	fi
}

getEtcd()
{
	if [ ${#RTVAR_DISABLE_ETCD_DATA} -gt 0 ] && [ ${RTVAR_DISABLE_ETCD_DATA} == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] DISABLE_ETCD_DATA is set to [${RTVAR_DISABLE_ETCD_DATA}]! Not collecting etcd data! Returning..."
		return 1
	fi

	local F_OUTDIR=$1
	local ETCD_POD=
	
	case "$CLOUD_PLATFORM" in
		ocp|OCP)
				if [ ${#F_OUTDIR} -eq 0 ]
				then
					local F_OUTDIR=$CLUSTER_DATA_OUTDIR/etcd
				fi
				
				echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
				
				if ! checkUserPriv create pods/exec openshift-etcd
				then
					echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD exec' in namespace [openshift-etcd]. Skipping..."
					return 1
				fi
				
				if [ ! -d $F_OUTDIR ]
				then
					mkdir -p $F_OUTDIR
				fi
				
				IFS=$'\n'
				
				for ETCD_POD in $($OC_CMD get pods -n openshift-etcd -l app=etcd --no-headers | $AWK '{ print $1 }')
				do
					echo "[$(date)] [${FUNCNAME[0]}] Collecting etcd information from pod [$ETCD_POD]"
					$OC_CMD exec -n openshift-etcd ${ETCD_POD} -c etcd --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- etcdctl member list >> $F_OUTDIR/$ETCD_POD.member 2>&1
					$OC_CMD exec -n openshift-etcd ${ETCD_POD} -c etcd --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- etcdctl endpoint health >> $F_OUTDIR/$ETCD_POD.health 2>&1
					$OC_CMD exec -n openshift-etcd ${ETCD_POD} -c etcd --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- etcdctl --write-out=table endpoint status >> $F_OUTDIR/$ETCD_POD.status 2>&1
					$OC_CMD exec -n openshift-etcd ${ETCD_POD} -c etcdctl --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- sh -c 'curl --cert $ETCDCTL_CERT --key $ETCDCTL_KEY --cacert $ETCDCTL_CACERT https://localhost:2379/metrics' >> $F_OUTDIR/$ETCD_POD.metrics
				done
				;;
		k3s|K3S)
				echo "[$(date)] [${FUNCNAME[0]}] ETCD data collection is not supported on CLOUD_PLATFORM [$CLOUD_PLATFORM]! Returning..."
				return 1
				;;		
		k8s|K8S)
				echo "[$(date)] [${FUNCNAME[0]}] ETCD data collection is not supported on CLOUD_PLATFORM [$CLOUD_PLATFORM]! Returning..."
				return 1
				;;		
	esac
}

getOcAll()
{
	local NAMESPACE=$1
	local OC_ALL_OUTFILE=$2
	
	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
	if ! checkUserPriv get,list all $NAMESPACE
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for all resources in namespace [$NAMESPACE]. Checking privilege for main resources..."
	
		# Checking RBAC for main 'oc get all' resources
		if ! checkUserPriv get,list pod $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'pod' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
		
		if ! checkUserPriv get,list deployment $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'deployment' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list statefulset $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'statefulset' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list service $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'service' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list job $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'job' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	fi
	
	if [ ! -d $(dirname $OC_ALL_OUTFILE) ]
	then
		mkdir -p $(dirname $OC_ALL_OUTFILE)
	fi
	
	echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get all -o wide -n $NAMESPACE' => $OC_ALL_OUTFILE"
	$OC_CMD get all -o wide -n $NAMESPACE > $OC_ALL_OUTFILE 2>&1
}

descAll()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local NAMESPACE=$1
	local OC_ALL_INFILE=$2
	local F_OUTDIR=$3
	local EXCL_OBJ_LIST=$4
	
	if [ $OC_DESC_ON == "false" ] && [ $COLLECT_YAML == "false" ] && [ $COLLECT_JSON == "false" ] && [ $GET_POD_LOGS == "false" ]
	then
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] '$OC_CMD describe', '$OC_CMD get -o yaml' and '$OC_CMD logs' are all disabled. Returning..."
		fi
	
		return 1
	fi
	
	if [ ! -s $OC_ALL_INFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Input file [$OC_ALL_INFILE] does not exist or zero-sized. Skipping..."
		return 1
	fi
		
	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
	if ! checkUserPriv get,list all $NAMESPACE
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for all resources in namespace [$NAMESPACE]. Checking privilege for main resources..."
	
		# Checking RBAC for main 'oc get all' resources
		if ! checkUserPriv get,list pod $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'pod' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
		
		if ! checkUserPriv get,list deployment $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'deployment' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list statefulset $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'statefulset' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list service $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'service' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
		
		if ! checkUserPriv get,list job $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'job' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	fi
		
	local JOB_PODS=()
	local JOB_WITHOUT_POD_ARR=()
	local JOB_WITH_SINGLE_POD_ARR=()
	local JOB_WITH_MULTI_POD_ARR=()
	local TO_SKIP_POD="false"
	local JOB_WITHOUT_POD=0
	local TOTAL_JOB=0
	
	local POD_SCC_OUTFILE=$F_OUTDIR/oc_pod_scc.out
	local LINE=
	local EXCLOBJ=
	
	IFS=$'\n'
	
	local JOB_OC_APIVERSION_NAME=$(getApiVersionName job.batch)
	local JOB_OC_API_KIND=$(getApiKind job.batch)
	local POD_OC_APIVERSION_NAME=$(getApiVersionName pod)
	local POD_OC_API_KIND=$(getApiKind pod)
	
	local FAST_OC_DESC_WORKFILE=$F_OUTDIR/fast_oc_desc_restype.tmp
	local FAST_OC_DESC_FOR_JOBS="true"
	local FAST_OC_YAML_WORKFILE=$F_OUTDIR/fast_oc_yaml_restype.tmp
	local FAST_OC_YAML_FOR_JOBS="true"

	# Give priority to JOBS to avoid missing data due to frequently executing jobs
	local IS_JOB_RESTRICTED="false"
	local IS_POD_RESTRICTED="false"

	if isRestrictedData "job.batch"
	then
		local IS_JOB_RESTRICTED="true"
		local TO_PROCEED_JOB_DESC="false"
		local TO_PROCEED_JOB_YAML="false"
		local TO_PROCEED_JOB_JSON="false"
	else
		local TO_PROCEED_JOB_DESC="true"

		if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ]
		then
			local TO_PROCEED_JOB_YAML="false"
			local TO_PROCEED_JOB_JSON="false"
	
			if isSensitiveData "job.batch"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] descAll() function does not support '$OC_CMD get -o yaml/json' of [job.batch] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [job.batch]!"
					local TO_PROCEED_JOB_YAML="true"
					local TO_PROCEED_JOB_JSON="true"
				fi
			else
				local TO_PROCEED_JOB_YAML="true"
				local TO_PROCEED_JOB_JSON="true"
			fi
		fi
	fi
	
	if isRestrictedData "pod"
	then
		local IS_POD_RESTRICTED="true"
		local TO_PROCEED_JOBPOD_DESC="false"
		local TO_PROCEED_JOBPOD_YAML="false"
		local TO_PROCEED_JOBPOD_JSON="false"
		local TO_PROCEED_JOBPOD_LOGS="false"
	else
		local TO_PROCEED_JOBPOD_DESC="true"

		if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ] || [ $GET_POD_LOGS == "true" ]
		then
			local TO_PROCEED_JOBPOD_YAML="false"
			local TO_PROCEED_JOBPOD_JSON="false"
			local TO_PROCEED_JOBPOD_LOGS="false"
	
			if isSensitiveData "pod"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] descAll() function does not support '$OC_CMD get -o yaml/json' and '$OC_CMD logs' of [pod] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [pod]!"
					local TO_PROCEED_JOBPOD_YAML="true"
					local TO_PROCEED_JOBPOD_JSON="true"
					local TO_PROCEED_JOBPOD_LOGS="true"
				fi
			else
				local TO_PROCEED_JOBPOD_YAML="true"
				local TO_PROCEED_JOBPOD_JSON="true"
				local TO_PROCEED_JOBPOD_LOGS="true"
			fi
		fi
	fi
	
	if [ $IS_JOB_RESTRICTED == "false" ] 
	then
		local TOTAL_OBJ=$(grep '^job.batch/' $OC_ALL_INFILE | wc -l)
		
		if [ ${TOTAL_OBJ} -ge $FAST_OC_YAML_PREREQ ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [job.batch] has met minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
			local FAST_OC_YAML_WORTHY="true"
		else
			echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [job.batch] did not meet minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
			local FAST_OC_YAML_WORTHY="false"
		fi
				
		for LINE in $(cat $OC_ALL_INFILE | grep -E -v '^NAME|^$|^I051|Throttling request|No resources found|^Error from server' | grep '^job.batch/' | $AWK '{ print $1 "~" $2 }') 
		do
			local TO_SKIP="false"
			(( TOTAL_JOB=TOTAL_JOB+1 ))
		
			local JOB_LINE=$(echo "$LINE" | $AWK -F~ '{ print $1 }')
			local JOB_STATUS=$(echo "$LINE" | $AWK -F~ '{ print $2 }')
			
			local OBJ=$(echo "$JOB_LINE" | $AWK -F'/' '{ print $1 }')
			local RES=$(echo "$JOB_LINE" | $AWK -F'/' '{ print $2 }')
		
			if [ -n $EXCL_OBJ_LIST ] && [ ${#EXCL_OBJ_LIST[@]} -gt 0 ]
			then
				for EXCLOBJ in ${EXCL_OBJ_LIST[@]}
				do
					if [ $OBJ == $EXCLOBJ ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Object [$OBJ/$RES] is in the object exclusion list [$EXCLOBJ]. Skipping..."
						fi
						local TO_SKIP="true"
						break
					fi
		
					if [ $EXCLOBJ == "pod" ] || [ $IS_POD_RESTRICTED == "true" ]
					then
						local TO_SKIP_POD="true"
					fi
				done
			fi
		
			if [ $TO_SKIP == "true" ]
			then
				continue
			fi
		
			if [ ! -d $F_OUTDIR/$OBJ ]
			then
				mkdir -p $F_OUTDIR/$OBJ
			fi
		
			if [ $OC_DESC_ON = "true" ] && [ $TO_PROCEED_JOB_DESC == "true" ]
			then
				if [ $FAST_OC_DESC == "true" ]
				then
					# Collecting all resource type for further processing
					
					if [ $FAST_OC_DESC_FOR_JOBS == "true" ]
					then
						local FAST_OC_DESC_OUTFILE=$F_OUTDIR/fast_oc_desc.$OBJ.desc-all
	
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe $OBJ -n $NAMESPACE' => $FAST_OC_DESC_OUTFILE"
						$OC_CMD describe $OBJ -n $NAMESPACE > $FAST_OC_DESC_OUTFILE
		
						if [ -s $FAST_OC_DESC_OUTFILE ]
						then
							local RECORD_SEPARATOR_KEYWORD=$(head -1 $FAST_OC_DESC_OUTFILE | $AWK -F':' '{ print $1 }' | sed 's/[ ]*$//')
		
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] RECORD_SEPARATOR_KEYWORD = [$RECORD_SEPARATOR_KEYWORD]"
							fi
						
							if [ ${#RECORD_SEPARATOR_KEYWORD} ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing [sed '/^$/N;/^\n$/D;s/\(^\n\)${RECORD_SEPARATOR_KEYWORD}:/\1#@@@%@@@#\n${RECORD_SEPARATOR_KEYWORD}:/' $FAST_OC_DESC_OUTFILE | $AWK -v OUTDIR=$F_OUTDIR/$OBJ 'BEGIN { RS=\"#@@@%@@@#\n\"; FS=\"\n\" } { OBJNAME=substr(\$1, index(\$1, \":\")+1); gsub(/^[ \t]*/, \"\", OBJNAME); gsub(/[\n]*$/, \"\", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR\"/\"OBJNAME\".desc\") } }]"
								sed '/^$/N;/^\n$/D;s/\(^\n\)'${RECORD_SEPARATOR_KEYWORD}':/\1#@@@%@@@#\n'${RECORD_SEPARATOR_KEYWORD}':/' $FAST_OC_DESC_OUTFILE | $AWK -v OUTDIR=$F_OUTDIR/$OBJ 'BEGIN { RS="#@@@%@@@#\n"; FS="\n" } { OBJNAME=substr($1, index($1, ":")+1); gsub(/^[ \t]*/, "", OBJNAME); gsub(/[\n]*$/, "", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR"/"OBJNAME".desc") } }'
		
								# Just need to execute this once
								local FAST_OC_DESC_FOR_JOBS="false"
							else
								echo "[$(date)] [${FUNCNAME[0]}] Unable to determine RECORD_SEPARATOR_KEYWORD for resource type [$OBJ] in namespace [$NAMESPACE]!"
							fi
		
							local SOURCE_COUNT=$(grep '^'$RECORD_SEPARATOR_KEYWORD':' $FAST_OC_DESC_OUTFILE | $AWK -F: 'NF>=2' | wc -l)
							local DESC_FILE_COUNT=$(ls -l $F_OUTDIR/$OBJ/*.desc | wc -l)
		
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] DESC_FILE_COUNT = [$DESC_FILE_COUNT] / SOURCE_COUNT = [$SOURCE_COUNT]"
							fi
					
							if [ ${#DESC_FILE_COUNT} -gt 0 ] && [ ${#SOURCE_COUNT} -gt 0 ]
							then
								if [ $DESC_FILE_COUNT -ne $SOURCE_COUNT ]
								then
									cp -p $FAST_OC_DESC_OUTFILE $F_OUTDIR/$OBJ
								fi
							else
								cp -p $FAST_OC_DESC_OUTFILE $F_OUTDIR/$OBJ
							fi
		
							if [ $MG_DEBUG == "true" ]
							then
								if [ ! -d $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE ]
								then
									mkdir -p $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
								fi
				
								echo "[$(date)] [${FUNCNAME[0]}] File listing (*.desc) on output directory [$F_OUTDIR/$OBJ] => [$(ls -l $F_OUTDIR/$OBJ/*.desc)]"
								echo "[$(date)] [${FUNCNAME[0]}] File count (*.desc) on output directory [$F_OUTDIR/$OBJ] => [$DESC_FILE_COUNT)] [SOURCE_COUNT=$SOURCE_COUNT]"
		
								echo "[$(date)] [${FUNCNAME[0]}] Backing up [$FAST_OC_DESC_OUTFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE]..."
								mv $FAST_OC_DESC_OUTFILE $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
							else
								echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_DESC_OUTFILE]..."
								rm $FAST_OC_DESC_OUTFILE
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC - '$OC_CMD describe $RESTYPE -n $NAMESPACE' output file [$FAST_OC_DESC_OUTFILE] does not exist or is zero-sized!"
						fi
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.desc"
					$OC_CMD describe -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.desc 2>&1
				fi
			fi
		
			if [ $COLLECT_YAML == "true" ]
			then
				if [ $TO_PROCEED_JOB_YAML == "true" ]
				then
					if [ ${FAST_OC_YAML} == "true" ] && [ ${FAST_OC_YAML_WORTHY} == "true" ]
					then
						if [ $FAST_OC == "true" ] 
						then
							if [ ${#JOB_OC_APIVERSION_NAME} -gt 0 ]
							then
								local YAML_CURL_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$JOB_OC_APIVERSION_NAME/namespaces/$NAMESPACE/jobs/$RES'"
							else
								local YAML_CURL_CMD=""
							fi
						else
							local YAML_CURL_CMD=""
						fi
	
						# To create fallback reference file for FAST_OC_YAML
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$NAMESPACE##$OBJ##$RES##$F_OUTDIR/$OBJ##$YAML_CURL_CMD] => $FAST_OC_YAML_WORKFILE"
						fi
					
						echo "$NAMESPACE##$OBJ##$RES##$F_OUTDIR/$OBJ##$YAML_CURL_CMD" >> $FAST_OC_YAML_WORKFILE
					else
						if [ $FAST_OC == "true" ]
						then
							if [ ${#JOB_OC_APIVERSION_NAME} -gt 0 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$JOB_OC_APIVERSION_NAME/namespaces/$NAMESPACE/jobs/$RES' => $F_OUTDIR/$OBJ/$RES.yaml"
								local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$JOB_OC_APIVERSION_NAME/namespaces/$NAMESPACE/jobs/$RES'"
								eval "$CMD" > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
				
								if [ -s $F_OUTDIR/$OBJ/$RES.yaml ]
								then
									if ( [[ $(head -1 $F_OUTDIR/$OBJ/$RES.yaml) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $F_OUTDIR/$OBJ/$RES.yaml) =~ \"paths\": ]] ) || [[ $(head -1 $F_OUTDIR/$OBJ/$RES.yaml) =~ ^404 ]] || [[ $(head -1 $F_OUTDIR/$OBJ/$RES.yaml) =~ "Moved Permanently" ]] 
									then
										echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
				
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
											$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
											$OC_CMD get -o yaml -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
										fi
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
										$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
										$OC_CMD get -o yaml -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									fi
								fi
							else
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
									$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
									$OC_CMD get -o yaml -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
								fi
							fi
						else
							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
								$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
								$OC_CMD get -o yaml -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
							fi
						fi
					fi
				fi
			fi
		
			if [ $COLLECT_JSON == "true" ]
			then
				if [ $TO_PROCEED_JOB_JSON == "true" ]
				then
					if [ $FAST_OC == "true" ]
					then
						if [ ${#JOB_OC_APIVERSION_NAME} -gt 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$JOB_OC_APIVERSION_NAME/namespaces/$NAMESPACE/jobs/$RES' => $F_OUTDIR/$OBJ/$RES.json"
							local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$JOB_OC_APIVERSION_NAME/namespaces/$NAMESPACE/jobs/$RES'"
							eval "$CMD" > $F_OUTDIR/$OBJ/$RES.json 2>&1
			
							if [ -s $F_OUTDIR/$OBJ/$RES.json ]
							then
								if ( [[ $(head -1 $F_OUTDIR/$OBJ/$RES.json) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $F_OUTDIR/$OBJ/$RES.json) =~ \"paths\": ]] ) || [[ $(head -1 $F_OUTDIR/$OBJ/$RES.json) =~ ^404 ]] || [[ $(head -1 $F_OUTDIR/$OBJ/$RES.json) =~ "Moved Permanently" ]]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
			
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.json"
										$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.json"
										$OC_CMD get -o json -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
									fi
								fi
							else
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.json"
									$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.json"
									$OC_CMD get -o json -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
								fi
							fi
						else
							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.json"
								$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.json"
								$OC_CMD get -o json -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
							fi
						fi
					else
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.json"
							$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $NAMESPACE $JOB_LINE' => $F_OUTDIR/$OBJ/$RES.json"
							$OC_CMD get -o json -n $NAMESPACE $JOB_LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
						fi
					fi
				fi
			fi
		
			if [ $TO_SKIP_POD == "false" ]
			then
				# Get pods spawned by the job
				if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_JOB_DESC == "true" ]
				then
					if [ -s $F_OUTDIR/$OBJ/$RES.desc ]
					then
						local JOB_UNIQUE_SELECTOR=$(grep '^Selector:' $F_OUTDIR/$OBJ/$RES.desc | $AWK '{ print $2 }')
					else
						local JOB_UNIQUE_SELECTOR=$($OC_CMD describe -n $NAMESPACE $JOB_LINE | grep '^Selector:' | $AWK '{ print $2 }')
					fi
				else
					local JOB_UNIQUE_SELECTOR=$($OC_CMD describe -n $NAMESPACE $JOB_LINE | grep '^Selector:' | $AWK '{ print $2 }')
				fi
		
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Job [$RES] unique selector = [$JOB_UNIQUE_SELECTOR]"
				fi
		
				if [ ${#JOB_UNIQUE_SELECTOR} -gt 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -n $NAMESPACE --selector="$JOB_UNIQUE_SELECTOR" -o=jsonpath='{.items[*].metadata.name}'"
					local JOB_POD=$($OC_CMD get pod -n $NAMESPACE --selector="$JOB_UNIQUE_SELECTOR" -o=jsonpath='{.items[*].metadata.name}')
		
					if [ ${#JOB_POD} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Unable to get related pod for job [$RES]. Skipping..."
						(( JOB_WITHOUT_POD=JOB_WITHOUT_POD+1 ))
						local JOB_WITHOUT_POD_ARR[${#JOB_WITHOUT_POD_ARR[@]}]="$RES : completion=$JOB_STATUS"
						continue
					else
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Retrieved JOB_POD for JOB [$RES] = [$JOB_POD]"
						fi
					fi
		
					if [ ! -d $F_OUTDIR/pod ]
					then
						mkdir -p $F_OUTDIR/pod
					fi
		
					local JOB_POD_CTR=0
					local MY_JOB_POD=
					local INIT_CONTAINER=
					local CONTAINER=
		
					IFS=$OLDIFS
					for MY_JOB_POD in $JOB_POD
					do
						# Added just for periodic cluster/context switch check
						if ! checkUserPriv get pod $NAMESPACE
						then
							echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource '$OBJ' in namespace [$NAMESPACE]. Skipping..."
							continue
						fi
		
						(( JOB_POD_CTR=JOB_POD_CTR+1 ))
						local JOB_PODS[${#JOB_PODS[@]}]="$RES/$MY_JOB_POD"
		
						if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_JOBPOD_DESC == "true" ]
						then
							if [ $FAST_OC_DESC == "true" ]
							then
								# Some ".desc" files for PODs might be missing due to this delay (pods spawned by completed jobs)
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Writing new line [pod] to file [$FAST_OC_DESC_WORKFILE]..."
								fi
		
								echo "pod" >> $FAST_OC_DESC_WORKFILE
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe pod -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.desc"
								$OC_CMD describe pod -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.desc 2>&1
							fi
						fi
			
						if [ $COLLECT_YAML == "true" ]
						then
							if [ $TO_PROCEED_JOBPOD_YAML == "true" ]
							then
								if [ ${FAST_OC_YAML} == "true" ] && [ ${FAST_OC_YAML_WORTHY} == "true" ]
								then
									if [ $FAST_OC == "true" ] 
									then
										if [ ${#POD_OC_APIVERSION_NAME} -gt 0 ]
										then
											local YAML_CURL_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD'"
										else
											local YAML_CURL_CMD=""
										fi
									else
										local YAML_CURL_CMD=""
									fi
				
									# To create fallback reference file for FAST_OC_YAML
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$NAMESPACE##pod##$MY_JOB_POD##$F_OUTDIR/pod##$YAML_CURL_CMD] => $FAST_OC_YAML_WORKFILE"
									fi
								
									echo "$NAMESPACE##pod##$MY_JOB_POD##$F_OUTDIR/pod##$YAML_CURL_CMD" >> $FAST_OC_YAML_WORKFILE
								else
									if [ $FAST_OC == "true" ]
									then
										if [ ${#POD_OC_APIVERSION_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.yaml"
											local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD'"
											eval "$CMD" > $F_OUTDIR/pod/$MY_JOB_POD.yaml 2>&1
				
											if [ -s $F_OUTDIR/pod/$MY_JOB_POD.yaml ]
											then
												if ( [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD.yaml) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $F_OUTDIR/pod/$MY_JOB_POD.yaml) =~ \"paths\": ]] ) || [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD.yaml) =~ ^404 ]] || [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD.yaml) =~ "Moved Permanently" ]]
												then
													echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
						
													if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o yaml --show-managed-fields -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.yaml"
														$OC_CMD get pod -o yaml --show-managed-fields -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.yaml 2>&1
													else
														echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o yaml -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.yaml"
														$OC_CMD get pod -o yaml -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.yaml 2>&1
													fi
												fi
											else
												if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o yaml --show-managed-fields -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.yaml"
													$OC_CMD get pod -o yaml --show-managed-fields -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.yaml 2>&1
												else
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o yaml -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.yaml"
													$OC_CMD get pod -o yaml -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.yaml 2>&1
												fi
											fi
										else
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o yaml --show-managed-fields -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.yaml"
												$OC_CMD get pod -o yaml --show-managed-fields -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.yaml 2>&1
											else
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o yaml -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.yaml"
												$OC_CMD get pod -o yaml -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.yaml 2>&1
											fi
										fi
									else
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o yaml --show-managed-fields -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.yaml"
											$OC_CMD get pod -o yaml --show-managed-fields -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.yaml 2>&1
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o yaml -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.yaml"
											$OC_CMD get pod -o yaml -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.yaml 2>&1
										fi
									fi
								fi
							fi
						fi
			
						if [ $COLLECT_JSON == "true" ]
						then
							if [ $TO_PROCEED_JOBPOD_JSON == "true" ]
							then
								if [ $FAST_OC == "true" ]
								then
									if [ ${#POD_OC_APIVERSION_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.json"
										local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD'"
										eval "$CMD" > $F_OUTDIR/pod/$MY_JOB_POD.json 2>&1
			
										if [ -s $F_OUTDIR/pod/$MY_JOB_POD.json ]
										then
											if ( [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD.json) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $F_OUTDIR/pod/$MY_JOB_POD.json) =~ \"paths\": ]] ) || [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD.json) =~ ^404 ]] || [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD.json) =~ "Moved Permanently" ]]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
		
												if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o json --show-managed-fields -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.json"
													$OC_CMD get pod -o json --show-managed-fields -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.json 2>&1
												else
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o json -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.json"
													$OC_CMD get pod -o json -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.json 2>&1
												fi
											fi
										else
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o json --show-managed-fields -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.json"
												$OC_CMD get pod -o json --show-managed-fields -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.json 2>&1
											else
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o json -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.json"
												$OC_CMD get pod -o json -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.json 2>&1
											fi
										fi
									else
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o json --show-managed-fields -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.json"
											$OC_CMD get pod -o json --show-managed-fields -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.json 2>&1
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o json -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.json"
											$OC_CMD get pod -o json -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.json 2>&1
										fi
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o json --show-managed-fields -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.json"
										$OC_CMD get pod -o json --show-managed-fields -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.json 2>&1
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get pod -o json -n $NAMESPACE $MY_JOB_POD' => $F_OUTDIR/pod/$MY_JOB_POD.json"
										$OC_CMD get pod -o json -n $NAMESPACE $MY_JOB_POD > $F_OUTDIR/pod/$MY_JOB_POD.json 2>&1
									fi
								fi
							fi
						fi
			
						if [ $GET_POD_LOGS == "true" ] && [ $TO_PROCEED_JOBPOD_LOGS == "true" ]
						then	
							IFS=$OLDIFS
							for INIT_CONTAINER in $($OC_CMD get pod $MY_JOB_POD -n $NAMESPACE -o=jsonpath="{.spec.initContainers[*].name}")
							do 
								if [ $FAST_OC == "true" ] 
								then
									if [ ${#POD_OC_APIVERSION_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD/log?container=${INIT_CONTAINER}${POD_LOG_TAILLINES_CURL_STR}' => $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log"
										local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD/log?container=${INIT_CONTAINER}${POD_LOG_TAILLINES_CURL_STR}'"
										eval "$CMD" > $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log 2>&1
		
										if [ ! -f $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log ] || [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log) =~ ^"404 page not found" ]] || ( [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log | wc -l) -gt 0 ] ) 
										then
											echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log"
											$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log 2>&1
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER $$POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log"
										$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log 2>&1
									fi
		
									if [ $COLL_PREV_LOGS == "true" ]
									then
										if [ ${#POD_OC_APIVERSION_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD/log?container=${INIT_CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}' => $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev"
											local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD/log?container=${INIT_CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}'"
											eval "$CMD" > $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev 2>&1
		
											if [ ! -f $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev ] || [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev) =~ ^"404 page not found" ]] || ( [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev | wc -l) -gt 0 ] )
											then
												echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER -p $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev"
												$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER -p $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev 2>&1
											fi
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER -p $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev"
											$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER -p $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev 2>&1
										fi
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log"
									$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log 2>&1
					
									if [ $COLL_PREV_LOGS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER -p $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev"
										$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $INIT_CONTAINER -p $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$INIT_CONTAINER.log.prev 2>&1
									fi
								fi
							done
		
							for CONTAINER in $($OC_CMD get pod $MY_JOB_POD -n $NAMESPACE -o=jsonpath="{.spec.containers[*].name}")
							do 
								if [ $FAST_OC == "true" ]
								then
									if [ ${#POD_OC_APIVERSION_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD/log?container=${CONTAINER}${POD_LOG_TAILLINES_CURL_STR}' => $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log"
										local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD/log?container=${CONTAINER}${POD_LOG_TAILLINES_CURL_STR}'"
										eval "$CMD" > $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log 2>&1
		
										if [ ! -f $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log ] || [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log) =~ ^"404 page not found" ]] || ( [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log | wc -l) -gt 0 ] )
										then
											echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log"
											$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log 2>&1
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log"
										$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log 2>&1
									fi
		
									if [ $COLL_PREV_LOGS == "true" ]
									then
										if [ ${#POD_OC_APIVERSION_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD/log?container=${CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}' => $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev"
											local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$POD_OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$MY_JOB_POD/log?container=${CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}'"
											eval "$CMD" > $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev 2>&1
		
											if [ ! -f $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev ] || [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev) =~ ^"404 page not found" ]] || ( [[ $(head -1 $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log | wc -l) -gt 0 ] )
											then
												echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER -p $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev"
												$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER -p $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev 2>&1
											fi
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER -p $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev"
											$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER -p $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev 2>&1
										fi
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log"
									$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log 2>&1
					
									if [ $COLL_PREV_LOGS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER -p $POD_LOG_TAILLINES_OC_STR' => $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev"
										$OC_CMD logs -n $NAMESPACE $MY_JOB_POD -c $CONTAINER -p $POD_LOG_TAILLINES_OC_STR > $F_OUTDIR/pod/$MY_JOB_POD~$CONTAINER.log.prev 2>&1
									fi
								fi
							done
							IFS=$'\n'
						fi
					done
					IFS=$'\n'
		
					if [ $JOB_POD_CTR -gt 1 ]
					then
						local JOB_WITH_MULTI_POD_ARR[${#JOB_WITH_MULTI_POD_ARR[@]}]="$RES : count=$JOB_POD_CTR"
					else
						local JOB_WITH_SINGLE_POD_ARR[${#JOB_WITH_SINGLE_POD_ARR[@]}]="$RES : count=$JOB_POD_CTR"
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Error getting unique selector of pod related to job [$RES]..."
					(( JOB_WITHOUT_POD=JOB_WITHOUT_POD+1 ))
					local JOB_WITHOUT_POD_ARR[${#JOB_WITHOUT_POD_ARR[@]}]="$RES : completion=$JOB_STATUS"
				fi
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Object pod is in the object exclusion list or is restricteded. Skipping..."
				fi
			fi
		done
		
		if [ $MG_DEBUG == "true" ]
		then
			if [ ${#JOB_PODS[@]} -gt 0 ]
			then
				local I_ARRAY_LEN=${#JOB_PODS[@]}
				echo "[$(date)] [${FUNCNAME[0]}] Listing processed job pods [TOTAL=$I_ARRAY_LEN]..."
		
				for (( i=0; i<$I_ARRAY_LEN; i++ ))
				do
					echo "[$(date)] [${FUNCNAME[0]}] JOB_PODS[$i] = $(echo "${JOB_PODS[$i]}" | $AWK -F'/' '{ print $2 }')"
				done
			else
				echo "[$(date)] [${FUNCNAME[0]}] Processed job pods array is empty!"
			fi
		
			echo "[$(date)] [${FUNCNAME[0]}] Total jobs = $TOTAL_JOB"
		
			if [ ${#JOB_WITHOUT_POD_ARR[@]} -gt 0 ]
			then
				local J_ARRAY_LEN=${#JOB_WITHOUT_POD_ARR[@]}
				echo "[$(date)] [${FUNCNAME[0]}] Listing jobs without pod [TOTAL=$JOB_WITHOUT_POD]..."
		
				for (( j=0; j<$J_ARRAY_LEN; j++ ))
				do
					echo "[$(date)] [${FUNCNAME[0]}] JOB_WITHOUT_POD[$j] = ${JOB_WITHOUT_POD_ARR[$j]}"
				done
			fi
		
			if [ ${#JOB_WITH_SINGLE_POD_ARR[@]} -gt 0 ]
			then
				local K_ARRAY_LEN=${#JOB_WITH_SINGLE_POD_ARR[@]}
				echo "[$(date)] [${FUNCNAME[0]}] Listing jobs with single pod [TOTAL=$K_ARRAY_LEN]..."
		
				for (( k=0; k<$K_ARRAY_LEN; k++ ))
				do
					echo "[$(date)] [${FUNCNAME[0]}] JOB_WITH_SINGLE_POD[$k] = ${JOB_WITH_SINGLE_POD_ARR[$k]}"
				done
			fi
		
			if [ ${#JOB_WITH_MULTI_POD_ARR[@]} -gt 0 ]
			then
				local L_ARRAY_LEN=${#JOB_WITH_MULTI_POD_ARR[@]}
				echo "[$(date)] [${FUNCNAME[0]}] Listing jobs with multiple pods [TOTAL=$L_ARRAY_LEN]..."
		
				for (( l=0; l<$L_ARRAY_LEN; l++ ))
				do
					echo "[$(date)] [${FUNCNAME[0]}] JOB_WITH_MULTI_POD[$l] = ${JOB_WITH_MULTI_POD_ARR[$l]}"
				done
			fi
		fi
	fi
	
	# For the rest of resource types (except jobs)
	local CUR_OBJ=
	local OLD_OBJ=
	
	for LINE in $(cat $OC_ALL_INFILE | grep -E -v '^NAME|^$|^job.batch/|^I051|Throttling request|No resources found|^Error from server' | $AWK '{ print $1 }')
	do
		if [ $(echo "$LINE" | $AWK '$1 !~ /.*\/.*/ { print "BAD_LINE" }')x == "BAD_LINEx" ]
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] LINE [$LINE] is invalid! Skipping..."
			fi

			continue
		fi

		local TO_SKIP="false"
	
		local OBJ=$(echo "$LINE" | $AWK -F'/' '{ print $1 }')
		local RES=$(echo "$LINE" | $AWK -F'/' '{ print $2 }')
	
		if [ -n $EXCL_OBJ_LIST ] && [ ${#EXCL_OBJ_LIST[@]} -gt 0 ]
		then
			for EXCLOBJ in ${EXCL_OBJ_LIST[@]}
			do
				if [ $OBJ == $EXCLOBJ ]
				then
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Object [$OBJ/$RES] is in the object exclusion list [$EXCLOBJ]. Skipping..."
					fi
					local TO_SKIP="true"
					break
				fi
			done
		fi
	
		if [ $TO_SKIP == "true" ] 
		then
			continue
		fi
	
		if [ ! -d $F_OUTDIR/$OBJ ]
		then
			mkdir -p $F_OUTDIR/$OBJ
		fi
	
		local CUR_OBJ=$OBJ
	
		if [ ${#OLD_OBJ} -eq 0 ]
		then
			if isRestrictedData "$OBJ"
			then
				local OLD_OBJ=$OBJ
				local TO_PROCEED="false"

				continue
			else
				local TO_PROCEED="true"
			fi

			local OC_APIVERSION_NAME=$(getApiVersionName $OBJ)
			local OC_API_KIND=$(getApiKind $OBJ)
			local OC_API_NAME=$(getApiName $OBJ)
		
			echo "[$(date)] [${FUNCNAME[0]}] NAMESPACE = [$NAMESPACE] / OBJ = [$OBJ] / CUR_OBJ = [$CUR_OBJ] / OLD_OBJ = [$OLD_OBJ] / OC_API_NAME = [$OC_API_NAME] / OC_API_KIND = [$OC_API_KIND] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME]"
			local OLD_OBJ=$OBJ

			if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ] || [ $GET_POD_LOGS == "true" ]
			then
				local TO_PROCEED_YAML="false"
				local TO_PROCEED_JSON="false"
				local TO_PROCEED_LOGS="false"
	
				if isSensitiveData "$OBJ"
				then
					if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
					then		
						if [ $OBJ == "pod" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] descAll() function does not support '$OC_CMD get -o yaml/json' and '$OC_CMD logs' of [$OBJ] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
						else
							echo "[$(date)] [${FUNCNAME[0]}] descAll() function does not support '$OC_CMD get -o yaml/json' of [$OBJ] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [$OBJ]!"
						local TO_PROCEED_YAML="true"
						local TO_PROCEED_JSON="true"
						local TO_PROCEED_LOGS="true"
					fi
				else
					local TO_PROCEED_YAML="true"
					local TO_PROCEED_JSON="true"
					local TO_PROCEED_LOGS="true"
				fi
			fi

			local TOTAL_OBJ=$(grep '^'$OBJ'/' $OC_ALL_INFILE | wc -l)
			
			if [ ${TOTAL_OBJ} -ge $FAST_OC_YAML_PREREQ ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$OBJ] has met minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
				local FAST_OC_YAML_WORTHY="true"
			else
				echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$OBJ] did not meet minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
				local FAST_OC_YAML_WORTHY="false"
			fi

			# Added just for periodic cluster/context switch check
			if ! checkUserPriv get $OBJ $NAMESPACE
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource '$OBJ' in namespace [$NAMESPACE]. Skipping..."
				continue
			fi
		else
			if [ $CUR_OBJ != $OLD_OBJ ]
			then
				if isRestrictedData "$OBJ"
				then
					local OLD_OBJ=$OBJ
					local TO_PROCEED="false"

					continue
				else
					local TO_PROCEED="true"
				fi

				local OC_APIVERSION_NAME=$(getApiVersionName $OBJ)
				local OC_API_KIND=$(getApiKind $OBJ)
				local OC_API_NAME=$(getApiName $OBJ)
			
				echo "[$(date)] [${FUNCNAME[0]}] NAMESPACE = [$NAMESPACE] / OBJ = [$OBJ] / CUR_OBJ = [$CUR_OBJ] / OLD_OBJ = [$OLD_OBJ] / OC_API_NAME = [$OC_API_NAME] / OC_API_KIND = [$OC_API_KIND] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME]"
				local OLD_OBJ=$OBJ

				if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ] || [ $GET_POD_LOGS == "true" ]
				then
					local TO_PROCEED_YAML="false"
					local TO_PROCEED_JSON="false"
					local TO_PROCEED_LOGS="false"
		
					if isSensitiveData "$OBJ"
					then
						if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
						then		
							if [ $OBJ == "pod" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] descAll() function does not support '$OC_CMD get -o yaml/json' and '$OC_CMD logs' of [$OBJ] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
							else
								echo "[$(date)] [${FUNCNAME[0]}] descAll() function does not support '$OC_CMD get -o yaml/json' of [$OBJ] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [$OBJ]!"
							local TO_PROCEED_YAML="true"
							local TO_PROCEED_JSON="true"
							local TO_PROCEED_LOGS="true"
						fi
					else
						local TO_PROCEED_YAML="true"
						local TO_PROCEED_JSON="true"
						local TO_PROCEED_LOGS="true"
					fi
				fi

				local TOTAL_OBJ=$(grep '^'$OBJ'/' $OC_ALL_INFILE | wc -l)
				
				if [ ${TOTAL_OBJ} -ge $FAST_OC_YAML_PREREQ ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$OBJ] has met minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
					local FAST_OC_YAML_WORTHY="true"
				else
					echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$OBJ] did not meet minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
					local FAST_OC_YAML_WORTHY="false"
				fi

				# Added just for periodic cluster/context switch check
				if ! checkUserPriv get $OBJ $NAMESPACE
				then
					echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource '$OBJ' in namespace [$NAMESPACE]. Skipping..."
					continue
				fi
			else
				if [ $TO_PROCEED == "false" ]
				then
					continue
				fi
			fi
		fi

		if [ $OBJ == "pod" ] || [ $OBJ == "replicaset.apps" ]
		then
			# Added just for periodic cluster/context switch check
			if ! checkUserPriv get $OBJ $NAMESPACE
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource '$OBJ' in namespace [$NAMESPACE]. Skipping..."
				continue
			fi
		fi	

		if [ $OBJ == "pod" ]
		then
			# To get SCC of pod
			if [ ! -s $POD_SCC_OUTFILE ]
			then
				printf "%-85s %-25s %-50s \n" "PODNAME" "SCC" "SVCACCT" > $POD_SCC_OUTFILE
			fi
	
			local POD_SCC_INFO=$($OC_CMD get pod -n $NAMESPACE $RES -o=jsonpath="{.metadata.annotations.openshift\.io/scc};{.spec.serviceAccount}" 2> /dev/null)
		
			if [ ${#POD_SCC_INFO} -gt 0 ]
			then
				local POD_SCC=$(echo "$POD_SCC_INFO" | $AWK -F';' '{ print $1 }')
				local POD_SA=$(echo "$POD_SCC_INFO" | $AWK -F';' '{ print $2 }')
			else
				local POD_SCC=
				local POD_SA=
			fi
	
			printf "%-85s %-25s %-50s \n" $RES $POD_SCC $POD_SA >> $POD_SCC_OUTFILE
	
			local SKIP_LINE="false"
			local JPOD=
	
			for JPOD in ${JOB_PODS[@]}	
			do
				local X_JOB_NAME=$(echo "$JPOD" | $AWK -F'/' '{ print $1 }')
				local X_POD_NAME=$(echo "$JPOD" | $AWK -F'/' '{ print $2 }')
	
				if [ $RES == $X_POD_NAME ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Pod [$RES] belongs to a job [$X_JOB_NAME] and has been processed. Skipping..."
					local SKIP_LINE="true"
					break
				fi
			done
	
			if [ $SKIP_LINE == "true" ]
			then
				continue
			fi
		fi
	
		if [ $OC_DESC_ON == "true" ]
		then
			if [ $FAST_OC_DESC == "true" ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$OBJ] to file [$FAST_OC_DESC_WORKFILE]..."
				fi
	
				echo $OBJ >> $FAST_OC_DESC_WORKFILE
			else
				echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.desc"
				$OC_CMD describe -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.desc 2>&1
			fi
		fi
	
		if [ $COLLECT_YAML == "true" ]
		then
			if [ $TO_PROCEED_YAML == "true" ]
			then
				if [ ${FAST_OC_YAML} == "true" ] && [ ${FAST_OC_YAML_WORTHY} == "true" ]
				then
					if [ $FAST_OC == "true" ] 
					then
						if [ ${#OC_APIVERSION_NAME} -gt 0 ]
						then
							local YAML_CURL_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/$OC_API_NAME/$RES"
						else
							local YAML_CURL_CMD=""
						fi
					else
						local YAML_CURL_CMD=""
					fi

					# To create fallback reference file for FAST_OC_YAML
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$NAMESPACE##$OBJ##$RES##$F_OUTDIR/$OBJ##$YAML_CURL_CMD] => $FAST_OC_YAML_WORKFILE"
					fi
				
					echo "$NAMESPACE##$OBJ##$RES##$F_OUTDIR/$OBJ##$YAML_CURL_CMD" >> $FAST_OC_YAML_WORKFILE
				else
					if [ $FAST_OC == "true" ]
					then
						if [ ${#OC_APIVERSION_NAME} -gt 0 ]
						then
							case $OBJ in
								deployment.apps)
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/deployments/$RES' => $F_OUTDIR/$OBJ/$RES.yaml"
									local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/deployments/$RES'"
									eval "$CMD" > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									;;
								pod)
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES' => $F_OUTDIR/$OBJ/$RES.yaml"
									local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES'"
									eval "$CMD" > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									;;
								replicaset.apps)
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/replicasets/$RES' => $F_OUTDIR/$OBJ/$RES.yaml"
									local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/replicasets/$RES'"
									eval "$CMD" > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									;;
								route.route.openshift.io)
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/routes/$RES' => $F_OUTDIR/$OBJ/$RES.yaml"
									local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/routes/$RES'"
									eval "$CMD" > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									;;
								service)
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/services/$RES' => $F_OUTDIR/$OBJ/$RES.yaml"
									local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/services/$RES'"
									eval "$CMD" > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									;;
								statefulset.apps)
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/statefulsets/$RES' => $F_OUTDIR/$OBJ/$RES.yaml"
									local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/statefulsets/$RES'"
									eval "$CMD" > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									;;
								*)
									if [ ${#OC_API_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/$OC_API_NAME/$RES' => $F_OUTDIR/$OBJ/$RES.yaml"
										local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/$OC_API_NAME/$RES"
										eval "$CMD" > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									else
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
											$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
											$OC_CMD get -o yaml -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
										fi
									fi
									;;	
							esac
			
							if [ -s $F_OUTDIR/$OBJ/$RES.yaml ]
							then
								if ( [[ $(head -1 $F_OUTDIR/$OBJ/$RES.yaml) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $F_OUTDIR/$OBJ/$RES.yaml) =~ \"paths\": ]] ) || [[ $(head -1 $F_OUTDIR/$OBJ/$RES.yaml) =~ ^404 ]] || [[ $(head -1 $F_OUTDIR/$OBJ/$RES.yaml) =~ "Moved Permanently" ]]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
					
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
										$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
										$OC_CMD get -o yaml -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
									fi
								fi
							else
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
									$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
									$OC_CMD get -o yaml -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
								fi
							fi
						else
							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
								$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
								$OC_CMD get -o yaml -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
							fi
						fi
					else
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
							$OC_CMD get -o yaml --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.yaml"
							$OC_CMD get -o yaml -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.yaml 2>&1
						fi
					fi
				fi
			fi
		fi
	
		if [ $COLLECT_JSON == "true" ]
		then
			if [ $TO_PROCEED_JSON == "true" ]
			then
				if [ $FAST_OC == "true" ]
				then
					if [ ${#OC_APIVERSION_NAME} -gt 0 ]
					then
						case $OBJ in
							deployment.apps)
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/deployments/$RES' => $F_OUTDIR/$OBJ/$RES.json"
								local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/deployments/$RES'"
								eval "$CMD" > $F_OUTDIR/$OBJ/$RES.json 2>&1
								;;
							pod)
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES' => $F_OUTDIR/$OBJ/$RES.json"
								local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES'"
								eval "$CMD" > $F_OUTDIR/$OBJ/$RES.json 2>&1
								;;
							replicaset.apps)
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/replicasets/$RES' => $F_OUTDIR/$OBJ/$RES.json"
								local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/replicasets/$RES'"
								eval "$CMD" > $F_OUTDIR/$OBJ/$RES.json 2>&1
								;;
							route.route.openshift.io)
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/routes/$RES' => $F_OUTDIR/$OBJ/$RES.json"
								local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/routes/$RES'"
								eval "$CMD" > $F_OUTDIR/$OBJ/$RES.json 2>&1
								;;
							service)
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/services/$RES' => $F_OUTDIR/$OBJ/$RES.json"
								local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/services/$RES'"
								eval "$CMD" > $F_OUTDIR/$OBJ/$RES.json 2>&1
								;;
							statefulset.apps)
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/statefulsets/$RES' => $F_OUTDIR/$OBJ/$RES.json"
								local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/statefulsets/$RES'"
								eval "$CMD" > $F_OUTDIR/$OBJ/$RES.json 2>&1
								;;
							*)
								if [ ${#OC_API_NAME} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/$OC_API_NAME/$RES' => $F_OUTDIR/$OBJ/$RES.json"
									local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/$OC_API_NAME/$RES"
									eval "$CMD" > $F_OUTDIR/$OBJ/$RES.json 2>&1
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
										$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
										$OC_CMD get -o json -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
									fi
								fi
								;;	
						esac
		
						if [ -s $F_OUTDIR/$OBJ/$RES.json ]
						then
							if ( [[ $(head -1 $F_OUTDIR/$OBJ/$RES.json) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $F_OUTDIR/$OBJ/$RES.json) =~ \"paths\": ]] ) || [[ $(head -1 $F_OUTDIR/$OBJ/$RES.json) =~ ^404 ]] || [[ $(head -1 $F_OUTDIR/$OBJ/$RES.json) =~ "Moved Permanently" ]]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
				
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
									$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
									$OC_CMD get -o json -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
								fi
							fi
						else
							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
								$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
								$OC_CMD get -o json -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
							fi
						fi
					else
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
							$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
							$OC_CMD get -o json -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
						fi
					fi
				else
					if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
						$OC_CMD get -o json --show-managed-fields -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
					else
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $NAMESPACE $LINE' => $F_OUTDIR/$OBJ/$RES.json"
						$OC_CMD get -o json -n $NAMESPACE $LINE > $F_OUTDIR/$OBJ/$RES.json 2>&1
					fi
				fi
			fi
		fi
	
		if [ $OBJ == "pod" ] && [ $GET_POD_LOGS == "true" ] && [ $TO_PROCEED_LOGS == "true" ]
		then	
			local INIT_CONTAINER=
			local CONTAINER=
	
			IFS=$OLDIFS
			for INIT_CONTAINER in $($OC_CMD get $LINE -n $NAMESPACE -o=jsonpath="{.spec.initContainers[*].name}")
			do 
				if [ $FAST_OC == "true" ]
				then
					if [ ${#OC_APIVERSION_NAME} -gt 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES/log?container=${INIT_CONTAINER}${POD_LOG_TAILLINES_CURL_STR}' => $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log"
						local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES/log?container=${INIT_CONTAINER}${POD_LOG_TAILLINES_CURL_STR}'"
						eval "$CMD" > $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log 2>&1
	
						if [ ! -f $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log ] || [[ $(head -1 $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log) =~ ^"404 page not found" ]] || ( [[ $(head -1 $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log | wc -l) -gt 0 ] )
						then
							echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log"
							$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log 2>&1
						fi
	
						if [ $COLL_PREV_LOGS == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES/log?container=${INIT_CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}' => $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log.prev"
							local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES/log?container=${INIT_CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}'"
							eval "$CMD" > $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log.prev 2>&1
	
							if [ ! -f $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log.prev ] || [[ $(head -1 $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log.prev) =~ ^"404 page not found" ]] || ( [[ $(head -1 $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log.prev) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $F_OUTDIR/pod/$RES~$INIT_CONTAINER.log.prev | wc -l) -gt 0 ] )
							then
								echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log.prev"
								$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log.prev 2>&1
							fi
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log"
						$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log 2>&1
	
						if [ $COLL_PREV_LOGS == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log.prev"
							$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log.prev 2>&1
						fi
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log"
					$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log 2>&1
	
					if [ $COLL_PREV_LOGS == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log.prev"
						$OC_CMD logs -n $NAMESPACE $LINE -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$INIT_CONTAINER.log.prev 2>&1
					fi
				fi
			done
	
			for CONTAINER in $($OC_CMD get $LINE -n $NAMESPACE -o=jsonpath="{.spec.containers[*].name}")
			do 
				if [ $FAST_OC == "true" ] 
				then
					if [ ${#OC_APIVERSION_NAME} -gt 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES/log?container=${CONTAINER}${POD_LOG_TAILLINES_CURL_STR}' => $F_OUTDIR/pod/$RES~$CONTAINER.log"
						local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES/log?container=${CONTAINER}${POD_LOG_TAILLINES_CURL_STR}'"
						eval "$CMD" > $F_OUTDIR/pod/$RES~$CONTAINER.log 2>&1
	
						if [ ! -f $F_OUTDIR/pod/$RES~$CONTAINER.log ] || [[ $(head -1 $F_OUTDIR/pod/$RES~$CONTAINER.log) =~ ^"404 page not found" ]] || ( [[ $(head -1 $F_OUTDIR/pod/$RES~$CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $F_OUTDIR/pod/$RES~$CONTAINER.log | wc -l) -gt 0 ] )
						then
							echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$CONTAINER.log"
							$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$CONTAINER.log 2>&1
						fi
	
						if [ $COLL_PREV_LOGS == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES/log?container=${CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}' => $F_OUTDIR/pod/$RES~$CONTAINER.log.prev"
							local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$RES/log?container=${CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}'"
							eval "$CMD" > $F_OUTDIR/pod/$RES~$CONTAINER.log.prev 2>&1
	
							if [ ! -f $F_OUTDIR/pod/$RES~$CONTAINER.log.prev ] || [[ $(head -1 $F_OUTDIR/pod/$RES~$CONTAINER.log.prev) =~ ^"404 page not found" ]] || ( [[ $(head -1 $F_OUTDIR/pod/$RES~$CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $F_OUTDIR/pod/$RES~$CONTAINER.log | wc -l) -gt 0 ] )
							then
								echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$CONTAINER.log.prev"
								$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$CONTAINER.log.prev 2>&1
							fi
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$CONTAINER.log"
						$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$CONTAINER.log 2>&1
	
						if [ $COLL_PREV_LOGS == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$CONTAINER.log.prev"
							$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$CONTAINER.log.prev 2>&1
						fi
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$CONTAINER.log"
					$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$CONTAINER.log 2>&1
	
					if [ $COLL_PREV_LOGS == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $F_OUTDIR/$OBJ/$RES~$CONTAINER.log.prev"
						$OC_CMD logs -n $NAMESPACE $LINE -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $F_OUTDIR/$OBJ/$RES~$CONTAINER.log.prev 2>&1
					fi
				fi
			done
			IFS=$'\n'
		fi
	done
	
	if [ $FAST_OC_DESC == "true" ]
	then
		if [ -s $FAST_OC_DESC_WORKFILE ]
		then
			for RESTYPE in $(cat $FAST_OC_DESC_WORKFILE | sort | uniq)
			do
				local FAST_OC_DESC_OUTFILE=$F_OUTDIR/fast_oc_desc.$RESTYPE.desc-all

				echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe $RESTYPE -n $NAMESPACE' => $FAST_OC_DESC_OUTFILE"
				$OC_CMD describe $RESTYPE -n $NAMESPACE > $FAST_OC_DESC_OUTFILE
	
				if [ -s $FAST_OC_DESC_OUTFILE ]
				then
					local RECORD_SEPARATOR_KEYWORD=$(head -1 $FAST_OC_DESC_OUTFILE | $AWK -F':' '{ print $1 }' | sed 's/[ ]*$//')
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] RECORD_SEPARATOR_KEYWORD = [$RECORD_SEPARATOR_KEYWORD]"
					fi
				
					if [ ${#RECORD_SEPARATOR_KEYWORD} ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing [sed '/^$/N;/^\n$/D;s/\(^\n\)${RECORD_SEPARATOR_KEYWORD}:/\1#@@@%@@@#\n${RECORD_SEPARATOR_KEYWORD}:/' $FAST_OC_DESC_OUTFILE | $AWK -v OUTDIR=$F_OUTDIR/$RESTYPE 'BEGIN { RS=\"#@@@%@@@#\n\"; FS=\"\n\" } { OBJNAME=substr(\$1, index(\$1, \":\")+1); gsub(/^[ \t]*/, \"\", OBJNAME); gsub(/[\n]*$/, \"\", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR\"/\"OBJNAME\".desc\") } }]"
						sed '/^$/N;/^\n$/D;s/\(^\n\)'${RECORD_SEPARATOR_KEYWORD}':/\1#@@@%@@@#\n'${RECORD_SEPARATOR_KEYWORD}':/' $FAST_OC_DESC_OUTFILE | $AWK -v OUTDIR=$F_OUTDIR/$RESTYPE 'BEGIN { RS="#@@@%@@@#\n"; FS="\n" } { OBJNAME=substr($1, index($1, ":")+1); gsub(/^[ \t]*/, "", OBJNAME); gsub(/[\n]*$/, "", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR"/"OBJNAME".desc") } }'
					else
						echo "[$(date)] [${FUNCNAME[0]}] Unable to determine RECORD_SEPARATOR_KEYWORD for resource type [$RESTYPE] in namespace [$NAMESPACE]!"
					fi
	
					local SOURCE_COUNT=$(grep '^'$RECORD_SEPARATOR_KEYWORD':' $FAST_OC_DESC_OUTFILE | $AWK -F: 'NF>=2' | wc -l)
					local DESC_FILE_COUNT=$(ls -l $F_OUTDIR/$RESTYPE/*.desc | wc -l)
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] DESC_FILE_COUNT = [$DESC_FILE_COUNT] / SOURCE_COUNT = [$SOURCE_COUNT]"
					fi
				
					if [ ${#DESC_FILE_COUNT} -gt 0 ] && [ ${#SOURCE_COUNT} -gt 0 ]
					then
						if [ $DESC_FILE_COUNT -ne $SOURCE_COUNT ]
						then
							cp -p $FAST_OC_DESC_OUTFILE $F_OUTDIR/$RESTYPE
						fi
					else
						cp -p $FAST_OC_DESC_OUTFILE $F_OUTDIR/$RESTYPE
					fi
	
					if [ $MG_DEBUG == "true" ]
					then
						if [ ! -d $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE ]
						then
							mkdir -p $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
						fi
	
						echo "[$(date)] [${FUNCNAME[0]}] File listing (*.desc) on output directory [$F_OUTDIR/$RESTYPE] => [$(ls -l $F_OUTDIR/$RESTYPE/*.desc)]"
						echo "[$(date)] [${FUNCNAME[0]}] File count (*.desc) on output directory [$F_OUTDIR/$RESTYPE] => [$DESC_FILE_COUNT] [SOURCE_COUNT=$SOURCE_COUNT]"
	
						echo "[$(date)] [${FUNCNAME[0]}] Backing up [$FAST_OC_DESC_OUTFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE]..."
						mv $FAST_OC_DESC_OUTFILE $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
					else
						echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_DESC_OUTFILE]..."
						rm $FAST_OC_DESC_OUTFILE
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC - '$OC_CMD describe $RESTYPE -n $NAMESPACE' output file [$FAST_OC_DESC_OUTFILE] does not exist or is zero-sized!"
				fi
			done
	
			if [ $MG_DEBUG == "true" ]
			then
				if [ ! -d $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE ]
				then
					mkdir -p $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
				fi
	
				echo "[$(date)] [${FUNCNAME[0]}] Backing up [$FAST_OC_DESC_WORKFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE]..."
				mv $FAST_OC_DESC_WORKFILE $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
			else
				echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_DESC_WORKFILE]..."
				rm $FAST_OC_DESC_WORKFILE
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC_WORKFILE [$FAST_OC_DESC_WORKFILE] does not exist or is zero-sized!"
		fi
	fi

	if [ $COLLECT_YAML == "true" ]
	then
		if [ ${FAST_OC_YAML} == "true" ] 
		then
			if [ -s $FAST_OC_YAML_WORKFILE ]
			then
				local FAST_OC_YAML_FAILED="false"
				local FAST_OC_YAML_FAILED_ARR=()

				for LINE in $($AWK -F## '{ print $1 "##" $2 "##" $4 }' $FAST_OC_YAML_WORKFILE | sort | uniq)
				do
					local FAST_OC_YAML_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
					local FAST_OC_YAML_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
					local FAST_OC_YAML_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')

					local FAST_OC_YAML_OUTFILE=$FAST_OC_YAML_OUTDIR/fast_oc_yaml.$FAST_OC_YAML_OBJTYPE.yaml-all

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_NS = [$FAST_OC_YAML_NS] / FAST_OC_YAML_OBJTYPE = [$FAST_OC_YAML_OBJTYPE] / FAST_OC_YAML_OUTDIR = [$FAST_OC_YAML_OUTDIR] / FAST_OC_YAML_OUTFILE = [$FAST_OC_YAML_OUTFILE]"
					fi

					if [ ${#FAST_OC_YAML_NS} -gt 0 ]
					then
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
							local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE"
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
							local BULK_YAML_CMD="$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE"
						fi
					else
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
							local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE"
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
							local BULK_YAML_CMD="$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE"
						fi
					fi

					eval "$BULK_YAML_CMD" > $FAST_OC_YAML_OUTFILE

					if [ -s $FAST_OC_YAML_OUTFILE ]
					then
						sed $(( $(wc -l <$FAST_OC_YAML_OUTFILE)-3+1 ))',$ d; 1,2d; s/^-[ ]/#@@@%@@@#\'$'\n/g; s/^[ ]\{2\}//' $FAST_OC_YAML_OUTFILE | sed '1d' | $AWK -v OUTDIR=$FAST_OC_YAML_OUTDIR 'BEGIN { RS="#@@@%@@@#\n"; FS="\n" } { METADATA_FOUND="false"; OBJNAME=""; for (i=1; i<=NF; i++) { if ( $i ~ /^metadata:/  ){ METADATA_FOUND="true" } else { if ( $i ~ /^[ ]{2}name: / && METADATA_FOUND == "true" ) { OBJNAME=substr($i, index($i, ":")+1); gsub(/^[ \t]*/, "", OBJNAME); gsub(/[\n]*$/, "", $0); break } } }; if ( length(OBJNAME) > 0 ) { print > (OUTDIR"/"OBJNAME".yaml") } }'

						local TMP_YAML_ALL_KEEP="false"
						local SOURCE_COUNT=$(grep '^- ' $FAST_OC_YAML_OUTFILE | wc -l)
						local YAML_FILE_COUNT=$(ls -l $FAST_OC_YAML_OUTDIR/*.yaml | wc -l)

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] YAML_FILE_COUNT = [$YAML_FILE_COUNT] / SOURCE_COUNT = [$SOURCE_COUNT]"
						fi
				
						if [ ${#YAML_FILE_COUNT} -gt 0 ] && [ ${#SOURCE_COUNT} -gt 0 ]
						then
							if [ $YAML_FILE_COUNT -ne $SOURCE_COUNT ]
							then
								local TMP_YAML_ALL_KEEP="true"
							fi
						else
							local TMP_YAML_ALL_KEEP="true"
						fi

						if [ $MG_DEBUG == "true" ]
						then
							if [ ! -d $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE ]
							then
								mkdir -p $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
							fi
	
							echo "[$(date)] [${FUNCNAME[0]}] File listing (*.yaml) on output directory [$FAST_OC_YAML_OUTDIR] => [$(ls -l $FAST_OC_YAML_OUTDIR/*.yaml)]"
							echo "[$(date)] [${FUNCNAME[0]}] File count (*.yaml) on output directory [$FAST_OC_YAML_OUTDIR] => [$YAML_FILE_COUNT] [SOURCE_COUNT=$SOURCE_COUNT]"

							echo "[$(date)] [${FUNCNAME[0]}] TMP_YAML_ALL_KEEP = [$TMP_YAML_ALL_KEEP]"
						
							if [ $TMP_YAML_ALL_KEEP == "false" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Moving FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE]..."
								mv $FAST_OC_YAML_OUTFILE $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
							else
								echo "[$(date)] [${FUNCNAME[0]}] Copying FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE]..."
								cp -p $FAST_OC_YAML_OUTFILE $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
							fi
						else	
							if [ $TMP_DESC_ALL_KEEP == "false" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_YAML_OUTFILE]..."
								rm $FAST_OC_YAML_OUTFILE
							fi
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] does not exist or is zero-sized!"
						local FAST_OC_YAML_FAILED="true"
						local FAST_OC_YAML_FAILED_ARR[${#FAST_OC_YAML_FAILED[@]}]="$FAST_OC_YAML_OBJTYPE"
					fi
				done

				if [ ${FAST_OC_YAML_FAILED} == "true" ]
				then	
					# Construct failed object filter
					for FAST_OC_YAML_FAILED_OBJTYPE in ${FAST_OC_YAML_FAILED_ARR[@]}
					do
						if [ ${#FAST_OC_YAML_FAILED_FILTER} -eq 0 ]
						then
							local FAST_OC_YAML_FAILED_FILTER="$FAST_OC_YAML_FAILED_OBJTYPE"
						else
							local FAST_OC_YAML_FAILED_FILTER="${FAST_OC_YAML_FAILED_FILTER}|${FAST_OC_YAML_FAILED_OBJTYPE}"
						fi
					done

					if [ ${#FAST_OC_YAML_FAILED_FILTER} -gt 0 ]
					then
						local FAST_OC_YAML_RETRY_CMD="sort $FAST_OC_YAML_WORKFILE | grep -E '^${FAST_OC_YAML_NS}##($FAST_OC_YAML_FAILED_FILTER)##'"
					else
						local FAST_OC_YAML_RETRY_CMD="sort $FAST_OC_YAML_WORKFILE"
					fi

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_FAILED_FILTER = [$FAST_OC_YAML_FAILED_FILTER]"
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_RETRY_CMD = [$FAST_OC_YAML_RETRY_CMD]"
					fi

					while read LINE
					do
						local FAST_OC_YAML_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
						local FAST_OC_YAML_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
						local FAST_OC_YAML_OBJNAME=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')
						local FAST_OC_YAML_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $4 }')
						local FAST_OC_YAML_CURL_CMD=$(echo "$LINE" | $AWK -F'##' '{ print $5 }')

						if [ ${#FAST_OC_YAML_CURL_CMD} -gt 0 ]
						then
							local BULK_YAML_CMD="$FAST_OC_YAML_CURL_CMD"
						else
							if [ ${#FAST_OC_YAML_NS} -gt 0 ]
							then
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
									local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
									local BULK_YAML_CMD="$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
								fi
							else
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
									local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
									local BULK_YAML_CMD="$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
								fi
							fi
						fi

						echo "[$(date)] [${FUNCNAME[0]}] [RETRY] Executing '$BULK_YAML_CMD' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
						eval "$BULK_YAML_CMD" > $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml
					# done < $FAST_OC_YAML_WORKFILE
					done < <(eval "$FAST_OC_YAML_RETRY_CMD")
				fi

				if [ $MG_DEBUG == "true" ]
				then
					if [ ! -d $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE ]
					then
						mkdir -p $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
					fi
	
					echo "[$(date)] [${FUNCNAME[0]}] Moving FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE]..."
					mv $FAST_OC_YAML_WORKFILE $MAIN_ROOT_DEBUG_OUTDIR/descAll/$NAMESPACE
				else	
					echo "[$(date)] [${FUNCNAME[0]}] Deleting FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE]..."
					rm $FAST_OC_YAML_WORKFILE
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE] does not exist or is zero-sized!"
			fi
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [NS=$NAMESPACE]"
	fi
}
	
analyzeOcAll()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local NAMESPACE=$1
	local OC_ALL_INFILE=$2
	local F_OUTDIR=$3
	
	if [[ $OC_ALL_INFILE =~ $EXTRA_NAMESPACES_OUTDIR ]]
	then
		local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/extra/$NAMESPACE
		local BAD_OBJ_MODE="extra"
	else
		local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/$MUSTGATHER_OPT/$NAMESPACE
		local BAD_OBJ_MODE="$MUSTGATHER_OPT"
	fi
	
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] BAD_OBJ_MODE = [$BAD_OBJ_MODE] / BAD_OBJ_ROOTDIR = [$BAD_OBJ_ROOTDIR]"
	fi
	
	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
	if ! checkUserPriv get,list all $NAMESPACE
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for all resources in namespace [$NAMESPACE]. Checking privilege for main resources..."
	
		# Checking RBAC for main 'oc get all' resources
		if ! checkUserPriv get,list pod $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'pod' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
		
		if ! checkUserPriv get,list deployment $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'deployment' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list statefulset $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'statefulset' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list daemonset $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'daemonset' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list service $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'service' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list job $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'job' in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi
	fi
	
	local BADCTR=0
	local BAD_DEPLOYMENT=0
	local BAD_STATEFULSET=0
	local BAD_DAEMONSET=0
	local BAD_POD=0
	local BAD_JOB=0
	
	local GOODCTR=0
	local GOOD_DEPLOYMENT=0
	local GOOD_STATEFULSET=0
	local GOOD_DAEMONSET=0
	local RUNNING_POD=0
	local COMPLETED_POD=0
	local GOOD_JOB=0
	
	local TOTAL_DEPLOYMENT=0
	local TOTAL_STATEFULSET=0
	local TOTAL_DAEMONSET=0
	local TOTAL_POD=0
	local TOTAL_JOB=0

	local DEPLOY_LINE=
	local STATEFULSET_LINE=
	local DAEMONSET_LINE=
	local POD_LINE=
	local JOB_LINE=
	local POD_EVENT=
	local TO_GET_EVENT=()
	
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "HEALTH REPORT OF NAMESPACE = $NAMESPACE " >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing '$OC_CMD get all -o wide -n $NAMESPACE' => $OC_ALL_INFILE" | tee -a $ANALYZE_OUTFILE
	# echo "[$(date)] [${FUNCNAME[0]}] BAD_OBJ_ROOTDIR = [$BAD_OBJ_ROOTDIR]"
	
	if [ ! -s $OC_ALL_INFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] File [$OC_ALL_INFILE] does not exist or is zero-sized!" 
	
		if [ ! -d $(dirname $OC_ALL_INFILE) ]
		then
			mkdir -p $(dirname $OC_ALL_INFILE)
		fi
	
		getOcAll $NAMESPACE $OC_ALL_INFILE
	fi
	
	if [ $OC_DESC_ON == "true" ] || [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ] || [ $GET_POD_LOGS == "true" ]
	then
		# Deployment
		local TO_PROCEED_DEPLOY_DESC="true"
		local TO_PROCEED_DEPLOY_YAML="false"
		local TO_PROCEED_DEPLOY_JSON="false"
	
		if isRestrictedData "deployment.apps"
		then
			local TO_PROCEED_DEPLOY_DESC="false"
		else
			if isSensitiveData "deployment.apps"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] analyzeOcAll() function does not support '$OC_CMD get -o yaml/json' of [deployment.apps] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [deployment.apps]!"
					local TO_PROCEED_DEPLOY_YAML="true"
					local TO_PROCEED_DEPLOY_JSON="true"
				fi
			else
				local TO_PROCEED_DEPLOY_YAML="true"
				local TO_PROCEED_DEPLOY_JSON="true"
			fi
		fi

		# Statefulset
		local TO_PROCEED_STATEFULSET_DESC="true"
		local TO_PROCEED_STATEFULSET_YAML="false"
		local TO_PROCEED_STATEFULSET_JSON="false"
	
		if isRestrictedData "statefulset.apps"
		then
			local TO_PROCEED_STATEFULSET_DESC="false"
		else
			if isSensitiveData "statefulset.apps"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] analyzeOcAll() function does not support '$OC_CMD get -o yaml/json' of [statefulset.apps] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [statefulset.apps]!"
					local TO_PROCEED_STATEFULSET_YAML="true"
					local TO_PROCEED_STATEFULSET_JSON="true"
				fi
			else
				local TO_PROCEED_STATEFULSET_YAML="true"
				local TO_PROCEED_STATEFULSET_JSON="true"
			fi
		fi

		# Daemonset
		local TO_PROCEED_DAEMONSET_DESC="true"
		local TO_PROCEED_DAEMONSET_YAML="false"
		local TO_PROCEED_DAEMONSET_JSON="false"
	
		if isRestrictedData "daemonset.apps"
		then
			local TO_PROCEED_DAEMONSET_DESC="false"
		else
			if isSensitiveData "daemonset.apps"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] analyzeOcAll() function does not support '$OC_CMD get -o yaml/json' of [daemonset.apps] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [daemonset.apps]!"
					local TO_PROCEED_DAEMONSET_YAML="true"
					local TO_PROCEED_DAEMONSET_JSON="true"
				fi
			else
				local TO_PROCEED_DAEMONSET_YAML="true"
				local TO_PROCEED_DAEMONSET_JSON="true"
			fi
		fi

		# Pod
		local TO_PROCEED_POD_DESC="true"
		local TO_PROCEED_POD_YAML="false"
		local TO_PROCEED_POD_JSON="false"
		local TO_PROCEED_POD_LOGS="false"
	
		if isRestrictedData "pod"
		then
			local TO_PROCEED_POD_DESC="false"
		else
			if isSensitiveData "pod"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] analyzeOcAll() function does not support '$OC_CMD get -o yaml/json' and '$OC_CMD logs' of [pod] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [pod]!"
					local TO_PROCEED_POD_YAML="true"
					local TO_PROCEED_POD_JSON="true"
					local TO_PROCEED_POD_LOGS="true"
				fi
			else
				local TO_PROCEED_POD_YAML="true"
				local TO_PROCEED_POD_JSON="true"
				local TO_PROCEED_POD_LOGS="true"
			fi
		fi

		# Job
		local TO_PROCEED_JOB_DESC="true"
		local TO_PROCEED_JOB_YAML="false"
		local TO_PROCEED_JOB_JSON="false"
	
		if isRestrictedData "job.batch"
		then
			local TO_PROCEED_JOB_DESC="false"
		else
			if isSensitiveData "job.batch"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] analyzeOcAll() function does not support '$OC_CMD get -o yaml/json' of [job.batch] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [job.batch]!"
					local TO_PROCEED_JOB_YAML="true"
					local TO_PROCEED_JOB_JSON="true"
				fi
			else
				local TO_PROCEED_JOB_YAML="true"
				local TO_PROCEED_JOB_JSON="true"
			fi
		fi
	fi

	IFS=$'\n'
	
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing DEPLOYMENTS [$NAMESPACE]" | tee -a $ANALYZE_OUTFILE
	
	local D_HEADER=0
	for DEPLOY_LINE in $(grep '^deployment.apps/' $OC_ALL_INFILE)
	do
		(( TOTAL_DEPLOYMENT=TOTAL_DEPLOYMENT+1 ))

		local DEPLOY=$(echo "$DEPLOY_LINE" | $AWK '{ print $1 }') 
		local DEPLOY_NAME=$(echo "$DEPLOY" | $AWK -F'/' '{ print $2 }') 
		local D_READY_COUNT=$(echo "$DEPLOY_LINE" | $AWK '{ print $2 }') 
		local D_CONTAINERS=$(echo "$DEPLOY_LINE" | $AWK '{ print $6 }')
		local D_CHECK_RES=$(echo "$D_READY_COUNT" | $AWK -F '/' '{ if ( $1 == $2 ) { print "OK" } else { print "NOK" } }')
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] DEPLOY = [$DEPLOY] / DEPLOY_NAME = [$DEPLOY_NAME] / D_READY_COUNT = [$D_READY_COUNT] / D_CONTAINERS = [$D_CONTAINERS] / D_CHECK_RES = [$D_CHECK_RES]"
		fi
	
		if [ $D_CHECK_RES == "NOK" ]
		then
			(( BADCTR=BADCTR+1 ))
			(( BAD_DEPLOYMENT=BAD_DEPLOYMENT+1 ))
	
			if [ $INCIDENT_REPORT_ENABLED == "true" ]
			then
				setIncident "ocp" "$DEPLOY_NAME" "oc_get_deployment" "RESOURCE_TYPE=deployment.apps;NAMESPACE=$NAMESPACE" "$DEPLOY_LINE"
			fi
	
			if [ $D_HEADER -eq 0 ]
			then
				printf "%-6s %-65s %-85s %-8s %-8s \n" "COUNT" "DEPLOYMENT" "CONTAINERS" "READY" "STATUS" >> $ANALYZE_OUTFILE
				local D_HEADER=1
			fi
	
			printf "%-6s %-65s %-85s %-8s %-8s \n" "${BAD_DEPLOYMENT}" "$DEPLOY_NAME" "$D_CONTAINERS" "$D_READY_COUNT" "NOK" >> $ANALYZE_OUTFILE
	
			if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" ) && ! -d $BAD_OBJ_ROOTDIR/deployment ]]
			then
				mkdir -p $BAD_OBJ_ROOTDIR/deployment
			fi
	
			# To copy .desc/.yaml of problematic resource to 0-README-FIRST directory
			if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_DEPLOY_DESC == "true" ] && [[ ( -f $F_OUTDIR/deployment.apps/$DEPLOY_NAME.desc || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/deployment.apps/$DEPLOY_NAME.desc ) ]]
			then
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/deployment.apps/$DEPLOY_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/deployment]..."
					cp -p $F_OUTDIR/deployment.apps/$DEPLOY_NAME.desc $BAD_OBJ_ROOTDIR/deployment
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/deployment.apps/$DEPLOY_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/deployment]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/deployment.apps/$DEPLOY_NAME.desc $BAD_OBJ_ROOTDIR/deployment
				fi
			fi
	
			if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_DEPLOY_YAML == "true" ] && [[ ( -f $F_OUTDIR/deployment.apps/$DEPLOY_NAME.yaml || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/deployment.apps/$DEPLOY_NAME.yaml ) ]]
			then
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/deployment.apps/$DEPLOY_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/deployment]..."
					cp -p $F_OUTDIR/deployment.apps/$DEPLOY_NAME.yaml $BAD_OBJ_ROOTDIR/deployment
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/deployment.apps/$DEPLOY_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/deployment]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/deployment.apps/$DEPLOY_NAME.yaml $BAD_OBJ_ROOTDIR/deployment
				fi
			fi	
	
			if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_DEPLOY_JSON == "true" ] && [[ ( -f $F_OUTDIR/deployment.apps/$DEPLOY_NAME.json || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/deployment.apps/$DEPLOY_NAME.json ) ]]
			then
				# if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/deployment.apps/$DEPLOY_NAME.json] to directory [$BAD_OBJ_ROOTDIR/deployment]..."
					cp -p $F_OUTDIR/deployment.apps/$DEPLOY_NAME.json $BAD_OBJ_ROOTDIR/deployment
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/deployment.apps/$DEPLOY_NAME.json] to directory [$BAD_OBJ_ROOTDIR/deployment]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/deployment.apps/$DEPLOY_NAME.json $BAD_OBJ_ROOTDIR/deployment
				fi
			fi	
		else
			(( GOOD_DEPLOYMENT=GOOD_DEPLOYMENT+1 ))
			(( GOODCTR=GOODCTR+1 ))
		fi
	done
	
	if [ $(( GOOD_DEPLOYMENT + BAD_DEPLOYMENT )) -gt 0 ]
	then
		if [ $BAD_DEPLOYMENT -gt 0 ]
		then
			echo ">>> [TOTAL OK] [$NAMESPACE] Deployment = $GOOD_DEPLOYMENT" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL NOK] [$NAMESPACE] Deployment = $BAD_DEPLOYMENT" >> $ANALYZE_OUTFILE
		else
			echo ">>> [TOTAL OK] [$NAMESPACE] Deployment = $GOOD_DEPLOYMENT" >> $ANALYZE_OUTFILE
		fi
	else
		echo ">>> [$NAMESPACE] There is no 'deployment' found!" >> $ANALYZE_OUTFILE
	fi

	echo ">>> [TOTAL DEPLOYMENT] = ${TOTAL_DEPLOYMENT}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE
	
	local S_HEADER=0
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing STATEFULESETS [$NAMESPACE]" | tee -a $ANALYZE_OUTFILE
	for STATEFULSET_LINE in $(grep '^statefulset.apps/' $OC_ALL_INFILE)
	do
		(( TOTAL_STATEFULSET=TOTAL_STATEFULSET+1 ))

		local STATEFULSET=$(echo "$STATEFULSET_LINE" | $AWK '{ print $1 }') 
		local STATEFULSET_NAME=$(echo "$STATEFULSET" | $AWK -F'/' '{ print $2 }') 
		local S_READY_COUNT=$(echo "$STATEFULSET_LINE" | $AWK '{ print $2 }') 
		local S_CONTAINERS=$(echo "$STATEFULSET_LINE" | $AWK '{ print $4 }')
		local S_CHECK_RES=$(echo "$S_READY_COUNT" | $AWK -F '/' '{ if ( $1 == $2 ) { print "OK" } else { print "NOK" } }')
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] STATEFULSET = [$STATEFULSET] / STATEFULSET_NAME = [$STATEFULSET_NAME] / S_READY_COUNT = [$S_READY_COUNT] / S_CONTAINERS = [$S_CONTAINERS] / S_CHECK_RES = [$S_CHECK_RES]"
		fi
	
		if [ $S_CHECK_RES == "NOK" ]
		then
			(( BADCTR=BADCTR+1 ))
			(( BAD_STATEFULSET=BAD_STATEFULSET+1 ))
	
			if [ $INCIDENT_REPORT_ENABLED == "true" ]
			then
				setIncident "ocp" "$STATEFULSET_NAME" "oc_get_statefulset" "RESOURCE_TYPE=statefulset.apps;NAMESPACE=$NAMESPACE" "$STATEFULSET_LINE"
			fi
	
			if [ $S_HEADER -eq 0 ]
			then
				printf "%-6s %-65s %-85s %-8s %-8s \n" "COUNT" "STATEFULSET" "CONTAINERS" "READY" "STATUS" >> $ANALYZE_OUTFILE
				local S_HEADER=1
			fi
	
			printf "%-6s %-65s %-85s %-8s %-8s \n" "${BAD_STATEFULSET}" "$STATEFULSET_NAME" "$S_CONTAINERS" "$S_READY_COUNT" "NOK" >> $ANALYZE_OUTFILE
	
			if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" ) && ! -d $BAD_OBJ_ROOTDIR/statefulset ]]
			then
				mkdir -p $BAD_OBJ_ROOTDIR/statefulset
			fi
	
			# To copy .desc/.yaml of problematic resource to 0-README-FIRST directory
			if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_STATEFULSET_DESC == "true" ] && [[ ( -f $F_OUTDIR/statefulset.apps/$STATEFULSET_NAME.desc || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/statefulset.apps/$STATEFULSET_NAME.desc ) ]]
			then
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/statefulset.apps/$STATEFULSET_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/statefulset]..."
					cp -p $F_OUTDIR/statefulset.apps/$STATEFULSET_NAME.desc $BAD_OBJ_ROOTDIR/statefulset
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/statefulset.apps/$STATEFULSET_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/statefulset]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/statefulset.apps/$STATEFULSET_NAME.desc $BAD_OBJ_ROOTDIR/statefulset
				fi
			fi
	
			if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_STATEFULSET_YAML == "true" ] && [[ ( -f $F_OUTDIR/statefulset.apps/$STATEFULSET_NAME.yaml || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/statefulset.apps/$STATEFULSET_NAME.yaml ) ]]
			then
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/statefulset.apps/$STATEFULSET_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/statefulset]..."
					cp -p $F_OUTDIR/statefulset.apps/$STATEFULSET_NAME.yaml $BAD_OBJ_ROOTDIR/statefulset
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/statefulset.apps/$STATEFULSET_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/statefulset]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/statefulset.apps/$STATEFULSET_NAME.yaml $BAD_OBJ_ROOTDIR/statefulset
				fi
			fi
	
			if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_STATEFULSET_JSON == "true" ] && [[ ( -f $F_OUTDIR/statefulset.apps/$STATEFULSET_NAME.json || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/statefulset.apps/$STATEFULSET_NAME.json ) ]]
			then
				# if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/statefulset.apps/$STATEFULSET_NAME.json] to directory [$BAD_OBJ_ROOTDIR/statefulset]..."
					cp -p $F_OUTDIR/statefulset.apps/$STATEFULSET_NAME.json $BAD_OBJ_ROOTDIR/statefulset
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/statefulset.apps/$STATEFULSET_NAME.json] to directory [$BAD_OBJ_ROOTDIR/statefulset]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/statefulset.apps/$STATEFULSET_NAME.json $BAD_OBJ_ROOTDIR/statefulset
				fi
			fi
		else
			(( GOOD_STATEFULSET=GOOD_STATEFULSET+1 ))
			(( GOODCTR=GOODCTR+1 ))
		fi
	done
	
	if [ $(( GOOD_STATEFULSET + BAD_STATEFULSET )) -gt 0 ]
	then
		if [ $BAD_STATEFULSET -gt 0 ]
		then
			echo ">>> [TOTAL OK] [$NAMESPACE] Statefulset = $GOOD_STATEFULSET" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL NOK] [$NAMESPACE] Statefulset = $BAD_STATEFULSET" >> $ANALYZE_OUTFILE
		else
			echo ">>> [TOTAL OK] [$NAMESPACE] Statefulset = $GOOD_STATEFULSET" >> $ANALYZE_OUTFILE
		fi
	else
		echo ">>> [$NAMESPACE] There is no 'statefuleset' found!" >> $ANALYZE_OUTFILE
	fi
		
	echo ">>> [TOTAL STATEFULSET] = ${TOTAL_STATEFULSET}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE

	local DS_HEADER=0
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing DAEMONSET [$NAMESPACE]" | tee -a $ANALYZE_OUTFILE
	for DAEMONSET_LINE in $(grep '^daemonset.apps/' $OC_ALL_INFILE)
	do
		(( TOTAL_DAEMONSET=TOTAL_DAEMONSET+1 ))

		local DAEMONSET=$(echo "$DAEMONSET_LINE" | $AWK '{ print $1 }') 
		local DAEMONSET_NAME=$(echo "$DAEMONSET" | $AWK -F'/' '{ print $2 }') 
		local DS_DESIRED_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $2 }') 
		local DS_CURRENT_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $3 }') 
		local DS_READY_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $4 }') 
		local DS_UPTODATE_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $5 }') 
		local DS_AVAILABLE_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $6 }') 
		local DS_CHECK_RES=$(echo "${DS_DESIRED_COUNT}##${DS_CURRENT_COUNT}##${DS_READY_COUNT}##${DS_UPTODATE_COUNT}##${DS_AVAILABLE_COUNT}" | $AWK -F## '{ if ( $1 == $2 && $1 == $3 && $1 == $4 && $1 == $5 ) { print "OK" } else { print "NOK" } }')
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] DAEMONSET = [$DAEMONSET] / DAEMONSET_NAME = [$DAEMONSET_NAME] / DS_DESIRED_COUNT = [$DS_DESIRED_COUNT] / DS_CURRENT_COUNT = [$DS_CURRENT_COUNT] / DS_READY_COUNT = [$DS_READY_COUNT] / DS_UPTODATE_COUNT = [$DS_UPTODATE_COUNT] / DS_AVAILABLE_COUNT = [$DS_AVAILABLE_COUNT]" 
		fi
	
		if [ $DS_CHECK_RES == "NOK" ]
		then
			(( BADCTR=BADCTR+1 ))
			(( BAD_DAEMONSET=BAD_DAEMONSET+1 ))
	
			if [ $INCIDENT_REPORT_ENABLED == "true" ]
			then
				setIncident "ocp" "$DAEMONSET_NAME" "oc_get_daemonset" "RESOURCE_TYPE=daemonset.apps;NAMESPACE=$NAMESPACE" "$DAEMONSET_LINE"
			fi
	
			if [ $DS_HEADER -eq 0 ]
			then
				printf "%-6s %-65s %-18s %-18s %-18s %-18s %-18s %-18s %-8s \n" "COUNT" "DAEMONSET" "DESIRED_COUNT" "CURRENT_COUNT" "READY_COUNT" "UPTODATE_COUNT" "AVAILABLE_COUNT" "STATUS" >> $ANALYZE_OUTFILE
				local DS_HEADER=1
			fi
	
			printf "%-6s %-65s %-18s %-18s %-18s %-18s %-18s %-18s %-8s \n" "${BAD_DAEMONSET}" "$DAEMONSET_NAME" "$DS_DESIRED_COUNT" "$DS_CURRENT_COUNT" "$DS_READY_COUNT" "$DS_UPTODATE_COUNT" "$DS_AVAILABLE_COUNT" "NOK" >> $ANALYZE_OUTFILE
	
			if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" ) && ! -d $BAD_OBJ_ROOTDIR/daemonset ]]
			then
				mkdir -p $BAD_OBJ_ROOTDIR/daemonset
			fi
	
			# To copy .desc/.yaml of problematic resource to 0-README-FIRST directory
			if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_DAEMONSET_DESC == "true" ] && [[ ( -f $F_OUTDIR/daemonset.apps/$DAEMONSET_NAME.desc || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/daemonset.apps/$DAEMONSET_NAME.desc ) ]]
			then
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/daemonset.apps/$DAEMONSET_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/daemonset]..."
					cp -p $F_OUTDIR/daemonset.apps/$DAEMONSET_NAME.desc $BAD_OBJ_ROOTDIR/daemonset
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/daemonset.apps/$DAEMONSET_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/daemonset]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/daemonset.apps/$DAEMONSET_NAME.desc $BAD_OBJ_ROOTDIR/daemonset
				fi
			fi
	
			if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_DAEMONSET_YAML == "true" ] && [[ ( -f $F_OUTDIR/daemonset.apps/$DAEMONSET_NAME.yaml || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/daemonset.apps/$DAEMONSET_NAME.yaml ) ]]
			then
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/daemonset.apps/$DAEMONSET_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/daemonset]..."
					cp -p $F_OUTDIR/daemonset.apps/$DAEMONSET_NAME.yaml $BAD_OBJ_ROOTDIR/daemonset
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/daemonset.apps/$DAEMONSET_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/daemonset]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/daemonset.apps/$DAEMONSET_NAME.yaml $BAD_OBJ_ROOTDIR/daemonset
				fi
			fi
	
			if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_DAEMONSET_JSON == "true" ] && [[ ( -f $F_OUTDIR/daemonset.apps/$DAEMONSET_NAME.json || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/daemonset.apps/$DAEMONSET_NAME.json ) ]]
			then
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/daemonset.apps/$DAEMONSET_NAME.json] to directory [$BAD_OBJ_ROOTDIR/daemonset]..."
					cp -p $F_OUTDIR/daemonset.apps/$DAEMONSET_NAME.json $BAD_OBJ_ROOTDIR/daemonset
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/daemonset.apps/$DAEMONSET_NAME.json] to directory [$BAD_OBJ_ROOTDIR/daemonset]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/daemonset.apps/$DAEMONSET_NAME.json $BAD_OBJ_ROOTDIR/daemonset
				fi
			fi
		else
			(( GOOD_DAEMONSET=GOOD_DAEMONSET+1 ))
			(( GOODCTR=GOODCTR+1 ))
		fi
	done
	
	if [ $(( GOOD_DAEMONSET + BAD_DAEMONSET )) -gt 0 ]
	then
		if [ $BAD_DAEMONSET -gt 0 ]
		then
			echo ">>> [TOTAL OK] [$NAMESPACE] Daemonset = $GOOD_DAEMONSET" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL NOK] [$NAMESPACE] Daemonset = $BAD_DAEMONSET" >> $ANALYZE_OUTFILE
		else
			echo ">>> [TOTAL OK] [$NAMESPACE] Daemonset = $GOOD_DAEMONSET" >> $ANALYZE_OUTFILE
		fi
	else
		echo ">>> [$NAMESPACE] There is no 'daemonset' found!" >> $ANALYZE_OUTFILE
	fi		
		
	echo ">>> [TOTAL DAEMONSET] = ${TOTAL_DAEMONSET}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE

	local P_HEADER=0
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing PODS [$NAMESPACE]" | tee -a $ANALYZE_OUTFILE
	for POD_LINE in $(grep '^pod/' $OC_ALL_INFILE)
	do
		(( TOTAL_POD=TOTAL_POD+1 ))

		local POD=$(echo "$POD_LINE" | $AWK '{ print $1 }') 
		local POD_NAME=$(echo "$POD" | $AWK -F'/' '{ print $2 }') 
		local P_READY_COUNT=$(echo "$POD_LINE" | $AWK '{ print $2 }') 
		local P_STATUS=$(echo "$POD_LINE" | $AWK '{ print $3 }')
		local P_CHECK_RES=$(echo "$P_READY_COUNT" | $AWK -F '/' '{ if ( $1 == $2 ) { print "OK" } else { print "NOK" } }')
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] POD = [$POD] / POD_NAME = [$POD_NAME] / P_READY_COUNT = [$P_READY_COUNT] / P_STATUS = [$P_STATUS] / P_CHECK_RES = [$P_CHECK_RES]"
		fi
	
		if [ $P_STATUS != "Running" ] || [ $P_CHECK_RES == "NOK"  ]
		then
			if [ $P_STATUS != "Completed" ]
			then
				(( BADCTR=BADCTR+1 ))
				(( BAD_POD=BAD_POD+1 ))
	
				if [ $INCIDENT_REPORT_ENABLED == "true" ]
				then
					setIncident "ocp" "$POD_NAME" "oc_get_pod" "RESOURCE_TYPE=pod;NAMESPACE=$NAMESPACE" "$POD_LINE"
				fi
	
				if [ $P_HEADER -eq 0 ]
				then
					printf "%-6s %-65s %-85s %-8s %-8s \n" "COUNT" "POD" "CONTAINERS" "READY" "STATUS" >> $ANALYZE_OUTFILE
					P_HEADER=1
				fi
	
				printf "%-6s %-65s %-85s %-8s %-8s \n" "${BAD_POD}" "$POD_NAME" "$($OC_CMD get $POD -n $NAMESPACE -o=jsonpath="{.spec.containers[*].name}" | sed 's/ /,/g')" "$P_READY_COUNT" "$P_STATUS" >> $ANALYZE_OUTFILE
	
				local TO_GET_EVENT[${#TO_GET_EVENT[@]}]=$POD_NAME
	
				if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" || $GET_POD_LOGS == "true" ) && ! -d $BAD_OBJ_ROOTDIR/pod ]]
				then
					mkdir -p $BAD_OBJ_ROOTDIR/pod
				fi
	
				# To copy .desc/.yaml/.log/.log.prev of problematic resource to 0-README-FIRST directory
				if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_POD_DESC == "true" ] && [[ ( -f $F_OUTDIR/pod/$POD_NAME.desc || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/$POD_NAME.desc ) ]]
				then
					if [ $BAD_OBJ_MODE != "extra" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/pod/$POD_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/pod]..."
						cp -p $F_OUTDIR/pod/$POD_NAME.desc $BAD_OBJ_ROOTDIR/pod
					else
						echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/$POD_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/pod]..."
						cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/$POD_NAME.desc $BAD_OBJ_ROOTDIR/pod
					fi
				fi
		
				if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_POD_YAML == "true" ] && [[ ( -f $F_OUTDIR/pod/$POD_NAME.yaml || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/$POD_NAME.yaml ) ]]
				then
					if [ $BAD_OBJ_MODE != "extra" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/pod/$POD_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/pod]..."
						cp -p $F_OUTDIR/pod/$POD_NAME.yaml $BAD_OBJ_ROOTDIR/pod
					else
						echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/$POD_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/pod]..."
						cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/$POD_NAME.yaml $BAD_OBJ_ROOTDIR/pod
					fi
				fi	
	
				if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_POD_JSON == "true" ] && [[ ( -f $F_OUTDIR/pod/$POD_NAME.json || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/$POD_NAME.json ) ]]
				then
					# if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
					if [ $BAD_OBJ_MODE != "extra" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/pod/$POD_NAME.json] to directory [$BAD_OBJ_ROOTDIR/pod]..."
						cp -p $F_OUTDIR/pod/$POD_NAME.json $BAD_OBJ_ROOTDIR/pod
					else
						echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/$POD_NAME.json] to directory [$BAD_OBJ_ROOTDIR/pod]..."
						cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/$POD_NAME.json $BAD_OBJ_ROOTDIR/pod
					fi
				fi	
	
				# Can't provide exact filename because a pod can contain multiple (container) log files (a leap of faith :)	
				if [ -d $F_OUTDIR/pod ] || [ -d $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod ]
				then
					if [ $GET_POD_LOGS == "true" ] && [ $TO_PROCEED_POD_LOGS == "true" ] 
					then
						# if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
						if [ $BAD_OBJ_MODE != "extra" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/pod/${POD_NAME}*.log] to directory [$BAD_OBJ_ROOTDIR/pod]..."
							cp -p $F_OUTDIR/pod/${POD_NAME}*.log $BAD_OBJ_ROOTDIR/pod
	
							if [ $COLL_PREV_LOGS == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/pod/${POD_NAME}*.log.prev] to directory [$BAD_OBJ_ROOTDIR/pod]..."
								cp -p $F_OUTDIR/pod/${POD_NAME}*.log.prev $BAD_OBJ_ROOTDIR/pod
							fi				
						else
							echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/${POD_NAME}*.log] to directory [$BAD_OBJ_ROOTDIR/pod]..."
							cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/${POD_NAME}*.log $BAD_OBJ_ROOTDIR/pod
	
							if [ $COLL_PREV_LOGS == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/${POD_NAME}*.log.prev] to directory [$BAD_OBJ_ROOTDIR/pod]..."
								cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pod/${POD_NAME}*.log.prev $BAD_OBJ_ROOTDIR/pod
							fi				
						fi
					fi
				fi	
			else
				(( COMPLETED_POD=COMPLETED_POD+1 ))
				(( GOODCTR=GOODCTR+1 ))
			fi
		else
			(( RUNNING_POD=RUNNING_POD+1 ))
			(( GOODCTR=GOODCTR+1 ))
		fi
	done
	
	if [ ${#TO_GET_EVENT[@]} -gt 0 ]
	then
		echo >> $ANALYZE_OUTFILE
	
		local PODCTR=1	
	
		for POD_EVENT in ${TO_GET_EVENT[@]}
		do
			echo "[$PODCTR] [PODNAME = $POD_EVENT]" >> $ANALYZE_OUTFILE
	
			local OLD_ANALYZE_OUTFILE_ROWCNT=$(wc -l $ANALYZE_OUTFILE | $AWK '{ print $1 }')
	
			if [ $OC_DESC_ON == "true" ] && [ -s $F_OUTDIR/pod/$POD_EVENT.desc ]
			then
				$AWK '/^Events:/{f=1}f' $F_OUTDIR/pod/$POD_EVENT.desc | sed '/^[ \t]*$/d' >> $ANALYZE_OUTFILE 2>&1
			else
				$OC_CMD describe pod -n $NAMESPACE $POD_EVENT | $AWK '/^Events:/{f=1}f' | sed '/^[ \t]*$/d' >> $ANALYZE_OUTFILE 2>&1
			fi
	
			local NOW_ANALYZE_OUTFILE_ROWCNT=$(wc -l $ANALYZE_OUTFILE | $AWK '{ print $1 }')
	
			if [ $NOW_ANALYZE_OUTFILE_ROWCNT -eq $OLD_ANALYZE_OUTFILE_ROWCNT ]
			then
				echo "<< Unable to retrieve events from pod >>"  >> $ANALYZE_OUTFILE	
			fi
	
			echo >> $ANALYZE_OUTFILE
			echo "----------------------------------------------------------" >> $ANALYZE_OUTFILE
	
			(( PODCTR=PODCTR+1 ))
		done
	
		echo >> $ANALYZE_OUTFILE
	fi
	
	if [ $(( RUNNING_POD + COMPLETED_POD + BAD_POD )) -gt 0 ]
	then
		if [ $BAD_POD -gt 0 ]
		then
			echo ">>> [TOTAL OK] [$NAMESPACE] Running = $RUNNING_POD / Completed = $COMPLETED_POD" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL NOK] [$NAMESPACE] Pod = $BAD_POD" >> $ANALYZE_OUTFILE
		else
			echo ">>> [TOTAL OK] [$NAMESPACE] Running = $RUNNING_POD / Completed = $COMPLETED_POD" >> $ANALYZE_OUTFILE
		fi
	else
		echo ">>> [$NAMESPACE] There is no 'pod' found!" >> $ANALYZE_OUTFILE
	fi
		
	echo ">>> [TOTAL POD] = ${TOTAL_POD}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE

	echo "[$(date)] [${FUNCNAME[0]}] Analyzing JOBS [$NAMESPACE]" | tee -a $ANALYZE_OUTFILE
	
	local J_HEADER=0

	# Newer k8s comes with an additional column - STATUS
	local JOB_HEADER=$($AWK '$1 ~ /^job.batch/ { print HEADER; exit } { HEADER=$0 }' $OC_ALL_INFILE | sed -E 's/ +/ /g')
	
	if [ ${#JOB_HEADER} -gt 0 ]
	then
		local JOB_COMPLETIONS_COL=$(echo "$JOB_HEADER" | $AWK 'BEGIN { RS=FS } /COMPLETIONS/ { print NR }')

		if [ ${#JOB_COMPLETIONS_COL} -eq 0 ] || [ ${JOB_COMPLETIONS_COL} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Unable to determine location of COMPLETIONS column! Setting JOB_COMPLETIONS_COL to default value [2]..." >&2
			local JOB_COMPLETIONS_COL=2
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Unable to extract headers for resource 'job.batch'! Setting JOB_COMPLETIONS_COL to default value [2]..." >&2
		local JOB_COMPLETIONS_COL=2
	fi

	# Default value
	local JOB_DURATION_COL=3
	(( JOB_DURATION_COL=JOB_COMPLETIONS_COL+1))

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] JOB_HEADER = [$JOB_HEADER]"
		echo "[$(date)] [${FUNCNAME[0]}] JOB_COMPLETIONS_COL = [$JOB_COMPLETIONS_COL]"
		echo "[$(date)] [${FUNCNAME[0]}] JOB_DURATION_COL = [$JOB_DURATION_COL]"
	fi
	
	for JOB_LINE in $(grep '^job.batch/' $OC_ALL_INFILE)
	do
		(( TOTAL_JOB=TOTAL_JOB+1 ))

		local JOB=$(echo "$JOB_LINE" | $AWK '{ print $1 }') 
		local JOB_NAME=$(echo "$JOB" | $AWK -F'/' '{ print $2 }') 
		local J_READY_COUNT=$(echo "$JOB_LINE" | $AWK '{ print $'$JOB_COMPLETIONS_COL' }') 
		local J_DURATION=$(echo "$JOB_LINE" | $AWK '{ print $'$JOB_DURATION_COL' }') 
		local J_CHECK_RES=$(echo "$J_READY_COUNT" | $AWK -F '/' '{ if ( $1 == $2 ) { print "OK" } else { print "NOK" } }')
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] JOB = [$JOB] / JOB_NAME = [$JOB_NAME] / J_READY_COUNT = [$J_READY_COUNT] / J_DURATION = [$J_DURATION] / J_CHECK_RES = [$J_CHECK_RES]"
		fi
	
		if [ $J_CHECK_RES == "NOK" ]
		then
			(( BADCTR=BADCTR+1 ))
			(( BAD_JOB=BAD_JOB+1 ))
	
			if [ $INCIDENT_REPORT_ENABLED == "true" ]
			then
				setIncident "ocp" "$JOB_NAME" "oc_get_job" "RESOURCE_TYPE=job.batch;NAMESPACE=$NAMESPACE" "$JOB_LINE"
			fi
	
			if [ $J_HEADER -eq 0 ]
			then
				printf "%-6s %-70s %-10s %-10s %-10s \n" "COUNT" "JOB" "READY" "DURATION" "STATUS" >> $ANALYZE_OUTFILE
				local J_HEADER=1
			fi
	
			printf "%-6s %-70s %-10s %-10s %-10s \n" "${BAD_JOB}" "$JOB_NAME" "$J_READY_COUNT" "$J_DURATION" "NOK" >> $ANALYZE_OUTFILE
	
			if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" ) && ! -d $BAD_OBJ_ROOTDIR/job ]]
			then
				mkdir -p $BAD_OBJ_ROOTDIR/job.batch
			fi
	
			if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_JOB_DESC == "true" ] && [[ ( -f $F_OUTDIR/job.batch/$JOB_NAME.desc || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/job.batch/$JOB_NAME.desc ) ]]
			then
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/job.batch/$JOB_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/job.batch]..."
					cp -p $F_OUTDIR/job.batch/$JOB_NAME.desc $BAD_OBJ_ROOTDIR/job.batch
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/job.batch/$JOB_NAME.desc] to directory [$BAD_OBJ_ROOTDIR/job.batch]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/job.batch/$JOB_NAME.desc $BAD_OBJ_ROOTDIR/job.batch
				fi
			fi	
	
			if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_JOB_YAML == "true" ] && [[ ( -f $F_OUTDIR/job.batch/$JOB_NAME.yaml || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/job.batch/$JOB_NAME.yaml ) ]]
			then
				if [ $BAD_OBJ_MODE != "extra" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/job.batch/$JOB_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/job.batch]..."
					cp -p $F_OUTDIR/job.batch/$JOB_NAME.yaml $BAD_OBJ_ROOTDIR/job.batch
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/job.batch/$JOB_NAME.yaml] to directory [$BAD_OBJ_ROOTDIR/job.batch]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/job.batch/$JOB_NAME.yaml $BAD_OBJ_ROOTDIR/job.batch
				fi
			fi
	
			if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_JOB_JSON == "true" ] && [[ ( -f $F_OUTDIR/job.batch/$JOB_NAME.json || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/job.batch/$JOB_NAME.json ) ]]
			then
				if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$F_OUTDIR/job.batch/$JOB_NAME.json] to directory [$BAD_OBJ_ROOTDIR/job.batch]..."
					cp -p $F_OUTDIR/job.batch/$JOB_NAME.json $BAD_OBJ_ROOTDIR/job.batch
				else
					echo "[$(date)] [${FUNCNAME[0]}] Copying file [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/job.batch/$JOB_NAME.json] to directory [$BAD_OBJ_ROOTDIR/job.batch]..."
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/job.batch/$JOB_NAME.json $BAD_OBJ_ROOTDIR/job.batch
				fi
			fi
		else
			(( GOOD_JOB=GOOD_JOB+1 ))
			(( GOODCTR=GOODCTR+1 ))
		fi
	done
	
	if [ $(( GOOD_JOB + BAD_JOB )) -gt 0 ]
	then
		if [ $BAD_JOB -gt 0 ]
		then
			echo ">>> [TOTAL OK] [$NAMESPACE] Job = $GOOD_JOB" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL NOK] [$NAMESPACE] Job = $BAD_JOB" >> $ANALYZE_OUTFILE
		else
			echo ">>> [TOTAL OK] [$NAMESPACE] Job = $GOOD_JOB" >> $ANALYZE_OUTFILE
		fi
	else
		echo ">>> [$NAMESPACE] There is no 'job' found!" >> $ANALYZE_OUTFILE
	fi

	echo ">>> [TOTAL JOB] = ${TOTAL_JOB}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE
		
	if [ $BADCTR -eq 0 ] 
	then
		if [ $GOODCTR -gt 0 ]
		then
			echo "[$(date)] [$NAMESPACE] Objects [Deployments, Statefulsets, Daemonsets, Pods, Jobs] seem to be operating fine!" >> $ANALYZE_OUTFILE
		else
			echo "[$(date)] [$NAMESPACE] does not seem to contain objects [Deployments, Statefulsets, Daemonsets, Pods, Jobs]!" >> $ANALYZE_OUTFILE
		fi

		echo >> $ANALYZE_OUTFILE
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [NS=$NAMESPACE]"
	fi
}

getAllResTypeForCL() 
{
	if ! checkUserPriv get,list all all > /dev/null
	then
		# echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get/list' on all resources in all namespaces Skipping..."
		return 1
	fi
	
	if [ -s $RES_LIST_PROCFILE ]
	then
		local LINE=
		local RES=
		local RES_TYPE_LIST=
		local RES_TYPE_CTR=0
	
		while read LINE
		do
			# echo "LINE = [$LINE]"
			local RES_NAME=$(echo "$LINE" | $AWK -F'|' '{ print $1 }')
			local RES_LONGNAME=$(echo "$LINE" | $AWK -F'|' '{ print $2 }')
			local RES_SHORTNAME=$(echo "$LINE" | $AWK -F'|' '{ print $3 }')
			local RES_KIND=$(echo "$LINE" | $AWK -F'|' '{ print $4 }')
			local RES_KIND_ORIG=$(echo "$LINE" | $AWK -F'|' '{ print $5 }')
			local IS_NAMESPACED=$(echo "$LINE" | $AWK -F'|' '{ print $6 }')
			# echo "$RES_LONGNAME / $IS_NAMESPACED"
	
			if [ ${#IS_NAMESPACED} -gt 0 ] && [ ${IS_NAMESPACED} == "false" ]
			then
				local RES_LIST=$($OC_CMD get --ignore-not-found $RES_LONGNAME --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}')
	
				if [ ${#RES_LIST} -gt 0 ]
				then
					(( RES_TYPE_CTR=RES_TYPE_CTR+1 ))
	
					if [ ${#RES_TYPE_LIST} -eq 0 ]
					then
						local RES_TYPE_LIST="$RES_LONGNAME"
					else
						local RES_TYPE_LIST="$RES_TYPE_LIST $RES_LONGNAME"
					fi
				fi
			fi
		done < $RES_LIST_PROCFILE
	else
		# echo "[$(date)] [${FUNCNAME[0]}] Resource list [$RES_LIST_PROCFILE] does not exist or is zero-sized!"
		return 1
	fi
	
	echo "$RES_TYPE_LIST"
}

getAllResTypeForNS() 
{
	local NAMESPACE="$1"
	
	if ! checkUserPriv get,list all $NAMESPACE > /dev/null
	then
		# echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get/list' on all resources in namespace [$NAMESPACE]. Skipping..."
		return 1
	fi
	
	if [ -s $RES_LIST_PROCFILE ]
	then
		local LINE=
		local RES=
		local RES_TYPE_LIST=
		local RES_TYPE_CTR=0
	
		while read LINE
		do
			# echo "LINE = [$LINE]"
			local RES_NAME=$(echo "$LINE" | $AWK -F'|' '{ print $1 }')
			local RES_LONGNAME=$(echo "$LINE" | $AWK -F'|' '{ print $2 }' | $AWK -F',' '{ print $1 }')
			local RES_SHORTNAME=$(echo "$LINE" | $AWK -F'|' '{ print $3 }')
			local RES_KIND=$(echo "$LINE" | $AWK -F'|' '{ print $4 }')
			local RES_KIND_ORIG=$(echo "$LINE" | $AWK -F'|' '{ print $5 }')
			local IS_NAMESPACED=$(echo "$LINE" | $AWK -F'|' '{ print $6 }')
			# echo "$RES_LONGNAME / $IS_NAMESPACED"
	
			if [ ${#IS_NAMESPACED} -gt 0 ] && [ ${IS_NAMESPACED} == "true" ]
			then
				local RES_LIST_CMD="$OC_CMD get --ignore-not-found -n ${NAMESPACE} $RES_LONGNAME --template '{{range .items}}{{.metadata.name}}{{\"\n\"}}{{end}}'"
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] RES_LIST_CMD = [$RES_LIST_CMD]" >&2
				fi
	
				# local RES_LIST=$($OC_CMD get --ignore-not-found -n ${NAMESPACE} $RES_LONGNAME --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}')
				local RES_LIST=$(eval "$RES_LIST_CMD")
	
				if [ ${#RES_LIST} -gt 0 ]
				then
					(( RES_TYPE_CTR=RES_TYPE_CTR+1 ))
	
					if [ ${#RES_TYPE_LIST} -eq 0 ]
					then
						local RES_TYPE_LIST="$RES_LONGNAME"
					else
						local RES_TYPE_LIST="$RES_TYPE_LIST $RES_LONGNAME"
					fi
				fi
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] RES_NAME=[$RES_NAME] / RES_LONGNAME=[$RES_LONGNAME] / RES_COUNT=[$(echo $RES_LIST | $AWK '{ print NF }')]" >&2
				fi
			fi
		done < $RES_LIST_PROCFILE
	else
		# echo "[$(date)] [${FUNCNAME[0]}] Resource list [$RES_LIST_PROCFILE] does not exist or is zero-sized!"
		return 1
	fi
	
	echo "$RES_TYPE_LIST"
}

getAllResForNS() 
{
	local NAMESPACE="$1"
	
	if ! checkUserPriv get all $NAMESPACE > /dev/null
	then
		# echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' on all resources in namespace [$NAMESPACE]. Skipping..."
		return 1
	fi
	
	if [ -s $RES_LIST_PROCFILE ]
	then
		local LINE=
		local RES=
		local RES_LIST=
		local RES_CTR=0
	
		while read LINE
		do
			# echo "LINE = [$LINE]"
			local RES_NAME=$(echo "$LINE" | $AWK -F'|' '{ print $1 }')
			local RES_LONGNAME=$(echo "$LINE" | $AWK -F'|' '{ print $2 }')
			local RES_SHORTNAME=$(echo "$LINE" | $AWK -F'|' '{ print $3 }')
			local RES_KIND=$(echo "$LINE" | $AWK -F'|' '{ print $4 }')
			local RES_KIND_ORIG=$(echo "$LINE" | $AWK -F'|' '{ print $5 }')
			local IS_NAMESPACED=$(echo "$LINE" | $AWK -F'|' '{ print $6 }')
			# echo "$RES_LONGNAME / $IS_NAMESPACED"
	
			if [ ${#IS_NAMESPACED} -gt 0 ] && [ ${IS_NAMESPACED} == "true" ]
			then
				for RES in $($OC_CMD get --ignore-not-found -n ${NAMESPACE} $RES_LONGNAME --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}')
				do
					(( RES_CTR=RES_CTR+1 ))
	
					if [ ${#RES_LIST} -eq 0 ]
					then
						local RES_LIST="$RES_LONGNAME/$RES"
					else
						local RES_LIST="$RES_LIST $RES_LONGNAME/$RES"
					fi
				done
			fi
		done < $RES_LIST_PROCFILE
	else
		# echo "[$(date)] [${FUNCNAME[0]}] Resource list [$RES_LIST_PROCFILE] does not exist or is zero-sized!"
		return 1
	fi
	
	echo "$RES_LIST"
}

getAllResTypeFromOcAll()
{
	local OC_ALL_FILE=$1
	local RESTYPE=
	local RESTYPE_LIST=
	
	if [ -s $OC_ALL_FILE ]
	then
		if [ $($AWK 'NR == 1 { print $1 }' $OC_ALL_FILE) == "NAMESPACE" ]
		then
			local TGT_COL="\$2"
		else
			local TGT_COL="\$1"
		fi
			
		for RESTYPE in $(grep -E -v '^NAME|^$' $OC_ALL_FILE | gawk '{ print '$TGT_COL' }' | gawk -F/ '{ print $1 }' | sort | uniq)
		do
			if [ ${#RESTYPE_LIST} -eq 0 ]
			then
				local RESTYPE_LIST="$RESTYPE"
			else
				local RESTYPE_LIST="$RESTYPE_LIST $RESTYPE"
			fi
		done
	else
		# echo "[$(date)] [${FUNCNAME[0]}] Input file [$OC_ALL_FILE] does not exist or is zero-sized!"
		return 1
	fi
	
	echo "$RESTYPE_LIST"
}

getApiResName()
{
	# INPUT = resource type long name (Eg. clusterrole.rbac.authorization.k8s.io)
	
	# Exit status
	# 0 = API resource name found
	# 1 = API resource name not found/failed
	# 2 = RES_LIST_PROCFILE reference file is unavailable 
	
	local RES_LONGNAME=$1
	
	if [ -s $RES_LIST_PROCFILE ]
	then
		local RES_NAME_CMD="$AWK -F'|' '{ if ( \$2 ~ /,/ ) { LEN=split(\$2,ARR,\",\"); for (i = 1; i <= LEN; i++) { if ( ARR[i] ~ /^"$RES_LONGNAME"\$/ ) { print \$4; break } } } else { if ( \$2 ~ /^"$RES_LONGNAME"\$/ ) { print \$4 } } }' $RES_LIST_PROCFILE"
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] RES_NAME_CMD = [$RES_NAME_CMD]" >&2
		fi
	
		local RES_NAME=$(eval "$RES_NAME_CMD")
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] RES_LONGNAME = [$RES_LONGNAME] / RES_NAME = [$RES_NAME]" >&2
		fi
	
		if [ ${#RES_NAME} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] RES_NAME is blank! Returning RES_LONGNAME [$RES_LONGNAME]..." >&2
			echo "$RES_LONGNAME"
			return 1
		else
			# To check whether there are more than one resource type with the same shortname
			local RES_NAME_COUNT_CMD="$AWK -F'|' 'BEGIN { CTR=0 } \$4 ~ /^"$RES_NAME"\$/ { CTR++ } END { print CTR }' $RES_LIST_PROCFILE"
			
			local RES_NAME_COUNT=$(eval "$RES_NAME_COUNT_CMD")
	
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] RES_NAME_COUNT_CMD = [$RES_NAME_COUNT_CMD]" >&2
				echo "[$(date)] [${FUNCNAME[0]}] RES_NAME_COUNT = [$RES_NAME_COUNT]" >&2
			fi
	
			if [ ${#RES_NAME_COUNT} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] RES_NAME_COUNT is blank! Returning RES_LONGNAME [$RES_LONGNAME]..." >&2
				echo "$RES_LONGNAME"
				return 1
			else
				if [ ${RES_NAME_COUNT} -gt 1 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] RES_NAME_COUNT is greater than one(1)! Returning RES_LONGNAME [$RES_LONGNAME]..." >&2
					echo "$RES_LONGNAME"
				else
					echo "$RES_NAME"
				fi
	
				return 0
			fi
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] RES_LIST_PROCFILE [$RES_LIST_PROCFILE] does not exists or is zero-sized! Returning RES_LONGNAME [$RES_LONGNAME]..." >&2
		echo "$RES_LONGNAME"
		return 2
	fi
}

testPodNw()
{
	local NAMESPACE=$1
	local POD_NAME=$2
	local URL_NAME=$3
	local NW_TEST_METHOD=$4
	
	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
	if ! checkUserPriv get pod $NAMESPACE 
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' on pods in namespace [$NAMESPACE]. Skipping..."
		return 1
	fi
	
	if ! checkUserPriv create pods/exec $NAMESPACE 
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD exec' on pods in namespace [$NAMESPACE]. Skipping..."
		return 1
	fi
	
	$OC_CMD get pod -n $NAMESPACE --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}' | $AWK '/'${POD_NAME}'/ { print }' > $OUTDIR/testPodNw.$$.tmp
	local POD_COUNT=$(wc -l $OUTDIR/testPodNw.$$.tmp | $AWK '{ print $1 }')
	
	if [ $POD_COUNT -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Pod [$POD_NAME] does not exist in namespace [$NAMESPACE] to test [$NW_TEST_METHOD] network connection to [$URL_NAME]!"
		rm $OUTDIR/testPodNw.$$.tmp
		return 1	
	else
		if [ $POD_COUNT -gt 1 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] More than one instances of [$POD_NAME] in namespace [$NAMESPACE]. The first instance will be selected!"
			cat $OUTDIR/testPodNw.$$.tmp | sed 's/^/>>> /'
			local POD_NAME=$(head -1 $OUTDIR/testPodNw.$$.tmp)
		else
			local POD_NAME=$(head -1 $OUTDIR/testPodNw.$$.tmp)
		fi
	fi
	
	rm $OUTDIR/testPodNw.$$.tmp
	
	if [ ${#POD_NAME} -gt 0 ] 
	then
		local GET_POD_OUTPUT=$($OC_CMD get pod $POD_NAME -n $NAMESPACE --no-headers | $AWK '{ print $2 ":" $3 }')
	else
		echo "[$(date)] [${FUNCNAME[0]}] Pod [$POD_NAME] in namespace [$NAMESPACE] is empty/null. Skipping..."
		return 1	
	fi
	
	if [ ${#GET_POD_OUTPUT} -gt 0 ]
	then
		local POD_READY=$(echo "$GET_POD_OUTPUT" | $AWK -F: '{ print $1 }')
		local POD_STATUS=$(echo "$GET_POD_OUTPUT" | $AWK -F: '{ print $2 }')
	else
		echo "[$(date)] [${FUNCNAME[0]}] Unable to execute '$OC_CMD get' on pod [$POD_NAME] in namespace [$NAMESPACE]. Skipping..."
		return 1
	fi
	
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Status of pod [$POD_NAME] in namespace [$NAMESPACE] = [$POD_STATUS]"
		echo "[$(date)] [${FUNCNAME[0]}] Readiness of pod [$POD_NAME] in namespace [$NAMESPACE] = [$POD_READY]"
	fi
	
	if [ ${#POD_STATUS} -gt 0 ] && [ ${POD_STATUS} != "Running" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Pod [$POD_NAME] in namespace [$NAMESPACE] is not in [running] state. Skipping..."
		return 1	
	fi
	
	if [ ${#POD_READY} -gt 0 ] && [ $(echo "$POD_READY" | $AWK -F/ '{ print $1 }') -lt $(echo "$POD_READY" | $AWK -F/ '{ print $2 }') ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Pod [$POD_NAME] in namespace [$NAMESPACE] is not ready [$POD_READY]. Skipping..."
		return 1	
	fi
	
	if [ $NW_TEST_METHOD == "ping" ]
	then
		echo "[PING RESULT] [$POD_NAME --> ${URL_NAME}]" >> ${ANALYZE_OUTFILE}.$$.tmp
		echo "[$(date)] [${FUNCNAME[0]}] Testing network connectivity [ping] of '$POD_NAME' to '${URL_NAME}'" | tee -a ${ANALYZE_OUTFILE}.$$.tmp
		$OC_CMD exec -n $NAMESPACE $POD_NAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- ping -c4 ${URL_NAME} 2>&1 | sed 's/^/| /' >> ${ANALYZE_OUTFILE}.$$.tmp 
		echo >> ${ANALYZE_OUTFILE}.$$.tmp
	fi
	
	if [ $NW_TEST_METHOD == "nslookup" ]
	then
		echo "[NSLOOKUP RESULT] [$POD_NAME --> ${URL_NAME}]" >> ${ANALYZE_OUTFILE}.$$.tmp
		echo "[$(date)] [${FUNCNAME[0]}] Testing network connectivity [nslookup] of '$POD_NAME' to '${URL_NAME}'" | tee -a ${ANALYZE_OUTFILE}.$$.tmp
		$OC_CMD exec -n $NAMESPACE $POD_NAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- nslookup ${URL_NAME} 2>&1 | sed 's/^/| /' >> ${ANALYZE_OUTFILE}.$$.tmp
		echo >> ${ANALYZE_OUTFILE}.$$.tmp
	fi
	
	echo "----------------------------------------------------------------------------------------------" >> ${ANALYZE_OUTFILE}.$$.tmp
	echo >> ${ANALYZE_OUTFILE}.$$.tmp
	
	if [ -s ${ANALYZE_OUTFILE}.$$.tmp ]
	then
		tr -d '
' < ${ANALYZE_OUTFILE}.$$.tmp >> $ANALYZE_OUTFILE
		rm ${ANALYZE_OUTFILE}.$$.tmp
		return 0
	else
		echo "Work file for network connectivity test [${ANALYZE_OUTFILE}.$$.tmp] does not exist or is zero-sized!"
		echo >> $ANALYZE_OUTFILE
		return 1
	fi
}

analyzeOcPvc()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local NAMESPACE=$1
	local OC_PVC_OUTFILE=$2
	local OC_DESC_PVC_DIR=$3
	
	if [ -s $OC_PVC_OUTFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Analyzing '$OC_CMD get pvc -o wide -n $NAMESPACE' => $OC_PVC_OUTFILE"
	else
		echo "[$(date)] [${FUNCNAME[0]}] Input file [$OC_PVC_OUTFILE] does not exist or is zero-sized!"
	
		if [ ! -d $(dirname $OC_PVC_OUTFILE) ]
		then
			mkdir -p $(dirname $OC_PVC_OUTFILE)
		fi
	
		ocGet pvc $OC_PVC_OUTFILE $NAMESPACE
	
		if [ ! -s $OC_PVC_OUTFILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Unable to generate input file [$OC_PVC_OUTFILE] with command '$OC_CMD get pvc -n $NAMESPACE'. Skipping..."
			return 1	
		fi
	fi
	
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing PVC [$NAMESPACE]"
	
	if [ ! -d $OC_DESC_PVC_DIR ] && [ $GET_PVC_USAGE == "true" ]
	then
		mkdir -p $OC_DESC_PVC_DIR
	fi
	
	if [[ $OC_PVC_OUTFILE =~ $EXTRA_NAMESPACES_OUTDIR ]]
	then
		local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/extra/$NAMESPACE
	else
		local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/$MUSTGATHER_OPT/$NAMESPACE
	fi
	
	if [ $GET_PVC_USAGE == "true" ]
	then
		local PVC_USAGE_TMPFILE=$OC_DESC_PVC_DIR/analyzeOcPvc.pvc.usage.tmp
		local PVC_DF_OK=0
		local PVC_DF_NOK=0
	fi
	
	local BADCTR=0
	local GOODCTR=0
	local TOTALCTR=0
	
	local PVC_HEADER=0
	local PVC_HEADER_LINE=
	local TO_GET_EVENT=()
	local PVC_NOK=()
	local PVC_WARN_ARR=()
	
	local CAN_EXEC_POD="true"
	local PVC_LINE=
	
	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	if ! checkUserPriv create pods/exec $NAMESPACE
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD exec' on pods in namespace [$NAMESPACE]. Unable to generate 'PVC Utilization Report'. Skipping..."
		local CAN_EXEC_POD="false"
	fi
	
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "STATUS REPORT OF PERSISTENTVOLUMECLAIMS (namespace = $NAMESPACE)" >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE
	
	IFS=$'\n'
	
	for PVC_LINE in $(grep -E -v '^I051|Throttling request|No resources found|^Error from server' $OC_PVC_OUTFILE)
	do
		if [[ ${PVC_LINE} =~ ^NAME ]]
		then
			local PVC_HEADER_LINE=$PVC_LINE
			continue
		fi

		(( TOTALCTR=TOTALCTR+1 ))
		
		local PVC=$(echo "$PVC_LINE" | $AWK '{ print $1 }') 
		local PVC_STATUS=$(echo "$PVC_LINE" | $AWK '{ print $2 }') 
		local PV_NAME=$(echo "$PVC_LINE" | $AWK '{ print $3 }')
	
		if [ $PVC_STATUS != "Bound" ]
		then
			(( BADCTR=BADCTR+1 ))
	
			if [ $INCIDENT_REPORT_ENABLED == "true" ]
			then
				setIncident "ocp" "$PVC" "oc_get_pvc" "RESOURCE_TYPE=pvc;NAMESPACE=$NAMESPACE" "$PVC_LINE"
			fi
	
			if [ $PVC_HEADER -eq 0 ]
			then
				echo "$PVC_HEADER_LINE" >> $ANALYZE_OUTFILE
				local PVC_HEADER=1
			fi
	
			echo "$PVC_LINE" >> $ANALYZE_OUTFILE
	
			if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" ) && ! -d $BAD_OBJ_ROOTDIR/pvc ]]
			then
				mkdir -p $BAD_OBJ_ROOTDIR/pvc
			fi
	
			if [ $OC_DESC_ON == "true" ] && [[ ( -f $OC_DESC_PVC_DIR/$PVC.desc || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc/$PVC.desc ) ]]
			then
				local TO_GET_EVENT[${#TO_GET_EVENT[@]}]=$PVC
	
				if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
				then
					cp -p $OC_DESC_PVC_DIR/$PVC.desc $BAD_OBJ_ROOTDIR/pvc
				else
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc/$PVC.desc $BAD_OBJ_ROOTDIR/pvc
				fi
			fi
	
			if [ $COLLECT_YAML == "true" ] && [[ ( -f $OC_DESC_PVC_DIR/$PVC.yaml || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc/$PVC.yaml ) ]]
			then
				if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
				then
					cp -p $OC_DESC_PVC_DIR/$PVC.yaml $BAD_OBJ_ROOTDIR/pvc
				else
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc/$PVC.yaml $BAD_OBJ_ROOTDIR/pvc
				fi	
			fi
	
			if [ $COLLECT_JSON == "true" ] && [[ ( -f $OC_DESC_PVC_DIR/$PVC.json || -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc/$PVC.json ) ]]
			then
				if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
				then
					cp -p $OC_DESC_PVC_DIR/$PVC.json $BAD_OBJ_ROOTDIR/pvc
				else
					cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc/$PVC.json $BAD_OBJ_ROOTDIR/pvc
				fi	
			fi
		else
			(( GOODCTR=GOODCTR+1 ))
		fi
	
		if [ $GET_PVC_USAGE == "true" ] && [ $CAN_EXEC_POD == "true" ] 
		then
			echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Getting PVC [NAMESPACE=$NAMESPACE / PVC=$PVC] usage data..." 
	
			if [ $PVC_STATUS != "Bound" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] PVC [NAMESPACE=$NAMESPACE / PVC=$PVC] is not in 'Bound' state. Skipping..."
				echo "[$(( $GOODCTR+$BADCTR ))] [ PVC = $PVC / NAMESPACE = $NAMESPACE / STATUS = $PVC_STATUS ]" >> $PVC_USAGE_TMPFILE
				echo "< PVC is not bound! >" >> $PVC_USAGE_TMPFILE
				echo >> $PVC_USAGE_TMPFILE
				echo "---------------------------------------------------" >> $PVC_USAGE_TMPFILE
				local PVC_NOK[${#PVC_NOK[@]}]=$PVC
				(( PVC_DF_NOK=PVC_DF_NOK+1 ))
				continue
			fi
	
			if [ -s $OC_DESC_PVC_DIR/$PVC.desc ]
			then
				local PVC_POD_CMD="$AWK '/^Used By:|Mounted By:/,/^Events:/' $OC_DESC_PVC_DIR/$PVC.desc | sed '\$d' | sed 's/^[ ]*//' | sed 's/^Used By:[ ]*//' | sed 's/^Mounted By:[ ]*//' | tr '\n' ' ' | sed 's/[ ]*$//'"
				echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Executing command '$PVC_POD_CMD'..."
				local PVC_POD_LIST=$(eval "$PVC_POD_CMD")
			else
				local PVC_POD_CMD="$OC_CMD describe pvc $PVC -n $NAMESPACE | sed '\$d' | $AWK '/^Used By:|Mounted By:/,/^Events:/' | sed 's/^[ ]*//' | sed 's/^Used By:[ ]*//' | sed 's/Mounted By:[ ]*//' | tr '\n' ' ' | sed 's/[ ]*$//'"
				echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Executing command '$PVC_POD_CMD'..."
				local PVC_POD_LIST=$(eval "$PVC_POD_CMD")
			fi
	
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] PVC_POD_LIST = [$PVC_POD_LIST]"
			fi
	
			if [ ${#PVC_POD_LIST} -gt 0 ] && [[ ! $PVC_POD_LIST =~ ^\<none\> ]]
			then
				echo "[$(( $GOODCTR+$BADCTR ))] [ PVC = $PVC / PV = $PV_NAME ]" >> $PVC_USAGE_TMPFILE
	
				local PVC_SUCC_CTR=0
				local PVC_FAIL_CTR=0
				local PVC_POD_RUNNING=0
				local PVC_POD_NOT_RUNNING=0
				local PVC_POD=
	
				IFS=$OLDIFS
	
				for PVC_POD in $PVC_POD_LIST
				do
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] PVC_POD = [$PVC_POD]"
					fi
	
					local POD_STATUS=$($OC_CMD get pod -n $NAMESPACE $PVC_POD --no-headers | $AWK '{ print $3 }')					
	
					if [ ${#POD_STATUS} -gt 0 ]
					then
						if [ $POD_STATUS != "Running" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Pod [$PVC_POD] in namespace [$NAMESPACE] for PVC [$PVC] is not in 'Running' state [STATUS = $PVC_STATUS]. Skipping..."
							echo ">> Pod [$PVC_POD] in namespace [$NAMESPACE] for PVC [$PVC] is not in 'Running' state [STATUS = $PVC_STATUS]" >> $PVC_USAGE_TMPFILE
							(( PVC_POD_NOT_RUNNING=PVC_POD_NOT_RUNNING+1 ))
							continue
						else
							(( PVC_POD_RUNNING=PVC_POD_RUNNING+1 ))
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Unable to determine status of pod [$PVC_POD] in namespace [$NAMESPACE] for PVC [$PVC]. Skipping..."
						echo ">> Unable to determine status of pod [$PVC_POD] in namespace [$NAMESPACE] for PVC [$PVC]" >> $PVC_USAGE_TMPFILE
						(( PVC_POD_NOT_RUNNING=PVC_POD_NOT_RUNNING+1 ))
						continue
					fi
	
					echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Extracting volume-name from pod [$PVC_POD] in namespace [$NAMESPACE] for PVC [$PVC]..."
					local PVC_VOL_NAME_CMD="$OC_CMD get pod -n $NAMESPACE $PVC_POD -o jsonpath=\"{.spec.volumes[?(@.persistentVolumeClaim.claimName=='$PVC')].name}\""
					echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Executing command [$PVC_VOL_NAME_CMD]..."
					local PVC_VOL_NAME=$(eval "$PVC_VOL_NAME_CMD")
	
					if [ ${#PVC_VOL_NAME} -gt 0 ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] PVC_VOL_NAME = [$PVC_VOL_NAME]"
						fi
	
						echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Determining container name for volume [$PVC_VOL_NAME] of pod [$PVC_POD] in namespace [$NAMESPACE] for PVC [$PVC]..."
						local PVC_CONTAINER_NAME_CMD="$OC_CMD get pod -n $NAMESPACE $PVC_POD -o jsonpath=\"{range .spec.containers[*]}{.volumeMounts[*].name==\"$PVC\"}{.name} {end}\""
						echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Executing command [$PVC_CONTAINER_NAME_CMD]..."
	
						local PVC_CONTAINER_CTR=0
						local PVC_CONTAINER=
	
						for PVC_CONTAINER in $(eval "$PVC_CONTAINER_NAME_CMD")
						do
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] PVC_CONTAINER = [$PVC_CONTAINER]"
							fi
	
							echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Extracting mount-path for volume [$PVC_VOL_NAME] from container [$PVC_CONTAINER] of pod [$PVC_POD] in namespace [$NAMESPACE] for PVC [$PVC]..."
							local PVC_MOUNT_PATH_CMD="$OC_CMD get pod -n $NAMESPACE $PVC_POD -o jsonpath=\"{.spec.containers[?(@.name=='$PVC_CONTAINER')].volumeMounts[?(@.name=='$PVC_VOL_NAME')].mountPath}\""
							echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Executing command [$PVC_MOUNT_PATH_CMD]..."
							local PVC_MOUNT_PATH=$(eval "$PVC_MOUNT_PATH_CMD")
		
							if [ ${#PVC_MOUNT_PATH} -gt 0 ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] PVC_MOUNT_PATH = [$PVC_MOUNT_PATH]"
								fi
	
								echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Executing 'df -h' on mount-path [$PVC_MOUNT_PATH] of volume [$PVC_VOL_NAME] of container [$PVC_CONTAINER] of pod [$PVC_POD] in namespace [$NAMESPACE]..."
								echo ">> [ POD = $PVC_POD | CONTAINER = $PVC_CONTAINER | VOLUME = $PVC_VOL_NAME | MOUNTPATH = $PVC_MOUNT_PATH ]" >> $PVC_USAGE_TMPFILE
								local PVC_DF_CMD="$OC_CMD exec -n $NAMESPACE $PVC_POD -c $PVC_CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- timeout $DEFAULT_OC_EXEC_TIMEOUT df -h $PVC_MOUNT_PATH"
								echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] PVC_DF_CMD = [$PVC_DF_CMD]"
	
								local PVC_USAGE_DF_OUTFILE=$OC_DESC_PVC_DIR/analyzeOcPvc.pvc.$PVC_POD.$PVC_CONTAINER.tmp
								# eval "$PVC_DF_CMD" >> $PVC_USAGE_TMPFILE 2>&1
								eval "$PVC_DF_CMD" > $PVC_USAGE_DF_OUTFILE 2>&1
								PVC_DF_CMD_RES=$?
								echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Exit status = [$PVC_DF_CMD_RES]"
								
								if [ ${PVC_DF_CMD_RES} -eq 0 ]
								then
									if [ $PVC_SUCC_CTR -eq 0 ]
									then
										(( PVC_DF_OK=PVC_DF_OK+1 ))
									fi
	
									(( PVC_SUCC_CTR=PVC_SUCC_CTR+1 ))
	
									# To extract pvc usage percentage
									local PVC_USAGE_DF_PERCENTAGE=$(grep -v ^Filesystem $PVC_USAGE_DF_OUTFILE | head -1 | $AWK '{ print $5 }' | sed 's/%$//')
									
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] PVC_USAGE_DF_PERCENTAGE = [${PVC_USAGE_DF_PERCENTAGE}%]"
									fi
	
									if [[ $PVC_USAGE_DF_PERCENTAGE =~ ^[0-9] ]]
									then
										if [ $PVC_USAGE_DF_PERCENTAGE -ge $PVC_WARNING ]
										then
											local PVC_WARN_ARR[${#PVC_WARN_ARR[@]}]="PVC=$PVC / POD=$PVC_POD / CONTAINER=$PVC_CONTAINER / PATH=$PVC_MOUNT_PATH / USAGE_PCT=${PVC_USAGE_DF_PERCENTAGE}%"
										fi
									fi
								else
									(( PVC_FAIL_CTR=PVC_FAIL_CTR+1 ))
								fi
	
								cat $PVC_USAGE_DF_OUTFILE >> $PVC_USAGE_TMPFILE
								echo >> $PVC_USAGE_TMPFILE
	
								rm $PVC_USAGE_DF_OUTFILE
							else
								echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Unable to determine mount-path of volume [$PVC_VOL_NAME] of container [$PVC_CONTAINER] of pod [$PVC_POD] in namespace [$NAMESPACE] for PVC [$PVC]! Skipping..."
							fi
	
							(( PVC_CONTAINER_CTR=PVC_CONTAINER_CTR+1 ))
						done
	
						if [ $PVC_CONTAINER_CTR -eq 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Unable to determine container name for volume [$PVC_VOL_NAME] of pod [$PVC_POD] in namespace [$NAMESPACE] for PVC [$PVC]..."
							local PVC_NOK[${#PVC_NOK[@]}]=$PVC
							(( PVC_DF_NOK=PVC_DF_NOK+1 ))
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Unable to determine volume-name for PVC [$PVC] in pod [$PVC_POD] in namespace [$NAMESPACE]! Skipping..."
						local PVC_NOK[${#PVC_NOK[@]}]=$PVC
						(( PVC_DF_NOK=PVC_DF_NOK+1 ))
					fi
				done
	
				if [ $PVC_POD_RUNNING -eq 0 ] || [ $PVC_SUCC_CTR -eq 0 ]
				then
					local PVC_NOK[${#PVC_NOK[@]}]=$PVC
					(( PVC_DF_NOK=PVC_DF_NOK+1 ))
	
					if [ $PVC_POD_RUNNING -eq 0 ]
					then
						echo "< No pod is available! >" >> $PVC_USAGE_TMPFILE
					fi
	
					if [ $PVC_SUCC_CTR -eq 0 ]
					then
						echo "< Unable to execute 'df' command! >" >> $PVC_USAGE_TMPFILE
					fi
	
					echo >> $PVC_USAGE_TMPFILE
				fi
	
				echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Total PVC pod(s) = [RUNNING = $PVC_POD_RUNNING / NOT_RUNNING = $PVC_POD_NOT_RUNNING]"
				echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Total successful 'df' = [$PVC_SUCC_CTR] / Total failed 'df' = [$PVC_FAIL_CTR]"
	
				echo "---------------------------------------------------" >> $PVC_USAGE_TMPFILE
	
				IFS=$'\n'
			else
				echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] Unable to determine pod for PVC [$PVC] in namespace [$NAMESPACE]! Skipping..."
	
				echo "[$(( $GOODCTR+$BADCTR ))] [ PVC = $PVC / PV = $PV_NAME ]" >> $PVC_USAGE_TMPFILE
				echo "< Unable to determine pod for PVC! >" >> $PVC_USAGE_TMPFILE
				echo >> $PVC_USAGE_TMPFILE
				echo "---------------------------------------------------" >> $PVC_USAGE_TMPFILE
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$(( $GOODCTR+$BADCTR ))] PVC_POD_LIST = [$PVC_POD_LIST]"
				fi
	
				local PVC_NOK[${#PVC_NOK[@]}]=$PVC
				(( PVC_DF_NOK=PVC_DF_NOK+1 ))
			fi
		fi
	done
	
	if [ ${#TO_GET_EVENT[@]} -gt 0 ]
	then
		echo >> $ANALYZE_OUTFILE
	
		local PVCCTR=1
		local PVC_EVENT=
	
		for PVC_EVENT in ${TO_GET_EVENT[@]}
		do
			echo "[$PVCCTR] [PVCNAME = $PVC_EVENT]" >> $ANALYZE_OUTFILE
	
			if [ $OC_DESC_ON == "true" ]
			then
				$AWK '/^Events:/{f=1}f' $OC_DESC_PVC_DIR/$PVC_EVENT.desc | sed '/^[ \t]*$/d' >> $ANALYZE_OUTFILE
			else
				$OC_CMD describe pvc -n $NAMESPACE $PVC_EVENT | $AWK '/^Events:/{f=1}f' | sed '/^[ \t]*$/d' >> $ANALYZE_OUTFILE 2>&1
			fi
	
			echo >> $ANALYZE_OUTFILE
			echo "----------------------------------------------------------" >> $ANALYZE_OUTFILE
	
			(( PVCCTR=PVCCTR+1 ))
		done
	
		echo >> $ANALYZE_OUTFILE
	fi
	
	if [ $BADCTR -eq 0 ]
	then	
		if [ $GOODCTR -gt 0 ]
		then
			echo "[$(date)] [$NAMESPACE] All PVCs seem to be operating fine!" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL OK] [$NAMESPACE] Bound (pvc) = $GOODCTR" >> $ANALYZE_OUTFILE
		else
			echo "[$(date)] [$NAMESPACE] does not seem to contain any PVC!" >> $ANALYZE_OUTFILE
		fi
	else
		echo ">>> [TOTAL OK] [$NAMESPACE] Bound (pvc) = $GOODCTR" >> $ANALYZE_OUTFILE
		echo ">>> [TOTAL NOK] [$NAMESPACE] Persistent Volume Claim (pvc) = $BADCTR" >> $ANALYZE_OUTFILE
	fi
	
	echo ">>> [TOTAL PVC] = ${TOTALCTR}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE
	
	if [ $GET_PVC_USAGE == "true" ] && [ -s $PVC_USAGE_TMPFILE ]
	then
		echo "===================================================" >> $ANALYZE_OUTFILE
		echo "PVC UTILIZATION REPORT (namespace = $NAMESPACE)" >> $ANALYZE_OUTFILE
		echo "===================================================" >> $ANALYZE_OUTFILE
		echo >> $ANALYZE_OUTFILE
		cat $PVC_USAGE_TMPFILE | tr -d '
' >> $ANALYZE_OUTFILE
		echo "Total PVC: $(( $GOODCTR+$BADCTR ))" >> $ANALYZE_OUTFILE
		echo "Total PVC with 'df' output: $PVC_DF_OK" >> $ANALYZE_OUTFILE
		echo "Total PVC without 'df' output: $PVC_DF_NOK"	>> $ANALYZE_OUTFILE
	
		if [ ${#PVC_NOK[@]} -gt 0 ]
		then
			echo "[${PVC_NOK[@]}]" >> $ANALYZE_OUTFILE
		fi
	
		if [ ${#PVC_WARN_ARR[@]} -gt 0 ]
		then
			echo "PVC usage over ${PVC_WARNING}%:" >> $ANALYZE_OUTFILE
	
			local PWARN_CTR=1
	
			for PWARN in ${PVC_WARN_ARR[@]}
			do	
				echo "($PWARN_CTR) $PWARN" >> $ANALYZE_OUTFILE
				(( PWARN_CTR=PWARN_CTR+1 ))
			done	
		fi
	
		echo >> $ANALYZE_OUTFILE
	
		if [ $MG_DEBUG == "true" ]
		then
			if [ ! -d $DEBUG_OUTDIR/${FUNCNAME[0]} ]
			then	
				mkdir -p $DEBUG_OUTDIR/${FUNCNAME[0]}
			fi
	
			cp -p $PVC_USAGE_TMPFILE $DEBUG_OUTDIR/${FUNCNAME[0]}
		fi
	
		rm $PVC_USAGE_TMPFILE
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [NS=$NAMESPACE]"
	fi
}

analyzeOcCert()
{
	local NAMESPACE=$1
	local OC_CERT_OUTFILE=$2
	local OC_DESC_CERT_DIR=$3
	
	local CERTCTR=0
	local BADCTR=0
	local GOODCTR=0
	
	local CERT_TMPFILE=$(dirname $OC_CERT_OUTFILE)/bad_cert.tmp
	local CERT_HEADER=
	
	if [ -s $OC_CERT_OUTFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Analyzing '$OC_CMD get cert -o wide -n $NAMESPACE' => $OC_CERT_OUTFILE"
	else
		echo "[$(date)] [${FUNCNAME[0]}] Input file [$OC_CERT_OUTFILE] does not exist or is zero-sized!"
	
		if [ ! -d $(dirname $OC_CERT_OUTFILE) ]
		then
			mkdir -p $(dirname $OC_CERT_OUTFILE)
		fi
	
		ocGet cert $OC_CERT_OUTFILE $NAMESPACE
	
		if [ ! -s $OC_CERT_OUTFILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Unable to generate input file [$OC_CERT_OUTFILE] with command '$OC_CMD get cert -n $NAMESPACE'. Skipping..."
	
			echo "===================================================" >> $ANALYZE_OUTFILE
			echo "STATUS REPORT OF CERTIFICATES (namespace = $NAMESPACE)" >> $ANALYZE_OUTFILE
			echo "===================================================" >> $ANALYZE_OUTFILE
			echo "< No certificate is available! >" >> $ANALYZE_OUTFILE
			echo >> $ANALYZE_OUTFILE
	
			return 1	
		fi
	fi
	
	local CERT_OUTFILE_CHECK=$(grep '^No resources found' $OC_CERT_OUTFILE)
	
	if [ ${#CERT_OUTFILE_CHECK} -gt 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Command '$OC_CMD get cert -n $NAMESPACE' returned 'No resources found' error! Skipping..."
	
		echo "===================================================" >> $ANALYZE_OUTFILE
		echo "STATUS REPORT OF CERTIFICATES (namespace = $NAMESPACE)" >> $ANALYZE_OUTFILE
		echo "===================================================" >> $ANALYZE_OUTFILE
		echo "< No certificate is available! >" >> $ANALYZE_OUTFILE
		echo >> $ANALYZE_OUTFILE
	
		return 1
	fi
	
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing certificates [$NAMESPACE]"
	
	if [ ! -d $OC_DESC_CERT_DIR ] 
	then
		mkdir -p $OC_DESC_CERT_DIR
	fi
	
	if [[ $OC_CERT_OUTFILE =~ $EXTRA_NAMESPACES_OUTDIR ]]
	then
		local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/extra/$NAMESPACE
	else
		local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/$MUSTGATHER_OPT/$NAMESPACE
	fi
	
	# To calculate width of the columns
	local TMP_FIELDWIDTHS=$(echo "$(head -1 $OC_CERT_OUTFILE)" | grep -E -o '[A-Z]+\s*' | $AWK '{printf "%d ", length($0)}' | sed 's/^[ ]*//;s/[ ]*$//')
	
	# Total length minus last column (not accurate using HEADERS)
	local TMP_FIELDWIDTHS_LEN=$(echo "$TMP_FIELDWIDTHS" | $AWK 'BEGIN { SUM=0 } { for (i=1; i<NF; i++) { SUM+=$i } } END { print SUM}')
	
	# Get longest line
	local LONGEST_LINE_LEN=$(cat $OC_CERT_OUTFILE | $AWK 'length > max_length { max_length = length; longest_line = $0 } END { print length(longest_line) }')
	
	# Calculate width of last column
	local LAST_COL_WIDTH=$((LONGEST_LINE_LEN-TMP_FIELDWIDTHS_LEN))
	
	local FINAL_FIELDWIDTHS="$(echo "$TMP_FIELDWIDTHS" | $AWK '{ for (i=1; i<NF; i++) { print $i } }') ${LAST_COL_WIDTH}"
	
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] TMP_FIELDWIDTHS=[$TMP_FIELDWIDTHS] / TMP_FIELDWIDTHS_LEN=[$TMP_FIELDWIDTHS_LEN] / LONGEST_LINE_LEN=[$LONGEST_LINE_LEN] / LAST_COL_WIDTH=[$LAST_COL_WIDTH] / FINAL_FIELDWIDTHS=[$( echo $FINAL_FIELDWIDTHS | tr '\n' ' ' | sed 's/[ ]*$//')]"
	fi
	
	local PRINTF_COL_ARR=()
	local COL_POSITION=0
	local PREV_COL=0
	
	local COL=
	
	IFS=$OLDIFS
	for COL in $FINAL_FIELDWIDTHS
	do
		local CUR_COL=$((PREV_COL+1))
	
		case "$COL_POSITION" in
			0) PRINTF_COL_ARR[$COL_POSITION]="1,$COL" 
			   PREV_COL=$COL
				;;
			1) NEW_COL_POS=$((CUR_COL+COL-1))
			   PRINTF_COL_ARR[$COL_POSITION]="$CUR_COL,$COL"
			   PREV_COL=$NEW_COL_POS
				;;	
			2) NEW_COL_POS=$((CUR_COL+COL-1))
			   PRINTF_COL_ARR[$COL_POSITION]="$CUR_COL,$COL"
			   PREV_COL=$NEW_COL_POS
				;;	
			3) NEW_COL_POS=$((CUR_COL+COL-1))
			   PRINTF_COL_ARR[$COL_POSITION]="$CUR_COL,$COL"
			   PREV_COL=$NEW_COL_POS
				;;	
			4) NEW_COL_POS=$((CUR_COL+COL-1))
			   PRINTF_COL_ARR[$COL_POSITION]="$CUR_COL,$COL"
			   PREV_COL=$NEW_COL_POS
				;;	
			5) NEW_COL_POS=$((CUR_COL+COL-1))
			   PRINTF_COL_ARR[$COL_POSITION]="$CUR_COL,$COL"
			   PREV_COL=$NEW_COL_POS
			   break
				;;	
		esac	
		
		(( COL_POSITION=COL_POSITION+1 ))
	done
	IFS=$'\n'
	
	if [ ${#PRINTF_COL_ARR[@]} -ne 6 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Failed to determine column widths. Returning..."
		return 1
	fi
	
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "STATUS REPORT OF CERTIFICATES (namespace = $NAMESPACE)" >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE
	
	while read CERT_LINE
	do
		if [[ ${CERT_LINE} =~ ^NAME ]]
		then
			local CERT_HEADER="$CERT_LINE"
			echo "$CERT_HEADER" >> $ANALYZE_OUTFILE
			continue
		else
			echo "$CERT_LINE" >> $ANALYZE_OUTFILE
		fi
	
		(( CERTCTR=CERTCTR+1 ))
	
		local CERT=$(echo "$CERT_LINE" | $AWK '{ print $1 }') 
		local CERT_READY=$(echo "$CERT_LINE" | $AWK '{ print $2 }') 
		local CERT_SCT_NAME=$(echo "$CERT_LINE" | $AWK '{ print $3 }')
		local CERT_ISSUER=$(echo "$CERT_LINE" | $AWK '{ print $4 }') 
	
		if [[ $AWK =~ gawk$ ]]
		then
			local PROC_CMD1="echo '$CERT_LINE' | $AWK '{ CERT_STATUS=gensub(/[ ]*$/,\"\",1,substr(\$0,"${PRINTF_COL_ARR[4]}")); print CERT_STATUS }'"
			local CERT_STATUS=$(eval "$PROC_CMD1")
			local PROC_CMD2="echo '$CERT_LINE' | $AWK '{ CERT_AGE=gensub(/[ ]*$/,\"\",1,substr(\$0,"${PRINTF_COL_ARR[5]}")); print CERT_AGE }'"
			local CERT_AGE=$(eval "$PROC_CMD2")
		else
			local PROC_CMD1="echo '$CERT_LINE' | $AWK '{ CERT_STATUS=substr(\$0,"${PRINTF_COL_ARR[4]}"); gsub(/[ ]*$/,\"\",CERT_STATUS); print CERT_STATUS }'"
			local CERT_STATUS=$(eval "$PROC_CMD1")
			local PROC_CMD2="echo '$CERT_LINE' | $AWK '{ CERT_AGE=substr(\$0,"${PRINTF_COL_ARR[5]}"); gsub(/[ ]*$/,\"\",CERT_AGE); print CERT_AGE }'"
			local CERT_AGE=$(eval "$PROC_CMD2")
		fi
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD1 = [$PROC_CMD1]"
			echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD2 = [$PROC_CMD2]"
			echo "[$(date)] [${FUNCNAME[0]}] CERT = [$CERT] / CERT_READY = [$CERT_READY] / CERT_SCT_NAME = [$CERT_SCT_NAME] / CERT_ISSUER = [$CERT_ISSUER] / CERT_STATUS = [$CERT_STATUS] / CERT_AGE = [$CERT_AGE]"
		fi
	
		if [ ${#CERT_READY} -gt 0 ] 
		then
			if [ $CERT_READY != "True" ]
			then
				# Copy to BAD_DIR
				if [ ! -d $BAD_OBJ_ROOTDIR/cert ]
				then
					mkdir -p $BAD_OBJ_ROOTDIR/cert
				fi
	
				if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
				then
					if [ $OC_DESC_ON == "true" ] && [ -f $OC_DESC_CERT_DIR/$CERT.desc ]
					then
						cp -p $OC_DESC_CERT_DIR/$CERT.desc $BAD_OBJ_ROOTDIR/cert
					fi
	
					if [ $COLLECT_YAML == "true" ] && [ -f $OC_DESC_CERT_DIR/$CERT.yaml ]
					then
						cp -p $OC_DESC_CERT_DIR/$CERT.yaml $BAD_OBJ_ROOTDIR/cert
					fi
	
					if [ $COLLECT_JSON == "true" ] && [ -f $OC_DESC_CERT_DIR/$CERT.json ]
					then
						cp -p $OC_DESC_CERT_DIR/$CERT.json $BAD_OBJ_ROOTDIR/cert
					fi
				else
					if [ $OC_DESC_ON == "true" ] && [ -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/cert/$CERT.desc ]
					then
						cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/cert/$CERT.desc $BAD_OBJ_ROOTDIR/cert
					fi
	
					if [ $COLLECT_YAML == "true" ] && [ -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/cert/$CERT.yaml ] 
					then
						cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/cert/$CERT.yaml $BAD_OBJ_ROOTDIR/cert
					fi
	
					if [ $COLLECT_JSON == "true" ] && [ -f $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/cert/$CERT.json ]
					then
						cp -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/cert/$CERT.json $BAD_OBJ_ROOTDIR/cert
					fi
				fi
	
				# Write to TMPFILE
				# echo "$CERT_LINE" >> $CERT_TMPFILE	
				echo "$CERT" >> $CERT_TMPFILE	
				(( BADCTR=BADCTR+1 ))
			else
				(( GOODCTR=GOODCTR+1 ))
			fi
		else
			(( BADCTR=BADCTR+1 ))
			echo "[$(date)] [${FUNCNAME[0]}] Certificate [$CERT] status = [UNKNOWN]! Skipping..."
			continue
		fi
	done < $OC_CERT_OUTFILE
	
	if [ $GOODCTR -gt 0 ] || [ $BADCTR -gt 0 ]
	then
		echo "---------------------------------------------------" >> $ANALYZE_OUTFILE
		echo >> $ANALYZE_OUTFILE
		echo ">>> TOTAL certificates = [$CERTCTR]" >> $ANALYZE_OUTFILE
		echo ">>> GOOD certificates = [$GOODCTR]" >> $ANALYZE_OUTFILE

		if [ $BADCTR -gt 0 ]
		then
			echo -n ">>> BAD certificates  = [$BADCTR] " >> $ANALYZE_OUTFILE

			if [ -s $CERT_TMPFILE ]
			then
				local BAD_CERTS=

				while read BAD_CERT_LINE
				do	
					if [ ${#BAD_CERTS} -eq 0 ]
					then
						local BAD_CERTS="$BAD_CERT_LINE"
					else
						local BAD_CERTS="$BAD_CERTS,$BAD_CERT_LINE"
					fi
				done < $CERT_TMPFILE	

				echo "[$BAD_CERTS]" >> $ANALYZE_OUTFILE

				rm $CERT_TMPFILE
			fi
		else
			echo ">>> BAD certificates  = [$BADCTR]" >> $ANALYZE_OUTFILE
		fi
	else
		if [ $CERTCTR -eq 0 ]
		then
			echo "< No certificate is available! >" >> $ANALYZE_OUTFILE
		fi
	fi
	
	echo >> $ANALYZE_OUTFILE
}

getCrdData()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local PATTERN=$1
	local F_OUTDIR=$2
	local NAMESPACE=$3

	local CRD_CTR=0
	local CRD_INSTANCES=0
	
	if [ ${#PATTERN} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] PATTERN input variable is NULL! Skipping..."
		return 1
	fi

	if [ ${#F_OUTDIR} -eq 0 ]
	then
		local F_OUTDIR=$CUSTOM_DATA_OUTDIR/custom_crd
	fi
	
	if [ ! -d $F_OUTDIR ]
	then	
		mkdir -p $F_OUTDIR
	fi

	if [ ${#NAMESPACE} -eq 0 ]
	then
		local NS_CMD="-A"
		local PRIV_SCOPE="all"
	else
		local NS_CMD="-n $NAMESPACE"
		local PRIV_SCOPE="$NAMESPACE"
	fi
	
	if ! checkUserPriv get crd $PRIV_SCOPE
	then	
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have verb [get] permission on resource [crd]!"
		return 1
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Creating temporary '$OC_CMD api-resources' output file => $F_OUTDIR/api-resources.$$.tmp"	
	$OC_CMD api-resources | grep -E -vi '^I051|throttling request' > $F_OUTDIR/api-resources.$$.tmp

	if [ ${#NAMESPACE} -eq 0 ]
	then
		local OC_CUSTOM_CRD_OUTFILE=$CUSTOM_DATA_OUTDIR/oc_custom_crd.out
	else
		local OC_CUSTOM_CRD_OUTFILE=$CUSTOM_DATA_OUTDIR/$NAMESPACE-oc_custom_crd.out
	fi

	local FAST_OC_DESC_WORKFILE=$CUSTOM_DATA_OUTDIR/fast_oc_desc.crd.tmp
	local FAST_OC_YAML_WORKFILE=$CUSTOM_DATA_OUTDIR/fast_oc_yaml.crd.tmp
	
	if [ $MG_DEBUG == "true" ]
	then
		mkdir -p $DEBUG_OUTDIR/getCrdData
	fi
	
	if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ]
	then
		local CRD_APIVERSION_NAME=$(getApiVersionName crd)
		local CRD_API_NAME=$(getApiName crd)
		local CRD_API_KIND=$(getApiKind crd)
	fi

	local CRD_CMD="$OC_CMD get crd --no-headers | grep -E -vi '^I051|throttling request' | $AWK '\$1 ~ /$PATTERN/ { print \$1 }'"
	local OC_APIRESOURCES_HEADER=$(head -1 $F_OUTDIR/api-resources.$$.tmp)
	local CRD=
	local LINE=
	
	echo "[$(date)] [${FUNCNAME[0]}] Obtaining CRDs that match PATTERN [$PATTERN]..."
	echo "[$(date)] [${FUNCNAME[0]}] Executing command [$CRD_CMD]..."
	
	for CRD in $(eval "$CRD_CMD")
	do
		(( CRD_CTR=CRD_CTR+1 ))

		# Let's get the 'oc get' and 'oc describe' of the CRD first before getting the CRD instances
		if [ ! -d $F_OUTDIR/$CRD/customresourcedefinition ]
		then
			mkdir -p $F_OUTDIR/$CRD/customresourcedefinition
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get crd $CRD' => $F_OUTDIR/$CRD/customresourcedefinition/oc_$CRD.out"
		$OC_CMD get crd $CRD > $F_OUTDIR/$CRD/customresourcedefinition/oc_crd_$CRD.out

		if [ $OC_DESC_ON == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe crd $CRD' => $F_OUTDIR/$CRD/customresourcedefinition/$CRD.desc"
			$OC_CMD describe crd $CRD > $F_OUTDIR/$CRD/customresourcedefinition/$CRD.desc
		fi

		if [ $COLLECT_YAML == "true" ]
		then
			if [ $FAST_OC == "true" ] 
			then
				if [ ${#CRD_APIVERSION_NAME} -gt 0 ] && [ ${#CRD_API_NAME} -gt 0 ]
				then
					local CRD_YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$CRD_APIVERSION_NAME/$CRD_API_NAME/$CRD"
				else
					if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
					then
						local CRD_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields crd $CRD"
					else
						local CRD_YAML_CMD="$OC_CMD get -o yaml crd $CRD"
					fi
				fi
			else
				if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
				then
					local CRD_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields crd $CRD"
				else
					local CRD_YAML_CMD="$OC_CMD get -o yaml crd $CRD"
				fi
			fi

			echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRD_YAML_CMD' => $F_OUTDIR/$CRD/customresourcedefinition/$CRD.yaml"
			eval "$CRD_YAML_CMD" > $F_OUTDIR/$CRD/customresourcedefinition/$CRD.yaml 2>&1
		fi

		if [ $COLLECT_JSON == "true" ]
		then
			if [ $FAST_OC == "true" ] 
			then
				if [ ${#CRD_APIVERSION_NAME} -gt 0 ] && [ ${#CRD_API_NAME} -gt 0 ]
				then
					local CRD_JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER $OC_APISVR/$CRD_APIVERSION_NAME/$CRD_API_NAME/$CRD"
				else
					if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
					then
						local CRD_JSON_CMD="$OC_CMD get -o json --show-managed-fields crd $CRD"
					else
						local CRD_JSON_CMD="$OC_CMD get -o json crd $CRD"
					fi
				fi
			else
				if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
				then
					local CRD_JSON_CMD="$OC_CMD get -o json --show-managed-fields crd $CRD"
				else
					local CRD_JSON_CMD="$OC_CMD get -o json crd $CRD"
				fi
			fi

			echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRD_JSON_CMD' => $F_OUTDIR/$CRD/customresourcedefinition/$CRD.json"
			eval "$CRD_JSON_CMD" > $F_OUTDIR/$CRD/customresourcedefinition/$CRD.json 2>&1
		fi
	
		if ! checkUserPriv get,list $CRD $PRIV_SCOPE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get/list' on [$CRD] at cluster level [--all-namespaces]. Skipping..."
			continue
		fi

		local TO_PROCEED="false"

		if [ ${#NAMESPACE} -eq 0 ]
		then
			local CRD_GET_OUTFILE=$F_OUTDIR/$CRD/oc_$CRD.out
		else
			local CRD_GET_OUTFILE=$F_OUTDIR/$CRD/$NAMESPACE-oc_$CRD.out
		fi
	
		local CRD_INST_CMD="$OC_CMD get $CRD $NS_CMD"

		echo "[$CRD]" >> $OC_CUSTOM_CRD_OUTFILE
		echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRD_INST_CMD' => $CRD_GET_OUTFILE"
		eval "$CRD_INST_CMD" > $CRD_GET_OUTFILE 2>&1 
		echo "[$(date)] [${FUNCNAME[0]}] Appending content of CRD_GET_OUTFILE [$CRD_GET_OUTFILE] to file OC_CUSTOM_CRD_OUTFILE [$OC_CUSTOM_CRD_OUTFILE]..."
		cat $CRD_GET_OUTFILE >> $OC_CUSTOM_CRD_OUTFILE
	
		local NO_RESOURCE=$(grep 'No resources found' $CRD_GET_OUTFILE)

		if [ ${#NO_RESOURCE} -gt 0 ]
		then
			local TO_PROCEED="false"
		else
			local TO_PROCEED="true"
		fi	
	
		if [ $MG_DEBUG == "true" ]
		then	
			echo "[$(date)] [${FUNCNAME[0]}] [CRD=$CRD / NS=$PRIV_SCOPE] NO_RESOURCE = [$NO_RESOURCE] / TO_PROCEED = [$TO_PROCEED]"
			cp -p $CRD_GET_OUTFILE $DEBUG_OUTDIR/getCrdData
		fi
	
		echo >> $OC_CUSTOM_CRD_OUTFILE	
	
		if [ $TO_PROCEED == "true" ]
		then
			# Check whether CRD is namespaced
			local CRD_NAME=$(echo "$CRD" | $AWK -F'.' '{ print $1 }')
			local CRD_APIVERSION=${CRD#*.} 
			local CRD_API=$($AWK '$1 ~ /^'$CRD_NAME'$/ { print $0 }' $F_OUTDIR/api-resources.$$.tmp | grep $CRD_APIVERSION)
			local CRD_NAMESPACED=$($AWK '$1 ~ /^'$CRD_NAME'$/ { print }' $F_OUTDIR/api-resources.$$.tmp | grep $CRD_APIVERSION | $AWK '{ print $(NF-1) }' | $AWK '{ print tolower($0) }')
	
			if [ $MG_DEBUG == "true" ]
			then 
				echo "CRD_NAME = $CRD_NAME / CRD_APIVERSION = $CRD_APIVERSION"
				echo "$OC_APIRESOURCES_HEADER"
				echo "$CRD_API"
				echo "NAMESPACED = ${CRD_NAMESPACED}"
			fi
	
			if [ $OC_DESC_ON == "true" ] || [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ]
			then
				if [ -s $CRD_GET_OUTFILE ]
				then
					local LINE_CMD="grep -E -v '^NAME' $CRD_GET_OUTFILE | grep -E -vi '^$|^I051|throttling request'"
					local TOTAL_OBJ=$(grep -E -v '^NAME' $CRD_GET_OUTFILE | grep -E -vi '^$|^I051|throttling request' | wc -l)
				else
					local LINE_CMD="$OC_CMD get $CRD $NS_CMD | grep -E -v '^NAME' | grep -E -vi '^$|^I051|throttling request'"
					local TOTAL_OBJ=$($OC_CMD get $CRD $NS_CMD | grep -E -v '^NAME' | grep -E -vi '^$|^I051|throttling request' | wc -l)
				fi

				if [ ${TOTAL_OBJ} -ge ${FAST_OC_YAML_PREREQ} ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$CRD] has met minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
					local FAST_OC_YAML_WORTHY="true"
				else
					echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$CRD] did not meet minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
					local FAST_OC_YAML_WORTHY="false"
				fi
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$CRD] LINE_CMD = $LINE_CMD"
				fi
				
				if [ $OC_DESC_ON == "true" ] || [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ]
				then
					local TO_PROCEED_DESC="true"
					local TO_PROCEED_YAML="false"
					local TO_PROCEED_JSON="false"

					if isRestrictedData "$CRD"
					then
						local TO_PROCEED_DESC="false"
					else
						if isSensitiveData "$CRD"
						then
							if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
							then		
								echo "[$(date)] [${FUNCNAME[0]}] getCrdData() function does not support '$OC_CMD get -o yaml/json' of [$CRD] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
							else
								echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [$CRD]!"
								local TO_PROCEED_YAML="true"
								local TO_PROCEED_JSON="true"
							fi
						else
							local TO_PROCEED_YAML="true"
							local TO_PROCEED_JSON="true"
						fi
					fi
				fi

				IFS=$'\n'	
	
				for LINE in $(eval "$LINE_CMD")
				do
					(( CRD_INSTANCES=CRD_INSTANCES+1 ))

					if [ ${CRD_NAMESPACED} == "true" ]
					then
						if [ ${#NAMESPACE} -eq 0 ]
						then
							local CRD_NAMESPACE=$(echo "$LINE" | $AWK '{ print $1 }')
							local CRD_NAMESPACE_STR="-n $(echo "$LINE" | $AWK '{ print $1 }')"
							local CRD_INSTANCE=$(echo "$LINE" | $AWK '{ print $2 }')
						else
							local CRD_NAMESPACE="$NAMESPACE"
							local CRD_NAMESPACE_STR="-n $NAMESPACE"
							local CRD_INSTANCE=$(echo "$LINE" | $AWK '{ print $1 }')
						fi
					else
						local CRD_NAMESPACE="all-namespaces"
						local CRD_NAMESPACE_STR=""
						local CRD_INSTANCE=$(echo "$LINE" | $AWK '{ print $1 }')
					fi
	
					if [ $MG_DEBUG == "true" ]
					then 
						echo "LINE = $LINE"
						echo "CRD_NAMESPACE = $CRD_NAMESPACE"
						echo "CRD_NAMESPACE_STR = $CRD_NAMESPACE_STR"
						echo "CRD_INSTANCE = $CRD_INSTANCE"
					fi
			
					if [ ! -d $F_OUTDIR/$CRD/$CRD_NAMESPACE ]
					then
						mkdir -p $F_OUTDIR/$CRD/$CRD_NAMESPACE
					fi
	
					local OC_APIVERSION_NAME=$(getApiVersionName $CRD)
					local OC_API_NAME=$(getApiName $CRD)
					local OC_API_KIND=$(getApiKind $CRD)
					local OC_API_IS_NAMESPACED=$(isNamespaced $CRD)
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] CRD = [$CRD] / OC_API_NAME = [$OC_API_NAME] / OC_API_KIND = [$OC_API_KIND] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME] / OC_API_IS_NAMESPACED = [$OC_API_IS_NAMESPACED]"
					fi
	
					if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_DESC == "true" ]
					then
						if [ $FAST_OC_DESC == "true" ]
						then
							echo "$CRD_NAMESPACE_STR##$CRD##$F_OUTDIR/$CRD/$CRD_NAMESPACE" >> $FAST_OC_DESC_WORKFILE
						else
							local CRDCMD="$OC_CMD describe $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRDCMD' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.desc"
							eval "$CRDCMD" > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.desc 2>&1
						fi
					fi
		
					if [ $COLLECT_YAML == "true" ]
					then
						if [ $TO_PROCEED_YAML == "true" ]
						then
							if [ ${FAST_OC_YAML} == "true" ] && [ ${FAST_OC_YAML_WORTHY} == "true" ]
							then
								if [ $FAST_OC == "true" ] 
								then
									if [ ${#OC_API_IS_NAMESPACED} -gt 0 ]
									then
										if [ $OC_API_IS_NAMESPACED -eq 0 ]
										then
											if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
											then
												local YAML_CURL_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$CRD_NAMESPACE/$OC_API_NAME/$CRD_INSTANCE'"
											else
												local YAML_CURL_CMD=""
											fi
										else
											if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
											then
												local YAML_CURL_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$CRD_INSTANCE'"
											else
												local YAML_CURL_CMD=""
											fi
										fi
									else
										local YAML_CURL_CMD=""
									fi
								else
									local YAML_CURL_CMD=""
								fi

								local NSNAME=$(echo "$CRD_NAMESPACE_STR" | sed 's/^-n //')

								# To create fallback reference file for FAST_OC_YAML
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$NSNAME##$CRD##$CRD_INSTANCE##$F_OUTDIR/$CRD/$CRD_NAMESPACE##$YAML_CURL_CMD] => $FAST_OC_YAML_WORKFILE"
								fi
						
								echo "$NSNAME##$CRD##$CRD_INSTANCE##$F_OUTDIR/$CRD/$CRD_NAMESPACE##$YAML_CURL_CMD" >> $FAST_OC_YAML_WORKFILE
							else
								if [ $FAST_OC == "true" ]
								then
									if [ ${#OC_API_IS_NAMESPACED} -gt 0 ]
									then
										if [ $OC_API_IS_NAMESPACED -eq 0 ]
										then
											if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$CRD_NAMESPACE/$OC_API_NAME/$CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
												local CRDCMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$CRD_NAMESPACE/$OC_API_NAME/$CRD_INSTANCE'"
											else
												if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
												then
													local CRDCMD="$OC_CMD get -o yaml --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
												else
													local CRDCMD="$OC_CMD get -o yaml $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
												fi
						
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRDCMD' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
											fi
										else
											if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
												local CRDCMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$CRD_INSTANCE'"
											else
												if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
												then
													local CRDCMD="$OC_CMD get -o yaml --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
												else
													local CRDCMD="$OC_CMD get -o yaml $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
												fi
						
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRDCMD' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
											fi	
										fi
									else
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
										then
											local CRDCMD="$OC_CMD get -o yaml --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
										else
											local CRDCMD="$OC_CMD get -o yaml $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
										fi
					
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRDCMD' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
									then
										local CRDCMD="$OC_CMD get -o yaml --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
									else
										local CRDCMD="$OC_CMD get -o yaml $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
									fi
			
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRDCMD' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
								fi
			
								eval "$CRDCMD" > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml 2>&1
		
								if [ -s $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml ]
								then
									if ( [[ $(head -1 $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml) =~ \"paths\": ]] ) || [[ $(head -1 $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml) =~ ^404 ]] || [[ $(head -1 $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml) =~ "Moved Permanently" ]] 
									then
										echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
				
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
											$OC_CMD get -o yaml --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml 2>&1
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
											$OC_CMD get -o yaml $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml 2>&1
										fi
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
										$OC_CMD get -o yaml --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml 2>&1
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml"
										$OC_CMD get -o yaml $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.yaml 2>&1
									fi
								fi
							fi
						fi
					fi
	
					if [ $COLLECT_JSON == "true" ]
					then
						if [ $TO_PROCEED_JSON == "true" ]
						then
							if [ $FAST_OC == "true" ]
							then
								if [ ${#OC_API_IS_NAMESPACED} -gt 0 ]
								then
									if [ $OC_API_IS_NAMESPACED -eq 0 ]
									then
										if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$CRD_NAMESPACE/$OC_API_NAME/$CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
											local CRDCMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$CRD_NAMESPACE/$OC_API_NAME/$CRD_INSTANCE'"
										else
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
											then
												local CRDCMD="$OC_CMD get -o json --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
											else
												local CRDCMD="$OC_CMD get -o json $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
											fi
					
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRDCMD' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
										fi
									else
										if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
											local CRDCMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$CRD_INSTANCE'"
										else
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
											then
												local CRDCMD="$OC_CMD get -o json --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
											else
												local CRDCMD="$OC_CMD get -o json $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
											fi
					
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRDCMD' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
										fi	
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
									then
										local CRDCMD="$OC_CMD get -o json --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
									else
										local CRDCMD="$OC_CMD get -o json $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
									fi
				
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRDCMD' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
								fi
							else
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
								then
									local CRDCMD="$OC_CMD get -o json --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
								else
									local CRDCMD="$OC_CMD get -o json $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE"
								fi
		
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$CRDCMD' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
							fi
		
							eval "$CRDCMD" > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json 2>&1
	
							if [ -s $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json ]
							then
								if ( [[ $(head -1 $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json) =~ \"paths\": ]] ) || [[ $(head -1 $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json) =~ ^404 ]] || [[ $(head -1 $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json) =~ "Moved Permanently" ]]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
			
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
										$OC_CMD get -o json --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json 2>&1
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
										$OC_CMD get -o json $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json 2>&1
									fi
								fi
							else
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
									$OC_CMD get -o json --show-managed-fields $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json 2>&1
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE' => $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json"
									$OC_CMD get -o json $CRD $CRD_NAMESPACE_STR $CRD_INSTANCE > $F_OUTDIR/$CRD/$CRD_NAMESPACE/$CRD_INSTANCE.json 2>&1
								fi
							fi
						fi
					fi
				done
			fi
		fi
	done
	
	if [ $FAST_OC_DESC == "true" ]
	then
		if [ -s $FAST_OC_DESC_WORKFILE ]
		then
			for LINE in $(cat $FAST_OC_DESC_WORKFILE | sort | uniq)
			do
				local FAST_OC_DESC_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
				local FAST_OC_DESC_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
				local FAST_OC_DESC_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')
	
				if [ ${#FAST_OC_DESC_NS} -gt 0 ]
				then
					local FAST_OC_DESC_TMPFILE=$FAST_OC_DESC_OUTDIR/fast_oc_desc.$FAST_OC_DESC_OBJTYPE.desc-all
					echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe $FAST_OC_DESC_OBJTYPE $FAST_OC_DESC_NS' => $FAST_OC_DESC_TMPFILE"
					local CMD="$OC_CMD describe $FAST_OC_DESC_OBJTYPE $FAST_OC_DESC_NS"
					eval "$CMD" > $FAST_OC_DESC_TMPFILE
				else
					local FAST_OC_DESC_TMPFILE=$FAST_OC_DESC_OUTDIR/fast_oc_desc.$FAST_OC_DESC_OBJTYPE.desc-all
					echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe $FAST_OC_DESC_OBJTYPE' => $FAST_OC_DESC_TMPFILE"
					local CMD="$OC_CMD describe $FAST_OC_DESC_OBJTYPE"
					eval "$CMD" > $FAST_OC_DESC_TMPFILE
				fi
	
				if [ -s $FAST_OC_DESC_TMPFILE ]
				then
					local RECORD_SEPARATOR_KEYWORD=$(head -1 $FAST_OC_DESC_TMPFILE | $AWK -F':' '{ print $1 }' | sed 's/[ ]*$//')
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] RECORD_SEPARATOR_KEYWORD = [$RECORD_SEPARATOR_KEYWORD]"
					fi
				
					if [ ${#RECORD_SEPARATOR_KEYWORD} ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing [sed '/^$/N;/^\n$/D;s/\(^\n\)${RECORD_SEPARATOR_KEYWORD}:/\1#@@@%@@@#\n${RECORD_SEPARATOR_KEYWORD}:/' $FAST_OC_DESC_TMPFILE | $AWK -v OUTDIR=$FAST_OC_DESC_OUTDIR 'BEGIN { RS=\"#@@@%@@@#\n\"; FS=\"\n\" } { OBJNAME=substr(\$1, index(\$1, \":\")+1); gsub(/^[ \t]*/, \"\", OBJNAME); gsub(/[\n]*$/, \"\", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR\"/\"OBJNAME\".desc\") } }]"
						sed '/^$/N;/^\n$/D;s/\(^\n\)'${RECORD_SEPARATOR_KEYWORD}':/\1#@@@%@@@#\n'${RECORD_SEPARATOR_KEYWORD}':/' $FAST_OC_DESC_TMPFILE | $AWK -v OUTDIR=$FAST_OC_DESC_OUTDIR 'BEGIN { RS="#@@@%@@@#\n"; FS="\n" } { OBJNAME=substr($1, index($1, ":")+1); gsub(/^[ \t]*/, "", OBJNAME); gsub(/[\n]*$/, "", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR"/"OBJNAME".desc") } }'
					else
						echo "[$(date)] [${FUNCNAME[0]}] Unable to determine RECORD_SEPARATOR_KEYWORD for resource type [$RESTYPE] in namespace [$NAMESPACE]!"
					fi
	
					local TMP_DESC_ALL_KEEP="false"
					local SOURCE_COUNT=$(grep '^'$RECORD_SEPARATOR_KEYWORD':' $FAST_OC_DESC_TMPFILE | $AWK -F: 'NF>=2' | wc -l)
					local DESC_FILE_COUNT=$(ls -l $FAST_OC_DESC_OUTDIR/*.desc | wc -l)
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] DESC_FILE_COUNT = [$DESC_FILE_COUNT] / SOURCE_COUNT = [$SOURCE_COUNT]"
					fi
				
					if [ ${#DESC_FILE_COUNT} -gt 0 ] && [ ${#SOURCE_COUNT} -gt 0 ]
					then
						if [ $DESC_FILE_COUNT -ne $SOURCE_COUNT ]
						then
							local TMP_DESC_ALL_KEEP="true"
						fi
					else
						local TMP_DESC_ALL_KEEP="true"
					fi
	
					if [ $MG_DEBUG == "true" ]
					then
						if [ ${#FAST_OC_DESC_NS} -eq 0 ]
						then
							local FAST_OC_DESC_NS="all-namespaces"
						else
							local FAST_OC_DESC_NS=$(echo "$FAST_OC_DESC_NS" | $AWK '{ print $2 }')
						fi
	
						if [ ! -d $DEBUG_OUTDIR/getCrdData/$FAST_OC_DESC_NS ]
						then
							mkdir -p $DEBUG_OUTDIR/getCrdData/$FAST_OC_DESC_NS
						fi
	
						echo "[$(date)] [${FUNCNAME[0]}] File listing (*.desc) on output directory [$FAST_OC_DESC_OUTDIR] => [$(ls -l $FAST_OC_DESC_OUTDIR/*.desc)]"
						echo "[$(date)] [${FUNCNAME[0]}] File count (*.desc) on output directory [$FAST_OC_DESC_OUTDIR] => [$DESC_FILE_COUNT] [SOURCE_COUNT=$SOURCE_COUNT]"
	
						echo "[$(date)] [${FUNCNAME[0]}] TMP_DESC_ALL_KEEP = [$TMP_DESC_ALL_KEEP]"
	
						if [ $TMP_DESC_ALL_KEEP == "false" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Moving [$FAST_OC_DESC_TMPFILE] to directory [$DEBUG_OUTDIR/getCrdData/$FAST_OC_DESC_NS]..."
							mv $FAST_OC_DESC_TMPFILE $DEBUG_OUTDIR/getCrdData/$FAST_OC_DESC_NS
						else
							echo "[$(date)] [${FUNCNAME[0]}] Copying [$FAST_OC_DESC_TMPFILE] to directory [$DEBUG_OUTDIR/getCrdData/$FAST_OC_DESC_NS]..."
							cp -p $FAST_OC_DESC_TMPFILE $DEBUG_OUTDIR/getCrdData/$FAST_OC_DESC_NS
						fi
					else
						if [ $TMP_DESC_ALL_KEEP == "false" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_DESC_TMPFILE]..."
							rm $FAST_OC_DESC_TMPFILE
						fi
					fi
				else
					if [ ${#FAST_OC_DESC_NS} -gt 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC - '$OC_CMD describe $FAST_OC_DESC_OBJTYPE $FAST_OC_DESC_NS' output file [$FAST_OC_DESC_TMPFILE] does not exist or is zero-sized!"
					else
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC - '$OC_CMD describe $FAST_OC_DESC_OBJTYPE' output file [$FAST_OC_DESC_TMPFILE] does not exist or is zero-sized!"
					fi
				fi
			done
	
			if [ $MG_DEBUG == "true" ]
			then
				if [ ${#FAST_OC_DESC_NS} -eq 0 ]
				then
					local FAST_OC_DESC_NS="all-namespaces"
				else
					local FAST_OC_DESC_NS=$(echo "$FAST_OC_DESC_NS" | $AWK '{ print $2 }')
				fi
	
				if [ ! -d $DEBUG_OUTDIR/getCrdData/$FAST_OC_DESC_NS ]
				then
					mkdir -p $DEBUG_OUTDIR/getCrdData/$FAST_OC_DESC_NS
				fi
	
				mv $FAST_OC_DESC_WORKFILE $DEBUG_OUTDIR/getCrdData/$FAST_OC_DESC_NS
			else
				rm $FAST_OC_DESC_WORKFILE
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC_WORKFILE [$FAST_OC_DESC_WORKFILE] does not exist or is zero-sized!"
		fi
	fi

	if [ $COLLECT_YAML == "true" ]
	then
		if [ ${FAST_OC_YAML} == "true" ]
		then
			if [ -s $FAST_OC_YAML_WORKFILE ]
			then
				local FAST_OC_YAML_FAILED="false"

				for LINE in $($AWK -F## '{ print $1 "##" $2 "##" $4 }' $FAST_OC_YAML_WORKFILE | sort | uniq)
				do
					local FAST_OC_YAML_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
					local FAST_OC_YAML_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
					local FAST_OC_YAML_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')

					local FAST_OC_YAML_OUTFILE=$FAST_OC_YAML_OUTDIR/fast_oc_yaml.$FAST_OC_YAML_OBJTYPE.yaml-all

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_NS = [$FAST_OC_YAML_NS] / FAST_OC_YAML_OBJTYPE = [$FAST_OC_YAML_OBJTYPE] / FAST_OC_YAML_OUTDIR = [$FAST_OC_YAML_OUTDIR] / FAST_OC_YAML_OUTFILE = [$FAST_OC_YAML_OUTFILE]"
					fi

					if [ ${#FAST_OC_YAML_NS} -gt 0 ]
					then
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
							local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE"
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
							local BULK_YAML_CMD="$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE"
						fi
					else	
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
							local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE"
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
							local BULK_YAML_CMD="$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE"
						fi
					fi

					eval "$BULK_YAML_CMD" > $FAST_OC_YAML_OUTFILE

					if [ -s $FAST_OC_YAML_OUTFILE ]
					then
						sed $(( $(wc -l <$FAST_OC_YAML_OUTFILE)-3+1 ))',$ d; 1,2d; s/^-[ ]/#@@@%@@@#\'$'\n/g; s/^[ ]\{2\}//' $FAST_OC_YAML_OUTFILE | sed '1d' | $AWK -v OUTDIR=$FAST_OC_YAML_OUTDIR 'BEGIN { RS="#@@@%@@@#\n"; FS="\n" } { METADATA_FOUND="false"; OBJNAME=""; for (i=1; i<=NF; i++) { if ( $i ~ /^metadata:/  ){ METADATA_FOUND="true" } else { if ( $i ~ /^[ ]{2}name: / && METADATA_FOUND == "true" ) { OBJNAME=substr($i, index($i, ":")+1); gsub(/^[ \t]*/, "", OBJNAME); gsub(/[\n]*$/, "", $0); break } } }; if ( length(OBJNAME) > 0 ) { print > (OUTDIR"/"OBJNAME".yaml") } }'

						local TMP_YAML_ALL_KEEP="false"
						local SOURCE_COUNT=$(grep '^- ' $FAST_OC_YAML_OUTFILE | wc -l)
						local YAML_FILE_COUNT=$(ls -l $FAST_OC_YAML_OUTDIR/*.yaml | wc -l)

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] YAML_FILE_COUNT = [$YAML_FILE_COUNT] / SOURCE_COUNT = [$SOURCE_COUNT]"
						fi
				
						if [ ${#YAML_FILE_COUNT} -gt 0 ] && [ ${#SOURCE_COUNT} -gt 0 ]
						then
							if [ $YAML_FILE_COUNT -ne $SOURCE_COUNT ]
							then
								local TMP_YAML_ALL_KEEP="true"
							fi
						else
							local TMP_YAML_ALL_KEEP="true"
						fi

						if [ $MG_DEBUG == "true" ]
						then
							if [ ${#FAST_OC_YAML_NS} -eq 0 ]
							then
								local FAST_OC_YAML_NS="all-namespaces"
							fi

							if [ ! -d $DEBUG_OUTDIR/getCrdData/$FAST_OC_YAML_NS ]
							then
								mkdir -p $DEBUG_OUTDIR/getCrdData/$FAST_OC_YAML_NS
							fi
	
							echo "[$(date)] [${FUNCNAME[0]}] File listing (*.yaml) on output directory [$FAST_OC_YAML_OUTDIR] => [$(ls -l $FAST_OC_YAML_OUTDIR/*.yaml)]"
							echo "[$(date)] [${FUNCNAME[0]}] File count (*.yaml) on output directory [$FAST_OC_YAML_OUTDIR] => [$YAML_FILE_COUNT] [SOURCE_COUNT=$SOURCE_COUNT]"

							echo "[$(date)] [${FUNCNAME[0]}] TMP_YAML_ALL_KEEP = [$TMP_YAML_ALL_KEEP]"
						
							if [ $TMP_YAML_ALL_KEEP == "false" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Moving FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] to directory [$DEBUG_OUTDIR/getCrdData/$FAST_OC_YAML_NS]..."
								mv $FAST_OC_YAML_OUTFILE $DEBUG_OUTDIR/getCrdData/$FAST_OC_YAML_NS
							else
								echo "[$(date)] [${FUNCNAME[0]}] Copying FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] to directory [$DEBUG_OUTDIR/getCrdData/$FAST_OC_YAML_NS]..."
								cp -p $FAST_OC_YAML_OUTFILE $DEBUG_OUTDIR/getCrdData/$FAST_OC_YAML_NS
							fi
						else	
							if [ $TMP_DESC_ALL_KEEP == "false" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_YAML_OUTFILE]..."
								rm $FAST_OC_YAML_OUTFILE
							fi
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] does not exist or is zero-sized!"
						local FAST_OC_YAML_FAILED="true"
					fi
				done

				if [ ${FAST_OC_YAML_FAILED} == "true" ]
				then	
					while read LINE
					do
						local FAST_OC_YAML_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
						local FAST_OC_YAML_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
						local FAST_OC_YAML_OBJNAME=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')
						local FAST_OC_YAML_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $4 }')
						local FAST_OC_YAML_CURL_CMD=$(echo "$LINE" | $AWK -F'##' '{ print $5 }')

						if [ ${#FAST_OC_YAML_CURL_CMD} -gt 0 ]
						then
							local BULK_YAML_CMD="$FAST_OC_YAML_CURL_CMD"
						else
							if [ ${#FAST_OC_YAML_NS} -gt 0 ]
							then
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
									local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
									local BULK_YAML_CMD="$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
								fi
							else
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
									local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
									local BULK_YAML_CMD="$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
								fi
							fi
						fi

						echo "[$(date)] [${FUNCNAME[0]}] [RETRY] Executing '$BULK_YAML_CMD' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
						eval "$BULK_YAML_CMD" > $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml
					done < $FAST_OC_YAML_WORKFILE
				fi

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Moving FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE] to directory [$DEBUG_OUTDIR/getCrdData]..."
					mv $FAST_OC_YAML_WORKFILE $DEBUG_OUTDIR/getCrdData
				else
					echo "[$(date)] [${FUNCNAME[0]}] Deleting FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE]..."
					rm $FAST_OC_YAML_WORKFILE
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE] does not exist or is zero-sized!"
			fi
		fi
	fi
	
	rm $F_OUTDIR/api-resources.$$.tmp

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [PATTERN=$PATTERN]"
	fi
}

getWhoCanScc()
{
	local F_OUTDIR=$1
	local NAMESPACE=$2
	
	local NS=
	local SCC=
	
	if [ $OC_CMD != "oc" ] || ([ "$CLOUD_PLATFORM" != "ocp" ] || [ "$CLOUD_PLATFORM" != "OCP" ])
	then
		echo "[$(date)] [${FUNCNAME[0]}] Function getWhoCanScc() is only supported on Openshift environment!"
		return 1
	fi
	
	if [ ${#F_OUTDIR} -eq 0 ]
	then
		local F_OUTDIR=$CUSTOM_DATA_OUTDIR/whocan-scc
	fi
	
	if [ ! -d $F_OUTDIR ]
	then
		mkdir -p $F_OUTDIR
	fi
	
	IFS=$OLDIFS
	
	if [ ${#NAMESPACE} -eq 0 ]
	then
		for NS in ${PROD_NAMESPACES_UNIQUE[@]}	
		do
			echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
			if ! checkUserPriv list securitycontextconstraints all
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have [list] privilege on resource [securitycontextconstraints] in namespace [$NS]. Skipping..."
				continue
			fi
	
			if ! checkUserPriv create localresourceaccessreviews $NS
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have [create] privilege on resource [localresourceaccessreviews] in namespace [$NS]. Skipping..."
				continue
			fi	
	
			if [ ! -d $F_OUTDIR/$NS ]
			then
	 			mkdir -p $F_OUTDIR/$NS
			fi
	
			for SCC in $($OC_CMD get scc -n $NS --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}')
			do
				echo "[$(date)] [${FUNCNAME[0]}] Executing command '$OC_CMD adm policy who-can scc $SCC -n $NS' => $F_OUTDIR/$NS/$SCC.whocan"
				$OC_CMD adm policy who-can use scc $SCC -n $NS > $F_OUTDIR/$NS/$SCC.whocan
			done
		done
	else
		echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
		if ! checkUserPriv create localresourceaccessreviews $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have [create] privilege on resource [localresourceaccessreviews] in namespace [$NAMESPACE]. Skipping..."
			return 1
		fi	
	
		if [ ! -d $F_OUTDIR/$NAMESPACE ]
		then
			mkdir -p $F_OUTDIR/$NAMESPACE
		fi
	
		for SCC in $($OC_CMD get scc -n $NAMESPACE --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}')
		do
			echo "[$(date)] [${FUNCNAME[0]}] Executing command '$OC_CMD adm policy who-can scc $SCC -n $NAMESPACE' => $F_OUTDIR/$NAMESPACE/$SCC.whocan"
			$OC_CMD adm policy who-can use scc $SCC -n $NAMESPACE > $F_OUTDIR/$NAMESPACE/$SCC.whocan
		done
	fi
	
	IFS=$'\n'
}

getOcAllNS()
{
	local OC_ALLNS_OUTFILE=$1
	
	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
	if ! checkUserPriv get all all
	then	
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to access cluster data! Checking privilege for main resources..."	
	
		# Checking RBAC for main 'oc get all' resources
		if ! checkUserPriv get,list pod all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'pod' at cluster-scope. Skipping..."
			return 1
		fi
		
		if ! checkUserPriv get,list deployment all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'deployment' at cluster-scope. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list statefulset all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'statefulset' at cluster-scope. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list service all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'service' at cluster-scope. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list job all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'job' at cluster-scope. Skipping..."
			return 1
		fi
	fi
	
	if [ ! -d $(dirname $OC_ALLNS_OUTFILE) ]
	then
		mkdir -p $(dirname $OC_ALLNS_OUTFILE)
	fi
	
	echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get all --all-namespaces' => $OC_ALLNS_OUTFILE"
	$OC_CMD get all -o wide --all-namespaces > $OC_ALLNS_OUTFILE 2>&1
}

analyzeOcAllNS()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local OC_ALL_NS_OUTFILE=$1
	local F_OUTDIR=$2
	
	local BADCTR=0
	local BAD_DEPLOYMENT=0
	local BAD_STATEFULSET=0
	local BAD_DAEMONSET=0
	local BAD_POD=0
	
	local GOOD_DEPLOYMENT=0
	local GOOD_STATEFULSET=0
	local GOOD_DAEMONSET=0
	local RUNNING_POD=0
	local COMPLETED_POD=0
	
	local TOTAL_DEPLOYMENT=0
	local TOTAL_STATEFULSET=0
	local TOTAL_DAEMONSET=0
	local TOTAL_POD=0
	
	local TO_GET_EVENT=()
	
	local NS=
	local TO_EXCLUDE_NS=
	local DEPLOY_LINE=
	local STATEFULSET_LINE=
	local DAEMONSET_LINE=
	local POD_LINE=
	local CONTAINER=
	local POD_EVENT=
	
	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
	if ! checkUserPriv get all all
	then	
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to access cluster data! Checking privilege for main resources..."	
	
		# Checking RBAC for main 'oc get all' resources
		if ! checkUserPriv get,list pod all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'pod' at cluster-scope. Skipping..."
			return 1
		fi
		
		if ! checkUserPriv get,list deployment all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'deployment' at cluster-scope. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list statefulset all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'statefulset' at cluster-scope. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list service all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'service' at cluster-scope. Skipping..."
			return 1
		fi
	
		if ! checkUserPriv get,list job all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform '$OC_CMD get' for resource 'job' at cluster-scope. Skipping..."
			return 1
		fi
	fi
	
	if [ ${#F_OUTDIR} -eq 0 ]
	then
		local F_OUTDIR=$ALL_NS_PROB_OUTDIR
	fi
	
	if [ ! -d $F_OUTDIR ]
	then
		mkdir -p $F_OUTDIR
	fi
	
	if [ ${#PROD_NAMESPACES_UNIQUE[@]} -gt 1 ]
	then
		local NS_CTR=0
	
		for NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do	
			if [ $NS_CTR -eq 0 ]
			then
				local TO_EXCLUDE_NS="^$NS$"	
			else
				local TO_EXCLUDE_NS="$TO_EXCLUDE_NS|^$NS$"
			fi
	
			(( NS_CTR=NS_CTR+1 ))
		done
	else
		local TO_EXCLUDE_NS="^${PROD_NAMESPACES_UNIQUE[0]}$"
	fi	
	
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Regex [TO_EXCLUDE_NS] = $TO_EXCLUDE_NS"
	fi
	
	if [ ${#PROD_NAMESPACES_UNIQUE[@]} -eq 0 ]
	then
		local EXCLUDED_NS="N/A"
	else
		local EXCLUDED_NS=${PROD_NAMESPACES_UNIQUE[@]}
	fi
	
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "HEALTH REPORT OF ALL NAMESPACES (excluding '${EXCLUDED_NS}')" >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing '$OC_CMD get all --all-namespaces' => $OC_ALL_NS_OUTFILE" | tee -a $ANALYZE_OUTFILE
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing DEPLOYMENTS [all-namespaces]" | tee -a $ANALYZE_OUTFILE
	
	if [ ! -s $OC_ALL_NS_OUTFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] File [$OC_ALL_NS_INFILE] does not exist or is zero-sized!" 
	
		if [ ! -d $(dirname $OC_ALL_NS_INFILE) ]
		then
			mkdir -p $(dirname $OC_ALL_NS_INFILE)
		fi
	
		getOcAllNS $OC_ALL_NS_OUTFILE
	fi
	
	if [ $OC_DESC_ON == "true" ] || [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ] || [ $GET_POD_LOGS == "true" ]
	then
		# Deployment
		local TO_PROCEED_DEPLOY_DESC="true"
		local TO_PROCEED_DEPLOY_YAML="false"
		local TO_PROCEED_DEPLOY_JSON="false"
	
		if isRestrictedData "deployment.apps"
		then
			local TO_PROCEED_DEPLOY_DESC="false"
		else
			if isSensitiveData "deployment.apps"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] analyzeOcAllNS() function does not support '$OC_CMD get -o yaml/json' of [deployment.apps] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [deployment.apps]!"
					local TO_PROCEED_DEPLOY_YAML="true"
					local TO_PROCEED_DEPLOY_JSON="true"
				fi
			else
				local TO_PROCEED_DEPLOY_YAML="true"
				local TO_PROCEED_DEPLOY_JSON="true"
			fi
		fi

		# Statefulset
		local TO_PROCEED_STATEFULSET_DESC="true"
		local TO_PROCEED_STATEFULSET_YAML="false"
		local TO_PROCEED_STATEFULSET_JSON="false"
	
		if isRestrictedData "statefulset.apps"
		then
			local TO_PROCEED_STATEFULSET_DESC="false"
		else
			if isSensitiveData "statefulset.apps"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] analyzeOcAllNS() function does not support '$OC_CMD get -o yaml/json' of [statefulset.apps] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [statefulset.apps]!"
					local TO_PROCEED_STATEFULSET_YAML="true"
					local TO_PROCEED_STATEFULSET_JSON="true"
				fi
			else
				local TO_PROCEED_STATEFULSET_YAML="true"
				local TO_PROCEED_STATEFULSET_JSON="true"
			fi
		fi

		# Daemonset
		local TO_PROCEED_DAEMONSET_DESC="true"
		local TO_PROCEED_DAEMONSET_YAML="false"
		local TO_PROCEED_DAEMONSET_JSON="false"
	
		if isRestrictedData "daemonset.apps"
		then
			local TO_PROCEED_DAEMONSET_DESC="false"
		else
			if isSensitiveData "daemonset.apps"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] analyzeOcAllNS() function does not support '$OC_CMD get -o yaml/json' of [daemonset.apps] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [daemonset.apps]!"
					local TO_PROCEED_DAEMONSET_YAML="true"
					local TO_PROCEED_DAEMONSET_JSON="true"
				fi
			else
				local TO_PROCEED_DAEMONSET_YAML="true"
				local TO_PROCEED_DAEMONSET_JSON="true"
			fi
		fi

		# Pod
		local TO_PROCEED_POD_DESC="true"
		local TO_PROCEED_POD_YAML="false"
		local TO_PROCEED_POD_JSON="false"
		local TO_PROCEED_POD_LOGS="false"
	
		if isRestrictedData "pod"
		then
			local TO_PROCEED_POD_DESC="false"
		else
			if isSensitiveData "pod"
			then
				if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
				then		
					echo "[$(date)] [${FUNCNAME[0]}] analyzeOcAllNS() function does not support '$OC_CMD get -o yaml/json' and '$OC_CMD logs' of [pod] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else
					echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [pod]!"
					local TO_PROCEED_POD_YAML="true"
					local TO_PROCEED_POD_JSON="true"
					local TO_PROCEED_POD_LOGS="true"
				fi
			else
				local TO_PROCEED_POD_YAML="true"
				local TO_PROCEED_POD_JSON="true"
				local TO_PROCEED_POD_LOGS="true"
			fi
		fi
	fi

	local ANALYZE_NS_ARR=()
	IFS=$'\n'
	
	local D_HEADER=0
	for DEPLOY_LINE in $($AWK '$2 ~ /^deployment.apps/ { print $0 }' $OC_ALL_NS_OUTFILE | $AWK '$1 !~ /'$TO_EXCLUDE_NS'/ { print }')
	do
		(( TOTAL_DEPLOYMENT=TOTAL_DEPLOYMENT+1 ))

		local D_NAMESPACE=$(echo "$DEPLOY_LINE" | $AWK '{ print $1 }')
		local DEPLOY=$(echo "$DEPLOY_LINE" | $AWK '{ print $2 }') 
		local DEPLOY_NAME=$(echo "$DEPLOY" | $AWK -F'/' '{ print $2 }') 
		local D_READY_COUNT=$(echo "$DEPLOY_LINE" | $AWK '{ print $3 }') 
		local D_CONTAINERS=$(echo "$DEPLOY_LINE" | $AWK '{ print $7 }')
		local D_CHECK_RES=$(echo "$D_READY_COUNT" | $AWK -F '/' '{ if ( $1 == $2 ) { print "OK" } else { print "NOK" } }')
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] D_NAMESPACE = [$D_NAMESPACE] / DEPLOY = [$DEPLOY] / DEPLOY_NAME = [$DEPLOY_NAME] / D_READY_COUNT = [$D_READY_COUNT] / D_CONTAINERS = [$D_CONTAINERS] / D_CHECK_RES = [$D_CHECK_RES]"
		fi
	
		if [ $D_CHECK_RES == "NOK" ]
		then
			(( BADCTR=BADCTR+1 ))
			(( BAD_DEPLOYMENT=BAD_DEPLOYMENT+1 ))
	
			if [ $D_HEADER -eq 0 ]
			then
				printf "%-6s %-50s %-65s %-85s %-8s %-8s \n" "COUNT" "NAMESPACE" "DEPLOYMENT" "CONTAINERS" "READY" "STATUS" >> $ANALYZE_OUTFILE
				local D_HEADER=1
			fi
	
			printf "%-6s %-50s %-65s %-85s %-8s %-8s \n" "${BAD_DEPLOYMENT}" "$D_NAMESPACE" "$DEPLOY_NAME" "$D_CONTAINERS" "$D_READY_COUNT" "NOK" >> $ANALYZE_OUTFILE
			
			if ! toIgnoreAddOnNS $D_NAMESPACE
			then
				if [[ ${D_NAMESPACE} =~ ^openshift ]] || [[ ${D_NAMESPACE} =~ ^kube ]] || [ $ALLNS_DATA == "true" ]
				then
					local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/$MUSTGATHER_OPT/$D_NAMESPACE
		
					if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" ) && ! -d $BAD_OBJ_ROOTDIR/deployment ]]
					then
						mkdir -p $BAD_OBJ_ROOTDIR/deployment
					fi
		
					if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_DEPLOY_DESC == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe deploy -n $D_NAMESPACE $DEPLOY_NAME' => $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.desc"
						$OC_CMD describe deploy -n $D_NAMESPACE $DEPLOY_NAME > $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.desc 2>&1
					fi
		
					if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_DEPLOY_YAML == "true" ]
					then	
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields deploy -n $D_NAMESPACE $DEPLOY_NAME' => $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.yaml"
							$OC_CMD get -o yaml --show-managed-fields deploy -n $D_NAMESPACE $DEPLOY_NAME > $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.yaml 2>&1
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml deploy -n $D_NAMESPACE $DEPLOY_NAME' => $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.yaml"
							$OC_CMD get -o yaml deploy -n $D_NAMESPACE $DEPLOY_NAME > $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.yaml 2>&1
						fi
					fi
		
					if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_DEPLOY_JSON == "true" ]
					then	
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields deploy -n $D_NAMESPACE $DEPLOY_NAME' => $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.json"
							$OC_CMD get -o json --show-managed-fields deploy -n $D_NAMESPACE $DEPLOY_NAME > $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.json 2>&1
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json deploy -n $D_NAMESPACE $DEPLOY_NAME' => $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.json"
							$OC_CMD get -o json deploy -n $D_NAMESPACE $DEPLOY_NAME > $BAD_OBJ_ROOTDIR/deployment/${DEPLOY_NAME}.json 2>&1
						fi
					fi
		
					local TGT_NS=
					local TGT_NS_FOUND="false"
		
					for TGT_NS in ${ANALYZE_NS_ARR[@]}
					do
						if [ $TGT_NS == ${D_NAMESPACE} ]
						then
							TGT_NS_FOUND="true"
							break
						fi
					done
		
					if [ $TGT_NS_FOUND == "false" ]
					then
						local ANALYZE_NS_ARR[${#ANALYZE_NS_ARR[@]}]=${D_NAMESPACE}
						echo "[$(date)] [${FUNCNAME[0]}] Added namespace [${D_NAMESPACE}] to ANALYZE_NS_ARR [count=${#ANALYZE_NS_ARR[@]}]..."
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Namespace [$D_NAMESPACE] of deployment [$DEPLOY_NAME] is non-Openshift/non-product! Skipping..."
				fi
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Skipping data extraction for bad deployment [$D_NAMESPACE/$DEPLOY_NAME]..."
				fi
			fi
		else
			(( GOOD_DEPLOYMENT=GOOD_DEPLOYMENT+1 ))
		fi
	done
	
	if [ $(( GOOD_DEPLOYMENT + BAD_DEPLOYMENT )) -gt 0 ]
	then
		if [ $BAD_DEPLOYMENT -gt 0 ]
		then
			echo ">>> [TOTAL OK] [all-namepsaces] Deployment = $GOOD_DEPLOYMENT" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL NOK] [all-namepsaces] Deployment = $BAD_DEPLOYMENT" >> $ANALYZE_OUTFILE
		else
			echo ">>> [TOTAL OK] [all-namepsaces] Deployment = $GOOD_DEPLOYMENT" >> $ANALYZE_OUTFILE
		fi
	else
		echo ">>> [all-namepsaces] There is no 'deployment' found!" >> $ANALYZE_OUTFILE
	fi
	
	echo ">>> [TOTAL DEPLOYMENT] = ${TOTAL_DEPLOYMENT}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE
	
	local S_HEADER=0
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing STATEFULESETS [all-namespaces]" | tee -a $ANALYZE_OUTFILE
	for STATEFULSET_LINE in $($AWK '$2 ~ /^statefulset.apps/ { print $0 }' $OC_ALL_NS_OUTFILE | $AWK '$1 !~ /'$TO_EXCLUDE_NS'/ { print }')
	do
		(( TOTAL_STATEFULSET=TOTAL_STATEFULSET+1 ))

		local S_NAMESPACE=$(echo "$STATEFULSET_LINE" | $AWK '{ print $1 }')
		local STATEFULSET=$(echo "$STATEFULSET_LINE" | $AWK '{ print $2 }') 
		local STATEFULSET_NAME=$(echo "$STATEFULSET" | $AWK -F'/' '{ print $2 }') 
		local S_READY_COUNT=$(echo "$STATEFULSET_LINE" | $AWK '{ print $3 }') 
		local S_CONTAINERS=$(echo "$STATEFULSET_LINE" | $AWK '{ print $5 }')
		local S_CHECK_RES=$(echo "$S_READY_COUNT" | $AWK -F '/' '{ if ( $1 == $2 ) { print "OK" } else { print "NOK" } }')
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] S_NAMESPACE = [$S_NAMESPACE] / STATEFULSET = [$STATEFULSET] / STATEFULSET_NAME = [$STATEFULSET_NAME] / S_READY_COUNT = [$S_READY_COUNT] / S_CONTAINERS = [$S_CONTAINERS] / S_CHECK_RES = [$S_CHECK_RES]"
		fi
	
		if [ $S_CHECK_RES == "NOK" ]
		then
			(( BADCTR=BADCTR+1 ))
			(( BAD_STATEFULSET=BAD_STATEFULSET+1 ))
	
			if [ $S_HEADER -eq 0 ]
			then
				printf "%-6s %-50s %-65s %-85s %-8s %-8s \n" "COUNT" "NAMESPACE" "STATEFULSET" "CONTAINERS" "READY" "STATUS" >> $ANALYZE_OUTFILE
				local S_HEADER=1
			fi
	
			printf "%-6s %-50s %-65s %-85s %-8s %-8s \n" "${BAD_STATEFULSET}" "$S_NAMESPACE" "$STATEFULSET_NAME" "$S_CONTAINERS" "$S_READY_COUNT" "NOK" >> $ANALYZE_OUTFILE
	
			if ! toIgnoreAddOnNS $S_NAMESPACE
			then
				if [[ ${S_NAMESPACE} =~ ^openshift ]] || [[ ${S_NAMESPACE} =~ ^kube ]] || [ $ALLNS_DATA == "true" ]
				then
					local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/$MUSTGATHER_OPT/$S_NAMESPACE
		
					if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" ) && ! -d $BAD_OBJ_ROOTDIR/statefulset ]]
					then
						mkdir -p $BAD_OBJ_ROOTDIR/statefulset
					fi
		
					if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_STATEFULSET_DESC == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe sts -n $S_NAMESPACE $STATEFULSET_NAME' => $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.desc"
						$OC_CMD describe sts -n $S_NAMESPACE $STATEFULSET_NAME > $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.desc 2>&1
					fi
		
					if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_STATEFULSET_YAML == "true" ]
					then
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields sts -n $S_NAMESPACE $STATEFULSET_NAME' => $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.yaml"
							$OC_CMD get -o yaml --show-managed-fields sts -n $S_NAMESPACE $STATEFULSET_NAME > $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.yaml 2>&1
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml sts -n $S_NAMESPACE $STATEFULSET_NAME' => $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.yaml"
							$OC_CMD get -o yaml sts -n $S_NAMESPACE $STATEFULSET_NAME > $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.yaml 2>&1
						fi
					fi
		
					if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_STATEFULSET_JSON == "true" ]
					then
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields sts -n $S_NAMESPACE $STATEFULSET_NAME' => $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.json"
							$OC_CMD get -o json --show-managed-fields sts -n $S_NAMESPACE $STATEFULSET_NAME > $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.json 2>&1
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json sts -n $S_NAMESPACE $STATEFULSET_NAME' => $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.json"
							$OC_CMD get -o json sts -n $S_NAMESPACE $STATEFULSET_NAME > $BAD_OBJ_ROOTDIR/statefulset/${STATEFULSET_NAME}.json 2>&1
						fi
					fi
		
					local TGT_NS=
					local TGT_NS_FOUND="false"
		
					for TGT_NS in ${ANALYZE_NS_ARR[@]}
					do
						if [ $TGT_NS == ${S_NAMESPACE} ]
						then
							TGT_NS_FOUND="true"
							break
						fi
					done
		
					if [ $TGT_NS_FOUND == "false" ]
					then
						local ANALYZE_NS_ARR[${#ANALYZE_NS_ARR[@]}]=${S_NAMESPACE}
						echo "[$(date)] [${FUNCNAME[0]}] Added namespace [${S_NAMESPACE}] to ANALYZE_NS_ARR [count=${#ANALYZE_NS_ARR[@]}]..."
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Namespace [$S_NAMESPACE] of statefulset [$STATEFULSET_NAME] is non-Openshift/non-product! Skipping..."
				fi
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Skipping data extraction for bad statefulset [$S_NAMESPACE/$STATEFULSET_NAME]..."
				fi
			fi
		else
			(( GOOD_STATEFULSET=GOOD_STATEFULSET+1 ))
		fi
	done
	
	if [ $(( GOOD_STATEFULSET + BAD_STATEFULSET )) -gt 0 ]
	then
		if [ $BAD_STATEFULSET -gt 0 ]
		then
			echo ">>> [TOTAL OK] [all-namespaces] Statefulset = $GOOD_STATEFULSET" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL NOK] [all-namespaces] Statefulset = $BAD_STATEFULSET" >> $ANALYZE_OUTFILE
		else
			echo ">>> [TOTAL OK] [all-namespaces] Statefulset = $GOOD_STATEFULSET" >> $ANALYZE_OUTFILE
		fi
	else
		echo ">>> [all-namepsaces] There is no 'statefulset' found!" >> $ANALYZE_OUTFILE
	fi
	
	echo ">>> [TOTAL STATEFULSET] = ${TOTAL_STATEFULSET}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE

	local DS_HEADER=0
	echo "[$(date)] [${FUNCNAME[0]}] Analyzing DAEMONSETS [all-namespaces]" | tee -a $ANALYZE_OUTFILE
	for DAEMONSET_LINE in $($AWK '$2 ~ /^daemonset.apps/ { print $0 }' $OC_ALL_NS_OUTFILE | $AWK '$1 !~ /'$TO_EXCLUDE_NS'/ { print }')
	do
		(( TOTAL_DAEMONSET=TOTAL_DAEMONSET+1 ))

		local DS_NAMESPACE=$(echo "$DAEMONSET_LINE" | $AWK '{ print $1 }')
		local DAEMONSET=$(echo "$DAEMONSET_LINE" | $AWK '{ print $2 }') 
		local DAEMONSET_NAME=$(echo "$STATEFULSET" | $AWK -F'/' '{ print $2 }') 
		local DS_DESIRED_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $3 }') 
		local DS_CURRENT_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $4 }') 
		local DS_READY_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $5 }') 
		local DS_UPTODATE_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $6 }') 
		local DS_AVAILABLE_COUNT=$(echo "$DAEMONSET_LINE" | $AWK '{ print $7 }') 
		local DS_CHECK_RES=$(echo "${DS_DESIRED_COUNT}##${DS_CURRENT_COUNT}##${DS_READY_COUNT}##${DS_UPTODATE_COUNT}##${DS_AVAILABLE_COUNT}" | $AWK -F## '{ if ( $1 == $2 && $1 == $3 && $1 == $4 && $1 == $5 ) { print "OK" } else { print "NOK" } }')
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] DS_NAMESPACE = [$DS_NAMESPACE] / DAEMONSET = [$DAEMONSET] / DAEMONSET_NAME = [$DAEMONSET_NAME] / DS_DESIRED_COUNT = [$DS_DESIRED_COUNT] / DS_CURRENT_COUNT = [$DS_CURRENT_COUNT] / DS_READY_COUNT = [$DS_READY_COUNT] / DS_UPTODATE_COUNT = [$DS_UPTODATE_COUNT] / DS_AVAILABLE_COUNT = [$DS_AVAILABLE_COUNT]" 
		fi
	
		if [ $DS_CHECK_RES == "NOK" ]
		then
			(( BADCTR=BADCTR+1 ))
			(( BAD_DAEMONSET=BAD_DAEMONSET+1 ))
	
			if [ $DS_HEADER -eq 0 ]
			then
				printf "%-6s %-50s %-65s %-18s %-18s %-18s %-18s %-18s %-18s %-8s \n" "COUNT" "NAMESPACE" "DAEMONSET" "DESIRED_COUNT" "CURRENT_COUNT" "READY_COUNT" "UPTODATE_COUNT" "AVAILABLE_COUNT" "STATUS" >> $ANALYZE_OUTFILE
				local DS_HEADER=1
			fi
	
			printf "%-6s %-50s %-65s %-18s %-18s %-18s %-18s %-18s %-18s %-8s \n" "${BAD_DAEMONSET}" "$DS_NAMESPACE" "$DAEMONSET_NAME" "$DS_DESIRED_COUNT" "$DS_CURRENT_COUNT" "$DS_READY_COUNT" "$DS_UPTODATE_COUNT" "$DS_AVAILABLE_COUNT" "NOK" >> $ANALYZE_OUTFILE
	
			if ! toIgnoreAddOnNS $DS_NAMESPACE
			then
				if [[ ${DS_NAMESPACE} =~ ^openshift ]] || [[ ${DS_NAMESPACE} =~ ^kube ]] || [ $ALLNS_DATA == "true" ]
				then
					local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/$MUSTGATHER_OPT/$DS_NAMESPACE
		
					if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" ) && ! -d $BAD_OBJ_ROOTDIR/daemonset ]]
					then
						mkdir -p $BAD_OBJ_ROOTDIR/daemonset
					fi
		
					if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_DAEMONSET_DESC == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe sts -n $DS_NAMESPACE $DAEMONSET_NAME' => $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.desc"
						$OC_CMD describe sts -n $DS_NAMESPACE $DAEMONSET_NAME > $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.desc 2>&1
					fi
		
					if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_DAEMONSET_YAML == "true" ]
					then
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields sts -n $DS_NAMESPACE $DAEMONSET_NAME' => $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.yaml"
							$OC_CMD get -o yaml --show-managed-fields sts -n $DS_NAMESPACE $DAEMONSET_NAME > $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.yaml 2>&1
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml sts -n $DS_NAMESPACE $DAEMONSET_NAME' => $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.yaml"
							$OC_CMD get -o yaml sts -n $DS_NAMESPACE $DAEMONSET_NAME > $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.yaml 2>&1
						fi
					fi
		
					if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_DAEMONSET_JSON == "true" ]
					then
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields sts -n $DS_NAMESPACE $DAEMONSET_NAME' => $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.json"
							$OC_CMD get -o json --show-managed-fields sts -n $DS_NAMESPACE $DAEMONSET_NAME > $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.json 2>&1
						else
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json sts -n $DS_NAMESPACE $DAEMONSET_NAME' => $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.json"
							$OC_CMD get -o json sts -n $DS_NAMESPACE $DAEMONSET_NAME > $BAD_OBJ_ROOTDIR/daemonset/${DAEMONSET_NAME}.json 2>&1
						fi
					fi
		
					local TGT_NS=
					local TGT_NS_FOUND="false"
		
					for TGT_NS in ${ANALYZE_NS_ARR[@]}
					do
						if [ $TGT_NS == ${DS_NAMESPACE} ]
						then
							TGT_NS_FOUND="true"
							break
						fi
					done
		
					if [ $TGT_NS_FOUND == "false" ]
					then
						local ANALYZE_NS_ARR[${#ANALYZE_NS_ARR[@]}]=${DS_NAMESPACE}
						echo "[$(date)] [${FUNCNAME[0]}] Added namespace [${DS_NAMESPACE}] to ANALYZE_NS_ARR [count=${#ANALYZE_NS_ARR[@]}]..."
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Namespace [$DS_NAMESPACE] of daemonset [$DAEMONSET_NAME] is non-Openshift/non-product! Skipping..."
				fi
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Skipping data extraction for bad daemonset [$DS_NAMESPACE/$DAEMONSET_NAME]..."
				fi
			fi
		else
			(( GOOD_DAEMONSET=GOOD_DAEMONSET+1 ))
		fi
	done
	
	if [ $(( GOOD_DAEMONSET + BAD_DAEMONSET )) -gt 0 ]
	then
		if [ $BAD_DAEMONSET -gt 0 ]
		then
			echo ">>> [TOTAL OK] [all-namespaces] Daemonset = $GOOD_DAEMONSET" >> $ANALYZE_OUTFILE
			echo ">>> [TOTAL NOK] [all-namespaces] Daemonset = $BAD_DAEMONSET" >> $ANALYZE_OUTFILE
		else
			echo ">>> [TOTAL OK] [all-namespaces] Daemonset = $GOOD_DAEMONSET" >> $ANALYZE_OUTFILE
		fi
	else
		echo ">>> [all-namepsaces] There is no 'daemonset' found!" >> $ANALYZE_OUTFILE
	fi
	
	echo ">>> [TOTAL DAEMONSET] = ${TOTAL_DAEMONSET}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE

	echo "[$(date)] [${FUNCNAME[0]}] Analyzing PODS [all-namespaces]" | tee -a $ANALYZE_OUTFILE
	
	local P_HEADER=0
	for POD_LINE in $($AWK '$2 ~ /^pod/ { print $0 }' $OC_ALL_NS_OUTFILE | $AWK '$1 !~ /'$TO_EXCLUDE_NS'/ { print }')
	do
		(( TOTAL_POD=TOTAL_POD+1 ))

		local P_NAMESPACE=$(echo "$POD_LINE" | $AWK '{ print $1 }')
		local POD=$(echo "$POD_LINE" | $AWK '{ print $2 }') 
		local PODNAME=$(echo "$POD" | $AWK -F '/' '{ print $2 }')
		local P_READY_COUNT=$(echo "$POD_LINE" | $AWK '{ print $3 }') 
		local P_STATUS=$(echo "$POD_LINE" | $AWK '{ print $4 }')
		local P_CHECK_RES=$(echo "$P_READY_COUNT" | $AWK -F '/' '{ if ( $1 == $2 ) { print "OK" } else { print "NOK" } }')
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] P_NAMESPACE = [$P_NAMESPACE] / POD = [$POD] / POD_NAME = [$POD_NAME] / P_READY_COUNT = [$P_READY_COUNT] / P_STATUS = [$P_STATUS] / P_CHECK_RES = [$P_CHECK_RES]"
		fi
	
		if [ $P_STATUS != "Running" -o $P_CHECK_RES == "NOK"  ]
		then
			if [ $P_STATUS != "Completed" ]
			then
				(( BADCTR=BADCTR+1 ))
				(( BAD_POD=BAD_POD+1 ))
	
				if [ $P_HEADER -eq 0 ]
				then
					printf "%-6s %-50s %-65s %-85s %-8s %-8s \n" "COUNT" "NAMESPACE" "POD" "CONTAINERS" "READY" "STATUS" >> $ANALYZE_OUTFILE
					local P_HEADER=1
				fi
	
				printf "%-6s %-50s %-65s %-85s %-8s %-8s \n" "${BAD_POD}" "$P_NAMESPACE" "$PODNAME" "$($OC_CMD get $POD -n $P_NAMESPACE -o=jsonpath="{.spec.containers[*].name}" | sed 's/ /,/g')" "$P_READY_COUNT" "$P_STATUS" >> $ANALYZE_OUTFILE
	
				if ! toIgnoreAddOnNS $P_NAMESPACE
				then
					if [[ ${P_NAMESPACE} =~ ^openshift ]] || [[ ${P_NAMESPACE} =~ ^kube ]] || [ $ALLNS_DATA == "true" ]
					then
						local BAD_OBJ_ROOTDIR=$ANALYZE_OUTDIR/$MUSTGATHER_OPT/$P_NAMESPACE
		
						if [[ ( $OC_DESC_ON == "true" || $COLLECT_YAML == "true" || $COLLECT_JSON == "true" || $GET_POD_LOGS == "true" ) && ! -d $BAD_OBJ_ROOTDIR/pod ]]
						then
							mkdir -p $BAD_OBJ_ROOTDIR/pod
						fi
		
						if [ $OC_DESC_ON == "true" ] && [ $TO_PROCEED_POD_DESC == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe po -n $P_NAMESPACE $PODNAME' => $BAD_OBJ_ROOTDIR/pod/${PODNAME}.desc"
							$OC_CMD describe po -n $P_NAMESPACE $PODNAME > $BAD_OBJ_ROOTDIR/pod/${PODNAME}.desc 2>&1
						fi
		
						if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_POD_YAML == "true" ]
						then
							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields po -n $P_NAMESPACE $PODNAME' => $BAD_OBJ_ROOTDIR/pod/${PODNAME}.yaml"
								$OC_CMD get -o yaml --show-managed-fields po -n $P_NAMESPACE $PODNAME > $BAD_OBJ_ROOTDIR/pod/${PODNAME}.yaml 2>&1
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml po -n $P_NAMESPACE $PODNAME' => $BAD_OBJ_ROOTDIR/pod/${PODNAME}.yaml"
								$OC_CMD get -o yaml po -n $P_NAMESPACE $PODNAME > $BAD_OBJ_ROOTDIR/pod/${PODNAME}.yaml 2>&1
							fi
						fi
		
						if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_POD_JSON == "true" ]
						then
							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields po -n $P_NAMESPACE $PODNAME' => $BAD_OBJ_ROOTDIR/pod/${PODNAME}.json"
								$OC_CMD get -o json --show-managed-fields po -n $P_NAMESPACE $PODNAME > $BAD_OBJ_ROOTDIR/pod/${PODNAME}.json 2>&1
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json po -n $P_NAMESPACE $PODNAME' => $BAD_OBJ_ROOTDIR/pod/${PODNAME}.json"
								$OC_CMD get -o json po -n $P_NAMESPACE $PODNAME > $BAD_OBJ_ROOTDIR/pod/${PODNAME}.json 2>&1
							fi
						fi
		
						if [ $GET_POD_LOGS == "true" ] && [ $TO_PROCEED_POD_LOGS == "true" ]
						then
							IFS=$OLDIFS
							for INIT_CONTAINER in $($OC_CMD get $POD -n $P_NAMESPACE -o=jsonpath="{.spec.initContainers[*].name}")
							do 
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $P_NAMESPACE $POD -c $INIT_CONTAINER' => $BAD_OBJ_ROOTDIR/pod/$PODNAME~$INIT_CONTAINER.log"
								$OC_CMD logs -n $P_NAMESPACE $POD -c $INIT_CONTAINER > $BAD_OBJ_ROOTDIR/pod/$PODNAME~$INIT_CONTAINER.log 2>&1
		
								if [ $COLL_PREV_LOGS == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $P_NAMESPACE $POD -c $INIT_CONTAINER -p' => $BAD_OBJ_ROOTDIR/pod/$PODNAME~$INIT_CONTAINER.log.prev"
									$OC_CMD logs -n $P_NAMESPACE $POD -c $INIT_CONTAINER -p > $BAD_OBJ_ROOTDIR/pod/$PODNAME~$INIT_CONTAINER.log.prev 2>&1
								fi
							done
	
							for CONTAINER in $($OC_CMD get $POD -n $P_NAMESPACE -o=jsonpath="{.spec.containers[*].name}")
							do 
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $P_NAMESPACE $POD -c $CONTAINER' => $BAD_OBJ_ROOTDIR/pod/$PODNAME~$CONTAINER.log"
								$OC_CMD logs -n $P_NAMESPACE $POD -c $CONTAINER > $BAD_OBJ_ROOTDIR/pod/$PODNAME~$CONTAINER.log 2>&1
		
								if [ $COLL_PREV_LOGS == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $P_NAMESPACE $POD -c $CONTAINER -p' => $BAD_OBJ_ROOTDIR/pod/$PODNAME~$CONTAINER.log.prev"
									$OC_CMD logs -n $P_NAMESPACE $POD -c $CONTAINER -p > $BAD_OBJ_ROOTDIR/pod/$PODNAME~$CONTAINER.log.prev 2>&1
								fi
							done
							IFS=$'\n'
						fi
		
						local TGT_NS=
						local TGT_NS_FOUND="false"
			
						for TGT_NS in ${ANALYZE_NS_ARR[@]}
						do
							if [ $TGT_NS == ${P_NAMESPACE} ]
							then
								TGT_NS_FOUND="true"
								break
							fi
						done
		
						if [ $TGT_NS_FOUND == "false" ]
						then
							local ANALYZE_NS_ARR[${#ANALYZE_NS_ARR[@]}]=${P_NAMESPACE}
							echo "[$(date)] [${FUNCNAME[0]}] Added namespace [${P_NAMESPACE}] to ANALYZE_NS_ARR [count=${#ANALYZE_NS_ARR[@]}]..."
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] Namespace [$P_NAMESPACE] of pod [$PODNAME] is non-Openshift/non-product! Skipping..."
					fi
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Adding value [${BAD_OBJ_ROOTDIR}~${P_NAMESPACE}~${PODNAME}] into array TO_GET_EVENT!"
					fi
	
					local TO_GET_EVENT[${#TO_GET_EVENT[@]}]=${BAD_OBJ_ROOTDIR}~${P_NAMESPACE}~${PODNAME}
				else
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Skipping data extraction for bad pod [$P_NAMESPACE/$PODNAME]..."
					fi
				fi
			else
				(( COMPLETED_POD=COMPLETED_POD+1 ))
			fi
		else
			(( RUNNING_POD=RUNNING_POD+1 ))
		fi
	done
	
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] TO_GET_EVENT [count=${#TO_GET_EVENT[@]}]"
	fi
	
	if [ ${#TO_GET_EVENT[@]} -gt 0 ]
	then
		echo >> $ANALYZE_OUTFILE
	
		local PODCTR=1
	
		for POD_EVENT in ${TO_GET_EVENT[@]}
		do
			local POD_OUTDIR=$(echo "$POD_EVENT" | $AWK -F'~' '{ print $1 }')
			local POD_NAMESPACE=$(echo "$POD_EVENT" | $AWK -F'~' '{ print $2 }')
			local POD_NAME=$(echo "$POD_EVENT" | $AWK -F'~' '{ print $3 }')
	
			echo "[$PODCTR] [PODNAME = $POD_NAMESPACE/$POD_NAME]" >> $ANALYZE_OUTFILE
	
			if [[ ${POD_NAMESPACE} =~ ^openshift ]] || [[ ${POD_NAMESPACE} =~ ^kube ]] || [ $ALLNS_DATA == "true" ]
			then
				local OLD_ANALYZE_OUTFILE_ROWCNT=$(wc -l $ANALYZE_OUTFILE | $AWK '{ print $1 }')
	
				if [ $OC_DESC_ON == "true" ]
				then
					$AWK '/^Events:/{f=1}f' $POD_OUTDIR/pod/$POD_NAME.desc | sed '/^[ \t]*$/d' >> $ANALYZE_OUTFILE 2>&1
				else
					$OC_CMD describe pod -n $POD_NAMESPACE $POD_NAME | $AWK '/^Events:/{f=1}f' | sed '/^[ \t]*$/d' >> $ANALYZE_OUTFILE 2>&1
				fi
	
				local NOW_ANALYZE_OUTFILE_ROWCNT=$(wc -l $ANALYZE_OUTFILE | $AWK '{ print $1 }')
	
				if [ $NOW_ANALYZE_OUTFILE_ROWCNT -eq $OLD_ANALYZE_OUTFILE_ROWCNT ]
				then
					echo "<< Unable to retrieve events from pod >>"  >> $ANALYZE_OUTFILE
				fi
			else
				if [ $ALLNS_DATA == "false" ]
				then
					echo "<< ALLNS_DATA is false! Not showing non-Openshift/non-product data! >>" >> $ANALYZE_OUTFILE	
				fi
			fi
				
			echo >> $ANALYZE_OUTFILE
			echo "----------------------------------------------------------" >> $ANALYZE_OUTFILE
	
			(( PODCTR=PODCTR+1 ))
		done
	
		echo >> $ANALYZE_OUTFILE
	fi
	
	if [ $BAD_POD -gt 0 ]
	then
		echo ">>> [TOTAL OK] [all-namespaces] Running = $RUNNING_POD / Completed = $COMPLETED_POD" >> $ANALYZE_OUTFILE
		echo ">>> [TOTAL NOK] [all-namespaces] Pod = $BAD_POD" >> $ANALYZE_OUTFILE
	else
		echo ">>> [TOTAL OK] [all-namespaces] Running = $RUNNING_POD / Completed = $COMPLETED_POD" >> $ANALYZE_OUTFILE
	fi

	echo ">>> [TOTAL POD] = ${TOTAL_POD}" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE
	
	if [ $BADCTR -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] [all-namespaces] Objects [Deployments, Statefulsets, Pods] seem to be operating fine!" >> $ANALYZE_OUTFILE
		echo >> $ANALYZE_OUTFILE
	fi
	
	echo "[$(date)] [${FUNCNAME[0]}] Size of ANALYZE_NS_ARR = [${#ANALYZE_NS_ARR[@]}]"
	
	local TGT_NS=
	for TGT_NS in ${ANALYZE_NS_ARR[@]}
	do
		if ! toIgnoreAddOnNS $TGT_NS
		then
			if [ $ALLNS_DATA == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing analyzeOcAllNSAddOn() on namespace [$TGT_NS]..."
				analyzeOcAllNSAddOn ${TGT_NS} $F_OUTDIR
			else
				if [[ ${TGT_NS} =~ ^openshift ]] || [[ ${TGT_NS} =~ ^kube ]]
				then
					echo "[$(date)] [${FUNCNAME[0]}] ALLNS_DATA is [$ALLNS_DATA], but it is not applicable to Openshift namespace [${TGT_NS}]!" 
					echo "[$(date)] [${FUNCNAME[0]}] Executing analyzeOcAllNSAddOn() on namespace [$TGT_NS]..."
					analyzeOcAllNSAddOn ${TGT_NS} $F_OUTDIR
				fi
			fi
		fi
	done

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" ""
	fi
}

toIgnoreAddOnNS()
{
	# Return 0 = to ignore namespace
	local TGT_NS=$1
	
	if [ -s $MUSTGATHER_DIRNAME/ignore-ns.cfg ]
	then
		local IGNORE_NS=
		local IGNORE_NS_FLAG="false"
	
		while read IGNORE_NS 
		do
			if [ $IGNORE_NS == "$TGT_NS" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Namespace [$TGT_NS] is found in configuration file [$MUSTGATHER_DIRNAME/ignore-ns.cfg]! To ignore (skipping)..."
				IGNORE_NS_FLAG="true"
				break
			fi
		done < $MUSTGATHER_DIRNAME/ignore-ns.cfg
	
		if [ $IGNORE_NS_FLAG == "true" ]
		then
			return 0	
		else
			return 1
		fi
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Ignore namespace configuration file [$MUSTGATHER_DIRNAME/ignore-ns.cfg] does not exist or is zero-sized!"
		fi
	
		return 1
	fi
}

analyzeOcAllNSAddOn()
{
	local ADDON_NS=$1
	local ADDON_OUTDIR=$2/$ADDON_NS
	
	if [ ! -d $ADDON_OUTDIR ]
	then
		mkdir -p $ADDON_OUTDIR
	fi
	
	if [ ! -s $ADDON_OUTDIR/oc_all.out ]
	then
		getOcAll $ADDON_NS $ADDON_OUTDIR/oc_all.out
	
		if [ $GET_POD_LOGS == "true" ]
		then
			descAll $ADDON_NS $ADDON_OUTDIR/oc_all.out $ADDON_OUTDIR logs
		else
			descAll $ADDON_NS $ADDON_OUTDIR/oc_all.out $ADDON_OUTDIR none
		fi
	fi
	
	if [ $MUSTGATHER_OPT == "all" ] && [ ${#RTVAR_GETALL_SUBSET_DATA} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Retrieving all resource types covered by 'oc get all' in namespace [$ADDON_NS]..."
		local OC_ALL_RESTYPE_LIST=$(getAllResTypeFromOcAll $ADDON_OUTDIR/oc_all.out)
	
		echo "[$(date)] [${FUNCNAME[0]}] Retrieving all resource types associated with namespace [$ADDON_NS]..."
		local NS_ALL_RESTYPE=$(getAllResTypeForNS $ADDON_NS)
		local RESTYPE=
		local OC_ALL_RESTYPE=
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [$ADDON_NS] OC_ALL_RESTYPE_LIST = [$OC_ALL_RESTYPE_LIST]"
			echo "[$(date)] [${FUNCNAME[0]}] [$ADDON_NS] NS_ALL_RESTYPE = [$NS_ALL_RESTYPE]"
		fi
	
		IFS=$OLDIFS
		local RES_LONGNAME=
	
		for RES_LONGNAME in $NS_ALL_RESTYPE
		do
			local RESTYPE=$(getApiResName "$RES_LONGNAME")
			local RESTYPE_FOUND="false"
			IFS=$OLDIFS
	
			for OC_ALL_RESTYPE in $OC_ALL_RESTYPE_LIST
			do
				if [ $RES_LONGNAME == $OC_ALL_RESTYPE ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Resource type [$RES_LONGNAME] was handled by 'getOcAll()'! Skipping..."
					local RESTYPE_FOUND="true"
					break
				fi
			done
	
			if [ $RESTYPE_FOUND == "false" ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Resource type long name [$RES_LONGNAME] => [$RESTYPE]"
				fi
	
				ocGet $RESTYPE $ADDON_OUTDIR/oc_$RESTYPE.out $ADDON_NS
				ocDesc $RESTYPE $ADDON_OUTDIR/$RESTYPE $ADDON_NS
			fi
		done
	else
		if [ ! -s $ADDON_OUTDIR/oc_pvc.out ]
		then
			ocGet pvc $ADDON_OUTDIR/oc_pvc.out $ADDON_NS
			ocDesc pvc $ADDON_OUTDIR/pvc $ADDON_NS
		fi
	
		if [ ! -s $ADDON_OUTDIR/oc_secrets.out ]
		then
			ocGet secrets $ADDON_OUTDIR/oc_secrets.out $ADDON_NS
			ocDesc secrets $ADDON_OUTDIR/secrets $ADDON_NS
		fi
	
		if [ ! -s $ADDON_OUTDIR/oc_configmap.out ]
		then
			ocGet configmaps $ADDON_OUTDIR/oc_configmaps.out $ADDON_NS
			ocDesc configmaps $ADDON_OUTDIR/configmaps $ADDON_NS
		fi
	
		if [ ! -s $ADDON_OUTDIR/oc_serviceaccount.out ]
		then
			ocGet serviceaccounts $ADDON_OUTDIR/oc_serviceaccounts.out $ADDON_NS
			ocDesc serviceaccounts $ADDON_OUTDIR/serviceaccounts $ADDON_NS
		fi
	fi
}

processMissingObjInputFile()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local INFILE=$1
	local OUTFILE=$2
	local CTRFILE=$3
	local MISSINGOBJ_PRODUCT_GROUP=$4
	local MISSINGOBJ_PRODUCT_VERSION=$5
	local NS_REFFILE=$6
	local TMPFILE=$OUTFILE.tmp
	
	local LINE_CTR=0
	local SKIP_CTR=0
	local EXCL_CTR=0
	local NEW_CTR=0
	local SAME_CTR=0
	local FAIL_LIMIT=3
	
	echo "[$(date)] [${FUNCNAME[0]}] Processing input file [${INFILE}]..."
	
	if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
	then
		local TMP_OBJ_OUTDIR=$MISSINGOBJ_OUTDIR
	else
		local TMP_OBJ_OUTDIR=$MISSINGOBJ_OUTDIR/PRODGRP=$MISSINGOBJ_PRODUCT_GROUP
	fi
	
	if [ ! -d $TMP_OBJ_OUTDIR ]
	then
		mkdir -p $TMP_OBJ_OUTDIR
	fi

	local CONFIG_SKIP_OUTFILE=$TMP_OBJ_OUTDIR/configline.skip
	local CONFIG_EXCL_OUTFILE=$TMP_OBJ_OUTDIR/configline.excl
	
	local TMP_CACHEFILE=$TMP_OBJ_OUTDIR/nsscript.cache
	local FAILSCRIPT_FILE=$TMP_OBJ_OUTDIR/nsscript.fail
	local NS_CACHEFILE=$TMP_OBJ_OUTDIR/validns.cache
	local NSSCRIPT_FILES=$TMP_OBJ_OUTDIR/nsscript.loc
	
	local REGEXSCRIPT_FILES=$TMP_OBJ_OUTDIR/regexscript.loc
	
	local TMP_EXCL_CACHEFILE=$TMP_OBJ_OUTDIR/exclscript.cache
	local EXCL_FAILSCRIPT_FILE=$TMP_OBJ_OUTDIR/exclscript.fail
	local EXCLSCRIPT_FILES=$TMP_OBJ_OUTDIR/exclscript.loc

 	if [ $BASH_V4 == "true" ]
 	then
 		declare -A NSSCRIPT_CACHE_ARR
 		declare -A NSSCRIPT_FAIL_ARR
		declare -A IS_VALID_NS_ARR
	
		declare -A EXCLSCRIPT_CACHE_ARR
 		declare -A EXCLSCRIPT_FAIL_ARR

		if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "false" ]
		then
			declare -A LOCAL_PROD_TO_NS_CACHE_ARR
		fi
	else
		local LOCAL_PROD_TO_NS_CACHE_FILE=$TMP_OBJ_OUTDIR/prodns.cache
	fi
	
	local MISSINGOBJ_PRODUCT_NSFILE=$TMP_OBJ_OUTDIR/product.ns.$$
	echo "[$(date)] [${FUNCNAME[0]}] Providing a copy of PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL] to MISSINGOBJ mode at location [$MISSINGOBJ_PRODUCT_NSFILE]..."
	cp -p $PROD_NAMESPACES_REFFILE_FINAL $MISSINGOBJ_PRODUCT_NSFILE
	echo "[$(date)] [${FUNCNAME[0]}] Backing up MISSINGOBJ_PROD_GROUP_NS_REFFILE [$MISSINGOBJ_PROD_GROUP_NS_REFFILE] to directory [$TMP_OBJ_OUTDIR]..."
	cp -p $MISSINGOBJ_PROD_GROUP_NS_REFFILE $TMP_OBJ_OUTDIR

	
	local DEF_ENV_ARR=("MISSINGOBJ_PRODUCT_NSFILE" "MISSINGOBJ_PROD_GROUP_NS_REFFILE" "MISSINGOBJ_PRODUCT_GROUP" "MISSINGOBJ_PRODUCT_VERSION" "MISSINGOBJ_OUTDIR" "MISSINGOBJ_ROOT_DEBUG_OUTDIR")

	local MISSINGOBJ_USER_INPUT_ENV=$(compgen -A variable | grep -E '^RTVAR_MISSINGOBJ_' | tr '\n' ' ')

	if [ ${#MISSINGOBJ_USER_INPUT_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for USER_INPUT_ENV in $MISSINGOBJ_USER_INPUT_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$USER_INPUT_ENV] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$USER_INPUT_ENV"
		done	
	fi

	local GMGFVAR_ENV=$(compgen -A variable | grep -E '^RTVAR_GMGFVAR_' | tr '\n' ' ')

	if [ ${#GMGFVAR_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for GMGFVAR in $GMGFVAR_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$GMGFVAR] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$GMGFVAR"
		done	
	fi

	local DEF_ENV=
	local LINE=
	local OBJ_NS=
	local TO_BACKUP=
	local CACHE_LINE=
	
	IFS=$'\n'
	for DEF_ENV in ${DEF_ENV_ARR[@]}
	do
		if [[ $DEF_ENV =~ ^-f ]]
		then
			local MISSINGOBJ_FUNCNAME=$(echo "$DEF_ENV" | $AWK '{ print $2 }')

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment function [$MISSINGOBJ_FUNCNAME]..."
			fi

			export -f $MISSINGOBJ_FUNCNAME
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$DEF_ENV = ${!DEF_ENV}]"
			fi

			export $DEF_ENV
		fi
	done

	local ORIG_CONTEXT_SWITCH_CHECK_PERIOD=$CONTEXT_SWITCH_CHECK_PERIOD
	local MISSINGOBJ_TOTAL_CONF_LINES=$(grep -E -v "^[[:space:]]*$MISSINGOBJ_CFGFILE_COMMENT" $INFILE | wc -l)
	local MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD=$(( $MISSINGOBJ_TOTAL_CONF_LINES / $MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD_DIVIDER ))

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] MISSINGOBJ_TOTAL_CONF_LINES = [$MISSINGOBJ_TOTAL_CONF_LINES] / MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD_DIVIDER = [$MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD_DIVIDER] / MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD = [$MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD]"
	fi
	
	if [ ${#MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD} -gt 0 ] && [[ $MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD =~ ^[0-9]+$ ]]
	then
		if [ $MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD -gt $CONTEXT_SWITCH_CHECK_PERIOD ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Setting CONTEXT_SWITCH_CHECK_PERIOD to [$MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD] temporarily..."
			CONTEXT_SWITCH_CHECK_PERIOD=$MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD
		else
			echo "[$(date)] [${FUNCNAME[0]}] CONTEXT_SWITCH_CHECK_PERIOD = [$CONTEXT_SWITCH_CHECK_PERIOD] / MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD = [$MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD] No change in CONTEXT_SWITCH_CHECK_PERIOD!"	
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD = [$MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD] No change in CONTEXT_SWITCH_CHECK_PERIOD!"
	fi

	while read LINE
	do
		# Skip all lines that start with @ and blank lines
		if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "$MISSINGOBJ_CFGFILE_COMMENT"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
		then
			continue
		fi
		
		(( LINE_CTR=LINE_CTR+1 ))
		echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] [CFGLINE = $LINE]"

		local READ_START_TIME=$(date +%s%N)
		
		if [ $(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print NF }') -ne 7 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Total column is not seven(7). Removing config line [$LINE]..."
			echo "$LINE" >> $CONFIG_SKIP_OUTFILE
			(( SKIP_CTR=SKIP_CTR+1 ))
			continue
		fi
	
		local OBJ_NS=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $1 }')
		local OBJ_TYPE=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $2 }')
		local OBJ_NAME=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $3 }')
		local OBJ_COUNT=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $4 }')
		local ROOT_NSSCRIPT=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $5 }')

		if [ ${#ROOT_NSSCRIPT} -gt 0 ]
		then
			if [[ $(echo "$ROOT_NSSCRIPT" | $AWK '{ print $1 }') =~ ^/ ]]
			then
				local NSSCRIPT_LOC=$(echo "$ROOT_NSSCRIPT" | $AWK '{ print $1 }')
				local NSSCRIPT=$ROOT_NSSCRIPT
			else
				if [ ${#USERSET_MISSINGOBJ_SCRIPTDIR} -gt 0 ]
				then
					local NSSCRIPT_LOC=$USERSET_MISSINGOBJ_SCRIPTDIR/$(echo "$ROOT_NSSCRIPT" | $AWK '{ print $1 }')
					local NSSCRIPT=$USERSET_MISSINGOBJ_SCRIPTDIR/$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $5 }')
				else
					local NSSCRIPT_LOC=$MUSTGATHER_DIRNAME/config/missingobj/$MISSINGOBJ_PRODUCT_VERSION/scripts/$(echo "$ROOT_NSSCRIPT" | $AWK '{ print $1 }')
					local NSSCRIPT=$MUSTGATHER_DIRNAME/config/missingobj/$MISSINGOBJ_PRODUCT_VERSION/scripts/$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $5 }')
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] NSSCRIPT_LOC = [$NSSCRIPT_LOC] / NSSCRIPT = [$NSSCRIPT]"
			fi
		fi

		local ROOT_REGEXSCRIPT=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $6 }')

		if [ ${#ROOT_REGEXSCRIPT} -gt 0 ]
		then
			if [[ $(echo "$ROOT_REGEXSCRIPT" | $AWK '{ print $1 }') =~ ^/ ]]
			then
				local REGEXSCRIPT_LOC=$(echo "$ROOT_REGEXSCRIPT" | $AWK '{ print $1 }')
				local REGEXSCRIPT=$ROOT_REGEXSCRIPT
			else
				if [ ${#USERSET_MISSINGOBJ_SCRIPTDIR} -gt 0 ]
				then
					local REGEXSCRIPT_LOC=$USERSET_MISSINGOBJ_SCRIPTDIR/$(echo "$ROOT_REGEXSCRIPT" | $AWK '{ print $1 }')
					local REGEXSCRIPT=$USERSET_MISSINGOBJ_SCRIPTDIR/$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $6 }')
				else
					local REGEXSCRIPT_LOC=$MUSTGATHER_DIRNAME/config/missingobj/$MISSINGOBJ_PRODUCT_VERSION/scripts/$(echo "$ROOT_REGEXSCRIPT" | $AWK '{ print $1 }')
					local REGEXSCRIPT=$MUSTGATHER_DIRNAME/config/missingobj/$MISSINGOBJ_PRODUCT_VERSION/scripts/$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $6 }')
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] REGEXSCRIPT_LOC = [$REGEXSCRIPT_LOC] / REGEXSCRIPT = [$REGEXSCRIPT]"
			fi
		fi

		local ROOT_EXCLSCRIPT=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $7 }')

		if [ ${#ROOT_EXCLSCRIPT} -gt 0 ] 
		then
			if [[ ! ${ROOT_EXCLSCRIPT} =~ ^0$ ]] && [[ ! ${ROOT_EXCLSCRIPT} =~ ^1$ ]]
			then
				if [[ $(echo "$ROOT_EXCLSCRIPT" | $AWK '{ print $1 }') =~ ^/ ]]
				then
					local EXCLSCRIPT_LOC=$(echo "$ROOT_EXCLSCRIPT" | $AWK '{ print $1 }')
					local EXCLSCRIPT=$ROOT_EXCLSCRIPT
				else
					if [ ${#USERSET_MISSINGOBJ_SCRIPTDIR} -gt 0 ]
					then
						local EXCLSCRIPT_LOC=$USERSET_MISSINGOBJ_SCRIPTDIR/$(echo "$ROOT_EXCLSCRIPT" | $AWK '{ print $1 }')
						local EXCLSCRIPT=$USERSET_MISSINGOBJ_SCRIPTDIR/$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $7 }')
					else
						local EXCLSCRIPT_LOC=$MUSTGATHER_DIRNAME/config/missingobj/$MISSINGOBJ_PRODUCT_VERSION/scripts/$(echo "$ROOT_EXCLSCRIPT" | $AWK '{ print $1 }')
						local EXCLSCRIPT=$MUSTGATHER_DIRNAME/config/missingobj/$MISSINGOBJ_PRODUCT_VERSION/scripts/$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $7 }')
					fi
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] EXCLSCRIPT_LOC = [$EXCLSCRIPT_LOC] / EXCLSCRIPT = [$EXCLSCRIPT]"
			fi
		fi

		if [ ${#OBJ_TYPE} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Columns OBJTYPE cannot be empty! Skipping..."
			echo "$LINE" >> $CONFIG_SKIP_OUTFILE
			(( SKIP_CTR=SKIP_CTR+1 ))
			continue
		fi
	
		if [ ${#OBJ_NAME} -eq 0 ] 
		then
			echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Columns OBJNAME cannot be empty! Skipping..."
			echo "$LINE" >> $CONFIG_SKIP_OUTFILE
			(( SKIP_CTR=SKIP_CTR+1 ))
			continue
		fi
	
		if [ ${#OBJ_COUNT} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Columns OBJCOUNT cannot be empty! Skipping..."
			echo "$LINE" >> $CONFIG_SKIP_OUTFILE
			(( SKIP_CTR=SKIP_CTR+1 ))
			continue
		fi
	
		if [ ${#ROOT_EXCLSCRIPT} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Column EXCLSCRIPT is null. Setting value to default [0]!"
			local ROOT_EXCLSCRIPT=0
			local EXCLSCRIPT_LOC=0
			local EXCLSCRIPT=0
		fi
	
		if [ ${#OBJ_NS} -eq 0 ]
		then
			if [ ${#NSSCRIPT} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] OBJ_NS and NSSCRIPT cannot be both empty/null. Removing config line [$LINE]..."
				echo "$LINE" >> $CONFIG_SKIP_OUTFILE
				(( SKIP_CTR=SKIP_CTR+1 ))
				continue
			else
				if [ -s ${NSSCRIPT_LOC} ]
				then
					local TO_EXEC_NSSCRIPT="true"
					local CACHE_OBJ_NS=
					echo "$NSSCRIPT_LOC" >> $NSSCRIPT_FILES
	
					if [ ${#MISSINGOBJ_NSSCRIPT_FAILCTR_CACHE} -gt 0 ] && [ $MISSINGOBJ_NSSCRIPT_FAILCTR_CACHE == "true" ]
					then
						if [ $BASH_V4 == "true" ]
						then
							local FAIL_COUNT=${NSSCRIPT_FAIL_ARR[$ROOT_NSSCRIPT]}	
		
							if [ ${#FAIL_COUNT} -eq 0 ]
							then
								local FAIL_COUNT=0
							fi
						else
							if [ -s $FAILSCRIPT_FILE ]
							then
								local FAIL_COUNT=$($AWK '/^'$ROOT_NSSCRIPT'$/ { print }' $FAILSCRIPT_FILE | wc -l)
							else
								local FAIL_COUNT=0
							fi
						fi
		
						if [ $FAIL_COUNT -ge $FAIL_LIMIT ]
						then
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Namespace script [$ROOT_NSSCRIPT] has failed more than $FAIL_LIMIT times. Removing config line [$LINE]..."
							fi
		
							echo "$LINE" >> $CONFIG_SKIP_OUTFILE
							(( SKIP_CTR=SKIP_CTR+1 ))
							continue
						fi
					fi
	
					# Check cache
					if [ ${#MISSINGOBJ_NSSCRIPT_CACHE} -gt 0 ] && [ $MISSINGOBJ_NSSCRIPT_CACHE == "true" ]
					then
						if [ $BASH_V4 == "true" ]
						then
							# Use BASH v4 associative array
							local CACHE_OBJ_NS=${NSSCRIPT_CACHE_ARR[$ROOT_NSSCRIPT]}
		
							if [ ${#CACHE_OBJ_NS} -gt 0 ]
							then
								local TO_EXEC_NSSCRIPT="false"
							fi
						else
							if [ -s $TMP_CACHEFILE ]
							then
								local CACHE_OBJ_NS=$($AWK -F'|' '$1 ~ /^'$ROOT_NSSCRIPT'$/ { print $2 }' $TMP_CACHEFILE)
	
								if [ ${#CACHE_OBJ_NS} -gt 0 ]
								then
									local TO_EXEC_NSSCRIPT="false"
								else
									echo "[$(date)] [${FUNCNAME[0]}] No cache is found for namespace script [key=$ROOT_NSSCRIPT]..."
								fi
							fi
						fi
					fi
	
					if [ $TO_EXEC_NSSCRIPT == "false" ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Retrieving namespace value from NSSCRIPT cache [key=$ROOT_NSSCRIPT] => [$CACHE_OBJ_NS]"
						fi
	
						local OBJ_NS_LIST=$CACHE_OBJ_NS
					else
						if [ ${#TIMEOUT} -gt 0 ]
						then
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing namespace script file [$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $NSSCRIPT]..."
							fi
		
							local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $NSSCRIPT"
							OBJ_NS_LIST=$(eval "$CMD")
							C_EXITSTATUS=$?
							
							if [ $C_EXITSTATUS -eq 124 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Namespace script file [$NSSCRIPT] timeout after $DEFAULT_TIMEOUT ! Removing config line [$LINE]..."
								echo "$LINE" >> $CONFIG_SKIP_OUTFILE
								(( SKIP_CTR=SKIP_CTR+1 ))
								continue
							else
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Namespace script file [$NSSCRIPT] exits with status [$C_EXITSTATUS]"
								fi
							fi	
						else
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing namespace script file [/bin/bash $NSSCRIPT]..."
							fi
		
							local CMD="/bin/bash $NSSCRIPT"
							local OBJ_NS_LIST=$(eval "$CMD")
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Namespace script file [$NSSCRIPT] exits with status [$?]"
							fi
						fi
	
						if [ ${#OBJ_NS_LIST} -gt 0 ]
						then
							if [ ${#MISSINGOBJ_NSSCRIPT_CACHE} -gt 0 ] && [ $MISSINGOBJ_NSSCRIPT_CACHE == "true" ]
							then
								if [ $BASH_V4 == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_NSSCRIPT / $OBJ_NS_LIST] to NSSCRIPT_CACHE_ARR"	
									NSSCRIPT_CACHE_ARR[$ROOT_NSSCRIPT]=$OBJ_NS_LIST
								else
									echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_NSSCRIPT / $OBJ_NS_LIST] to TMP_CACHEFILE [$TMP_CACHEFILE]"
									echo "$ROOT_NSSCRIPT|$OBJ_NS_LIST" >> $TMP_CACHEFILE
								fi
							fi
						else
							if [ ${#MISSINGOBJ_NSSCRIPT_FAILCTR_CACHE} -gt 0 ] && [ $MISSINGOBJ_NSSCRIPT_FAILCTR_CACHE == "true" ]
							then
								if [ $BASH_V4 == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_NSSCRIPT] to NSSCRIPT_FAIL_ARR"
									NSSCRIPT_FAIL_ARR[$ROOT_NSSCRIPT]=$(( NSSCRIPT_FAIL_ARR[$ROOT_NSSCRIPT]+1 ))
								else
									echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_NSSCRIPT] to FAILSCRIPT_FILE [$FAILSCRIPT_FILE]"
									echo "$ROOT_NSSCRIPT" >> $FAILSCRIPT_FILE
								fi
							fi
						fi
					fi
	
					if [ ${#OBJ_NS_LIST} -gt 0 ]
					then
						IFS=$OLDIFS

						local FINAL_OBJ_NS_LIST=
						
						for TMP_NS in $OBJ_NS_LIST
						do
							if toExcludeProdNamespace $TMP_NS
							then
								echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] To exclude namespace [$TMP_NS]. Skipping..."
							else
								if [ ${#FINAL_OBJ_NS_LIST} -eq 0 ]
								then
									local FINAL_OBJ_NS_LIST="$TMP_NS"
								else
									local FINAL_OBJ_NS_LIST="$FINAL_OBJ_NS_LIST $TMP_NS"	
								fi
							fi
						done
			
						if [ ${#FINAL_OBJ_NS_LIST} -eq 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] FINAL_OBJ_NS_LIST is empty/null! Skipping..."
							echo "$LINE" >> $CONFIG_SKIP_OUTFILE
							(( SKIP_CTR=SKIP_CTR+1 ))
							continue	
						else
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Setting OBJ_NS_LIST to FINAL_OBJ_NS_LIST [$FINAL_OBJ_NS_LIST]..."
							local OBJ_NS_LIST="$FINAL_OBJ_NS_LIST"
						fi
	
						for OBJ_NS in ${OBJ_NS_LIST}
						do
							echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
							if ! checkUserPriv get $OBJ_TYPE $OBJ_NS
							then
								echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege for resource type [$OBJ_TYPE] in namespace [$OBJ_NS]! Skipping..."
								continue
							fi
	
							if [ ${#MISSINGOBJ_VALIDNS_CACHE} -gt 0 ] && [ $MISSINGOBJ_VALIDNS_CACHE == "true" ]
							then
								if [ $BASH_V4 == "true" ]
								then
									local IS_VALID=${IS_VALID_NS_ARR[$OBJ_NS]}
		
									if [ ${#IS_VALID} -gt 0 ]
									then
										local IS_VALID_NS="true"
									else
										if ! checkUserPriv get namespace all
										then
											echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege on resource 'namespace'! Assuming the namespace is valid..."
											echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into array IS_VALID_NS_ARR!"
											IS_VALID_NS_ARR[$OBJ_NS]="true"
											local IS_VALID_NS="true"
										else
											if $OC_CMD get ns $OBJ_NS > /dev/null
											then
												echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into array IS_VALID_NS_ARR!"
												IS_VALID_NS_ARR[$OBJ_NS]="true"
												local IS_VALID_NS="true"
											else
												local IS_VALID_NS="false"
											fi
										fi
									fi
								else
									if [ -s $NS_CACHEFILE ]
									then
										local IS_VALID_CACHED_NS=$($AWK '/^'$OBJ_NS'$/' $NS_CACHEFILE)
								
										if [ ${#IS_VALID_CACHED_NS} -gt 0 ] && [ "$IS_VALID_CACHED_NS" == "$OBJ_NS" ]
										then
											local IS_VALID="true"
										else
											local IS_VALID="false"
										fi
	
										if [ $IS_VALID == "false" ]
										then
											if ! checkUserPriv get namespace all
											then
												echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege on resource 'namespace'! Assuming the namespace is valid..."
												local IS_VALID_NS="true"
	
												echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into cache file NS_CACHEFILE [$NS_CACHEFILE]..."
												echo "$OBJ_NS" >> $NS_CACHEFILE
											else
												if $OC_CMD get ns $OBJ_NS > /dev/null
												then
													echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into cache file NS_CACHEFILE [$NS_CACHEFILE]..."
													echo "$OBJ_NS" >> $NS_CACHEFILE
	
													local IS_VALID_NS="true"
												else
													local IS_VALID_NS="false"
												fi
											fi
										else
											local IS_VALID_NS="true"
										fi
									else
										if ! checkUserPriv get namespace all
										then
											echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege on resource 'namespace'! Assuming the namespace is valid..."
											local IS_VALID_NS="true"
	
											echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into cache file NS_CACHEFILE [$NS_CACHEFILE]..."
											echo "$OBJ_NS" >> $NS_CACHEFILE
										else
											if $OC_CMD get ns $OBJ_NS > /dev/null
											then
												echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into cache file NS_CACHEFILE [$NS_CACHEFILE]..."
												echo "$OBJ_NS" >> $NS_CACHEFILE
	
												local IS_VALID_NS="true"
											else
												local IS_VALID_NS="false"
											fi
										fi
									fi
								fi
							else
								if ! checkUserPriv get namespace all
								then
									echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege on resource 'namespace'! Assuming the namespace is valid..."
									local IS_VALID_NS="true"
								else
									if $OC_CMD get ns $OBJ_NS > /dev/null
									then
										local IS_VALID_NS="true"
									else
										local IS_VALID_NS="false"
									fi
								fi
							fi
	
							if [ $IS_VALID_NS == "false" ]
							then	
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Namespace [$OBJ_NS] returned by script [$NSSCRIPT] is invalid! Removing config line [$LINE]..."
								fi
	
								echo "$LINE" >> $CONFIG_SKIP_OUTFILE
								(( SKIP_CTR=SKIP_CTR+1 ))
								continue
							else
								if [[ "$ROOT_EXCLSCRIPT" =~ ^[01]$ ]] && [ "$ROOT_EXCLSCRIPT" -eq 1 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Config line [$LINE] has EXCLSCRIPT column set to [$ROOT_EXCLSCRIPT]. Removing config line..."
									echo "$LINE" >> $CONFIG_EXCL_OUTFILE
									(( EXCL_CTR=EXCL_CTR+1 ))
	
									local TMP_OBJ_OUTFILE=$TMP_OBJ_OUTDIR/$OBJ_NS~$OBJ_TYPE~$$.excl
	
									if [ ${OBJ_NAME} == "OBJNAME" ]
									then
										local REGEXSCRIPT_TVALUE="15m"
	
										if [ ${#TIMEOUT} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS]..."
											fi
							
											local CMD="$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS"
											REGEX_CMD_RST=$(eval "$CMD")
											C_EXITSTATUS=$?
												
											if [ $C_EXITSTATUS -eq 124 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] timeout after $REGEXSCRIPT_TVALUE!"
											fi	
										else
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [/bin/bash $REGEXSCRIPT $OBJ_NS]..."
											fi
						
											local CMD="/bin/bash $REGEXSCRIPT $OBJ_NS"
											REGEX_CMD_RST=$(eval "$CMD")
											C_EXITSTATUS=$?
										fi
				
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] exits with status [$C_EXITSTATUS]"
										fi
	
										if [ $C_EXITSTATUS -ne 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] failed with exit code [$C_EXITSTATUS]! Not writing to exclusion file [$TMP_OBJ_OUTFILE]..."
										else
											echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] Regex script file [$REGEXSCRIPT $OBJ_NS] = [$REGEX_CMD_RST]"
	
											if [ ${#REGEX_CMD_RST} -gt 0 ]
											then
												local FINAL_OBJ_NAME="$REGEX_CMD_RST"
											else
												echo "[$(date)] [${FUNCNAME[0]}] REGEX_CMD_RST [$REGEX_CMD_RST] is empty/null! Skipping..."
											fi
	
											local EXCL_LINE="$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$FINAL_OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT"	
											echo "$EXCL_LINE" >> $TMP_OBJ_OUTFILE
	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$EXCL_LINE] to exclusion file [$TMP_OBJ_OUTFILE]..."
											fi
										fi
									else
										local EXCL_LINE="$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT"	
										echo "$EXCL_LINE" >> $TMP_OBJ_OUTFILE
	
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$EXCL_LINE] to exclusion file [$TMP_OBJ_OUTFILE]..."
										fi
									fi
	
									continue
								fi
	
								local TO_EXCL="true"	
							
								if [[ "$ROOT_EXCLSCRIPT" =~ ^[01]$ ]] && [ "$ROOT_EXCLSCRIPT" -eq 0 ]
								then
									local TO_EXCL="false"
								else
									if [ -s $EXCLSCRIPT_LOC ]
									then
										local TO_EXEC_EXCLSCRIPT="true"
										local EXCLSCRIPT_TVALUE="15m"
										echo "$EXCLSCRIPT_LOC" >> $EXCLSCRIPT_FILES
					
										if [ ${#MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE == "true" ]
										then
											if [ $BASH_V4 == "true" ]
											then
												local EXCL_FAIL_COUNT=${EXCLSCRIPT_FAIL_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]}	
							
												if [ ${#EXCL_FAIL_COUNT} -eq 0 ]
												then
													local EXCL_FAIL_COUNT=0
												fi
											else
												if [ -s $EXCL_FAILSCRIPT_FILE ]
												then
													local EXCL_FAIL_CMD="$AWK '/^$ROOT_EXCLSCRIPT $OBJ_NS$/ { print }' $EXCL_FAILSCRIPT_FILE"
													local EXCL_FAIL_COUNT=$(eval "$EXCL_FAIL_CMD" | wc -l)
												else
													local EXCL_FAIL_COUNT=0
												fi
											fi
		
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] EXCL_FAIL_COUNT of script [$ROOT_EXCLSCRIPT $OBJ_NS] = [$EXCL_FAIL_COUNT]"
											fi
		
											if [ $EXCL_FAIL_COUNT -ge $FAIL_LIMIT ]
											then
												if [ $MG_DEBUG == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] To-exclude script [$ROOT_EXCLSCRIPT $OBJ_NS] has failed more than $FAIL_LIMIT times. Removing config line [$LINE]..."
												fi
						
												echo "$LINE" >> $CONFIG_SKIP_OUTFILE
												(( SKIP_CTR=SKIP_CTR+1 ))
												continue
											fi
										fi
					
										# Check cache
										if [ ${#MISSINGOBJ_EXCLSCRIPT_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_CACHE == "true" ]
										then
											if [ $BASH_V4 == "true" ]
											then
												# Use BASH v4 associative array
												local CACHE_EXCL=${EXCLSCRIPT_CACHE_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]}
						
												if [ ${#CACHE_EXCL} -gt 0 ]
												then
													local TO_EXEC_EXCLSCRIPT="false"
												fi
											else
												if [ -s $TMP_EXCL_CACHEFILE ]
												then
													local CACHE_EXCL_CMD="$AWK -F'|' '\$1 ~ /^$ROOT_EXCLSCRIPT $OBJ_NS\$/ { print \$2 }' $TMP_EXCL_CACHEFILE"
													local CACHE_EXCL=$(eval "$CACHE_EXCL_CMD")
	
													if [ $MG_DEBUG == "true" ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] CACHE_EXCL_CMD = [$CACHE_EXCL_CMD]"
													fi
										
													if [ ${#CACHE_EXCL} -gt 0 ]
													then
														local TO_EXEC_EXCLSCRIPT="false"
													else
														if [ $MG_DEBUG == "true" ]
														then
															echo "[$(date)] [${FUNCNAME[0]}] No cache is found for to-exclude script [key=$ROOT_EXCLSCRIPT $OBJ_NS]..."
														fi
													fi
												fi
											fi
										fi
					
										if [ $TO_EXEC_EXCLSCRIPT == "false" ]
										then
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Retrieving to-exclude value from EXCLSCRIPT cache [key=$ROOT_EXCLSCRIPT $OBJ_NS] => [$CACHE_EXCL]"
											fi
						
											local TO_EXCL=$CACHE_EXCL
										else
											local MISSINGOBJ_PRODUCT_NSFILE=$TMP_OBJ_OUTDIR/product.ns.$$
	
											if [ -s $MISSINGOBJ_PRODUCT_NSFILE ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Providing a copy of PROD_NAMESPACES_REFFILE_FINAL to MISSINGOBJ custom script at location [$MISSINGOBJ_PRODUCT_NSFILE]..."
												cp -p $PROD_NAMESPACES_REFFILE_FINAL $MISSINGOBJ_PRODUCT_NSFILE
											fi
											
											if [ ${#TIMEOUT} -gt 0 ]
											then
												if [ $MG_DEBUG == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] Executing to-exclude script file [$TIMEOUT $EXCLSCRIPT_TVALUE /bin/bash $EXCLSCRIPT $OBJ_NS]..."
												fi
							
												local CMD="$TIMEOUT $EXCLSCRIPT_TVALUE /bin/bash $EXCLSCRIPT $OBJ_NS"
												EXCL_CMD_RST=$(eval "$CMD")
												C_EXITSTATUS=$?
												
												if [ $C_EXITSTATUS -eq 124 ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] To-exclude script file [$EXCLSCRIPT $OBJ_NS] timeout after $EXCLSCRIPT_TVALUE! Removing config line [$LINE]..."
													echo "$LINE" >> $CONFIG_SKIP_OUTFILE
													(( SKIP_CTR=SKIP_CTR+1 ))
													continue
												else
													if [ $MG_DEBUG == "true" ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] To-exclude script file [$EXCLSCRIPT $OBJ_NS] exits with status [$C_EXITSTATUS]"
													fi
												fi	
											else
												if [ $MG_DEBUG == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] Executing to-exclude script file [/bin/bash $EXCLSCRIPT $OBJ_NS]..."
												fi
							
												local CMD="/bin/bash $EXCLSCRIPT $OBJ_NS"
												local EXCL_CMD_RST=$(eval "$CMD")
											fi
					
											echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] To-exclude script file [$EXCLSCRIPT $OBJ_NS] = [$EXCL_CMD_RST]"
	
											if [ ${#EXCL_CMD_RST} -gt 0 ]
											then
												if [[ "$EXCL_CMD_RST" =~ ^[0-9]+$ ]] && [ "$EXCL_CMD_RST" -eq 0 ]
												then
													local TO_EXCL="false"
												else
													if [[ "$EXCL_CMD_RST" =~ ^[0-9]+$ ]] && [ "$EXCL_CMD_RST" -eq 1 ]
													then
														local TO_EXCL="true"
													else
														echo "[$(date)] [${FUNCNAME[0]}] Unable to determine EXCL_CMD_RST. Setting TO_EXCL to [true]!"
														local TO_EXCL="true"
													fi
												fi
					
												if [ ${#MISSINGOBJ_EXCLSCRIPT_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_CACHE == "true" ]
												then
													if [ $BASH_V4 == "true" ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_EXCLSCRIPT $OBJ_NS / $TO_EXCL] to EXCLSCRIPT_CACHE_ARR"
														EXCLSCRIPT_CACHE_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]=$TO_EXCL
													else
														echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_EXCLSCRIPT $OBJ_NS / $TO_EXCL] to TMP_EXCL_CACHEFILE [$TMP_EXCL_CACHEFILE]"
														echo "$ROOT_EXCLSCRIPT $OBJ_NS|$TO_EXCL" >> $TMP_EXCL_CACHEFILE
													fi
												fi
											else
												if [ ${#MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE == "true" ]
												then
													if [ $BASH_V4 == "true" ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_EXCLSCRIPT $OBJ_NS] to EXCLSCRIPT_FAIL_ARR"
														EXCLSCRIPT_FAIL_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]=$(( EXCLSCRIPT_FAIL_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]+1 ))
													else
														echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_EXCLSCRIPT $OBJ_NS] to EXCL_FAILSCRIPT_FILE [$EXCL_FAILSCRIPT_FILE]"
														echo "$ROOT_EXCLSCRIPT $OBJ_NS" >> $EXCL_FAILSCRIPT_FILE
													fi
												fi
											fi
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] To-exclude script file [$EXCLSCRIPT_LOC] does not exist or is zero-sized. Removing config line [$LINE]..."
										echo "$LINE" >> $CONFIG_SKIP_OUTFILE
										(( SKIP_CTR=SKIP_CTR+1 ))
										continue
									fi
								fi
	
								if [ $TO_EXCL == "false" ]
								then 
									if [ $OBJ_NAME == "OBJNAME" ]
									then
										local REGEXSCRIPT_TVALUE="15m"
	
										if [ ${#TIMEOUT} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS]..."
											fi
							
											local CMD="$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS"
											REGEX_CMD_RST=$(eval "$CMD")
											C_EXITSTATUS=$?
												
											if [ $C_EXITSTATUS -eq 124 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] timeout after $REGEXSCRIPT_TVALUE! Removing config line [$LINE]..."
												echo "$LINE" >> $CONFIG_SKIP_OUTFILE
												(( SKIP_CTR=SKIP_CTR+1 ))
												continue
											fi	
										else
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [/bin/bash $REGEXSCRIPT $OBJ_NS]..."
											fi
						
											local CMD="/bin/bash $REGEXSCRIPT $OBJ_NS"
											REGEX_CMD_RST=$(eval "$CMD")
											C_EXITSTATUS=$?
										fi
				
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] exits with status [$C_EXITSTATUS]"
											echo "$REGEXSCRIPT_LOC" >> $REGEXSCRIPT_FILES
										fi
	
										if [ $C_EXITSTATUS -ne 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] failed with exit code [$C_EXITSTATUS]! Removing config line [$LINE]..."
											echo "$LINE" >> $CONFIG_SKIP_OUTFILE
											(( SKIP_CTR=SKIP_CTR+1 ))
											continue
										fi
	
										echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] Regex script file [$REGEXSCRIPT $OBJ_NS] = [$REGEX_CMD_RST]"
	
										if [ ${#REGEX_CMD_RST} -gt 0 ]
										then
											local FINAL_OBJ_NAME="$REGEX_CMD_RST"
										else
											echo "[$(date)] [${FUNCNAME[0]}] REGEX_CMD_RST [$REGEX_CMD_RST] is empty/null! Skipping..."
											echo "$LINE" >> $CONFIG_SKIP_OUTFILE
											(( SKIP_CTR=SKIP_CTR+1 ))
											continue
										fi
									else
										local FINAL_OBJ_NAME=$OBJ_NAME	
									fi	
	
									local NEW_LINE="$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$FINAL_OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT"
			
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Generating new config line [$NEW_LINE] from [$LINE]..."
									fi
			
									echo "$NEW_LINE" >> $TMPFILE
									(( NEW_CTR=NEW_CTR+1 ))
								else
									echo "[$(date)] [${FUNCNAME[0]}] Removing config line [$LINE]..."
									echo "$LINE" >> $CONFIG_EXCL_OUTFILE
									(( EXCL_CTR=EXCL_CTR+1 ))
	
									local TMP_OBJ_OUTFILE=$TMP_OBJ_OUTDIR/$OBJ_NS~$OBJ_TYPE~$$.excl
	
									if [ ${OBJ_NAME} == "OBJNAME" ]
									then
										local REGEXSCRIPT_TVALUE="15m"
	
										if [ ${#TIMEOUT} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS]..."
											fi
							
											local CMD="$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS"
											REGEX_CMD_RST=$(eval "$CMD")
											C_EXITSTATUS=$?
												
											if [ $C_EXITSTATUS -eq 124 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] timeout after $REGEXSCRIPT_TVALUE!"
											fi	
										else
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [/bin/bash $REGEXSCRIPT $OBJ_NS]..."
											fi
						
											local CMD="/bin/bash $REGEXSCRIPT $OBJ_NS"
											REGEX_CMD_RST=$(eval "$CMD")
											C_EXITSTATUS=$?
										fi
				
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] exits with status [$C_EXITSTATUS]"
										fi
	
										if [ $C_EXITSTATUS -ne 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] failed with exit code [$C_EXITSTATUS]! Not writing to exclusion file [$TMP_OBJ_OUTFILE]..."
										else
											echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] Regex script file [$REGEXSCRIPT $OBJ_NS] = [$REGEX_CMD_RST]"
	
											if [ ${#REGEX_CMD_RST} -gt 0 ]
											then
												local FINAL_OBJ_NAME="$REGEX_CMD_RST"
											else
												echo "[$(date)] [${FUNCNAME[0]}] REGEX_CMD_RST [$REGEX_CMD_RST] is empty/null! Skipping..."
											fi
	
											local EXCL_LINE="$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$FINAL_OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT"	
											echo "$EXCL_LINE" >> $TMP_OBJ_OUTFILE
	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$EXCL_LINE] to exclusion file [$TMP_OBJ_OUTFILE]..."
											fi
										fi
									else
										local EXCL_LINE="$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT"	
										echo "$EXCL_LINE" >> $TMP_OBJ_OUTFILE
	
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$EXCL_LINE] to exclusion file [$TMP_OBJ_OUTFILE]..."
										fi
									fi
									
									continue
								fi
							fi
						done
	
						IFS=$'\n'
					else
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Unable to determine object namespace. Removing config line [$LINE]..."
						fi
	
						echo "$LINE" >> $CONFIG_SKIP_OUTFILE
						(( SKIP_CTR=SKIP_CTR+1 ))
						continue
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Namespace script file [$NSSCRIPT_LOC] does not exist or is zero-sized. Removing config line [$LINE]..."
					echo "$LINE" >> $CONFIG_SKIP_OUTFILE
					(( SKIP_CTR=SKIP_CTR+1 ))
					continue
				fi
			fi
		else
			local NS4PROC="false"
	
			if [[ $OBJ_NS =~ ^NS4PROD= ]]
			then
				local NS4PROC="true"
				local PROD_NAME=$(echo "$OBJ_NS" | $AWK -F= '{ print $2 }')
	
				echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Attempting to retrieve namespace for product [$PROD_NAME]..."
	
				local TO_GET_OBJ_NS_LIST="true"

				if [ ${#MISSINGOBJ_MULTI_PRODGRP_NS_CACHE} -gt 0 ] && [ $MISSINGOBJ_MULTI_PRODGRP_NS_CACHE == "true" ]
				then
					if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "false" ] 
					then
						if [ $BASH_V4 == "true" ]
						then
							if [ ${#LOCAL_PROD_TO_NS_CACHE_ARR[@]} -gt 0 ] && [ ${LOCAL_PROD_TO_NS_CACHE_ARR[$PROD_NAME]+_} ]
							then
								local OBJ_NS_LIST=${LOCAL_PROD_TO_NS_CACHE_ARR[$PROD_NAME]}
								echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] OBJ_NS_LIST retrieved from local cache = [$OBJ_NS_LIST]"
		
								if [ ${#OBJ_NS_LIST} -gt 0 ]
								then
									local TO_GET_OBJ_NS_LIST="false"
								fi
							fi
						else
							if [ -s $LOCAL_PROD_TO_NS_CACHE_FILE ]
							then
								local LOCAL_PROD_TO_NS_FILE_CACHE=$($AWK -F= '$1 ~ /^'$PROD_NAME'$/ { print $2 }' $LOCAL_PROD_TO_NS_CACHE_FILE)
	
								if [ ${#LOCAL_PROD_TO_NS_FILE_CACHE} -gt 0 ]
								then
									local OBJ_NS_LIST="$LOCAL_PROD_TO_NS_FILE_CACHE"
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] OBJ_NS_LIST retrieved from local cache = [$OBJ_NS_LIST]"
		
									if [ ${#OBJ_NS_LIST} -gt 0 ]
									then
										local TO_GET_OBJ_NS_LIST="false"
									fi
								fi
							fi
						fi
					fi
				fi

				if [ $TO_GET_OBJ_NS_LIST == "true" ]
				then
					if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
					then
						local OBJ_NS_LIST=$(getProdToNamespacesMapping $PROD_NAME)
					else
						local OBJ_NS_LIST=$(getProdToNamespacesMapping $PROD_NAME "$NS_REFFILE")
					fi

					if [ ${#MISSINGOBJ_MULTI_PRODGRP_NS_CACHE} -gt 0 ] && [ $MISSINGOBJ_MULTI_PRODGRP_NS_CACHE == "true" ]
					then
						if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "false" ]
						then
							if [ $BASH_V4 == "true" ]
							then
								if [ ! ${LOCAL_PROD_TO_NS_CACHE_ARR[$PROD_NAME]+_} ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Adding value [$OBJ_NS_LIST] into LOCAL_PROD_TO_NS_CACHE_ARR[$PROD_NAME]..."
									local LOCAL_PROD_TO_NS_CACHE_ARR[$PROD_NAME]="$OBJ_NS_LIST"
								fi
							else
								if [ -s $LOCAL_PROD_TO_NS_CACHE_FILE ]
								then
									local LOCAL_PROD_TO_NS_FILE_CACHE=$($AWK -F= '$1 ~ /^'$PROD_NAME'$/ { print $2 }' $LOCAL_PROD_TO_NS_CACHE_FILE)
	
									if [ ${#LOCAL_PROD_TO_NS_FILE_CACHE} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] File cache key [$PROD_NAME] exists => [$LOCAL_PROD_TO_NS_FILE_CACHE]..."
									else
										echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Adding value [$OBJ_NS_LIST] into LOCAL_PROD_TO_NS_CACHE_FILE[$PROD_NAME]..."
										echo "${PROD_NAME}=${OBJ_NS_LIST}" >> $LOCAL_PROD_TO_NS_CACHE_FILE	
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Adding value [$OBJ_NS_LIST] into LOCAL_PROD_TO_NS_CACHE_FILE[$PROD_NAME]..."
									echo "${PROD_NAME}=${OBJ_NS_LIST}" >> $LOCAL_PROD_TO_NS_CACHE_FILE	
								fi
							fi
						fi
					fi
				fi
	
				echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Namespace retrieved for product [$PROD_NAME] = [$OBJ_NS_LIST]"
	
				if [ "$OBJ_NS_LIST" == $PROD_NAMESPACES_INVALID_STR ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Unable to determine namespace! Skipping..."
					echo "$LINE" >> $CONFIG_SKIP_OUTFILE
					(( SKIP_CTR=SKIP_CTR+1 ))
					continue
				fi
			else
				local OBJ_NS_LIST=$OBJ_NS
			fi
	
			local FINAL_OBJ_NS_LIST=
			
			for TMP_NS in $OBJ_NS_LIST
			do
				if toExcludeProdNamespace $TMP_NS
				then
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] To exclude namespace [$TMP_NS]. Skipping..."
				else
					if [ ${#FINAL_OBJ_NS_LIST} -eq 0 ]
					then
						local FINAL_OBJ_NS_LIST="$TMP_NS"
					else
						local FINAL_OBJ_NS_LIST="$FINAL_OBJ_NS_LIST $TMP_NS"	
					fi
				fi
			done

			if [ ${#FINAL_OBJ_NS_LIST} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] FINAL_OBJ_NS_LIST is empty/null! Skipping..."
				echo "$LINE" >> $CONFIG_SKIP_OUTFILE
				(( SKIP_CTR=SKIP_CTR+1 ))
				continue	
			else
				echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Setting OBJ_NS_LIST to FINAL_OBJ_NS_LIST [$FINAL_OBJ_NS_LIST]..."
				local OBJ_NS_LIST="$FINAL_OBJ_NS_LIST"
			fi

			IFS=$OLDIFS
	
			for OBJ_NS in $OBJ_NS_LIST
			do
				if [ $OBJ_NS != "ALLNS" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges [verb=get / objtype=$OBJ_TYPE / ns=$OBJ_NS]..." 
	
					if ! checkUserPriv get $OBJ_TYPE $OBJ_NS
					then
						echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege for resource type [$OBJ_TYPE] in namespace [$OBJ_NS]! Skipping..."
						continue
					fi
		
					if [ ${#MISSINGOBJ_VALIDNS_CACHE} -gt 0 ] && [ $MISSINGOBJ_VALIDNS_CACHE == "true" ]
					then
						if [ $BASH_V4 == "true" ]
						then
							local IS_VALID=${IS_VALID_NS_ARR[$OBJ_NS]}
			
							if [ ${#IS_VALID} -gt 0 ]
							then
								local IS_VALID_NS="true"
							else
								echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges [verb=get / objtype=namespace / ns=all]..." 
	
								if ! checkUserPriv get namespace all
								then
									echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege on resource 'namespace'! Assuming the namespace is valid..."
									echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into array IS_VALID_NS_ARR!"
									IS_VALID_NS_ARR[$OBJ_NS]="true"
									local IS_VALID_NS="true"
								else
									if $OC_CMD get ns $OBJ_NS > /dev/null
									then
										echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into array IS_VALID_NS_ARR!"
										IS_VALID_NS_ARR[$OBJ_NS]="true"
										local IS_VALID_NS="true"
									else
										local IS_VALID_NS="false"
									fi
								fi
							fi
						else
							if [ -s $NS_CACHEFILE ]
							then
								local IS_VALID_CACHED_NS=$($AWK '/^'$OBJ_NS'$/' $NS_CACHEFILE)
								
								if [ ${#IS_VALID_CACHED_NS} -gt 0 ] && [ "$IS_VALID_CACHED_NS" == "$OBJ_NS" ]
								then
									local IS_VALID="true"
								else
									local IS_VALID="false"
								fi
	
								if [ $IS_VALID == "false" ]
								then
									if ! checkUserPriv get namespace all
									then
										echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege on resource 'namespace'! Assuming the namespace is valid..."
										local IS_VALID_NS="true"

										echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into cache file NS_CACHEFILE [$NS_CACHEFILE]..."
										echo "$OBJ_NS" >> $NS_CACHEFILE
									else
										if $OC_CMD get ns $OBJ_NS > /dev/null
										then
											echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into cache file NS_CACHEFILE [$NS_CACHEFILE]..."
											echo "$OBJ_NS" >> $NS_CACHEFILE

											local IS_VALID_NS="true"
										else
											local IS_VALID_NS="false"
										fi
									fi
								else
									local IS_VALID_NS="true"
								fi
							else
								if ! checkUserPriv get namespace all
								then
									echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege on resource 'namespace'! Assuming the namespace is valid..."
									local IS_VALID_NS="true"

									echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into cache file NS_CACHEFILE [$NS_CACHEFILE]..."
									echo "$OBJ_NS" >> $NS_CACHEFILE
								else
									if $OC_CMD get ns $OBJ_NS > /dev/null
									then
										echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$OBJ_NS] into cache file NS_CACHEFILE [$NS_CACHEFILE]..."
										echo "$OBJ_NS" >> $NS_CACHEFILE

										local IS_VALID_NS="true"
									else
										local IS_VALID_NS="false"
									fi
								fi
							fi
						fi
					else
						if ! checkUserPriv get namespace all
						then
							echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege on resource 'namespace'! Assuming the namespace is valid..."
							local IS_VALID_NS="true"
						else
							if $OC_CMD get ns $OBJ_NS > /dev/null
							then
								local IS_VALID_NS="true"
							else
								local IS_VALID_NS="false"
							fi
						fi
					fi
				else
					# If it is cluster scope resource (NAMESPACE=ALLNS)
					IS_VALID_NS="true"
				fi
	
				if [ $IS_VALID_NS == "true" ]
				then
					if [[ "$ROOT_EXCLSCRIPT" =~ ^[01]$ ]] && [ "$ROOT_EXCLSCRIPT" -eq 1 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Config line [$LINE] has EXCLSCRIPT column set to [$ROOT_EXCLSCRIPT]. Removing config line..."
						echo "$LINE" >> $CONFIG_EXCL_OUTFILE
						(( EXCL_CTR=EXCL_CTR+1 ))
	
						local TMP_OBJ_OUTFILE=$TMP_OBJ_OUTDIR/$OBJ_NS~$OBJ_TYPE~$$.excl
	
						if [ ${OBJ_NAME} == "OBJNAME" ]
						then
							local REGEXSCRIPT_TVALUE="15m"
	
							if [ ${#TIMEOUT} -gt 0 ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS]..."
								fi
				
								local CMD="$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS"
								REGEX_CMD_RST=$(eval "$CMD")
								C_EXITSTATUS=$?
									
								if [ $C_EXITSTATUS -eq 124 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] timeout after $REGEXSCRIPT_TVALUE!"
								fi	
							else
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [/bin/bash $REGEXSCRIPT $OBJ_NS]..."
								fi
			
								local CMD="/bin/bash $REGEXSCRIPT $OBJ_NS"
								REGEX_CMD_RST=$(eval "$CMD")
								C_EXITSTATUS=$?
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] exits with status [$C_EXITSTATUS]"
							fi
	
							if [ $C_EXITSTATUS -ne 0 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] failed with exit code [$C_EXITSTATUS]! Not writing to exclusion file [$TMP_OBJ_OUTFILE]..."
							else
								echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] Regex script file [$REGEXSCRIPT $OBJ_NS] = [$REGEX_CMD_RST]"
	
								if [ ${#REGEX_CMD_RST} -gt 0 ]
								then
									local FINAL_OBJ_NAME="$REGEX_CMD_RST"
								else
									echo "[$(date)] [${FUNCNAME[0]}] REGEX_CMD_RST [$REGEX_CMD_RST] is empty/null! Skipping..."
								fi
	
								local EXCL_LINE="$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$FINAL_OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT"	
								echo "$EXCL_LINE" >> $TMP_OBJ_OUTFILE
	
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$EXCL_LINE] to exclusion file [$TMP_OBJ_OUTFILE]..."
								fi
							fi
						else
							local EXCL_LINE="$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT"	
							echo "$EXCL_LINE" >> $TMP_OBJ_OUTFILE
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$EXCL_LINE] to exclusion file [$TMP_OBJ_OUTFILE]..."
							fi
						fi
	
						continue
					fi
	
					local TO_EXCL="true"	
								
					if [[ "$ROOT_EXCLSCRIPT" =~ ^[01]$ ]] && [ "$ROOT_EXCLSCRIPT" -eq 0 ]
					then
						local TO_EXCL="false"
					else
						if [ -s $EXCLSCRIPT_LOC ]
						then
							local TO_EXEC_EXCLSCRIPT="true"
							local EXCLSCRIPT_TVALUE="15m"
							echo "$EXCLSCRIPT_LOC" >> $EXCLSCRIPT_FILES
		
							if [ ${#MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE == "true" ]
							then
								if [ $BASH_V4 == "true" ]
								then
									local EXCL_FAIL_COUNT=${EXCLSCRIPT_FAIL_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]}
				
									if [ ${#EXCL_FAIL_COUNT} -eq 0 ]
									then
										local EXCL_FAIL_COUNT=0
									fi
								else
									if [ -s $EXCL_FAILSCRIPT_FILE ]
									then
										local EXCL_FAIL_CMD="$AWK '/^$ROOT_EXCLSCRIPT $OBJ_NS$/ { print }' $EXCL_FAILSCRIPT_FILE"
										local EXCL_FAIL_COUNT=$(eval "$EXCL_FAIL_CMD" | wc -l)
									else
										local EXCL_FAIL_COUNT=0
									fi
								fi
			
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] EXCL_FAIL_COUNT of script [$ROOT_EXCLSCRIPT $OBJ_NS] = [$EXCL_FAIL_COUNT]"
								fi
		
								if [ $EXCL_FAIL_COUNT -ge $FAIL_LIMIT ]
								then
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] To-exclude script [$ROOT_EXCLSCRIPT $OBJ_NS] has failed more than $FAIL_LIMIT times. Removing config line [$LINE]..."
									fi
			
									echo "$LINE" >> $CONFIG_SKIP_OUTFILE
									(( SKIP_CTR=SKIP_CTR+1 ))
									continue
								fi
							fi
		
							if [ ${#MISSINGOBJ_EXCLSCRIPT_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_CACHE == "true" ]
							then
								# Check cache
								if [ $BASH_V4 == "true" ]
								then
									# Use BASH v4 associative array
									local CACHE_EXCL=${EXCLSCRIPT_CACHE_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]}
			
									if [ ${#CACHE_EXCL} -gt 0 ]
									then
										local TO_EXEC_EXCLSCRIPT="false"
									fi
								else
									if [ -s $TMP_EXCL_CACHEFILE ]
									then
										local CACHE_EXCL_CMD="$AWK -F'|' '\$1 ~ /^$ROOT_EXCLSCRIPT $OBJ_NS\$/ { print \$2 }' $TMP_EXCL_CACHEFILE"
										local CACHE_EXCL=$(eval "$CACHE_EXCL_CMD")
	
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] CACHE_EXCL_CMD = [$CACHE_EXCL_CMD]"
										fi
										
										if [ ${#CACHE_EXCL} -gt 0 ]
										then
											local TO_EXEC_EXCLSCRIPT="false"
										else
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] No cache is found for to-exclude script [key=$ROOT_EXCLSCRIPT $OBJ_NS]..."
											fi
										fi
									fi
								fi
							fi
		
							if [ $TO_EXEC_EXCLSCRIPT == "false" ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Retrieving to-exclude value from EXCLSCRIPT cache [key=$ROOT_EXCLSCRIPT $OBJ_NS] => [$CACHE_EXCL]"
								fi
			
								local TO_EXCL=$CACHE_EXCL
							else
								if [ ${#TIMEOUT} -gt 0 ]
								then
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing to-exclude script file [$TIMEOUT $EXCLSCRIPT_TVALUE /bin/bash $EXCLSCRIPT $OBJ_NS]..."
									fi
				
									local CMD="$TIMEOUT $EXCLSCRIPT_TVALUE /bin/bash $EXCLSCRIPT $OBJ_NS"
									EXCL_CMD_RST=$(eval "$CMD")
									C_EXITSTATUS=$?
									
									if [ $C_EXITSTATUS -eq 124 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] To-exclude script file [$EXCLSCRIPT $OBJ_NS] timeout after $EXCLSCRIPT_TVALUE! Removing config line [$LINE]..."
										echo "$LINE" >> $CONFIG_SKIP_OUTFILE
										(( SKIP_CTR=SKIP_CTR+1 ))
										continue
									else
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] To-exclude script file [$EXCLSCRIPT $OBJ_NS] exits with status [$C_EXITSTATUS]"
										fi
									fi	
								else
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing to-exclude script file [/bin/bash $EXCLSCRIPT $OBJ_NS]..."
									fi
				
									local CMD="/bin/bash $EXCLSCRIPT $OBJ_NS"
									local EXCL_CMD_RST=$(eval "$CMD")
								fi
		
								echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] To-exclude script file [$EXCLSCRIPT $OBJ_NS] = [$EXCL_CMD_RST]"
				
								if [ ${#EXCL_CMD_RST} -gt 0 ]
								then
									if [[ "$EXCL_CMD_RST" =~ ^[0-9]+$ ]] && [ "$EXCL_CMD_RST" -eq 0 ]
									then
										local TO_EXCL="false"
									else
										if [[ "$EXCL_CMD_RST" =~ ^[0-9]+$ ]] && [ "$EXCL_CMD_RST" -eq 1 ]
										then
											local TO_EXCL="true"
										else
											echo "[$(date)] [${FUNCNAME[0]}] Unable to determine EXCL_CMD_RST. Setting TO_EXCL to [true]!"
											local TO_EXCL="true"
										fi
									fi
		
									if [ ${#MISSINGOBJ_EXCLSCRIPT_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_CACHE == "true" ]
									then
										if [ $BASH_V4 == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_EXCLSCRIPT $OBJ_NS / $TO_EXCL] to EXCLSCRIPT_CACHE_ARR"
											EXCLSCRIPT_CACHE_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]=$TO_EXCL
										else
											echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_EXCLSCRIPT $OBJ_NS / $TO_EXCL] to TMP_EXCL_CACHEFILE [$TMP_EXCL_CACHEFILE]"
											echo "$ROOT_EXCLSCRIPT $OBJ_NS|$TO_EXCL" >> $TMP_EXCL_CACHEFILE
										fi
									fi
								else
									if [ ${#MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE == "true" ]
									then
										if [ $BASH_V4 == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_EXCLSCRIPT $OBJ_NS] to EXCLSCRIPT_FAIL_ARR"
											EXCLSCRIPT_FAIL_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]=$(( EXCLSCRIPT_FAIL_ARR[$ROOT_EXCLSCRIPT $OBJ_NS]+1 ))
										else
											echo "[$(date)] [${FUNCNAME[0]}] Adding cache [$ROOT_EXCLSCRIPT $OBJ_NS] to EXCL_FAILSCRIPT_FILE [$EXCL_FAILSCRIPT_FILE]"
											echo "$ROOT_EXCLSCRIPT $OBJ_NS" >> $EXCL_FAILSCRIPT_FILE
										fi
									fi
								fi
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] To-exclude script file [$EXCLSCRIPT_LOC] does not exist or is zero-sized. Removing config line [$LINE]..."
							echo "$LINE" >> $CONFIG_SKIP_OUTFILE
							(( SKIP_CTR=SKIP_CTR+1 ))
							continue
						fi
					fi
	
					if [ $TO_EXCL == "false" ]
					then
						if [ $OBJ_NAME == "OBJNAME" ]
						then
							local REGEXSCRIPT_TVALUE="15m"
	
							if [ ${#TIMEOUT} -gt 0 ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS]..."
								fi
				
								local CMD="$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS"
								REGEX_CMD_RST=$(eval "$CMD")
								C_EXITSTATUS=$?
									
								if [ $C_EXITSTATUS -eq 124 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] timeout after $REGEXSCRIPT_TVALUE! Removing config line [$LINE]..."
									echo "$LINE" >> $CONFIG_SKIP_OUTFILE
									(( SKIP_CTR=SKIP_CTR+1 ))
									continue
								fi	
							else
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [/bin/bash $REGEXSCRIPT $OBJ_NS]..."
								fi
			
								local CMD="/bin/bash $REGEXSCRIPT $OBJ_NS"
								REGEX_CMD_RST=$(eval "$CMD")
								C_EXITSTATUS=$?
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] exits with status [$C_EXITSTATUS]"
								echo "$REGEXSCRIPT_LOC" >> $REGEXSCRIPT_FILES
							fi
	
							if [ $C_EXITSTATUS -ne 0 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] failed with exit code [$C_EXITSTATUS]! Removing config line [$LINE]..."
								echo "$LINE" >> $CONFIG_SKIP_OUTFILE
								(( SKIP_CTR=SKIP_CTR+1 ))
								continue
							fi
	
							echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] Regex script file [$REGEXSCRIPT $OBJ_NS] = [$REGEX_CMD_RST]"
	
							if [ ${#REGEX_CMD_RST} -gt 0 ]
							then
								local FINAL_OBJ_NAME="$REGEX_CMD_RST"
							else
								echo "[$(date)] [${FUNCNAME[0]}] REGEX_CMD_RST [$REGEX_CMD_RST] is empty/null! Skipping..."
								echo "$LINE" >> $CONFIG_SKIP_OUTFILE
								(( SKIP_CTR=SKIP_CTR+1 ))
								continue
							fi
						else
							local FINAL_OBJ_NAME=$OBJ_NAME	
						fi	
	
						if [ $MG_DEBUG == "true" ]
						then
							if [ $NS4PROC == "false" ]
							then	
								echo "[$(date)] [${FUNCNAME[0]}] Config line [$LINE] untouched..."
							else
								echo "[$(date)] [${FUNCNAME[0]}] Namespace(s) for config line [$LINE] is resolved to [$OBJ_NS]..."
							fi
						fi
	
						if [ $NS4PROC == "false" ]
						then
							if [ $FINAL_OBJ_NAME == $OBJ_NAME ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Adding untouched config line [$LINE]..." 
								echo "$LINE" >> $TMPFILE
	
								(( SAME_CTR=SAME_CTR+1 ))
							else
								echo "[$(date)] [${FUNCNAME[0]}] Generating new config line [$OBJ_NS,$OBJ_TYPE,$FINAL_OBJ_NAME,$OBJ_COUNT]..."
								echo "$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$FINAL_OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT" >> $TMPFILE
	
								(( NEW_CTR=NEW_CTR+1 ))
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] Generating new config line [$OBJ_NS,$OBJ_TYPE,$FINAL_OBJ_NAME,$OBJ_COUNT]..."
							echo "$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$FINAL_OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT" >> $TMPFILE
	
							(( NEW_CTR=NEW_CTR+1 ))
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] Removing config line [$LINE]..."
						echo "$LINE" >> $CONFIG_EXCL_OUTFILE
						(( EXCL_CTR=EXCL_CTR+1 ))
	
						local TMP_OBJ_OUTFILE=$TMP_OBJ_OUTDIR/$OBJ_NS~$OBJ_TYPE~$$.excl
	
						if [ ${OBJ_NAME} == "OBJNAME" ]
						then
							local REGEXSCRIPT_TVALUE="15m"
	
							if [ ${#TIMEOUT} -gt 0 ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS]..."
								fi
				
								local CMD="$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT $OBJ_NS"
								REGEX_CMD_RST=$(eval "$CMD")
								C_EXITSTATUS=$?
									
								if [ $C_EXITSTATUS -eq 124 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] timeout after $REGEXSCRIPT_TVALUE!"
								fi	
							else
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [/bin/bash $REGEXSCRIPT $OBJ_NS]..."
								fi
			
								local CMD="/bin/bash $REGEXSCRIPT $OBJ_NS"
								REGEX_CMD_RST=$(eval "$CMD")
								C_EXITSTATUS=$?
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] exits with status [$C_EXITSTATUS]"
							fi
	
							if [ $C_EXITSTATUS -ne 0 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT $OBJ_NS] failed with exit code [$C_EXITSTATUS]! Not writing to exclusion file [$TMP_OBJ_OUTFILE]..."
							else
								echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] Regex script file [$REGEXSCRIPT $OBJ_NS] = [$REGEX_CMD_RST]"
	
								if [ ${#REGEX_CMD_RST} -gt 0 ]
								then
									local FINAL_OBJ_NAME="$REGEX_CMD_RST"
								else
									echo "[$(date)] [${FUNCNAME[0]}] REGEX_CMD_RST [$REGEX_CMD_RST] is empty/null! Skipping..."
								fi
	
								local EXCL_LINE="$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$FINAL_OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT"	
								echo "$EXCL_LINE" >> $TMP_OBJ_OUTFILE
	
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$EXCL_LINE] to exclusion file [$TMP_OBJ_OUTFILE]..."
								fi
							fi
						else
							local EXCL_LINE="$OBJ_NS${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_TYPE${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_NAME${MISSINGOBJ_CFGFILE_DELIMITER}$OBJ_COUNT"	
							echo "$EXCL_LINE" >> $TMP_OBJ_OUTFILE
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$EXCL_LINE] to exclusion file [$TMP_OBJ_OUTFILE]..."
							fi
						fi
	
						continue
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Namespace [$OBJ_NS] does not exist! Removing config line [$LINE]..."
					echo "$LINE" >> $CONFIG_SKIP_OUTFILE
					(( SKIP_CTR=SKIP_CTR+1 ))
					continue
				fi
			done
			
			IFS=$'\n'
		fi

		local READ_END_TIME=$(date +%s%N)

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] READ_START_TIME = [$READ_START_TIME] / READ_END_TIME = [$READ_END_TIME]"
		fi

		if [[ $READ_START_TIME =~ N$ ]] && [[ $READ_END_TIME =~ N$ ]]
          then
			echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] Unable to read time in miliseconds! Skipping..."
		else
			local READ_DURATION=$(($((READ_END_TIME-READ_START_TIME))/1000000))
			echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] READ_TIME = [${READ_DURATION}ms]"
		fi
	done < $INFILE

	if [ ${#MISSINGOBJ_CONTEXT_SWITCH_CHECK_PERIOD} -gt 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Setting CONTEXT_SWITCH_CHECK_PERIOD back to original value of [$ORIG_CONTEXT_SWITCH_CHECK_PERIOD]..."
		CONTEXT_SWITCH_CHECK_PERIOD=$ORIG_CONTEXT_SWITCH_CHECK_PERIOD
	fi
	
	# Sort the processed file
	if [ -s $TMPFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Sorting [$TMPFILE] to create output file [$OUTFILE]..."
		sort -t, -k1,1 -k2,2 $TMPFILE > $OUTFILE
		rm $TMPFILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] File [$TMPFILE] does not exist or is zero-sized!"
	fi
	
	echo "[$(date)] [${FUNCNAME[0]}] Total config line read = $LINE_CTR" 
	echo "[$(date)] [${FUNCNAME[0]}] Total config line skipped = $SKIP_CTR" 
	echo "[$(date)] [${FUNCNAME[0]}] Total config line excluded = $EXCL_CTR"
	echo "[$(date)] [${FUNCNAME[0]}] Total config line re-generated = $NEW_CTR"
	echo "[$(date)] [${FUNCNAME[0]}] Total config line untouched = $SAME_CTR"
	echo "[$(date)] [${FUNCNAME[0]}] Total config line (final) = $(( $NEW_CTR+$SAME_CTR ))"

	echo "Total config line read = $LINE_CTR" >> $CTRFILE
	echo "Total config line skipped = $SKIP_CTR" >> $CTRFILE
	echo "Total config line excluded = $EXCL_CTR" >> $CTRFILE
	echo "Total config line re-generated = $NEW_CTR" >> $CTRFILE
	echo "Total config line untouched = $SAME_CTR" >> $CTRFILE
	echo "Total config line (final) = $(( $NEW_CTR+$SAME_CTR ))" >> $CTRFILE

	if [ $MG_DEBUG == "true" ]
	then
		if [ -s $NSSCRIPT_FILES ]
		then
			for TO_BACKUP in $(sort $NSSCRIPT_FILES | uniq)
			do
				echo "[$(date)] [${FUNCNAME[0]}] Copying namespace script file [$TO_BACKUP] to directory [$TMP_OBJ_OUTDIR]..."
				cp -p $TO_BACKUP $TMP_OBJ_OUTDIR
			done
		
			rm $NSSCRIPT_FILES
		fi
	
		if [ -s $REGEXSCRIPT_FILES ]
		then
			for TO_BACKUP in $(sort $REGEXSCRIPT_FILES | uniq)
			do
				echo "[$(date)] [${FUNCNAME[0]}] Copying regex script file [$TO_BACKUP] to directory [$TMP_OBJ_OUTDIR]..."
				cp -p $TO_BACKUP $TMP_OBJ_OUTDIR
			done
		
			rm $NSSCRIPT_FILES
		fi
	
		if [ -s $EXCLSCRIPT_FILES ]
		then
			for TO_BACKUP in $(sort $EXCLSCRIPT_FILES | uniq)
			do
				echo "[$(date)] [${FUNCNAME[0]}] Copying to-exclude script file [$TO_BACKUP] to directory [$TMP_OBJ_OUTDIR]..."
				cp -p $TO_BACKUP $TMP_OBJ_OUTDIR
			done
		
			rm $EXCLSCRIPT_FILES
		fi
	
		if [ $BASH_V4 == "true" ]
		then
			if [ ${#MISSINGOBJ_NSSCRIPT_CACHE} -gt 0 ] && [ $MISSINGOBJ_NSSCRIPT_CACHE == "true" ]
			then
				for x in "${!NSSCRIPT_CACHE_ARR[@]}"
				do 		
					printf "[%s]=%s\n" "$x" "${NSSCRIPT_CACHE_ARR[$x]}" >> $TMP_OBJ_OUTDIR/NSSCRIPT_CACHE_ARR.cache
				done
			fi
	
			if [ ${#MISSINGOBJ_NSSCRIPT_FAILCTR_CACHE} -gt 0 ] && [ $MISSINGOBJ_NSSCRIPT_FAILCTR_CACHE == "true" ]
			then
				for x in "${!NSSCRIPT_FAIL_ARR[@]}"
				do 		
					printf "[%s]=%s\n" "$x" "${NSSCRIPT_FAIL_ARR[$x]}" >> $TMP_OBJ_OUTDIR/NSSCRIPT_FAIL_ARR.cache
				done
			fi
	
			if [ ${#MISSINGOBJ_VALIDNS_CACHE} -gt 0 ] && [ $MISSINGOBJ_VALIDNS_CACHE == "true" ]
			then
				for x in "${!IS_VALID_NS_ARR[@]}"
				do 		
					printf "[%s]=%s\n" "$x" "${IS_VALID_NS_ARR[$x]}" >> $TMP_OBJ_OUTDIR/IS_VALID_NS_ARR.cache
				done
			fi
		
			if [ ${#MISSINGOBJ_EXCLSCRIPT_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_CACHE == "true" ]
			then
				for x in "${!EXCLSCRIPT_CACHE_ARR[@]}"
				do 		
					printf "[%s]=%s\n" "$x" "${EXCLSCRIPT_CACHE_ARR[$x]}" >> $TMP_OBJ_OUTDIR/EXCLSCRIPT_CACHE_ARR.cache
				done
			fi
		
			if [ ${#MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE} -gt 0 ] && [ $MISSINGOBJ_EXCLSCRIPT_FAILCTR_CACHE == "true" ]
			then
				for x in "${!EXCLSCRIPT_FAIL_ARR[@]}"
				do 		
					printf "[%s]=%s\n" "$x" "${EXCLSCRIPT_FAIL_ARR[$x]}" >> $TMP_OBJ_OUTDIR/EXCLSCRIPT_FAIL_ARR.cache
				done
			fi
	
			if [ ${#MISSINGOBJ_MULTI_PRODGRP_NS_CACHE} -gt 0 ] && [ $MISSINGOBJ_MULTI_PRODGRP_NS_CACHE == "true" ]
			then
				if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "false" ]
				then
					for x in "${!LOCAL_PROD_TO_NS_CACHE_ARR[@]}"
					do
						printf "[%s]=%s\n" "$x" "${LOCAL_PROD_TO_NS_CACHE[$x]}" >> $TMP_OBJ_OUTDIR/LOCAL_PROD_TO_NS_CACHE.cache
					done
	
					unset LOCAL_PROD_TO_NS_CACHE
				fi
			fi
	
			# Clean up associative array
	 		unset NSSCRIPT_CACHE_ARR
	 		unset NSSCRIPT_FAIL_ARR
			unset IS_VALID_NS_ARR
	
			unset EXCLSCRIPT_CACHE_ARR
	 		unset EXCLSCRIPT_FAIL_ARR
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [PRODGRP=$MISSINGOBJ_PRODUCT_GROUP / PRODVER=$MISSINGOBJ_PRODUCT_VERSION]"
	fi
}

doMissingObjects()
{
	if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
	then
		while read PROD_VER_LINE
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_VER_LINE = [$PROD_VER_LINE]"
			fi

			local MISSINGOBJ_PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
	
			if [ $USERSET_MISSINGOBJ_VERSION -eq 1 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] MISSINGOBJ_PROD_VER is overwritten with user provided USERSET_MISSINGOBJ_VERSION [$MISSINGOBJ_VERSION]..."
				local MISSINGOBJ_PROD_VER=$MISSINGOBJ_VERSION
			else
				if [ ${#RTVAR_MISSINGOBJ_PRODVER} -gt 0 ]
				then
					local MISSINGOBJ_PRODVER_VALID="false"
		
					for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
					do
						if [ $RTVAR_MISSINGOBJ_PRODVER == $VALID_PROD_VERSION ]
						then
							local MISSINGOBJ_PRODVER_VALID="true"
							break
						fi
					done	
		
					if [ $MISSINGOBJ_PRODVER_VALID == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] MISSINGOBJ_PRODVER is set to [$RTVAR_MISSINGOBJ_PRODVER]! Setting MISSINGOBJ_PROD_VER to [$RTVAR_MISSINGOBJ_PRODVER]!"
						local MISSINGOBJ_PROD_VER=$RTVAR_MISSINGOBJ_PRODVER
					else
						local MISSINGOBJ_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
						echo "[$(date)] [${FUNCNAME[0]}] MISSINGOBJ_PRODVER [$RTVAR_MISSINGOBJ_PRODVER] is invalid or not supported product version! Setting MISSINGOBJ_PROD_VER to default [$MISSINGOBJ_PROD_VER]!"
					fi
				else
					local MISSINGOBJ_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
				fi
			fi
	
			local MISSINGOBJ_PROD_VER_SHORT=$(echo "$MISSINGOBJ_PROD_VER" | sed 's/\.//g')

			if [ ${#MISSINGOBJ_INPUTFILE} -gt 0 ] && [ -s $MISSINGOBJ_INPUTFILE ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] INPUT_FILE is overwritten with user provided MISSINGOBJ_INPUTFILE [$MISSINGOBJ_INPUTFILE]..."
				local INPUT_FILE=$MISSINGOBJ_INPUTFILE
			else
				if [ ${#USERSET_MISSINGOBJ_CFGFILE} -gt 0 ]
				then
					local INPUT_FILE="$MUSTGATHER_DIRNAME/data/missingobj/$MISSINGOBJ_PROD_VER/config/$USERSET_MISSINGOBJ_CFGFILE"
			
					if [ ! -s $INPUT_FILE ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Custom input file [$INPUT_FILE] does not exist or is zero-sized!"
						local INPUT_FILE="$MUSTGATHER_DIRNAME/data/missingobj/config/$USERSET_MISSINGOBJ_CFGFILE"

						if [ ! -s $INPUT_FILE ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Custom input file [$INPUT_FILE] does not exist or is zero-sized!"
							local INPUT_FILE="$MUSTGATHER_DIRNAME/config/missingobj/$MISSINGOBJ_PROD_VER/config/missingobj.cfg"
						else
							USERSET_MISSINGOBJ_SCRIPTDIR="$MUSTGATHER_DIRNAME/data/missingobj/scripts"
						fi
					else
						USERSET_MISSINGOBJ_SCRIPTDIR="$MUSTGATHER_DIRNAME/data/missingobj/$MISSINGOBJ_PROD_VER/scripts"
					fi
				else
					local INPUT_FILE="$MUSTGATHER_DIRNAME/config/missingobj/$MISSINGOBJ_PROD_VER/config/missingobj.cfg"
				fi

				echo "[$(date)] [${FUNCNAME[0]}] INPUT_FILE = [$INPUT_FILE]"
			fi

			if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
			then
				local PROC_INPUT_FILE=$MISSINGOBJ_OUTDIR/missingobj-$(echo "${PRODUCT_NAME}" | $AWK '{ print tolower($0) }')-${MISSINGOBJ_PROD_VER_SHORT}.cfg.proc
				local CTR_FILE=$MISSINGOBJ_OUTDIR/missingobj-$(echo "${PRODUCT_NAME}" | $AWK '{ print tolower($0) }')-${MISSINGOBJ_PROD_VER_SHORT}.ctr
			else			
				local PROC_INPUT_FILE=$MISSINGOBJ_OUTDIR/PRODGRP=$MISSINGOBJ_PROD_GROUP/missingobj-$(echo "${PRODUCT_NAME}" | $AWK '{ print tolower($0) }')-${MISSINGOBJ_PROD_VER_SHORT}.cfg.proc
				local CTR_FILE=$MISSINGOBJ_OUTDIR/PRODGRP=$MISSINGOBJ_PROD_GROUP/missingobj-$(echo "${PRODUCT_NAME}" | $AWK '{ print tolower($0) }')-${MISSINGOBJ_PROD_VER_SHORT}.ctr
			fi

			local MISSINGOBJ_PROD_GROUP_NS_REFFILE=${REFFILE_OUTDIR}/${MISSINGOBJ_PROD_GROUP}.ns-ref
	
			if [ -f ${MISSINGOBJ_PROD_GROUP_NS_REFFILE} ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Calling function getMissingObjects() - [INPUT_FILE=$INPUT_FILE ## PROC_INPUT_FILE=$PROC_INPUT_FILE ## CTR_FILE=$CTR_FILE ## MISSINGOBJ_PROD_GROUP=$MISSINGOBJ_PROD_GROUP ## MISSINGOBJ_PROD_VER=$MISSINGOBJ_PROD_VER ## MISSINGOBJ_PROD_GROUP_NS_REFFILE=$MISSINGOBJ_PROD_GROUP_NS_REFFILE]"
				getMissingObjects "$INPUT_FILE" "$PROC_INPUT_FILE" "$CTR_FILE" "$MISSINGOBJ_PROD_GROUP" "$MISSINGOBJ_PROD_VER" "$MISSINGOBJ_PROD_GROUP_NS_REFFILE"
			else
				echo "[$(date)] [${FUNCNAME[0]}] Product group namespace reference file [${REFFILE_OUTDIR}/${MISSINGOBJ_PROD_GROUP}.ns-ref] does not exist or is zero-sized! Skipping..."
				continue
			fi
		done < $PROD_VERSIONS_REFFILE_FINAL
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product group namespace reference file [$PROD_VERSIONS_REFFILE_FINAL] does not exist or is zero-sized!"
		echo "[$(date)] [${FUNCNAME[0]}] Falling back to default 'non-product-group' execution..."

		local MISSINGOBJ_PROD_GROUP="default"
		local MISSINGOBJ_PROD_VER_SHORT=$(echo "$PRODUCT_VERSION" | sed 's/\.//g')
		local INPUT_FILE="$MUSTGATHER_DIRNAME/config/missingobj/$PRODUCT_VERSION/config/missingobj.cfg"
		local PROC_INPUT_FILE=$MISSINGOBJ_OUTDIR/$MISSINGOBJ_PROD_GROUP/missingobj-$(echo "${PRODUCT_NAME}" | $AWK '{ print tolower($0) }')-${MISSINGOBJ_PROD_VER_SHORT}.cfg.proc
		local CTR_FILE=$MISSINGOBJ_OUTDIR/$MISSINGOBJ_PROD_GROUP/missingobj-$(echo "${PRODUCT_NAME}" | $AWK '{ print tolower($0) }')-${MISSINGOBJ_PROD_VER_SHORT}.ctr
		local MISSINGOBJ_PROD_GROUP_NS_REFFILE=$PROD_NAMESPACES_REFFILE

		echo "[$(date)] [${FUNCNAME[0]}] Calling function getMissingObjects() - [INPUT_FILE=$INPUT_FILE ## PROC_INPUT_FILE=$PROC_INPUT_FILE ## CTR_FILE=$CTR_FILE ## MISSINGOBJ_PROD_GROUP=$MISSINGOBJ_PROD_GROUP ## MISSINGOBJ_PROD_VER=$MISSINGOBJ_PROD_VER ## MISSINGOBJ_PROD_GROUP_NS_REFFILE=$MISSINGOBJ_PROD_GROUP_NS_REFFILE]"
		getMissingObjects "$INPUT_FILE" "$PROC_INPUT_FILE" "$CTR_FILE" "$MISSINGOBJ_PROD_GROUP" "$MISSINGOBJ_PROD_VER" "$MISSINGOBJ_PROD_GROUP_NS_REFFILE"
	fi
}

getMissingObjects()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local INPUT_FILE=$1
	local PROC_INPUT_FILE=$2
	local CTR_FILE=$3
	local MISSINGOBJ_PROD_GROUP=$4
	local MISSINGOBJ_PROD_VER=$5
	local MISSINGOBJ_PROD_GROUP_NS_REFFILE=$6
	
	local MISSING_OBJ=0
	local COUNT_MISMATCH_OBJ=0

	echo "[$(date)] [${FUNCNAME[0]}] Scanning for missing objects with input file [$INPUT_FILE]..." 

	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "REPORT OF MISSING OBJECTS (PROD_GROUP = $MISSINGOBJ_PROD_GROUP / PROD_VER = $MISSINGOBJ_PROD_VER)" >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "NOTE(1): Please be as accurate as possible with the regex of OBJNAME. Otherwise, an object is considered found as long as there is at least one instance!" >> $ANALYZE_OUTFILE
	echo "NOTE(2): The algorithm is based on matching '$OC_CMD get' returned object name against AWK regular expression defined by 'OBJNAME'!" >> $ANALYZE_OUTFILE
	echo "NOTE(3): For missing object with label [Count condition OK], it is likely to be either optional or deleted job pod. To investigate further!" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE
	echo "[INPUT FILE]" >> $ANALYZE_OUTFILE
	echo "$INPUT_FILE" >> $ANALYZE_OUTFILE
	echo >> $ANALYZE_OUTFILE

	if [ -s $INPUT_FILE ]
	then
		if [ ! -d $MISSINGOBJ_OUTDIR ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Making directory [$MISSINGOBJ_OUTDIR]..."
			mkdir -p $MISSINGOBJ_OUTDIR
		fi

		if [ ${#CMD_EXEC_RESULT_MISSINGOBJ_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_MISSINGOBJ_FILE ]
		then
			if [ ${#CMD_EXEC_MISSINGOBJ_ONLY} -gt 0 ] && [ ${CMD_EXEC_MISSINGOBJ_ONLY} == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_MISSINGOBJ_ONLY = [$CMD_EXEC_MISSINGOBJ_ONLY] - Setting INPUT_FILE to [$CMD_EXEC_RESULT_MISSINGOBJ_FILE]..."
				local INPUT_FILE=$CMD_EXEC_RESULT_MISSINGOBJ_FILE
			else
				local INPUT_FILE_MERGED=$(echo "$PROC_INPUT_FILE" | sed 's/.proc$/.merged/')
				echo "[$(date)] [${FUNCNAME[0]}] Merging INPUT FILE [$INPUT_FILE] with CMD_EXEC_RESULT_MISSINGOBJ_FILE [$CMD_EXEC_RESULT_MISSINGOBJ_FILE] => [$INPUT_FILE_MERGED]..."
				cat $INPUT_FILE $CMD_EXEC_RESULT_MISSINGOBJ_FILE >> $INPUT_FILE_MERGED

				echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_MISSINGOBJ_ONLY = [$CMD_EXEC_MISSINGOBJ_ONLY] - Setting INPUT_FILE to [$INPUT_FILE_MERGED]..."
				local INPUT_FILE=$INPUT_FILE_MERGED
			fi
		fi

		processMissingObjInputFile "$INPUT_FILE" "$PROC_INPUT_FILE" "$CTR_FILE" "$MISSINGOBJ_PROD_GROUP" "$MISSINGOBJ_PROD_VER" "$MISSINGOBJ_PROD_GROUP_NS_REFFILE"

		if [ -s $CTR_FILE ]
		then
			echo "[INPUT FILE PROCESSING DETAILS]" >> $ANALYZE_OUTFILE
			cat $CTR_FILE >> $ANALYZE_OUTFILE
			echo >> $ANALYZE_OUTFILE
		fi

		if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
		then
			local TMP_OBJ_OUT=$MISSINGOBJ_OUTDIR
			local TMPFILE_OUTDIR=$MISSINGOBJ_ROOT_DEBUG_OUTDIR
		else
			local TMP_OBJ_OUT=$MISSINGOBJ_OUTDIR/PRODGRP=$MISSINGOBJ_PROD_GROUP
			local TMPFILE_OUTDIR=$MISSINGOBJ_ROOT_DEBUG_OUTDIR/PRODGRP=$MISSINGOBJ_PROD_GROUP
		fi

		local TMPFILE_ARRAY=()
		local EXCLFILE_ARRAY=()
		local PROB_RES_LIST=()
		local OC_MAX_RETRY=2

		local LINE_CTR=0
		local SKIP_CTR=0
		local TOTAL_MATCH_COUNT=0
		local TOTAL_COUNT_COND_OK=0

		local EXCL_FILE=
		local TMPFILE=
		local EXCL_REGEX=
		local LINE=
		local DEBUGLINE=
		local NOTMATCH_LINE=

		# To include all '.excl' files into the EXCLFILE_ARRAY for processing
		for EXCL_FILE in $(ls $TMP_OBJ_OUT | grep -E '.excl$')
		do
			echo "[$(date)] [${FUNCNAME[0]}] Adding exclude file [$EXCL_FILE] into EXCLFILE_ARRAY for further processing..."
			local EXCLFILE_ARRAY[${#EXCLFILE_ARRAY[@]}]=$EXCL_FILE
		done

		if [ ! -s $PROC_INPUT_FILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Processed input file [${PROC_INPUT_FILE}] for function 'getMissingObjects()' is not available or zero-sized! Exiting..." | tee -a $ANALYZE_OUTFILE
			echo >> $ANALYZE_OUTFILE
		
			return 1
		fi

		echo "[SCAN RESULT]" >> $ANALYZE_OUTFILE

		local MISSINGOBJ_UNIQUE_NS_OUTFILE=$TMP_OBJ_OUT/missingobj-ns.uniq
		local MISSINGOBJ_UNIQUE_NS_WORKFILE=$TMP_OBJ_OUT/missingobj-ns.uniq.tmp

		while read LINE
		do
			# Skip all lines that start with @ and blank lines
			if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "$MISSINGOBJ_CFGFILE_COMMENT"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi

			local OC_RETRY=0
			(( LINE_CTR=LINE_CTR+1 ))

			local OBJ_NS=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $1}')
			local OBJ_TYPE=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $2}')
			local OBJ_NAME=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $3}')
			local OBJ_COUNT=$(echo "$LINE" | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $4}')

			# if [ $OBJ_NS == "?" ]
			if [ $OBJ_NS == "ALLNS" ]
			then
				local OBJ_NS="all"
				local OBJ_NS_CMD="-A"
			else
				local OBJ_NS_CMD="-n $OBJ_NS"
			fi
			
			echo "$OBJ_NS" >> $MISSINGOBJ_UNIQUE_NS_WORKFILE

			local TMP_OBJ_OUTFILE=$TMP_OBJ_OUT/$OBJ_NS~$OBJ_TYPE~$$
			echo "$LINE" >> $TMP_OBJ_OUTFILE.cfg

			if [ ! -f $TMP_OBJ_OUTFILE ]
			then
				if ! checkUserPriv get $OBJ_TYPE $OBJ_NS
				then
					echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform [get] on resource [$OBJ_TYPE] in namespace [$OBJ_NS]!"
					touch $TMP_OBJ_OUTFILE
				else
					while [ $OC_RETRY -le $OC_MAX_RETRY ]
					do
						echo "[$(date)] [${FUNCNAME[0]}] [$OC_RETRY] Executing '$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_NS_CMD' => $TMP_OBJ_OUTFILE" 
						local OC_GET_CMD="$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{\"\n\"}}{{end}}' $OBJ_NS_CMD"
						eval "$OC_GET_CMD" > $TMP_OBJ_OUTFILE 
	
						(( OC_RETRY=OC_RETRY+1 ))
	
						if [ -s $TMP_OBJ_OUTFILE ]
						then
							local TMPFILE_ARRAY[${#TMPFILE_ARRAY[@]}]=$TMP_OBJ_OUTFILE
							local OC_RETRY=0
							break
						else
							sleep $DEFAULT_SLEEP_SEC
						fi
					done
	
					if [ $OC_RETRY -eq 3 ] && [ ! -s $TMP_OBJ_OUTFILE ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Error executing '$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}' $OBJ_NS_CMD'. Maximum retries reached!"	
						echo "[$(date)] [${FUNCNAME[0]}] Creating an empty file for object [$OBJ_TYPE] in namespace [$OBJ_NS] => [$TMP_OBJ_OUTFILE]..."
						touch $TMP_OBJ_OUTFILE

						local PROB_RES_LIST[${#PROB_RES_LIST[@]}]="$OBJ_NS/$OBJ_TYPE"
					fi
				fi
			fi

			if [ ! -f $TMP_OBJ_OUTFILE ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] File [$TMP_OBJ_OUTFILE] is unavailable. Skipping config line [$LINE]..."
				fi

				(( SKIP_CTR=SKIP_CTR+1 ))
				continue	
			fi

			local MATCH=$($AWK '/'$OBJ_NAME'/ { print }' $TMP_OBJ_OUTFILE | tr '\n' ' ' | sed 's/[ ]$//')

			local MATCH_COUNT=$(echo "$MATCH" | $AWK '{ print NF }')
			(( TOTAL_MATCH_COUNT=TOTAL_MATCH_COUNT+MATCH_COUNT ))
			echo "$MATCH_COUNT @ $LINE @ $MATCH" >> $TMP_OBJ_OUTFILE.matchcount

			local COUNT_CMD="echo $MATCH_COUNT | $AWK '{ if ( +\$0$OBJ_COUNT ) { print \"OK\" } else { print \"NOK\" } }'"
			local COUNT_RESULT=$(eval "$COUNT_CMD")

			if [ ${#MATCH} -eq 0 ]
			then
				if [ ! -s $TMP_OBJ_OUTFILE ]
				then
					local PROB_OBJ_SYMBOL="**"
				else
					local PROB_OBJ_SYMBOL=""
				fi

				if [ $COUNT_RESULT == "OK" ]
				then
					echo ">>> [$OBJ_NS] Missing '$OBJ_TYPE' object [Count condition OK] = $OBJ_NAME [Expected: '$OBJ_COUNT' / Found: $MATCH_COUNT ] ${PROB_OBJ_SYMBOL}" >> $ANALYZE_OUTFILE
					(( TOTAL_COUNT_COND_OK=TOTAL_COUNT_COND_OK+1 ))
				else
					echo ">>> [$OBJ_NS] Missing '$OBJ_TYPE' object = $OBJ_NAME [Expected: '$OBJ_COUNT' / Found: $MATCH_COUNT ] ${PROB_OBJ_SYMBOL}" >> $ANALYZE_OUTFILE
				fi

				(( MISSING_OBJ=MISSING_OBJ+1 ))

				echo "$LINE" >> $TMP_OBJ_OUTFILE.cfg_miss

				# Help to construct pod-to-pod dependency data for missing object
				if [ $GET_DEPENDENCY_DATA == "true" ]
				then
					if isProdNamespace $OBJ_NS
					then
						if [ $OBJ_TYPE == "po" ] || [ $OBJ_TYPE == "pod" ] || [ $OBJ_TYPE == "pods" ]
						then
							echo "$OBJ_NAME" >> $RUNTIME_OUTDIR/dependency/$OBJ_NS/pod.missing
						fi
					fi
				fi
			else
				echo "$LINE" >> $TMP_OBJ_OUTFILE.cfg_hit

				if [ $COUNT_RESULT ==  "NOK" ]
				then
					echo ">>> [$OBJ_NS] Count mismatch '$OBJ_TYPE' object = $OBJ_NAME [Expected: '$OBJ_COUNT' / Found: $MATCH_COUNT ]" >> $ANALYZE_OUTFILE
					(( COUNT_MISMATCH_OBJ=COUNT_MISMATCH_OBJ+1 ))
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE => $LINE] matches [$MATCH] [COUNT=$MATCH_COUNT] [OBJCOUNT: $OBJ_COUNT / $COUNT_RESULT]"
			fi	

		done < $PROC_INPUT_FILE

		if [ $MISSING_OBJ -eq 0 ]
		then
			echo "No object is found missing!" >> $ANALYZE_OUTFILE
		fi

		echo >> $ANALYZE_OUTFILE

		if [ $LINE_CTR -eq $SKIP_CTR ]
		then
			local MSG="Scan for missing objects is incomplete/aborted!" 
			echo "[$(date)] [${FUNCNAME[0]}] $MSG"
			echo "$MSG" >> $ANALYZE_OUTFILE
		else
			if [ ${#PROB_RES_LIST[@]} -gt 0 ]
			then
				local PROB_RES_LIST_CTR=1
				local PROB_RES=

				echo "[PROBLEMATIC RESOURCE LISTING **]" >> $ANALYZE_OUTFILE

				for PROB_RES in ${PROB_RES_LIST[@]}
				do
					local PROB_RES_NS=$(echo "$PROB_RES" | $AWK -F/ '{ print $1 }')
					local PROB_RES_TYPE=$(echo "$PROB_RES" | $AWK -F/ '{ print $2 }')

					echo "($PROB_RES_LIST_CTR) There is 0 resource of type [$PROB_RES_TYPE] in namespace [$PROB_RES_NS]!" >> $ANALYZE_OUTFILE

					(( PROB_RES_LIST_CTR=PROB_RES_LIST_CTR+1 ))
				done

				echo >> $ANALYZE_OUTFILE
			fi

			echo "[SCAN CONFIGURATION DETAILS]" >> $ANALYZE_OUTFILE
			local MSG="Total configuration line = $LINE_CTR"
			echo "[$(date)] [${FUNCNAME[0]}] $MSG"
			echo "$MSG" >> $ANALYZE_OUTFILE
			local MSG="Total skipped configuration = $SKIP_CTR"
			echo "[$(date)] [${FUNCNAME[0]}] $MSG"
			echo "$MSG" >> $ANALYZE_OUTFILE
			echo >> $ANALYZE_OUTFILE
			echo "[STATISTICS]" >> $ANALYZE_OUTFILE

			for TMPFILE in ${TMPFILE_ARRAY[@]}
			do
				local TMPFILE_CFG_COUNT=$(wc -l $TMPFILE.cfg | $AWK '{ print $1 }')

				if [ ! -s $TMPFILE.cfg_hit ]
				then
					local TMPFILE_CFG_HIT=0
				else
					local TMPFILE_CFG_HIT=$(wc -l $TMPFILE.cfg_hit | $AWK '{ print $1 }')
				fi

				if [ ! -s $TMPFILE.cfg_miss ]
				then
					local TMPFILE_CFG_MISS=0
				else
					local TMPFILE_CFG_MISS=$(wc -l $TMPFILE.cfg_miss | $AWK '{ print $1 }')
				fi

				local TMPFILE_OBJ_COUNT=$(wc -l $TMPFILE | $AWK '{ print $1 }')
				local TMPFILE_OBJ_MATCH_COUNT=$($AWK -F'@' '{ sum += $1 } END { print sum }' $TMPFILE.matchcount)
				local TMPFILE_OBJ_NOTMATCH_COUNT=$((TMPFILE_OBJ_COUNT-TMPFILE_OBJ_MATCH_COUNT))
				local TOTAL_EXCL_MATCHED_REMOVE_CTR=0

				local TMPFILE_NS=$(echo "$TMPFILE" | $AWK -F'/' '{ print $NF }' | $AWK -F'~' '{ print $1 }')
				local TMPFILE_OBJTYPE=$(echo "$TMPFILE" | $AWK -F'/' '{ print $NF }' | $AWK -F'~' '{ print $2 }')

				if [ $MG_DEBUG == "true" ]
				then
					if [ $TMPFILE_OBJ_NOTMATCH_COUNT -gt 0 ] 
					then
						while read DEBUGLINE
						do
							echo "$DEBUGLINE" | $AWK -F'@' '{ print $3 }' | sed 's/ /\n/g' | $AWK 'NF' >> $TMPFILE.matchcount.tmp
						done < $TMPFILE.matchcount
	
						if [ -s $TMPFILE.matchcount.tmp ]
						then
							# sed -i '/^$/d' $TMPFILE.matchcount.tmp
							sort $TMPFILE.matchcount.tmp > $TMPFILE.matchcount.objs
							sort $TMPFILE > $TMPFILE.tmp

							diff $TMPFILE.matchcount.objs $TMPFILE.tmp | grep -v '^[0-9]' > $TMPFILE.diff
							local ORIG_TMPFILE_OBJ_NOTMATCH_COUNT=$TMPFILE_OBJ_NOTMATCH_COUNT
							
							if [ -s $TMPFILE.excl ]
							then
								while read NOTMATCH_LINE
								do
									local EXCL_MATCHED=0
									local NOTMATCH_OBJ=$(echo "$NOTMATCH_LINE" | $AWK '{ print $2 }')

									for EXCL_REGEX in $(sort $TMPFILE.excl | $AWK -F${MISSINGOBJ_CFGFILE_DELIMITER} '{ print $3 }')
									do
										local EXCL_MATCHED_CMD="echo $NOTMATCH_OBJ | $AWK '/$EXCL_REGEX/ { print }' | tr '\n' ' ' | sed 's/[ ]$//'"
										echo "[$(date)] [${FUNCNAME[0]}] [$TMPFILE_NS/$TMPFILE_OBJTYPE] EXCL_MATCHED_CMD = [$EXCL_MATCHED_CMD]"	
										local EXCL_MATCHED=$(eval "$EXCL_MATCHED_CMD")
										
										if [ $MG_DEBUG == "true" ]
										then
											echo -n "[$(date)] [${FUNCNAME[0]}] [$TMPFILE_NS/$TMPFILE_OBJTYPE] Comparing excluded object regex [$EXCL_REGEX] against not-matched object [$NOTMATCH_OBJ]. Match output = [$EXCL_MATCHED]. Result = "
										fi

										if [ ${#EXCL_MATCHED} -gt 0 ]	
										then
											if [ $MG_DEBUG == "true" ]
											then
												echo "[MATCHED]"

												echo "$NOTMATCH_OBJ" >> $TMPFILE.excl-rm
											fi

											echo "[$(date)] [${FUNCNAME[0]}] [$TMPFILE_NS/$TMPFILE_OBJTYPE] Not-matched object [$NOTMATCH_OBJ] matches excluded object regex [$EXCL_REGEX]. Removing [$NOTMATCH_OBJ] from not-match list..."
											
											(( TMPFILE_OBJ_NOTMATCH_COUNT=TMPFILE_OBJ_NOTMATCH_COUNT-1 ))
											(( TOTAL_EXCL_MATCHED_REMOVE_CTR=TOTAL_EXCL_MATCHED_REMOVE_CTR+1 ))
											break
										else
											if [ $MG_DEBUG == "true" ]
											then
												echo "[NOT MATCHED]"
											fi
										fi
									done

									if [ ${#EXCL_MATCHED} -eq 0 ]
									then
										echo "> $NOTMATCH_OBJ" >> $TMPFILE.not_match
									fi
								done < $TMPFILE.diff
							else
								cp -p $TMPFILE.diff $TMPFILE.not_match
							fi

							echo "[$(date)] [${FUNCNAME[0]}] [$TMPFILE_NS/$TMPFILE_OBJTYPE] Total not-matched object found excluded and removed = [$TOTAL_EXCL_MATCHED_REMOVE_CTR] from not-matched object list of size [$ORIG_TMPFILE_OBJ_NOTMATCH_COUNT] => Final not-matched count = [$TMPFILE_OBJ_NOTMATCH_COUNT]"

							rm $TMPFILE.matchcount.tmp
							rm $TMPFILE.tmp
						else
							echo "[$(date)] [${FUNCNAME[0]}] Debug file [$TMPFILE.matchcount.tmp] does not exist or zero-sized!"

							if [ -f $TMPFILE.matchcount.tmp ]
							then
								rm $TMPFILE.matchcount.tmp
							fi
						fi
					fi
				fi

				if [ $TOTAL_EXCL_MATCHED_REMOVE_CTR -gt 0 ]
				then
					local MSG="Context [$TMPFILE_NS/$TMPFILE_OBJTYPE] : Total Config = $TMPFILE_CFG_COUNT / Total Config Hit = $TMPFILE_CFG_HIT / Total Config Missed = $TMPFILE_CFG_MISS / Total Objects Found = $TMPFILE_OBJ_COUNT / Total Objects Matched = $TMPFILE_OBJ_MATCH_COUNT / Total Objects Not Matched = $TMPFILE_OBJ_NOTMATCH_COUNT / Total Excluded Objects Removed = $TOTAL_EXCL_MATCHED_REMOVE_CTR" 
					echo "[$(date)] [${FUNCNAME[0]}] $MSG"
					echo "$MSG" >> $ANALYZE_OUTFILE
				else
					local MSG="Context [$TMPFILE_NS/$TMPFILE_OBJTYPE] : Total Config = $TMPFILE_CFG_COUNT / Total Config Hit = $TMPFILE_CFG_HIT / Total Config Missed = $TMPFILE_CFG_MISS / Total Objects Found = $TMPFILE_OBJ_COUNT / Total Objects Matched = $TMPFILE_OBJ_MATCH_COUNT / Total Objects Not Matched = $TMPFILE_OBJ_NOTMATCH_COUNT" 
					echo "[$(date)] [${FUNCNAME[0]}] $MSG"
					echo "$MSG" >> $ANALYZE_OUTFILE
				fi

				if [ -s $TMPFILE.not_match ] 
				then
					local NOT_MATCHED_CNT=$(wc -l $TMPFILE.not_match | $AWK '{ print $1 }')

					if [ $NOT_MATCHED_CNT -le $MISSINGOBJ_DIFF_MAX ]
					then
						echo "[Objects Not Matched]" >> $ANALYZE_OUTFILE
						cat $TMPFILE.not_match >> $ANALYZE_OUTFILE
					else
						echo "[Objects Not Matched]" >> $ANALYZE_OUTFILE
						echo "<INFO>: Not-matched object count is more than [$MISSINGOBJ_DIFF_MAX]. Not displaying!" >> $ANALYZE_OUTFILE
					fi
				fi
			done
	
			echo >> $ANALYZE_OUTFILE
			echo "[SCAN SUMMARY]" >> $ANALYZE_OUTFILE
			if [ -s $MISSINGOBJ_UNIQUE_NS_WORKFILE ]
			then
				sort $MISSINGOBJ_UNIQUE_NS_WORKFILE | uniq > $MISSINGOBJ_UNIQUE_NS_OUTFILE
				local MSG="Total namespace(s) scanned = [$(wc -l $MISSINGOBJ_UNIQUE_NS_OUTFILE | $AWK '{ print $1 }')] [$(cat $MISSINGOBJ_UNIQUE_NS_OUTFILE | tr '\n' ' ' | sed 's/[ ]*$//')]"
				echo "[$(date)] [${FUNCNAME[0]}] $MSG"
				echo "$MSG" >> $ANALYZE_OUTFILE
			fi
			local MSG="Total objects matched = $TOTAL_MATCH_COUNT" 
			echo "[$(date)] [${FUNCNAME[0]}] $MSG"
			echo "$MSG" >> $ANALYZE_OUTFILE

			if [ ${MISSING_OBJ} -eq 0 ]
			then
				local MSG="No object is found missing!"
				echo "[$(date)] [${FUNCNAME[0]}] $MSG"
				echo "$MSG" >> $ANALYZE_OUTFILE
			else
				if [ $TOTAL_COUNT_COND_OK -gt 0 ]
				then
					if [ $TOTAL_COUNT_COND_OK -eq $MISSING_OBJ ]
					then
						local MSG="Total of $MISSING_OBJ object(s) are found missing, but ALL of them [$TOTAL_COUNT_COND_OK] matched their count condition!"
						echo "[$(date)] [${FUNCNAME[0]}] $MSG"
						echo "$MSG" >> $ANALYZE_OUTFILE
					else
						local MSG="Total of $MISSING_OBJ object(s) are found missing [missing=$((MISSING_OBJ-TOTAL_COUNT_COND_OK)) count_ok=$TOTAL_COUNT_COND_OK]!"
						echo "[$(date)] [${FUNCNAME[0]}] $MSG"
						echo "$MSG" >> $ANALYZE_OUTFILE
					fi
				else
					local MSG="Total of $MISSING_OBJ object(s) are found missing!"
					echo "[$(date)] [${FUNCNAME[0]}] $MSG"
					echo "$MSG" >> $ANALYZE_OUTFILE
				fi
			fi

			if [ ${COUNT_MISMATCH_OBJ} -eq 0 ]
			then
				local MSG="No object with mismatched count is found!"
				echo "[$(date)] [${FUNCNAME[0]}] $MSG"
				echo "$MSG" >> $ANALYZE_OUTFILE
			else
				local MSG="Total of $COUNT_MISMATCH_OBJ object(s) are found to have mismatched count!"
				echo "[$(date)] [${FUNCNAME[0]}] $MSG"
				echo "$MSG" >> $ANALYZE_OUTFILE
			fi

			local MSG="Scan for missing objects is completed."
			echo "[$(date)] [${FUNCNAME[0]}] $MSG"
			echo "$MSG" >> $ANALYZE_OUTFILE
		fi
		
		echo "" >> $ANALYZE_OUTFILE

		for TMPFILE in ${TMPFILE_ARRAY[@]}
		do
			if [ -f $TMPFILE ]
			then
				if [ ! -d $TMPFILE_OUTDIR ]
				then
					mkdir -p $TMPFILE_OUTDIR
				fi

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE] to directory [$TMPFILE_OUTDIR]..."
					cp -p $TMPFILE $TMPFILE_OUTDIR
					echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.cfg] to directory [$TMPFILE_OUTDIR]..."
					cp -p $TMPFILE.cfg $TMPFILE_OUTDIR
					echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.matchcount] to directory [$TMPFILE_OUTDIR]..."
					cp -p $TMPFILE.matchcount $TMPFILE_OUTDIR

					if [ -f  $TMPFILE.cfg_hit ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.cfg_hit] to directory [$TMPFILE_OUTDIR]..."
						cp -p $TMPFILE.cfg_hit $TMPFILE_OUTDIR
					fi

					if [ -f $TMPFILE.cfg_miss ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.cfg_miss] to directory [$TMPFILE_OUTDIR]..."
						cp -p $TMPFILE.cfg_miss $TMPFILE_OUTDIR
					fi

					if [ -f $TMPFILE.cfg_skip ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.cfg_skip] to directory [$TMPFILE_OUTDIR]..."
						cp -p $TMPFILE.cfg_skip $TMPFILE_OUTDIR
					fi

					if [ -f $TMPFILE.matchcount.objs ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.matchcount.objs] to directory [$TMPFILE_OUTDIR]..."
						cp -p $TMPFILE.matchcount.objs $TMPFILE_OUTDIR
					fi

					if [ -f $TMPFILE.not_match ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.not_match] to directory [$TMPFILE_OUTDIR]..."
						cp -p $TMPFILE.not_match $TMPFILE_OUTDIR
					fi
	
					if [ -f $TMPFILE.excl ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.excl] to directory [$TMPFILE_OUTDIR]..."
						cp -p $TMPFILE.excl $TMPFILE_OUTDIR
					fi
	
					if [ -f $TMPFILE.excl-rm ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.excl-rm] to directory [$TMPFILE_OUTDIR]..."
						cp -p $TMPFILE.excl-rm $TMPFILE_OUTDIR
					fi
	
					if [ -f $TMPFILE.diff ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE.diff] to directory [$TMPFILE_OUTDIR]..."
						cp -p $TMPFILE.diff $TMPFILE_OUTDIR
					fi
				fi
	
				echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMPFILE] [$TMPFILE.cfg] [$TMPFILE.matchcount]..."
				rm $TMPFILE $TMPFILE.cfg $TMPFILE.matchcount
	
				if [ -f $TMPFILE.cfg_hit ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMPFILE.cfg_hit]..."
					rm $TMPFILE.cfg_hit
				fi

				if [ -f $TMPFILE.cfg_miss ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMPFILE.cfg_miss]..."
					rm $TMPFILE.cfg_miss
				fi

				if [ -f $TMPFILE.cfg_skip ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMPFILE.cfg_skip]..."
					rm $TMPFILE.cfg_skip
				fi

				if [ -f $TMPFILE.matchcount.objs ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMPFILE.matchcount.objs]..."
					rm $TMPFILE.matchcount.objs
				fi

				if [ -f $TMPFILE.not_match ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMPFILE.not_match]..."
					rm $TMPFILE.not_match 
				fi

				if [ -f $TMPFILE.excl ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMPFILE.excl]..."
					rm $TMPFILE.excl
				fi

				if [ -f $TMPFILE.diff ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMPFILE.diff]..."
					rm $TMPFILE.diff
				fi
			fi
		done

		echo "[$(date)] [${FUNCNAME[0]}] Copying 'getMissingObjects()' input file [$INPUT_FILE] to [$TMP_OBJ_OUT]..."
		cp -p $INPUT_FILE $TMP_OBJ_OUT
	else
		local MSG="Input file [${INPUT_FILE}] for function 'getMissingObjects()' is not available or zero-sized! Skipping..."
		echo "[$(date)] [${FUNCNAME[0]}] $MSG"
		echo "$MSG" >> $ANALYZE_OUTFILE
		echo >> $ANALYZE_OUTFILE
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [PRODGRP=$MISSINGOBJ_PROD_GROUP / PRODVER=$MISSINGOBJ_PROD_VER]"
	fi
}

processComplianceInputFile()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local COMPLIANCE_WORKFILE=$1
	local COMPLIANCE_PROCFILE=$2
	local COMPLIANCE_PROD_GROUP=$3
	local COMPLIANCE_PROD_VER=$4
	local COMPLIANCE_PROD_GROUP_NS_REFFILE=$5
	local COMPLIANCE_SCRIPT_DIR=$6

	local COMPLIANCE_ROOTDIR=$COMPLIANCE_OUTDIR/$COMPLIANCE_PROD_VER

	if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
	then	
		local COMPLIANCE_WORKDIR=$COMPLIANCE_OUTDIR
		local COMPLIANCE_DEBUGDIR=$COMPLIANCE_ROOT_DEBUG_OUTDIR
	else
		local COMPLIANCE_WORKDIR=$COMPLIANCE_OUTDIR/PRODGRP=$COMPLIANCE_PROD_GROUP
		local COMPLIANCE_DEBUGDIR=$COMPLIANCE_ROOT_DEBUG_OUTDIR/PRODGRP=$COMPLIANCE_PROD_GROUP
	fi

	if [ ! -s ${COMPLIANCE_WORKFILE} ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_WORKFILE [$COMPLIANCE_WORKFILE] does not exist or is zero-sized!"
		return 1
	fi

	if [ ! -d $COMPLIANCE_WORKDIR ]
	then
		mkdir -p $COMPLIANCE_WORKDIR
	fi

	if [ ! -d $COMPLIANCE_DEBUGDIR ]
	then
		mkdir -p $COMPLIANCE_DEBUGDIR
	fi

	if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "false" ] && [ $BASH_V4 == "true" ]
	then
		declare -A LOCAL_PROD_TO_NS_CACHE
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_WORKFILE = [$COMPLIANCE_WORKFILE] / COMPLIANCE_PROD_GROUP = [$COMPLIANCE_PROD_GROUP] / COMPLIANCE_PROD_VER = [$COMPLIANCE_PROD_VER] / COMPLIANCE_PROD_GROUP_NS_REFFILE = [$COMPLIANCE_PROD_GROUP_NS_REFFILE] / COMPLIANCE_SCRIPT_DIR = [$COMPLIANCE_SCRIPT_DIR]"
	fi

	# COMPLIANCE_PROCFILE=$COMPLIANCE_WORKDIR/$(basename ${COMPLIANCE_WORKFILE}).proc
	# touch $COMPLIANCE_PROCFILE

	# TOTAL_CFGLINE = SKIP_CFGLINE + SAME_CFGLINE + PROC_CFGLINE
	# NEW_CFGLINE = Expanded config lines (final COMPLIANCE_PROCFILE)
	local TOTAL_CFGLINE=0
	local SKIP_CFGLINE=0
	local SAME_CFGLINE=0
	local PROC_CFGLINE=0
	local NEW_CFGLINE=0

	local CFGLINE=

	local DEF_ENV_ARR=("COMPLIANCE_PRODUCT_NSFILE" "COMPLIANCE_PROD_GROUP_NS_REFFILE" "COMPLIANCE_PROD_GROUP" "COMPLIANCE_PROD_VER" "COMPLIANCE_OUTDIR" "COMPLIANCE_ROOT_DEBUG_OUTDIR")

	local COMPLIANCE_USER_INPUT_ENV=$(compgen -A variable | grep -E '^RTVAR_COMPLIANCE_' | tr '\n' ' ')

	if [ ${#COMPLIANCE_USER_INPUT_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for USER_INPUT_ENV in $COMPLIANCE_USER_INPUT_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$USER_INPUT_ENV] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$USER_INPUT_ENV"
		done	
	fi

	local GMGFVAR_ENV=$(compgen -A variable | grep -E '^RTVAR_GMGFVAR_' | tr '\n' ' ')

	if [ ${#GMGFVAR_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for GMGFVAR in $GMGFVAR_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$GMGFVAR] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$GMGFVAR"
		done	
	fi

	IFS=$'\n'
	for DEF_ENV in ${DEF_ENV_ARR[@]}
	do
		if [[ $DEF_ENV =~ ^-f ]]
		then
			local COMPLIANCE_FUNCNAME=$(echo "$DEF_ENV" | $AWK '{ print $2 }')
		
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment function [$COMPLIANCE_FUNCNAME]..."
			fi

			export -f $COMPLIANCE_FUNCNAME
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$DEF_ENV = ${!DEF_ENV}]"
			fi

			export $DEF_ENV
		fi
	done

	while read CFGLINE
	do
		# Skip all lines that start with @ and blank lines
		if [[ $(echo "$CFGLINE" | $AWK '{$1=$1};1') == "$COMPLIANCE_CFGFILE_COMMENT"* ]] || [[ $(echo "$CFGLINE" | $AWK '{ print NF }') -eq 0 ]]
		then
			continue
		else
			(( TOTAL_CFGLINE=TOTAL_CFGLINE+1 ))

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] CFGLINE = [$CFGLINE]"
			fi

			local COMPLIANCE_CFGLINE_TOTAL_COLUMNS=14
			local COMPLIANCE_CFGLINE_CURRENT_COLUMNS=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print NF }')

			if [ $COMPLIANCE_CFGLINE_CURRENT_COLUMNS -ne $COMPLIANCE_CFGLINE_TOTAL_COLUMNS ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Current columns [$COMPLIANCE_CFGLINE_CURRENT_COLUMNS] is not [$COMPLIANCE_CFGLINE_TOTAL_COLUMNS]! Skipping..."
				(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
				continue
			fi
		fi
		
		local COMPLIANCE_TAG=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $1 }')
		local COMPLIANCE_SOURCENS=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $2 }')
		local COMPLIANCE_SOURCEOBJTYPE=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $3 }')
		local COMPLIANCE_SOURCEOBJNAME=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $4 }')
		local COMPLIANCE_SOURCEREGEX=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $5 }')
		local COMPLIANCE_TARGETNS=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $6 }')
		local COMPLIANCE_TARGETOBJTYPE=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $7 }')
		local COMPLIANCE_TARGETOBJNAME=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $8 }')
		local COMPLIANCE_TARGETREGEX=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $9 }')
		local COMPLIANCE_COMPLIANCESCRIPT=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $10 }')
		local COMPLIANCE_EXCLSCRIPT=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $11 }')
		local COMPLIANCE_PREPROC=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $12 }')
		local COMPLIANCE_ACTIONWHEN=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $13 }')
		local COMPLIANCE_ACTIONSCRIPT=$(echo "$CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $14 }')

		local C_TAG=
		local SOURCENS=
		local STR_MATCH=
		local TARGETNS=
		local STR=
		local STR1=
		local STR2=

		local COMPLIANCE_PROCFILE_TMP=$COMPLIANCE_WORKDIR/$TOTAL_CFGLINE-$COMPLIANCE_TAG.proc.tmp
		touch $COMPLIANCE_PROCFILE_TMP

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_TAG[$COMPLIANCE_TAG] / COMPLIANCE_SOURCENS[$COMPLIANCE_SOURCENS] / COMPLIANCE_SOURCEOBJTYPE[$COMPLIANCE_SOURCEOBJTYPE] / COMPLIANCE_SOURCEOBJNAME[$COMPLIANCE_SOURCEOBJNAME] / COMPLIANCE_SOURCEREGEX[$COMPLIANCE_SOURCEREGEX] / COMPLIANCE_TARGETNS[$COMPLIANCE_TARGETNS] / COMPLIANCE_TARGETOBJTYPE[$COMPLIANCE_TARGETOBJTYPE] / COMPLIANCE_TARGETOBJNAME[$COMPLIANCE_TARGETOBJNAME] / COMPLIANCE_TARGETREGEX[$COMPLIANCE_TARGETREGEX] / COMPLIANCE_COMPLIANCESCRIPT[$COMPLIANCE_COMPLIANCESCRIPT] / COMPLIANCE_EXCLSCRIPT[$COMPLIANCE_EXCLSCRIPT] / COMPLIANCE_PREPROC[$COMPLIANCE_PREPROC] / COMPLIANCE_ACTIONWHEN[$COMPLIANCE_ACTIONWHEN] / COMPLIANCE_ACTIONSCRIPT[$COMPLIANCE_ACTIONSCRIPT]"
		fi

		if [ ${#COMPLIANCE_TAG} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_TAG is empty/null! Skipping..."
			(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
			continue
		fi

		if [ ${#COMPLIANCE_SOURCEOBJNAME} -gt 0 ] && [ $COMPLIANCE_SOURCEOBJNAME == "OBJNAME" ]
		then
			if [ ${#COMPLIANCE_SOURCEREGEX} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_SOURCEOBJNAME is set to [OBJNAME], but COMPLIANCE_SOURCEREGEX is empty/null! Skipping..."
				(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
				continue
			else
				if [[ ! $COMPLIANCE_SOURCEREGEX =~ ^/ ]]
				then
					local COMPLIANCE_SOURCEREGEX=$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_SOURCEREGEX
				fi
	
				local COMPLIANCE_SOURCEREGEX_LOC=$(echo "$COMPLIANCE_SOURCEREGEX" | $AWK '{ print $1 }')

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_SOURCEREGEX_LOC = [$COMPLIANCE_SOURCEREGEX_LOC]"
				fi

				if [ ! -s $COMPLIANCE_SOURCEREGEX_LOC ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_SOURCEREGEX [$COMPLIANCE_SOURCEREGEX_LOC] does not exist or is zero-sized! Skipping..."
					(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
					continue
				fi
			fi
		fi

		if [ ${#COMPLIANCE_TARGETOBJNAME} -gt 0 ] && [ $COMPLIANCE_TARGETOBJNAME == "OBJNAME" ]
		then
			if [ ${#COMPLIANCE_TARGETREGEX} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_TARGETOBJNAME is set to [OBJNAME], but COMPLIANCE_TARGETREGEX is empty/null! Skipping..."
				(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
				continue
			else
				if [[ ! $COMPLIANCE_TARGETREGEX =~ ^/ ]]
				then
					local COMPLIANCE_TARGETREGEX=$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_TARGETREGEX
				fi

				local COMPLIANCE_TARGETREGEX_LOC=$(echo "$COMPLIANCE_TARGETREGEX" | $AWK '{ print $1 }')

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_TARGETREGEX_LOC = [$COMPLIANCE_TARGETREGEX_LOC]"
				fi

				if [ ! -s $COMPLIANCE_TARGETREGEX_LOC ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_TARGETREGEX [$COMPLIANCE_TARGETREGEX_LOC] does not exist or is zero-sized! Skipping..."
					(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
					continue
				fi
			fi
		fi

		if [ ${#COMPLIANCE_COMPLIANCESCRIPT} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_COMPLIANCESCRIPT is empty/null! Skipping..."
			(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
			continue
		else
			if [[ ! $COMPLIANCE_COMPLIANCESCRIPT =~ ^/ ]]
			then
				local COMPLIANCE_COMPLIANCESCRIPT=$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_COMPLIANCESCRIPT
			fi

			if [ ! -s $COMPLIANCE_COMPLIANCESCRIPT ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_COMPLIANCESCRIPT [$COMPLIANCE_COMPLIANCESCRIPT] does not exist or is zero-sized! Skipping..."
				(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
				continue
			fi
		fi

		if [ ${#COMPLIANCE_EXCLSCRIPT} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_EXCLSCRIPT is empty/null! Skipping..."
			(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
			continue
		else
			if [[ ! $COMPLIANCE_EXCLSCRIPT =~ ^0$ ]] && [[ ! $COMPLIANCE_EXCLSCRIPT =~ ^1$ ]]
			then
				if [[ ! $COMPLIANCE_EXCLSCRIPT =~ ^/ ]]
				then
					local COMPLIANCE_EXCLSCRIPT=$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_EXCLSCRIPT
				fi
	
				if [ ! -s $COMPLIANCE_EXCLSCRIPT ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_EXCLSCRIPT [$COMPLIANCE_EXCLSCRIPT] does not exist or is zero-sized! Skipping..."
					(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
					continue
				fi
			fi
		fi

		if [ ${#COMPLIANCE_ACTIONSCRIPT} -gt 0 ]
		then
			if [ ${#COMPLIANCE_ACTIONWHEN} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_ACTIONSCRIPT [$COMPLIANCE_ACTIONSCRIPT] is set, but COMPLIANCE_ACTIONWHEN is empty/null! Skipping..."
				(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
				continue
			else
				if [[ ! ${COMPLIANCE_ACTIONWHEN} =~ ^0$ ]] && [[ ! ${COMPLIANCE_ACTIONWHEN} =~ ^1$ ]]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_ACTIONWHEN [$COMPLIANCE_ACTIONWHEN] is invalid! Must be 0 (successful) or 1 (failed)! Skipping..."
					(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
					continue
				else
					if [[ $COMPLIANCE_ACTIONSCRIPT =~ ^/ ]]
					then
						if [ ! -s $COMPLIANCE_ACTIONSCRIPT ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_ACTIONSCRIPT [$COMPLIANCE_ACTIONSCRIPT] does not exist or is zero-sized! Skipping..."
							(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
							continue
						fi
					else
						if [ ! -s $COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_ACTIONSCRIPT ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_ACTIONSCRIPT [$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_ACTIONSCRIPT] does not exist or is zero-sized! Skipping..."
							(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
							continue
						fi
					fi
				fi
			fi
		fi

		if [ $COMPLIANCE_INPUTTAG != "ALL" ]
		then
			local TAG_MATCHED="false"

			IFS=$OLDIFS
			local PROC_COMPLIANCE_INPUTTAG=$(echo "$COMPLIANCE_INPUTTAG" | sed 's/,/ /g')

			for C_TAG in $(echo "$PROC_COMPLIANCE_INPUTTAG")
			do
				# echo "C_TAG = $C_TAG"
				# echo "COMPLIANCE_TAG = $COMPLIANCE_TAG"

				if [ $COMPLIANCE_TAG == "$C_TAG" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_TAG [$COMPLIANCE_TAG] matches tag [$C_TAG] in COMPLIANCE_INPUTTAG[$COMPLIANCE_INPUTTAG]..." 
					local TAG_MATCHED="true"
					break
				fi
			done
			IFS=$'\n'

			if [ $TAG_MATCHED == "false" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] COMPLIANCE_TAG does not match COMPLIANCE_INPUTTAG[$COMPLIANCE_INPUTTAG]. Skipping config line [$CFGLINE]..."
				(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
				continue
			fi
		fi

		if [ ${#COMPLIANCE_EXCLSCRIPT} -gt 0 ] && [[ "$COMPLIANCE_EXCLSCRIPT" =~ ^[01]$ ]] && [ $COMPLIANCE_EXCLSCRIPT -eq 1 ]
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT is set to [$COMPLIANCE_EXCLSCRIPT]. Skipping config line [$CFGLINE]..."
			fi

			(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
			continue
		else
			if [ ${#COMPLIANCE_EXCLSCRIPT} -gt 0 ] && [[ "$COMPLIANCE_EXCLSCRIPT" =~ ^[01]$ ]] && [ $COMPLIANCE_EXCLSCRIPT -eq 0 ]
			then
				local TO_EXCL="false"
			else	
				# EXCLSCRIPT is defined, to execute after SOURCE/TARGET object lists are available
				local TO_EXCL="false"
 			fi

			if [ $TO_EXCL == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT returned [$EXCLSCRIPT_RESULT]. Skipping config line [$CFGLINE]..."
				(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
				continue
			else
				if [ ${#COMPLIANCE_SOURCENS} -gt 0 ]
				then
					local SOURCENS_MATCHOBJ_ARR=()
					local TARGETNS_MATCHOBJ_ARR=()

					if [[ $COMPLIANCE_SOURCENS =~ ^NS4PROD= ]]
					then
						# Namespace auto-expansion
						local NS4PROC="true"
						local PROD_NAME=$(echo "$COMPLIANCE_SOURCENS" | $AWK -F= '{ print $2 }')

						echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Attempting to retrieve namespace for product [$PROD_NAME]..."
						local TO_GET_SOURCENS_LIST="true"
				
						if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "false" ] && [ $BASH_V4 == "true" ]
						then
							if [ ${#LOCAL_PROD_TO_NS_CACHE[@]} -gt 0 ] && [ ${LOCAL_PROD_TO_NS_CACHE[$PROD_NAME]+_} ]
							then
								local SOURCENS_LIST=${LOCAL_PROD_TO_NS_CACHE[$PROD_NAME]}
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] SOURCENS_LIST retrieved from local cache = [$SOURCENS_LIST]"

								local TO_GET_SOURCENS_LIST="false"
							fi
						fi
		
						if [ $TO_GET_SOURCENS_LIST == "true" ]
						then
							if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
							then
								local SOURCENS_LIST=$(getProdToNamespacesMapping $PROD_NAME)
							else
								local SOURCENS_LIST=$(getProdToNamespacesMapping $PROD_NAME "$COMPLIANCE_PROD_GROUP_NS_REFFILE")
							fi
	
							if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "false" ] && [ $BASH_V4 == "true" ]
							then
								if [ ! ${LOCAL_PROD_TO_NS_CACHE[$PROD_NAME]+_} ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Adding value [$SOURCENS_LIST] into LOCAL_PROD_TO_NS_CACHE[$PROD_NAME]..."
									local LOCAL_PROD_TO_NS_CACHE[$PROD_NAME]="$SOURCENS_LIST"
								fi
							fi
						fi

						echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Namespace retrieved for product [$PROD_NAME] = [$SOURCENS_LIST]"
		
						if [ "$SOURCENS_LIST" == $PROD_NAMESPACES_INVALID_STR ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Unable to determine namespace! Skipping..."
							(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
							continue
						fi
					else
						if [[ $COMPLIANCE_SOURCENS =~ ^bash ]]
						then
							# To execute namespace script
							local COMPLIANCE_NSCMD=$(echo "$COMPLIANCE_SOURCENS" | $AWK '{ $1=""; print }' | sed 's/^[ ]*//')
							local COMPLIANCE_FULL_NSCMD="$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_NSCMD"
							local COMPLIANCE_NSSCRIPT=$COMPLIANCE_SCRIPT_DIR/$(echo "$COMPLIANCE_NSCMD" | $AWK '{ print $1 }')

							if [ $MG_DEBUG == "true" ]
							then
								cp -p $COMPLIANCE_NSSCRIPT $COMPLIANCE_DEBUGDIR
							fi

							if [ -s $COMPLIANCE_NSSCRIPT ]
							then
								if [ ${#TIMEOUT} -gt 0 ]
								then
									local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $COMPLIANCE_FULL_NSCMD"	
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing namespace script [$CMD]..."
									SOURCENS_LIST=$(eval "$CMD")
									C_EXITSTATUS=$?
				
									if [ $C_EXITSTATUS -eq 124 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Namespace script [$COMPLIANCE_NSSCRIPT] timeout after $DEFAULT_TIMEOUT! Skipping..."
										(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
										continue
									else	
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Namespace script file [$COMPLIANCE_NSSCRIPT] exits with status [$C_EXITSTATUS]"
										fi
									fi
								else
									local CMD="/bin/bash $COMPLIANCE_NSCMD"	
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing namespace script [$CMD]..."
									SOURCENS_LIST=$(eval "$CMD")
									C_EXITSTATUS=$?

									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Namespace script file [$COMPLIANCE_NSSCRIPT] exits with status [$C_EXITSTATUS]"
									fi
								fi

								if [ ${#SOURCENS_LIST} -gt 0 ]
								then
									if [ "$SOURCENS_LIST" == $PROD_NAMESPACES_INVALID_STR ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Unable to determine namespace! Skipping..."
										(( SKIP_CFGLINE=SKIPCFGLINE+1 ))
										continue
									fi

									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Namespace script file [$COMPLIANCE_NSSCRIPT] produced output = [$SOURCENS_LIST]"
								else
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Unable to determine namespace! Skipping..."
									(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
									continue
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Namespace script [$COMPLIANCE_NSSCRIPT] does not exists or is zero-sized! Skipping config line [$CFGLINE]..."
								(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
								continue
							fi
						else
							# Hardcoded namespace
							local SOURCENS_LIST=$COMPLIANCE_SOURCENS	
						fi
					fi

					if [ ${#COMPLIANCE_SOURCEOBJTYPE} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] SOURCEOBJTYPE is null! Skipping..."
						(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
						continue
					else
						# To retrieve object list based on SOURCENS and SOURCEOBJTYPE
						IFS=$OLDIFS
						for SOURCENS in $SOURCENS_LIST	
						do
							if toExcludeProdNamespace $SOURCENS
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] To exclude namespace [$SOURCENS]! Skipping..."
								continue
							fi

							local TMP_OBJ_OUTFILE=$COMPLIANCE_WORKDIR/$COMPLIANCE_TAG~$SOURCENS~$COMPLIANCE_SOURCEOBJTYPE~$$.tmp

							if [ $SOURCENS == "ALLNS" ]
							then
								local IS_NAMESPACED	
								IS_NAMESPACED=$(isNamespaced "$COMPLIANCE_SOURCEOBJTYPE")
								COMPLIANCE_OJBTYPE_EXITCODE=$?

								if [ $COMPLIANCE_OJBTYPE_EXITCODE -eq 0 ]	
								then
									if ! checkUserPriv get,list $COMPLIANCE_SOURCEOBJTYPE all
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] User [$OC_WHOAMI] does not have privilege to perform [get,list] on resource [$COMPLIANCE_SOURCEOBJTYPE] at cluster scope. Skipping config line [$CFGLINE]..."
										continue	
									fi

									if [ $IS_NAMESPACED -eq 0 ]
									then
										local NS_CMD="-A"
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] SOURCE object type [$COMPLIANCE_SOURCEOBJTYPE] is namespace scoped! Setting NS_CMD to [$NS_CMD]..."
									else
										local NS_CMD=""
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] SOURCE object type [$COMPLIANCE_SOURCEOBJTYPE] is cluster scoped! Setting NS_CMD to null..."
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Failed to determine whether COMPLIANCE_SOURCEOBJTYPE [$COMPLIANCE_SOURCEOBJTYPE] is namespace/cluster scope! Skipping config line [$CFGLINE]..."
									(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
									continue	
								fi
							else
								if ! checkUserPriv get,list $COMPLIANCE_SOURCEOBJTYPE $SOURCENS
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] User [$OC_WHOAMI] does not have privilege to perform [get,list] on resource [$COMPLIANCE_SOURCEOBJTYPE] in namespace [$SOURCENS]. Skipping config line [$CFGLINE]..."
									continue	
								fi

								local NS_CMD="-n $SOURCENS"
							fi	

							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing '$OC_CMD get $COMPLIANCE_SOURCEOBJTYPE --template '{{range .items}}{{.metadata.namespace}}{{\""'/'"\"}}{{\"$COMPLIANCE_SOURCEOBJTYPE\"}}{{\""'/'"\"}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $NS_CMD' => $TMP_OBJ_OUTFILE" 
							local OC_GET_CMD="$OC_CMD get $COMPLIANCE_SOURCEOBJTYPE --template '{{range .items}}{{.metadata.namespace}}{{\"/\"}}{{\"$COMPLIANCE_SOURCEOBJTYPE\"}}{{\"/\"}}{{.metadata.name}}{{\"\n\"}}{{end}}' $NS_CMD"
							eval "$OC_GET_CMD" > $TMP_OBJ_OUTFILE 

							if [ -s $TMP_OBJ_OUTFILE ]
							then
								if [ ${#COMPLIANCE_SOURCEOBJNAME} -gt 0 ] && [ $COMPLIANCE_SOURCEOBJNAME == "OBJNAME" ]
								then
									if [ ${#TIMEOUT} -gt 0 ]
									then
										local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $COMPLIANCE_SOURCEREGEX $SOURCENS"	
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing regex script [$CMD]..."
										COMPLIANCE_SOURCEOBJNAME=$(eval "$CMD")
										C_EXITSTATUS=$?
					
										if [ $C_EXITSTATUS -eq 124 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Regex script [$COMPLIANCE_SOURCEREGEX] timeout after $DEFAULT_TIMEOUT! Skipping..."
											(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
											continue
										else	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Regex script file [$COMPLIANCE_SOURCEREGEX] exits with status [$C_EXITSTATUS]"
											fi
										fi
									else
										local CMD="/bin/bash $COMPLIANCE_SOURCEREGEX $SOURCENS"	
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing regex script [$CMD]..."
										COMPLIANCE_SOURCEOBJNAME=$(eval "$CMD")
										C_EXITSTATUS=$?
	
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Regex script file [$COMPLIANCE_SOURCEREGEX] exits with status [$C_EXITSTATUS]"
										fi
									fi
								fi

								if [ ${#COMPLIANCE_SOURCEOBJNAME} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Matching regex [$COMPLIANCE_SOURCEOBJNAME] against object outfile [$TMP_OBJ_OUTFILE]..."	
									# local MATCH=$($AWK -F/ '$3 ~ /'$COMPLIANCE_SOURCEOBJNAME'/ { print }' $TMP_OBJ_OUTFILE | tr '\n' ' ' | sed 's/[ ]$//' | sed 's/<no value>//g')
									local MATCH=$($AWK -F/ '$3 ~ /'$COMPLIANCE_SOURCEOBJNAME'/ { print }' $TMP_OBJ_OUTFILE | sed 's/[ ]$//' | sed 's/<no value>//g')
								else
									local MATCH=$(cat $TMP_OBJ_OUTFILE | sed 's/<no value>//g' | sort)
								fi

								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] MATCH = [$MATCH]"
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] File [$TMP_OBJ_OUTFILE] is unavailable. Skipping config line [$CFGLINE]..."	
								(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
								continue
							fi

							for STR_MATCH in $MATCH
							do
								local SOURCENS_MATCHOBJ=$(echo "$STR_MATCH")
									
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Adding matched object [$SOURCENS_MATCHOBJ] into array SOURCENS_MATCHOBJ_ARR..."
								SOURCENS_MATCHOBJ_ARR[${#SOURCENS_MATCHOBJ_ARR[@]}]=$SOURCENS_MATCHOBJ
							done

							# echo ${SOURCENS_MATCHOBJ_ARR[@]}
						done
						IFS=$'\n'
					fi

					if [ ${#SOURCENS_MATCHOBJ_ARR[@]} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] No object SOURCE object matched. Skipping config line [$CFGLINE]..."
						(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
						continue
					fi

					if [ ${#COMPLIANCE_TARGETNS} -gt 0 ]
					then
						if [[ $COMPLIANCE_TARGETNS =~ ^NS4PROD= ]]
						then
							# Namespace auto-expansion
							local NS4PROC="true"
							local PROD_NAME=$(echo "$COMPLIANCE_TARGETNS" | $AWK -F= '{ print $2 }')
			
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Attempting to retrieve namespace for product [$PROD_NAME]..."

							if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
							then
								local TARGETNS_LIST=$(getProdToNamespacesMapping $PROD_NAME)
							else
								local TARGETNS_LIST=$(getProdToNamespacesMapping $PROD_NAME "$COMPLIANCE_PROD_GROUP_NS_REFFILE")
							fi

							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Namespace retrieved for product [$PROD_NAME] = [$TARGETNS_LIST]"
			
							if [ "$TARGETNS_LIST" == $PROD_NAMESPACES_INVALID_STR ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Unable to determine namespace! Skipping..."
								(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
								continue
							fi
						else
							if [[ $COMPLIANCE_TARGETNS =~ ^bash ]]
							then
								# To execute namespace script
								local COMPLIANCE_NSCMD=$(echo "$COMPLIANCE_TARGETNS" | $AWK '{ $1=""; print }' | sed 's/^[ ]*//')
								local COMPLIANCE_FULL_NSCMD="$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_NSCMD"
								local COMPLIANCE_NSSCRIPT=$COMPLIANCE_SCRIPT_DIR/$(echo "$COMPLIANCE_NSCMD" | $AWK '{ print $1 }')
	
								if [ $MG_DEBUG == "true" ]
								then
									cp -p $COMPLIANCE_NSSCRIPT $COMPLIANCE_DEBUGDIR
								fi

								if [ -s $COMPLIANCE_NSSCRIPT ]
								then
									if [ ${#TIMEOUT} -gt 0 ]
									then
										local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $COMPLIANCE_FULL_NSCMD"	
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing namespace script [$CMD]..."
										TARGETNS_LIST=$(eval "$CMD")
										C_EXITSTATUS=$?
					
										if [ $C_EXITSTATUS -eq 124 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Namespace script [$COMPLIANCE_NSSCRIPT] timeout after $DEFAULT_TIMEOUT! Skipping..."
											(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
											continue
										else	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Namespace script file [$COMPLIANCE_NSSCRIPT] exits with status [$C_EXITSTATUS]"
											fi
										fi
									else
										local CMD="/bin/bash $COMPLIANCE_NSCMD"	
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing namespace script [$CMD]..."
										TARGETNS_LIST=$(eval "$CMD")
										C_EXITSTATUS=$?
	
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Namespace script file [$COMPLIANCE_NSSCRIPT] exits with status [$C_EXITSTATUS]"
										fi
									fi
	
									if [ ${#TARGETNS_LIST} -gt 0 ]
									then
										if [ "$TARGETNS_LIST" == $PROD_NAMESPACES_INVALID_STR ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Unable to determine namespace! Skipping..."
											(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
											continue
										fi
	
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Namespace script file [$COMPLIANCE_NSSCRIPT] produced output = [$TARGETNS_LIST]"
									else
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Unable to determine namespace! Skipping..."
										(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
										continue
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Namespace script [$COMPLIANCE_NSSCRIPT] does not exists or is zero-sized! Skipping config line [$CFGLINE]..."
									(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
									continue
								fi
							else
								# Hardcoded namespace
								local TARGETNS_LIST=$COMPLIANCE_TARGETNS	
							fi
						fi

						if [ ${#COMPLIANCE_TARGETOBJTYPE} -eq 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] TARGETOBJTYPE is null! Skipping..."
							(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
							continue
						else
							# To retrieve object list based on TARGETNS and TARGETOBJTYPE
							IFS=$OLDIFS
							for TARGETNS in $TARGETNS_LIST	
							do
								if toExcludeProdNamespace $TARGETNS
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] To exclude namespace [$TARGETNS]! Skipping..."
									continue
								fi

								local TMP_OBJ_OUTFILE=$COMPLIANCE_WORKDIR/$COMPLIANCE_TAG~$TARGETNS~$COMPLIANCE_TARGETOBJTYPE~$$.tmp
	
								if [ $TARGETNS == "ALLNS" ]
								then
									local IS_NAMESPACED	
									IS_NAMESPACED=$(isNamespaced "$COMPLIANCE_TARGETOBJTYPE")
									COMPLIANCE_OJBTYPE_EXITCODE=$?
	
									if [ $COMPLIANCE_OJBTYPE_EXITCODE -eq 0 ]	
									then
										if ! checkUserPriv get,list $COMPLIANCE_TARGETOBJTYPE all
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] User [$OC_WHOAMI] does not have privilege to perform [get,list] on resource [$COMPLIANCE_TARGETOBJTYPE] at cluster scope. Skipping config line [$CFGLINE]..."
											continue	
										fi
	
										if [ $IS_NAMESPACED -eq 0 ]
										then
											local NS_CMD="-A"
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] SOURCE object type [$COMPLIANCE_TARGETOBJTYPE] is namespace scoped! Setting NS_CMD to [$NS_CMD]..."
										else
											local NS_CMD=""
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] SOURCE object type [$COMPLIANCE_TARGETOBJTYPE] is cluster scoped! Setting NS_CMD to null..."
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Failed to determine whether COMPLIANCE_TARGETOBJTYPE [$COMPLIANCE_TARGETOBJTYPE] is namespace/cluster scope! Skipping config line [$CFGLINE]..."
										(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
										continue	
									fi
								else
									if ! checkUserPriv get,list $COMPLIANCE_TARGETOBJTYPE $TARGETNS
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] User [$OC_WHOAMI] does not have privilege to perform [get,list] on resource [$COMPLIANCE_TARGETOBJTYPE] in namespace [$TARGETNS]. Skipping config line [$CFGLINE]..."
										continue	
									fi

									local NS_CMD="-n $TARGETNS"
								fi	

								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing '$OC_CMD get $COMPLIANCE_TARGETOBJTYPE --template '{{range .items}}{{.metadata.namespace}}{{\""'/'"\"}}{{\"$COMPLIANCE_TARGETOBJTYPE\"}}{{\""'/'"\"}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $NS_CMD' => $TMP_OBJ_OUTFILE" 
								local OC_GET_CMD="$OC_CMD get $COMPLIANCE_TARGETOBJTYPE --template '{{range .items}}{{.metadata.namespace}}{{\"/\"}}{{\"$COMPLIANCE_TARGETOBJTYPE\"}}{{\"/\"}}{{.metadata.name}}{{\"\n\"}}{{end}}' $NS_CMD"
								eval "$OC_GET_CMD" > $TMP_OBJ_OUTFILE 
	
								if [ -s $TMP_OBJ_OUTFILE ]
								then
									if [ ${#COMPLIANCE_TARGETOBJNAME} -gt 0 ] && [ $COMPLIANCE_TARGETOBJNAME == "OBJNAME" ]
									then
										if [ ${#TIMEOUT} -gt 0 ]
										then
											local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $COMPLIANCE_TARGETREGEX $TARGETNS"	
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing regex script [$CMD]..."
											COMPLIANCE_TARGETOBJNAME=$(eval "$CMD")
											C_EXITSTATUS=$?
						
											if [ $C_EXITSTATUS -eq 124 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] [CFGLINE = $CFGLINE] Regex script [$COMPLIANCE_TARGETREGEX] timeout after $DEFAULT_TIMEOUT! Skipping..."
												(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
												continue
											else	
												if [ $MG_DEBUG == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Regex script file [$COMPLIANCE_TARGETREGEX] exits with status [$C_EXITSTATUS]"
												fi
											fi
										else
											local CMD="/bin/bash $COMPLIANCE_TARGETREGEX $TARGETNS"	
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing regex script [$CMD]..."
											COMPLIANCE_TARGETOBJNAME=$(eval "$CMD")
											C_EXITSTATUS=$?
		
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Regex script file [$COMPLIANCE_TARGETREGEX] exits with status [$C_EXITSTATUS]"
											fi
										fi
									fi

									if [ ${#COMPLIANCE_TARGETOBJNAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Matching regex [$COMPLIANCE_TARGETOBJNAME] against object outfile [$TMP_OBJ_OUTFILE]..."	
										# local MATCH=$($AWK -F/ '$3 ~ /'$COMPLIANCE_TARGETOBJNAME'/ { print }' $TMP_OBJ_OUTFILE | tr '\n' ' ' | sed 's/[ ]$//' | sed 's/<no value>//g')
										local MATCH=$($AWK -F/ '$3 ~ /'$COMPLIANCE_TARGETOBJNAME'/ { print }' $TMP_OBJ_OUTFILE | sed 's/[ ]$//' | sed 's/<no value>//g')
									else
										local MATCH=$(cat $TMP_OBJ_OUTFILE | sed 's/<no value>//g' | sort)
									fi
		
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] MATCH = [$MATCH]"
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] File [$TMP_OBJ_OUTFILE] is unavailable. Skipping config line [$CFGLINE]..."	
									(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
									continue
								fi
	
								for STR_MATCH in $MATCH
								do
									local TARGETNS_MATCHOBJ=$(echo "$STR_MATCH")
										
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Adding matched object [$TARGETNS_MATCHOBJ] into array TARGETNS_MATCHOBJ_ARR..."
									TARGETNS_MATCHOBJ_ARR[${#TARGETNS_MATCHOBJ_ARR[@]}]=$TARGETNS_MATCHOBJ
								done
	
								# echo ${TARGETNS_MATCHOBJ_ARR[@]}
							done
							IFS=$'\n'
						fi

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] SOURCENS_MATCHOBJ_ARR = [${#SOURCENS_MATCHOBJ_ARR[@]}] / TARGETNS_MATCHOBJ_ARR = [${#TARGETNS_MATCHOBJ_ARR[@]}]"
						fi
	
						# Combine SOURCENS_MATCHOBJ_ARR and TARGETNS_MATCHOBJ_ARR
						if [ ${#TARGETNS_MATCHOBJ_ARR[@]} -eq 0 ]
						then
							if [ $COMPLIANCE_PREPROC -eq 0 ]
							then
								for STR in ${SOURCENS_MATCHOBJ_ARR[@]}
								do
									local C_NEWLINE="$COMPLIANCE_TAG$COMPLIANCE_CFGFILE_DELIMITER$STR$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_COMPLIANCESCRIPT$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONWHEN$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONSCRIPT"

									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Writing new config line [$C_NEWLINE] to work file [$COMPLIANCE_PROCFILE_TMP]..."
									fi

									echo "$C_NEWLINE" >> $COMPLIANCE_PROCFILE_TMP
								done
							else
								local FINAL_STR=""
					
								for STR in ${SOURCENS_MATCHOBJ_ARR[@]}
								do
									if [ ${#FINAL_STR} -eq 0 ]
									then
										FINAL_STR="$STR"
									else
										FINAL_STR="$FINAL_STR,$STR"
									fi
								done

								local C_NEWLINE="$COMPLIANCE_TAG$COMPLIANCE_CFGFILE_DELIMITER$FINAL_STR$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_COMPLIANCESCRIPT$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONWHEN$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONSCRIPT"

								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Writing new config line [$C_NEWLINE] to work file [$COMPLIANCE_PROCFILE_TMP]..."
								fi

								echo "$C_NEWLINE" >> $COMPLIANCE_PROCFILE_TMP
							fi
						else
							if [ $COMPLIANCE_PREPROC -eq 0 ]
							then
								for STR1 in ${SOURCENS_MATCHOBJ_ARR[@]}
								do
									for STR2 in ${TARGETNS_MATCHOBJ_ARR[@]}	
									do
										local C_NEWLINE="$COMPLIANCE_TAG$COMPLIANCE_CFGFILE_DELIMITER$STR1$COMPLIANCE_CFGFILE_DELIMITER$STR2$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_COMPLIANCESCRIPT$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONWHEN$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONSCRIPT"

										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Writing new config line [$C_NEWLINE] to work file [$COMPLIANCE_PROCFILE_TMP]..."
										fi

										echo "$C_NEWLINE" >> $COMPLIANCE_PROCFILE_TMP
									done
								done
							else
								local FINAL_STR1=""
								local FINAL_STR2=""
					
								for STR1 in ${SOURCENS_MATCHOBJ_ARR[@]}
								do
									if [ ${#FINAL_STR1} -eq 0 ]
									then
										FINAL_STR1="$STR1"
									else
										FINAL_STR1="$FINAL_STR1,$STR1"
									fi
								done

								for STR2 in ${TARGETNS_MATCHOBJ_ARR[@]}	
								do
									if [ ${#FINAL_STR2} -eq 0 ]
									then
										FINAL_STR2="$STR2"
									else
										FINAL_STR2="$FINAL_STR2,$STR2"
									fi
								done

								local C_NEWLINE="$COMPLIANCE_TAG$COMPLIANCE_CFGFILE_DELIMITER$FINAL_STR1$COMPLIANCE_CFGFILE_DELIMITER$FINAL_STR2$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_COMPLIANCESCRIPT$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONWHEN$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONSCRIPT"

								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Writing new config line [$C_NEWLINE] to work file [$COMPLIANCE_PROCFILE_TMP]..."
								fi

								echo "$C_NEWLINE" >> $COMPLIANCE_PROCFILE_TMP
							fi
						fi	

						(( PROC_CFGLINE=PROC_CFGLINE+1 ))

						if [ ${#COMPLIANCE_EXCLSCRIPT} -gt 0 ] && [ $COMPLIANCE_EXCLSCRIPT != "0" ]
						then
							# To execute EXCLSCRIPT
							local EXCLSCRIPT=$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_EXCLSCRIPT			
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT = [$EXCLSCRIPT]"

							# Create SOURCE and TARGET object lists
							local S_OBJ=
							local S_OBJ_LIST=
							local T_OBJ=
							local T_OBJ_LIST=

							for S_OBJ in ${SOURCENS_MATCHOBJ_ARR[@]} 
							do
								if [ ${#S_OBJ_LIST} -eq 0 ]
								then
									local S_OBJ_LIST="$S_OBJ"
								else
									local S_OBJ_LIST="$S_OBJ_LIST,$S_OBJ"
								fi
							done
				
							for T_OBJ in ${TARGETNS_MATCHOBJ_ARR[@]} 
							do
								if [ ${#T_OBJ_LIST} -eq 0 ]
								then
									local T_OBJ_LIST="$T_OBJ"
								else
									local T_OBJ_LIST="$T_OBJ_LIST,$T_OBJ"
								fi
							done
				
							if [ -s $EXCLSCRIPT ]
							then
								# Backup script
								if [ $MG_DEBUG == "true" ]
								then
									cp -p $EXCLSCRIPT $COMPLIANCE_DEBUGDIR
								fi

								if [ ${#TIMEOUT} -gt 0 ]
								then
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing exclude script file [$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXCLSCRIPT]..."
									fi
						
									local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXCLSCRIPT \"$S_OBJ_LIST\" \"$T_OBJ_LIST\""
									EXCLSCRIPT_RESULT=$(eval "$CMD")
									EXCLSCRIPT_EXITSTATUS=$?
										
									if [ $EXCLSCRIPT_EXITSTATUS -eq 124 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script file [$EXCLSCRIPT] timeout after $DEFAULT_TIMEOUT ! Skipping config line [$CFGLINE]..."
										(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
										continue
									else
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script file [$EXCLSCRIPT] exits with status [$EXCLSCRIPT_EXITSTATUS]"
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT_RESULT = [$EXCLSCRIPT_RESULT]"
										fi
									fi
								else
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing exclude script file [/bin/bash $EXCLSCRIPT]..."
									fi
						
									local CMD="/bin/bash $EXCLSCRIPT  \"$S_OBJ_LIST\" \"$T_OBJ_LIST\""
									local EXCLSCRIPT_RESULT=$(eval "$CMD")
				
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script file [$EXCLSCRIPT] exits with status [$?]"
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT_RESULT = [$EXCLSCRIPT_RESULT]"
									fi
								fi
				
								if [ $EXCLSCRIPT_RESULT -eq 0 ]
								then
									local TO_EXCL="false"
								else
									local TO_EXCL="true"
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script [$EXCLSCRIPT] does not exists or is zero-sized!"
								local TO_EXCL="true"
							fi
						else
							local TO_EXCL="false"
						fi

						if [ $TO_EXCL == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Skipping config line [$CFGLINE]..."
							(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
							continue
						else
							if [ -s $COMPLIANCE_PROCFILE_TMP ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Writing compliance workfile [$COMPLIANCE_PROCFILE_TMP] to processed file [$COMPLIANCE_PROCFILE]..."
								(( NEW_CFGLINE=NEW_CFGLINE+1 ))
								cat $COMPLIANCE_PROCFILE_TMP >> $COMPLIANCE_PROCFILE
							else
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Compliance output workfile [$COMPLIANCE_PROCFILE_TMP] does not exists or is zero-sized!"
								(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
								continue
							fi
						fi
					else
						# TARGET details is not set. Proceed to create COMPLIANCE_PROCFILE
						(( PROC_CFGLINE=PROC_CFGLINE+1 ))

						if [ $COMPLIANCE_PREPROC -eq 0 ]
						then
							for STR in ${SOURCENS_MATCHOBJ_ARR[@]}
							do
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Writing new config line [$STR] to work file [$COMPLIANCE_PROCFILE_TMP]..."
								fi
	
								echo "$COMPLIANCE_TAG$COMPLIANCE_CFGFILE_DELIMITER$STR$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_COMPLIANCESCRIPT$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONWHEN$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONSCRIPT" >> $COMPLIANCE_PROCFILE_TMP
							done
						else
							local FINAL_STR=""
				
							for STR in ${SOURCENS_MATCHOBJ_ARR[@]}
							do
								if [ ${#FINAL_STR} -eq 0 ]
								then
									FINAL_STR="$STR"
								else
									FINAL_STR="$FINAL_STR,$STR"
								fi
							done

							local C_NEWLINE="$COMPLIANCE_TAG$COMPLIANCE_CFGFILE_DELIMITER$FINAL_STR$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_COMPLIANCESCRIPT$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONWHEN$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONSCRIPT"

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Writing new config line [$C_NEWLINE] to work file [$COMPLIANCE_PROCFILE_TMP]..."
							fi

							echo "$C_NEWLINE" >> $COMPLIANCE_PROCFILE_TMP
						fi

						if [ ${#COMPLIANCE_EXCLSCRIPT} -gt 0 ] && [ $COMPLIANCE_EXCLSCRIPT != "0" ]
						then
							# To execute EXCLSCRIPT
							local EXCLSCRIPT=$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_EXCLSCRIPT			
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT = [$EXCLSCRIPT]"
				
							# Create SOURCE and TARGET object lists
							local S_OBJ=
							local S_OBJ_LIST=
							local T_OBJ=
							local T_OBJ_LIST=

							for S_OBJ in ${SOURCENS_MATCHOBJ_ARR[@]} 
							do
								if [ ${#S_OBJ_LIST} -eq 0 ]
								then
									local S_OBJ_LIST="$S_OBJ"
								else
									local S_OBJ_LIST="$S_OBJ_LIST,$S_OBJ"
								fi
							done
				
							for T_OBJ in ${TARGETNS_MATCHOBJ_ARR[@]} 
							do
								if [ ${#T_OBJ_LIST} -eq 0 ]
								then
									local T_OBJ_LIST="$T_OBJ"
								else
									local T_OBJ_LIST="$T_OBJ_LIST,$T_OBJ"
								fi
							done
				
							if [ -s $EXCLSCRIPT ]
							then
								# Backup script
								if [ $MG_DEBUG == "true" ]
								then
									cp -p $EXCLSCRIPT $COMPLIANCE_DEBUGDIR
								fi

								if [ ${#TIMEOUT} -gt 0 ]
								then
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing exclude script file [$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXCLSCRIPT]..."
									fi
						
									local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXCLSCRIPT \"$S_OBJ_LIST\" \"$T_OBJ_LIST\""
									EXCLSCRIPT_RESULT=$(eval "$CMD")
									EXCLSCRIPT_EXITSTATUS=$?
										
									if [ $EXCLSCRIPT_EXITSTATUS -eq 124 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script file [$EXCLSCRIPT] timeout after $DEFAULT_TIMEOUT ! Skipping config line [$CFGLINE]..."
										(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
										continue
									else
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script file [$EXCLSCRIPT] exits with status [$EXCLSCRIPT_EXITSTATUS]"
											echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT_RESULT = [$EXCLSCRIPT_RESULT]"
										fi
									fi
								else
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing exclude script file [/bin/bash $EXCLSCRIPT]..."
									fi
						
									local CMD="/bin/bash $EXCLSCRIPT \"$S_OBJ_LIST\" \"$T_OBJ_LIST\""
									local EXCLSCRIPT_RESULT=$(eval "$CMD")
				
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script file [$EXCLSCRIPT] exits with status [$?]"
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT_RESULT = [$EXCLSCRIPT_RESULT]"
									fi
								fi
				
								if [ $EXCLSCRIPT_RESULT -eq 0 ]
								then
									local TO_EXCL="false"
								else
									local TO_EXCL="true"
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script [$EXCLSCRIPT] does not exists or is zero-sized!"
								local TO_EXCL="true"
							fi
						else
							local TO_EXCL="false"
						fi

						if [ $TO_EXCL == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Skipping config line [$CFGLINE]..."
							(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
							continue
						else
							if [ -s $COMPLIANCE_PROCFILE_TMP ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Writing compliance workfile [$COMPLIANCE_PROCFILE_TMP] to processed file [$COMPLIANCE_PROCFILE]..."
								cat $COMPLIANCE_PROCFILE_TMP >> $COMPLIANCE_PROCFILE
								(( NEW_CFGLINE=NEW_CFGLINE+1 ))
							else
								echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Compliance output workfile [$COMPLIANCE_PROCFILE_TMP] does not exists or is zero-sized!"
								(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
								continue
							fi
						fi
					fi
				else
					# No SOURCE object details (ignoring TARGET object too). Proceed to write processed config line.

					# To execute EXCLSCRIPT
					if [ ${#COMPLIANCE_EXCLSCRIPT} -gt 0 ] && [ $COMPLIANCE_EXCLSCRIPT != "0" ]
					then
						local EXCLSCRIPT=$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_EXCLSCRIPT			
						echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT = [$EXCLSCRIPT]"

						if [ -s $EXCLSCRIPT ]
						then
							# Backup script
							if [ $MG_DEBUG == "true" ]
							then
								cp -p $EXCLSCRIPT $COMPLIANCE_DEBUGDIR
							fi

							if [ ${#TIMEOUT} -gt 0 ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing exclude script file [$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXCLSCRIPT]..."
								fi
					
								local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXCLSCRIPT"
								EXCLSCRIPT_RESULT=$(eval "$CMD")
								EXCLSCRIPT_EXITSTATUS=$?
									
								if [ $EXCLSCRIPT_EXITSTATUS -eq 124 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script file [$EXCLSCRIPT] timeout after $DEFAULT_TIMEOUT ! Skipping config line [$CFGLINE]..."
									(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
									continue
								else
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script file [$EXCLSCRIPT] exits with status [$EXCLSCRIPT_EXITSTATUS]"
										echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT_RESULT = [$EXCLSCRIPT_RESULT]"
									fi
								fi
							else
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Executing exclude script file [/bin/bash $EXCLSCRIPT]..."
								fi
					
								local CMD="/bin/bash $EXCLSCRIPT"
								local EXCLSCRIPT_RESULT=$(eval "$CMD")
			
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script file [$EXCLSCRIPT] exits with status [$?]"
									echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] EXCLSCRIPT_RESULT = [$EXCLSCRIPT_RESULT]"
								fi
							fi
			
							if [ $EXCLSCRIPT_RESULT -eq 0 ]
							then
								local TO_EXCL="false"
							else
								local TO_EXCL="true"
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Exclude script [$EXCLSCRIPT] does not exists or is zero-sized!"
							local TO_EXCL="true"
						fi
					else
						local TO_EXCL="false"
					fi

					if [ $TO_EXCL == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Skipping config line [$CFGLINE]..."
						(( SKIP_CFGLINE=SKIP_CFGLINE+1 ))
						continue
					else
						local NEWLINE="$COMPLIANCE_TAG$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_COMPLIANCESCRIPT$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONWHEN$COMPLIANCE_CFGFILE_DELIMITER$COMPLIANCE_ACTIONSCRIPT"

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] SOURCENS is null. Ignoring SOURCE and TARGET details. Writing processed config line [$NEWLINE]..."
							echo "[$(date)] [${FUNCNAME[0]}] [$TOTAL_CFGLINE] Writing same config line [$NEWLINE] to processed file [$COMPLIANCE_PROCFILE]..."
						fi

						echo "$NEWLINE" >> $COMPLIANCE_PROCFILE
						(( SAME_CFGLINE=SAME_CFGLINE+1 ))
					fi
				fi
			fi	
		fi	
	done < $COMPLIANCE_WORKFILE

	echo "[$(date)] [${FUNCNAME[0]}] TOTAL_CONFIGLINE_READ = $TOTAL_CFGLINE [PROC = $PROC_CFGLINE / SAME = $SAME_CFGLINE]"
	echo "[$(date)] [${FUNCNAME[0]}] TOTAL_CONFIGLINE_SKIPPED = $SKIP_CFGLINE"
	# echo "[$(date)] [${FUNCNAME[0]}] TOTAL_CONFIGLINE_PROC = $PROC_CFGLINE"
	# echo "[$(date)] [${FUNCNAME[0]}] TOTAL_CONFIGLINE_SAME = $SAME_CFGLINE"
	# echo "[$(date)] [${FUNCNAME[0]}] TOTAL_CONFIGLINE_NEW = $NEW_CFGLINE"

	# Backup original compliance configuration file
	cp -p $COMPLIANCE_WORKFILE $COMPLIANCE_DEBUGDIR/$(basename ${COMPLIANCE_WORKFILE})

	# Unset 
	if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "false" ] && [ $BASH_V4 == "true" ]
	then
		unset LOCAL_PROD_TO_NS_CACHE
	fi

	if [ -s $COMPLIANCE_PROCFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] FINAL_CONFIGLINE = $(wc -l $COMPLIANCE_PROCFILE | $AWK '{ print $1 }')"
	else
		echo "[$(date)] [${FUNCNAME[0]}] FINAL_CONFIGLINE = 0"
		return 1
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [PRODGRP=$COMPLIANCE_PROD_GROUP / PRODVER=$COMPLIANCE_PROD_VER]"
	fi
}

doCompliance()
{
	if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
	then
		while read PROD_VER_LINE
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_VER_LINE = [$PROD_VER_LINE]"
			fi

			local COMPLIANCE_PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
			# local COMPLIANCE_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')

			if [ ${#RTVAR_COMPLIANCE_PRODVER} -gt 0 ]
			then
				local COMPLIANCE_PRODVER_VALID="false"
	
				for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
				do
					if [ $RTVAR_COMPLIANCE_PRODVER == $VALID_PROD_VERSION ]
					then
						local COMPLIANCE_PRODVER_VALID="true"
						break
					fi
				done	
	
				if [ $COMPLIANCE_PRODVER_VALID == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_PRODVER is set to [$RTVAR_COMPLIANCE_PRODVER]! Setting COMPLIANCE_PROD_VER to [$RTVAR_COMPLIANCE_PRODVER]!"
					local COMPLIANCE_PROD_VER=$RTVAR_COMPLIANCE_PRODVER
				else
					local COMPLIANCE_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
					echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_PRODVER [$RTVAR_COMPLIANCE_PRODVER] is invalid or not supported product version! Setting COMPLIANCE_PROD_VER to default [$COMPLIANCE_PROD_VER]!"
				fi
			else
				local COMPLIANCE_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
			fi

			local COMPLIANCE_PROD_GROUP_NS_REFFILE=${REFFILE_OUTDIR}/${COMPLIANCE_PROD_GROUP}.ns-ref

			if [ ${#COMPLIANCE_INPUTFILE} -gt 0 ]
			then
				if [ ${COMPLIANCE_INPUTFILE} == "custom" ]
				then
					local INPUT_FILE=$MUSTGATHER_DIRNAME/data/compliance/$COMPLIANCE_PROD_VER/config/compliance_custom.cfg
					local COMPLIANCE_SCRIPT_DIR=$MUSTGATHER_DIRNAME/data/compliance/$COMPLIANCE_PROD_VER/scripts

					if [ ! -s $INPUT_FILE ]
					then
						local INPUT_FILE=$MUSTGATHER_DIRNAME/data/compliance/config/compliance_custom.cfg
						local COMPLIANCE_SCRIPT_DIR=$MUSTGATHER_DIRNAME/data/compliance/scripts

						if [ ! -s $INPUT_FILE ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Unable to determine custom COMPLIANCE_INPUTFILE! Skipping..."
							continue
						fi
					fi

					echo "[$(date)] [${FUNCNAME[0]}] INPUT_FILE is overwritten with custom COMPLIANCE_INPUTFILE [$INPUT_FILE]..."
				else
					echo "[$(date)] [${FUNCNAME[0]}] INPUT_FILE is overwritten with user provided COMPLIANCE_INPUTFILE [$COMPLIANCE_INPUTFILE]..."
					local INPUT_FILE=$COMPLIANCE_INPUTFILE
					local COMPLIANCE_SCRIPT_DIR=$MUSTGATHER_DIRNAME/config/compliance/$COMPLIANCE_PROD_VER/scripts
				fi
			else
				if [ $COMPLIANCE_INPUTTAG == ".listcompliance_custom" ]
				then
					local INPUT_FILE=$MUSTGATHER_DIRNAME/data/compliance/$COMPLIANCE_PROD_VER/config/compliance_custom.cfg
					local COMPLIANCE_SCRIPT_DIR=$MUSTGATHER_DIRNAME/data/compliance/$COMPLIANCE_PROD_VER/scripts

					if [ ! -s $INPUT_FILE ]
					then
						local INPUT_FILE=$MUSTGATHER_DIRNAME/data/compliance/config/compliance_custom.cfg
						local COMPLIANCE_SCRIPT_DIR=$MUSTGATHER_DIRNAME/data/compliance/scripts
					fi
				else
					local INPUT_FILE=$MUSTGATHER_DIRNAME/config/compliance/$COMPLIANCE_PROD_VER/config/compliance.cfg
					local COMPLIANCE_SCRIPT_DIR=$MUSTGATHER_DIRNAME/config/compliance/$COMPLIANCE_PROD_VER/scripts
				fi
			fi
	
			if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
			then
				local PROC_INPUT_FILE=$COMPLIANCE_OUTDIR/$(basename ${INPUT_FILE}).proc
			else			
				local PROC_INPUT_FILE=$COMPLIANCE_OUTDIR/PRODGRP=$COMPLIANCE_PROD_GROUP/$(basename ${INPUT_FILE}).proc
			fi

			if [ -f ${COMPLIANCE_PROD_GROUP_NS_REFFILE} ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Calling function execCompliance() - [ INPUT_FILE=$INPUT_FILE ## PROC_INPUT_FILE=$PROC_INPUT_FILE ## COMPLIANCE_PROD_GROUP=$COMPLIANCE_PROD_GROUP ## COMPLIANCE_PROD_VER=$COMPLIANCE_PROD_VER ## COMPLIANCE_PROD_GROUP_NS_REFFILE=$COMPLIANCE_PROD_GROUP_NS_REFFILE] ## COMPLIANCE_SCRIPT_DIR=$COMPLIANCE_SCRIPT_DIR ]"
				execCompliance "$INPUT_FILE" "$PROC_INPUT_FILE" "$COMPLIANCE_PROD_GROUP" "$COMPLIANCE_PROD_VER" "$COMPLIANCE_PROD_GROUP_NS_REFFILE" "$COMPLIANCE_SCRIPT_DIR"
			else
				echo "[$(date)] [${FUNCNAME[0]}] Product group namespace reference file [${REFFILE}/${COMPLIANCE_PROD_GROUP}.ns-ref] does not exist or is zero-sized! Skipping..."
				continue
			fi
		done < $PROD_VERSIONS_REFFILE_FINAL
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product group namespace reference file [$PROD_VERSIONS_REFFILE_FINAL] does not exist or is zero-sized!"
		echo "[$(date)] [${FUNCNAME[0]}] Falling back to default 'non-product-group' execution..."

		local COMPLIANCE_PROD_GROUP="default"
		local COMPLIANCE_PROD_VER=$PRODUCT_VERSION
		local COMPLIANCE_PROD_GROUP_NS_REFFILE=$PROD_NAMESPACES_REFFILE
		local INPUT_FILE=$MUSTGATHER_DIRNAME/config/compliance/$COMPLIANCE_PROD_VER/config/compliance.cfg
		local PROC_INPUT_FILE=$COMPLIANCE_OUTDIR/$(basename ${INPUT_FILE}).proc
		local COMPLIANCE_SCRIPT_DIR=$MUSTGATHER_DIRNAME/config/compliance/$COMPLIANCE_PROD_VER/script

		echo "[$(date)] [${FUNCNAME[0]}] Calling function execCompliance() - [ INPUT_FILE=$INPUT_FILE ## PROC_INPUT_FILE=$PROC_INPUT_FILE ## COMPLIANCE_PROD_GROUP=$COMPLIANCE_PROD_GROUP ## COMPLIANCE_PROD_VER=$COMPLIANCE_PROD_VER ## COMPLIANCE_PROD_GROUP_NS_REFFILE=$COMPLIANCE_PROD_GROUP_NS_REFFILE ## COMPLIANCE_SCRIPT_DIR=$COMPLIANCE_SCRIPT_DIR ]"
		execCompliance "$INPUT_FILE" "$PROC_INPUT_FILE" "$COMPLIANCE_PROD_GROUP" "$COMPLIANCE_PROD_VER" "$COMPLIANCE_PROD_GROUP_NS_REFFILE" "$COMPLIANCE_SCRIPT_DIR"
	fi
}

execCompliance()
{
	local COMPLIANCE_WORKFILE=$1
	local COMPLIANCE_PROCFILE=$2
	local COMPLIANCE_PROD_GROUP=$3
	local COMPLIANCE_PROD_VER=$4
	local COMPLIANCE_PROD_GROUP_NS_REFFILE=$5
	local COMPLIANCE_SCRIPT_DIR=$6

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_WORKFILE = [$COMPLIANCE_WORKFILE] / COMPLIANCE_PROCFILE = [$COMPLIANCE_PROCFILE] / COMPLIANCE_PROD_GROUP = [$COMPLIANCE_PROD_GROUP] / COMPLIANCE_PROD_VER = [$COMPLIANCE_PROD_VER] / COMPLIANCE_PROD_GROUP_NS_REFFILE = [$COMPLIANCE_PROD_GROUP_NS_REFFILE] / COMPLIANCE_SCRIPT_DIR=[$COMPLIANCE_SCRIPT_DIR]"
	fi

	if [ ${COMPLIANCE_INPUTTAG} == ".listcompliance" ] || [ ${COMPLIANCE_INPUTTAG} == ".listcompliance_custom" ] 
	then
		if [ ${COMPLIANCE_INPUTTAG} == ".listcompliance" ]
		then
			local COMPLIANCE_HELPFILE=$(dirname $COMPLIANCE_WORKFILE)/compliance.help
		else
			local COMPLIANCE_HELPFILE=$(dirname $COMPLIANCE_WORKFILE)/compliance_custom.help
		fi

		if [ -s $COMPLIANCE_HELPFILE ]
		then
			if [ ${REPORT_ON_SCREEN} != "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Setting REPORT_ON_SCREEN to [true]..."
				REPORT_ON_SCREEN="true"
				REPORT_ON_SCREEN_SUMMARY_FILE=$ROOT_OUTDIR/${ANALYZE_OUTFILE##*/}.$$
			fi	
	
			echo "[PROD_GRP = $COMPLIANCE_PROD_GROUP / PROV_VER = $COMPLIANCE_PROD_VER]" >> $ANALYZE_OUTFILE
			echo "====================================================================================================================================================================================" >> $ANALYZE_OUTFILE
			printf "%-35s %-120s \n" "TAG" "DESCRIPTION" >> $ANALYZE_OUTFILE
			echo "====================================================================================================================================================================================" >> $ANALYZE_OUTFILE
	
			while read LINE
			do
				# Skip all lines that start with @ and blank lines
				if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "$MANUAL_COLL_CFGFILE_COMMENT"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi
	
				local C_TAG=$(echo "$LINE" | $AWK -F"$COMPLIANCE_CFGFILE_DELIMITER" '{ print $1 }')
	
				local C_DESC=$(grep -E "^${C_TAG}${COMPLIANCE_HELPFILE_DELIMITER}" $COMPLIANCE_HELPFILE | $AWK -F"${COMPLIANCE_HELPFILE_DELIMITER}" '{ print $2 }')
	
				if [ ${#C_DESC} -eq 0 ]
				then
					local C_DESC="N/A"
				fi
	
				printf "%-35s %-120s \n" "$C_TAG" "$C_DESC" >> $ANALYZE_OUTFILE
			done < <(sort "$COMPLIANCE_WORKFILE")	
	
			echo >> $ANALYZE_OUTFILE
		else
			echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_HELPFILE [$COMPLIANCE_HELPFILE] does not exist or is zero-sized! Returning..."
			return 1
		fi
	else
		if [ ${#CMD_EXEC_RESULT_COMPLIANCE_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_COMPLIANCE_FILE ]
		then
			if [ ${#CMD_EXEC_COMPLIANCE_ONLY} -gt 0 ] && [ ${CMD_EXEC_COMPLIANCE_ONLY} == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_COMPLIANCE_ONLY = [$CMD_EXEC_COMPLIANCE_ONLY] - Setting COMPLIANCE_WORKFILE to [$CMD_EXEC_RESULT_COMPLIANCE_FILE]..."
				local COMPLIANCE_WORKFILE=$CMD_EXEC_RESULT_COMPLIANCE_FILE
			else
				local COMPLIANCE_WORKFILE_MERGED=$(echo "$COMPLIANCE_PROCFILE" | sed 's/.proc$/.merged/')
				echo "[$(date)] [${FUNCNAME[0]}] Merging COMPLIANCE_WORKFILE [$COMPLIANCE_WORKFILE] with CMD_EXEC_RESULT_COMPLIANCE_FILE [$CMD_EXEC_RESULT_COMPLIANCE_FILE] => [$COMPLIANCE_WORKFILE_MERGED]..."
				cat $COMPLIANCE_WORKFILE $CMD_EXEC_RESULT_COMPLIANCE_FILE >> $COMPLIANCE_WORKFILE_MERGED
	
				echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_COMPLIANCE_ONLY = [$CMD_EXEC_COMPLIANCE_ONLY] - Setting COMPLIANCE_WORKFILE to [$COMPLIANCE_WORKFILE_MERGED]..."
				local COMPLIANCE_WORKFILE=$COMPLIANCE_WORKFILE_MERGED
			fi
		fi
	
		if ! processComplianceInputFile "$COMPLIANCE_WORKFILE" "$COMPLIANCE_PROCFILE" "$COMPLIANCE_PROD_GROUP" "$COMPLIANCE_PROD_VER" "$COMPLIANCE_PROD_GROUP_NS_REFFILE" "$COMPLIANCE_SCRIPT_DIR"
		then
			echo "[$(date)] [${FUNCNAME[0]}] Compliance mode failed! Skipping..."
			return 1
		fi
	
		if [ $MG_DEBUG == "true" ]
		then
			local FUNC_START=$(getFuncStartTime)
		fi
	
		if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
		then
			local COMPLIANCE_RES_OUTDIR=$COMPLIANCE_OUTDIR
			local COMPLIANCE_DEBUG_OUTDIR=$COMPLIANCE_ROOT_DEBUG_OUTDIR
		else
			local COMPLIANCE_RES_OUTDIR=$COMPLIANCE_OUTDIR/PRODGRP=$COMPLIANCE_PROD_GROUP
			local COMPLIANCE_DEBUG_OUTDIR=$COMPLIANCE_ROOT_DEBUG_OUTDIR/PRODGRP=$COMPLIANCE_PROD_GROUP
		fi
	
		local HEADER_PRINTED="false"
		local CFGLINE_CTR=0
		local COMPLIANCE_PASSED_CTR=0
		local COMPLIANCE_FAILED_CTR=0
		local COMPLIANCE_PASSED_ARR=()
		local COMPLIANCE_FAILED_ARR=()
		
		local CFGLINE=
	
		local COMPLIANCE_PRODUCT_NSFILE=$COMPLIANCE_RES_OUTDIR/product.ns.$$
		echo "[$(date)] [${FUNCNAME[0]}] Providing a copy of PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL] to COMPLIANCE mode at location [$COMPLIANCE_PRODUCT_NSFILE]..."
		cp -p $PROD_NAMESPACES_REFFILE_FINAL $COMPLIANCE_PRODUCT_NSFILE
		echo "[$(date)] [${FUNCNAME[0]}] Backing up COMPLIANCE_PROD_GROUP_NS_REFFILE [$COMPLIANCE_PROD_GROUP_NS_REFFILE] to directory [$COMPLIANCE_RES_OUTDIR]..."
		cp -p $COMPLIANCE_PROD_GROUP_NS_REFFILE $COMPLIANCE_RES_OUTDIR
		
		while read CFGLINE
		do
			(( CFGLINE_CTR=CFGLINE_CTR+1 ))
	
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CFGLINE = [$CFGLINE]"
			fi
	
			local COMPLIANCE_CONFIGLINE_COLWIDTH=6
			local THIS_CFGLINE_COLWIDTH=$(echo "$CFGLINE" | $AWK -F${COMPLIANCE_CFGFILE_DELIMITER} '{ print NF }')
	
			if [ $THIS_CFGLINE_COLWIDTH -ne $COMPLIANCE_CONFIGLINE_COLWIDTH ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CFGLINE](WIDTH=$THIS_CFGLINE_COLWIDTH) is not [$COMPLIANCE_CONFIGLINE_COLWIDTH] wide! Skipping..."
				continue
			fi
	
			local C_TAG=$(echo "$CFGLINE" | $AWK -F${COMPLIANCE_CFGFILE_DELIMITER} '{ print $1 }')
			local SOURCE_OBJ=$(echo "$CFGLINE" | $AWK -F${COMPLIANCE_CFGFILE_DELIMITER} '{ print $2 }')
			local TARGET_OBJ=$(echo "$CFGLINE" | $AWK -F${COMPLIANCE_CFGFILE_DELIMITER} '{ print $3 }')
			local COMPLIANCE_SCRIPT_RAW=$(echo "$CFGLINE" | $AWK -F${COMPLIANCE_CFGFILE_DELIMITER} '{ print $4 }')
			
			if [[ $COMPLIANCE_SCRIPT_RAW =~ ^/ ]]
			then
				local COMPLIANCE_SCRIPT=$COMPLIANCE_SCRIPT_RAW
			else
				local COMPLIANCE_SCRIPT=$COMPLIANCE_SCRIPT_DIR/$COMPLIANCE_SCRIPT_RAW
			fi
	
			local ACTION_WHEN=$(echo "$CFGLINE" | $AWK -F${COMPLIANCE_CFGFILE_DELIMITER} '{ print $5 }')
			local ACTION_SCRIPT_RAW=$(echo "$CFGLINE" | $AWK -F${COMPLIANCE_CFGFILE_DELIMITER} '{ print $6 }')
	
			if [ ${#ACTION_SCRIPT_RAW} -gt 0 ] 
			then
				if [ ${#ACTION_WHEN} -eq 0 ]
				then
					# If ACTION_WHEN is empty but ACTION_SCRIPT is defined, default behavior is to execute when compliance failed.
					echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] ACTION_WHEN is not set and will be defaulted to value of [1]..."
					local ACTION_WHEN=1
				else
					if [[ $ACTION_SCRIPT_RAW =~ ^/ ]]
					then
						local ACTION_SCRIPT=$ACTION_SCRIPT_RAW
					else
						local ACTION_SCRIPT=$COMPLIANCE_SCRIPT_DIR/$ACTION_SCRIPT_RAW
					fi
				fi
			fi
	
			local COMPLIANCE_OUTFILE=$COMPLIANCE_OUTDIR/$CFGLINE_CTR-$C_TAG.for-action
	
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] C_TAG = [$C_TAG]"
				echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] SOURCE_OBJ = [$SOURCE_OBJ]"
				echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] TARGET_OBJ = [$TARGET_OBJ]"
				echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] COMPLIANCE_SCRIPT = [$COMPLIANCE_SCRIPT]"
				echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] ACTION_WHEN = [$ACTION_WHEN]"
				echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] ACTION_SCRIPT = [$ACTION_SCRIPT]"
			fi
	
			if [ -s $COMPLIANCE_SCRIPT ]
			then
				# Backup script
				if [ $MG_DEBUG == "true" ]
				then
					cp -p $COMPLIANCE_SCRIPT $COMPLIANCE_DEBUG_OUTDIR
				fi
	
				if [ ${#TIMEOUT} -gt 0 ]
				then
					local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $COMPLIANCE_SCRIPT \"$SOURCE_OBJ\" \"$TARGET_OBJ\" \"$COMPLIANCE_OUTFILE\""
					echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Executing compliance script [$CMD]..."
					COMPLIANCE_MSG=$(eval "$CMD")
					C_EXITSTATUS=$?
	
					if [ $C_EXITSTATUS -eq 124 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $CFGLINE] [$CFGLINE_CTR] Compliance script [$COMPLIANCE_SCRIPT] timeout after $DEFAULT_TIMEOUT! Skipping..."
						(( COMPLIANCE_FAILED_CTR=COMPLIANCE_FAILED_CTR+1 ))
						continue
					else	
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Compliance script file [$COMPLIANCE_SCRIPT] exits with status [$C_EXITSTATUS]"
						fi
					fi
				else
					local CMD="/bin/bash $COMPLIANCE_SCRIPT \"$SOURCE_OBJ\" \"$TARGET_OBJ\" \"$COMPLIANCE_OUTFILE\""	
					echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Executing compliance script [$CMD]..."
					COMPLIANCE_MSG=$(eval "$CMD")
					C_EXITSTATUS=$?
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Compliance script file [$COMPLIANCE_SCRIPT] exits with status [$C_EXITSTATUS]"
					fi
				fi
	
				echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Compliance result [$C_EXITSTATUS] / Compliance message [$COMPLIANCE_MSG]"
	
				if [ $HEADER_PRINTED == "false" ]
				then
					echo "===================================================" >> $COMPLIANCE_REPORT
					echo "[PRODUCT GROUP = $COMPLIANCE_PROD_GROUP / $PRODUCT_NAME v$COMPLIANCE_PROD_VER] COMPLIANCE REPORT" >> $COMPLIANCE_REPORT
					echo "===================================================" >> $COMPLIANCE_REPORT
	
					HEADER_PRINTED="true"
				fi
	
				echo "[TAGNAME] = $C_TAG" >> $COMPLIANCE_REPORT
				echo "[SOURCE OBJECT] = $SOURCE_OBJ" >> $COMPLIANCE_REPORT
				echo "[TARGET OBJECT] = $TARGET_OBJ" >> $COMPLIANCE_REPORT
				echo "[COMPLIANCE SCRIPT] = $COMPLIANCE_SCRIPT" >> $COMPLIANCE_REPORT
				echo "[COMPLIANCE MESSAGE] = $COMPLIANCE_MSG" >> $COMPLIANCE_REPORT
	
				if [ $C_EXITSTATUS -eq 0 ]
				then
					(( COMPLIANCE_PASSED_CTR=COMPLIANCE_PASSED_CTR+1 ))
					COMPLIANCE_PASSED_ARR[${#COMPLIANCE_PASSED_ARR[@]}]=$C_TAG
	
					echo "[COMPLIANCE RESULT] = $C_EXITSTATUS [PASSED]" >> $COMPLIANCE_REPORT
	
					if [ ${#ACTION_WHEN} -gt 0 ] && [ ${#ACTION_SCRIPT} -gt 0 ]
					then
						if [[ "$ACTION_WHEN" =~ ^0$ ]] && [ $ACTION_WHEN -eq 0 ]
						then
							echo "[ACTION SCRIPT] = $ACTION_SCRIPT" >> $COMPLIANCE_REPORT
		
							if [ ${#ACTION_SCRIPT} -gt 0 ]
							then
								if [ -s $ACTION_SCRIPT ]
								then
									# Backup script
									if [ $MG_DEBUG == "true" ]
									then
										cp -p $ACTION_SCRIPT $COMPLIANCE_DEBUG_OUTDIR
									fi
			
									if [ ${#TIMEOUT} -gt 0 ]
									then
										local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $ACTION_SCRIPT $COMPLIANCE_OUTFILE"
										echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Executing action script [$CMD] using input file [$COMPLIANCE_OUTFILE]..."
										CA_ACTION_MSG=$(eval "$CMD")	
										CA_EXITSTATUS=$?
			
										if [ $CA_EXITSTATUS -eq 124 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $CFGLINE] [$CFGLINE_CTR] Action script [$ACTION_SCRIPT] timeout after $DEFAULT_TIMEOUT! Skipping..."
											continue
										else	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Action script [$ACTION_SCRIPT] exits with status [$CA_EXITSTATUS]"
											fi
										fi
									else
										local CMD="/bin/bash $ACTION_SCRIPT $COMPLIANCE_OUTFILE"
										echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Executing action script [$CMD] using input file [$COMPLIANCE_OUTFILE]..."
										CA_ACTION_MSG=$(eval "$CMD")	
										CA_EXITSTATUS=$?
			
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Action script [$ACTION_SCRIPT] exits with status [$CA_EXITSTATUS]"
										fi
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Action script [$ACTION_SCRIPT] does not exist or is zero-sized!"
								fi
							fi
			
							echo "[ACTION MESSAGE] = $CA_ACTION_MSG" >> $COMPLIANCE_REPORT
			
							if [ ${#CA_EXITSTATUS} -gt 0 ]
							then
								if [ $CA_EXITSTATUS -eq 0 ]
								then
									echo "[ACTION RESULT] = $CA_EXITSTATUS [PASSED]" >> $COMPLIANCE_REPORT
								else
									echo "[ACTION RESULT] = $CA_EXITSTATUS [FAILED]" >> $COMPLIANCE_REPORT
								fi
							else
								echo "[ACTION RESULT] = " >> $COMPLIANCE_REPORT
							fi
						else
							if [ ${#ACTION_SCRIPT} -gt 0 ]
							then
								if [[ "$ACTION_WHEN" =~ ^1$ ]] && [ ${ACTION_WHEN} -eq 1 ]
								then
									echo "[ACTION_WHEN] = $ACTION_WHEN [FAILED]" >> $COMPLIANCE_REPORT
								else
									echo "[ACTION_WHEN] = $ACTION_WHEN [INVALID]" >> $COMPLIANCE_REPORT
								fi
							fi
		
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] ACTION_WHEN is set to [$ACTION_WHEN]! Not executing ACTION_SCRIPT [$ACTION_SCRIPT]!"
							fi
						fi
					else
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Both ACTION_WHEN and ACTION_SCRIPT are not set!"
						fi
					fi
				else
					(( COMPLIANCE_FAILED_CTR=COMPLIANCE_FAILED_CTR+1 ))
					COMPLIANCE_FAILED_ARR[${#COMPLIANCE_FAILED_ARR[@]}]=$C_TAG
	
					echo "[COMPLIANCE RESULT] = $C_EXITSTATUS [FAILED]" >> $COMPLIANCE_REPORT
	
					if [ ${#ACTION_WHEN} -gt 0 ] && [ ${#ACTION_SCRIPT} -gt 0 ]	
					then
						if [[ "$ACTION_WHEN" =~ ^1$ ]] && [ $ACTION_WHEN -eq 1 ]
						then
							echo "[ACTION SCRIPT] = $ACTION_SCRIPT" >> $COMPLIANCE_REPORT
		
							if [ ${#ACTION_SCRIPT} -gt 0 ]
							then
								if [ -s $ACTION_SCRIPT ]
								then
									# Backup script
									if [ $MG_DEBUG == "true" ]
									then
										cp -p $ACTION_SCRIPT $COMPLIANCE_DEBUG_OUTDIR
									fi
			
									if [ ${#TIMEOUT} -gt 0 ]
									then
										local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $ACTION_SCRIPT $COMPLIANCE_OUTFILE"
										echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Executing action script [$CMD] using input file [$COMPLIANCE_OUTFILE]..."
										CA_ACTION_MSG=$(eval "$CMD")	
										CA_EXITSTATUS=$?
			
										if [ $CA_EXITSTATUS -eq 124 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $CFGLINE] [$CFGLINE_CTR] Action script [$ACTION_SCRIPT] timeout after $DEFAULT_TIMEOUT! Skipping..."
											continue
										else	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Action script [$ACTION_SCRIPT] exits with status [$CA_EXITSTATUS]"
											fi
										fi
									else
										local CMD="/bin/bash $ACTION_SCRIPT $COMPLIANCE_OUTFILE"
										echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Executing action script [$CMD] using input file [$COMPLIANCE_OUTFILE]..."
										CA_ACTION_MSG=$(eval "$CMD")	
										CA_EXITSTATUS=$?
			
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Action script [$ACTION_SCRIPT] exits with status [$CA_EXITSTATUS]"
										fi
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Action script [$ACTION_SCRIPT] does not exist or is zero-sized!"
								fi
							fi
			
							echo "[ACTION MESSAGE] = $CA_ACTION_MSG" >> $COMPLIANCE_REPORT
			
							if [ ${#CA_EXITSTATUS} -gt 0 ]
							then
								if [ $CA_EXITSTATUS -eq 0 ]
								then
									echo "[ACTION RESULT] = $CA_EXITSTATUS [PASSED]" >> $COMPLIANCE_REPORT
								else
									echo "[ACTION RESULT] = $CA_EXITSTATUS [FAILED]" >> $COMPLIANCE_REPORT
								fi
							else
								echo "[ACTION RESULT] = " >> $COMPLIANCE_REPORT
							fi
						else
							if [ ${#ACTION_SCRIPT} -gt 0 ]
							then
								if [[ "$ACTION_WHEN" =~ ^0$ ]] && [ ${ACTION_WHEN} -eq 0 ]
								then
									echo "[ACTION_WHEN] = $ACTION_WHEN [PASSED]" >> $COMPLIANCE_REPORT
								else
									echo "[ACTION_WHEN] = $ACTION_WHEN [INVALID]" >> $COMPLIANCE_REPORT
								fi
							fi
		
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] ACTION_WHEN is set to [$ACTION_WHEN]! Not executing ACTION_SCRIPT [$ACTION_SCRIPT]!"
							fi
						fi
					else
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Both ACTION_WHEN and ACTION_SCRIPT are not set!"
						fi
					fi
				fi
	
				echo >> $COMPLIANCE_REPORT
				echo "===================================================" >> $COMPLIANCE_REPORT
			else
				echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_SCRIPT [$COMPLIANCE_SCRIPT] does not exist or is zero-sized! Skipping config line [$CFGLINE]..."
				(( COMPLIANCE_FAILED_CTR=COMPLIANCE_FAILED_CTR+1 ))
				continue
			fi	
		done < $COMPLIANCE_PROCFILE
	
		if [ $CFGLINE_CTR -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_PROCFILE [$COMPLIANCE_PROCFILE] is empty!"
		fi
	
		echo "===================================================" >> $ANALYZE_OUTFILE
		echo "[PRODUCT GROUP = $COMPLIANCE_PROD_GROUP / $PRODUCT_NAME v$COMPLIANCE_PROD_VER] COMPLIANCE SUMMARY REPORT" >> $ANALYZE_OUTFILE
		echo "===================================================" >> $ANALYZE_OUTFILE
		echo "Total PROCESSED compliance rules = [$CFGLINE_CTR]" >> $ANALYZE_OUTFILE
		echo "Total PASSED compliance rules = [$COMPLIANCE_PASSED_CTR]" >> $ANALYZE_OUTFILE
		
		if [ ${#COMPLIANCE_PASSED_ARR[@]} -gt 0 ]
		then
			local COMPLIANCE_PASSED_RULES=
	
			for COMPLIANCE_PASSED_RULE in ${COMPLIANCE_PASSED_ARR[@]}
			do
				if [ ${#COMPLIANCE_PASSED_RULES} -eq 0 ]
				then
					COMPLIANCE_PASSED_RULES=$COMPLIANCE_PASSED_RULE
				else
					COMPLIANCE_PASSED_RULES="$COMPLIANCE_PASSED_RULES,$COMPLIANCE_PASSED_RULE"
				fi
			done
	
			echo ">>> [$COMPLIANCE_PASSED_RULES]" >> $ANALYZE_OUTFILE
		fi
	
		echo "Total FAILED compliance rules = [$COMPLIANCE_FAILED_CTR]" >> $ANALYZE_OUTFILE
	
		if [ ${#COMPLIANCE_FAILED_ARR[@]} -gt 0 ]
		then
			local COMPLIANCE_FAILED_RULES=
	
			for COMPLIANCE_FAILED_RULE in ${COMPLIANCE_FAILED_ARR[@]}
			do
				if [ ${#COMPLIANCE_FAILED_RULES} -eq 0 ]
				then
					COMPLIANCE_FAILED_RULES=$COMPLIANCE_FAILED_RULE
				else
					COMPLIANCE_FAILED_RULES="$COMPLIANCE_FAILED_RULES,$COMPLIANCE_FAILED_RULE"
				fi
			done
	
			echo ">>> [$COMPLIANCE_FAILED_RULES]" >> $ANALYZE_OUTFILE
		fi
	
		echo >> $ANALYZE_OUTFILE	
	
		if [ $MG_DEBUG == "true" ]
		then	
			local FUNC_END=$(getFuncEndTime)
			getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [PRODGRP=$COMPLIANCE_PROD_GROUP / PRODVER=$COMPLIANCE_PROD_VER]"
		fi
	fi
}

checkManualCollection()
{
	local MC_INFILE=$1
	# local MC_PRODGRP=$2

	local TO_WARN_SECRET="false"
	local LINE=

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] MC_INFILE = [$MC_INFILE]" | tee -a $RUNTIME_LOGFILE
	fi

	local SENSITIVE_CONFIG_LIST=

	while read LINE
	do
		if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "$MANUAL_COLL_CFGFILE_COMMENT"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
		then
			continue
		fi

		local TAG=$(echo "$LINE" | $AWK -F$MANUAL_COLL_CFGFILE_DELIMITER '{ print $1 }')
		local OBJ_NS=$(echo "$LINE" | $AWK -F$MANUAL_COLL_CFGFILE_DELIMITER '{ print $2 }')
		local OBJ_TYPE=$(echo "$LINE" | $AWK -F$MANUAL_COLL_CFGFILE_DELIMITER '{ print tolower($3) }')
		local OBJ_NAME=$(echo "$LINE" | $AWK -F$MANUAL_COLL_CFGFILE_DELIMITER '{ print $4 }')
		local CONTAINER=$(echo "$LINE" | $AWK -F$MANUAL_COLL_CFGFILE_DELIMITER '{ print $5 }')
		local EXECPREP=$(echo "$LINE" | $AWK -F$MANUAL_COLL_CFGFILE_DELIMITER '{ print $6 }')
		local EXECPREPRMSRC=$(echo "$LINE" | $AWK -F$MANUAL_COLL_CFGFILE_DELIMITER '{ print $7 }')
		local EXECCMD=$(echo "$LINE" | $AWK -F$MANUAL_COLL_CFGFILE_DELIMITER '{ print $8 }')

		local MANUAL_COLL_TAG_MATCHED="false"

		IFS=$OLDIFS
		for MANUAL_COLL_TAG in $(echo "$MANUAL_COLL_INPUTTAG" | sed 's/,/ /g')
		do
			if [ $MANUAL_COLL_TAG == $TAG ]
			then
				local MANUAL_COLL_TAG_MATCHED="true"
				break
			fi
		done
		IFS=$'\n'

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] TAG = [$TAG] / OBJ_NS = [$OBJ_NS] / OBJ_TYPE = [$OBJ_TYPE] / OBJ_NAME = [$OBJ_NAME] / CONTAINER = [$CONTAINER] / EXECPREP = [$EXECPREP] / EXECPREPRMSRC = [$EXECPREPRMSRC] / EXECCMD = [$EXECCMD] / MANUAL_COLL_TAG_MATCHED = [$MANUAL_COLL_TAG_MATCHED]"
		fi
			
		if [ $(echo "${OBJ_NS}X" | sed 's/[ ]*//') != "X" ]
		then
			if [ ${#OBJ_TYPE} -gt 0 ] 
			then
				if ([ $MANUAL_COLL_TAG_MATCHED == "true" ] || [ $MANUAL_COLL_INPUTTAG == "ALL" ] || [ $TAG == "ALL" ]) && isSensitiveData "$OBJ_TYPE"
				then
					TO_WARN_SECRET="true"

					if [ ${#SENSITIVE_CONFIG_LIST} -eq 0 ]
					then
						local SENSITIVE_CONFIG_LIST="$OBJ_TYPE"
					else
						local SENSITIVE_CONFIG_LIST="$SENSITIVE_CONFIG_LIST $OBJ_TYPE"
					fi

					local SENSITIVE_CONFIG_LINES[${#SENSITIVE_CONFIG_LINES[@]}]="$LINE"
				fi
			fi	
		fi
	done < $MC_INFILE

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] SENSITIVE_CONFIG_LIST = [$SENSITIVE_CONFIG_LIST] / LEN(SENSITIVE_CONFIG_LINES) = [${#SENSITIVE_CONFIG_LINES[@]}]"
	fi

	if [ $TO_WARN_SECRET == "true" ]
	then
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Preliminary check of the 'manualcollect' data collection mode (-m) found its configuration file [$MC_INFILE] to contain configuration to collect sensitive data [$SENSITIVE_CONFIG_LIST]: ${NORMAL}${NEWLINE}"
		echo "[$(date)] [${FUNCNAME[0]}] Preliminary check of the 'manualcollect' data collection mode (-m) found its configuration file [$MC_INFILE] to contain configuration to collect sensitive data [$SENSITIVE_CONFIG_LIST]: " >> $RUNTIME_LOGFILE
		# grep -vE '^[ ]*'$MANUAL_COLL_CFGFILE_COMMENT'|^$' $MC_INFILE | $AWK -F'##' 'tolower($3) ~ /'$(echo "$SENSITIVE_CONFIG_LIST" | sed 's/ /|/g')'/ { print }' | tee -a $RUNTIME_LOGFILE

		for SCT_LINE in ${SENSITIVE_CONFIG_LINES[@]}
		do
			echo "$SCT_LINE"
		done
	
		if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ]
		then
			if [ ${#IS_SENSITIVE_DATA_ALLOWED} -gt 0 ] 
			then
				if [ ${IS_SENSITIVE_DATA_ALLOWED} == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] IS_SENSITIVE_DATA_ALLOWED = [$IS_SENSITIVE_DATA_ALLOWED]. Collection of sensitive data is allowed explicitly!" | tee -a $RUNTIME_LOGFILE
					local WARN_SECRET_MSG=0
				else
					local WARN_SECRET_MSG=1
				fi
			else
				local WARN_SECRET_MSG=1
			fi
		else
			if [ $COLLECT_YAML == "false" ] || [ $COLLECT_JSON == "false" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] COLLECT_YAML is [$COLLECT_YAML] and COLLECT_JSON is [$COLLECT_JSON]. No sensitive data will be collected. To proceed..." | tee -a $RUNTIME_LOGFILE
				local WARN_SECRET_MSG=0
			fi
		fi

		while [ $WARN_SECRET_MSG -eq 1 ]
		do
			printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Do you want to proceed (y/n)? ${NORMAL}"
			echo -n "[$(date)] [${FUNCNAME[0]}] Do you want to proceed (y/n)? " >> $RUNTIME_LOGFILE

			if [ $AUTO_YES == "true" ]
			then
				local SECRET_AGREEMENT="y"
				echo "$SECRET_AGREEMENT" | tee -a $RUNTIME_LOGFILE
				echo "[$(date)] [${FUNCNAME[0]}] Option [-Y] is set! Auto answering [y]..." | tee -a $RUNTIME_LOGFILE

				echo "[$(date)] [${FUNCNAME[0]}] Setting MANUAL_COLL_SENSITIVE_DATA_OVERRIDE to [true]!" | tee -a $RUNTIME_LOGFILE
				MANUAL_COLL_SENSITIVE_DATA_OVERRIDE="true"
			else
				if [ $MG_TTY == "false" ]
				then
					local SECRET_AGREEMENT="n"
					echo "$SECRET_AGREEMENT" | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [${FUNCNAME[0]}] In non-TTY mode, auto answering [n]..." | tee -a $RUNTIME_LOGFILE
				else
					read -t $DEFAULT_USERINPUT_TIMEOUT SECRET_AGREEMENT
					local EXIT_STATUS=$?	
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] EXIT_STATUS = [$EXIT_STATUS]" | tee -a $RUNTIME_LOGFILE
					fi
	
					if [ $EXIT_STATUS -gt 128 ]
					then
						echo | tee -a $RUNTIME_LOGFILE
						echo "[$(date)] [${FUNCNAME[0]}] Timeout waiting for user input. Auto answer [N]..." | tee -a $RUNTIME_LOGFILE
						SECRET_AGREEMENT="N"
					else
						echo "$SECRET_AGREEMENT" >> $RUNTIME_LOGFILE
					fi
				fi
			fi

			if [ ${#SECRET_AGREEMENT} -gt 0 ]
			then
				if [ ${SECRET_AGREEMENT} == "n" ] || [ ${SECRET_AGREEMENT} == "N" ]
				then
					echo "User input [$SECRET_AGREEMENT]. To skip sensitive data [$OBJ_TYPE] collection for 'manualcollect' data collection mode......"  | tee -a $RUNTIME_LOGFILE
					return 1	
				else
					if [ ${SECRET_AGREEMENT} == "y" ] || [ ${SECRET_AGREEMENT} == "Y" ]
					then
						echo "User input [$SECRET_AGREEMENT]. To proceed..." | tee -a $RUNTIME_LOGFILE
						echo "[$(date)] [${FUNCNAME[0]}] Setting MANUAL_COLL_SENSITIVE_DATA_OVERRIDE to [true]!" | tee -a $RUNTIME_LOGFILE
						MANUAL_COLL_SENSITIVE_DATA_OVERRIDE="true"
	
						return 0
					else
						echo "Invalid user input [$SECRET_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
					fi
				fi
			else
				echo "Invalid user input [$SECRET_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
			fi
		done
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] The 'manualcollect' data collection mode (-m) is not configured to collect any sensitive data!"
		fi

		return 1
	fi
}

processManualCollFile()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local INFILE=$1
	local OUTFILE=$2
	local NS_REFFILE=$3
	local PROD_VER=$4

	local CTR=0
	local TOTAL_CFG_COLUMNS=10
	local TOTAL_LINE_PROC=0
	local TOTAL_LINE_SAME=0
	local TOTAL_LINE_SKIP=0

	local LINE=

	echo "[$(date)] [${FUNCNAME[0]}] Processing 'getManualCollection()' input file [$INFILE]..."
	echo "[$(date)] [${FUNCNAME[0]}] Output file = [$OUTFILE]..."

	if [ ! -d $(dirname $OUTFILE) ]
	then
		mkdir -p $(dirname $OUTFILE)
	fi

	local DEF_ENV_ARR=()

	local MANUALCOLLECT_USER_INPUT_ENV=$(compgen -A variable | grep -E '^RTVAR_MANUALCOLLECT_' | tr '\n' ' ')

	if [ ${#MANUALCOLLECT_USER_INPUT_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for USER_INPUT_ENV in $MANUALCOLLECT_USER_INPUT_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$USER_INPUT_ENV] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$USER_INPUT_ENV"
		done	
	fi

	local GMGFVAR_ENV=$(compgen -A variable | grep -E '^RTVAR_GMGFVAR_' | tr '\n' ' ')

	if [ ${#GMGFVAR_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for GMGFVAR in $GMGFVAR_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$GMGFVAR] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$GMGFVAR"
		done	
	fi

	local DEF_ENV=
	
	IFS=$'\n'
	for DEF_ENV in ${DEF_ENV_ARR[@]}
	do
		if [[ $DEF_ENV =~ ^-f ]]
		then
			local MANUALCOLLECT_FUNCNAME=$(echo "$DEF_ENV" | $AWK '{ print $2 }')
		
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment function [$MANUALCOLLECT_FUNCNAME]..."
			fi

			export -f $MANUALCOLLECT_FUNCNAME
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$DEF_ENV = ${!DEF_ENV}]"
			fi

			export $DEF_ENV
		fi
	done

 	while read LINE	
 	do
		# Skip all lines that start with @ and blank lines
		if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "$MANUAL_COLL_CFGFILE_COMMENT"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
		then
			continue
		else
			(( CTR=CTR+1 ))
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] = $LINE"
		fi

		if [ $(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print NF }') -ne ${TOTAL_CFG_COLUMNS} ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Total column is not [${TOTAL_CFG_COLUMNS}]. Removing config line [$LINE]..."
			(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
			continue
		fi

		local OBJ_NS_PROC="false"
		local OBJ_NAME_PROC="false"
		
		local TAG=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $1 }')
		local OBJ_NS=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $2 }')
		local OBJ_TYPE=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print tolower($3) }')
		local OBJ_NAME=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $4 }')
		local OBJ_FILTER=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $5 }')
		local CONTAINER=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $6 }')
		local EXECPREP=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $7 }')
		local EXECPREPRMSRC=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $8 }')
		local EXECCMD=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $9 }')
		local POSTEXEC=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $10 }')

		local IN_TAG=
		local PROC_MANUAL_COLL_ENV_PAIRS=
		local VERB=
		local PROD_NS=

		# Check mandatory fields
		if [ ${#TAG} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] The column TAG is empty. Skipping..."
			continue
		fi

		if [ ${#OBJ_NS} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] The column OBJ_NS is empty. Skipping..."
			continue
		fi

		if [ ${#MANUAL_COLL_INPUTTAG} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] MANUAL_COLL_INPUTTAG is null. Exiting..."
			return 1
		else
			if [ $MANUAL_COLL_INPUTTAG != "ALL" ]
			then
				IFS=$OLDIFS
				TAG_MATCHED="false"

				if [ $TAG == "ALL" ]
				then
					TAG_MATCHED="true"
				else
					for IN_TAG in $(echo "$MANUAL_COLL_INPUTTAG" | sed 's/,/ /g')
					do
						if [ $IN_TAG == $TAG ]
						then
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] matches input tag [$IN_TAG]..."
							fi
		
							TAG_MATCHED="true"
						fi
					done
				fi

				if [ $TAG_MATCHED == "false" ]
				then
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] is tagged as [$TAG] and not MANUAL_COLL_INPUTTAG [$MANUAL_COLL_INPUTTAG]. Skipping..."
					fi
	
					continue
				fi
				
				IFS=$'\n'
			fi
		fi

		if [ ${#OBJ_NAME} -gt 0 ]
		then
			if [ $OBJ_NAME == "OBJNAME" ]
			then
				if [ ${#MANUAL_COLL_OBJNAME} -gt 0 ]
				then
					local ALL_OBJ_NAME=$(getManualCollectObjName ALL)
					MC_SUB_OBJ_NAME=$(getManualCollectObjName $TAG)
					local MC_OBJNAME_EXIT_STATUS=$?
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] ALL_OBJ_NAME = [$ALL_OBJ_NAME]"
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] MC_SUB_OBJ_NAME = [$MC_SUB_OBJ_NAME]"
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] MC_OBJNAME_EXIT_STATUS = [$MC_OBJNAME_EXIT_STATUS]"
					fi
	
					if [ $MC_OBJNAME_EXIT_STATUS -ne 0 ]
					then
						if [ ${#ALL_OBJ_NAME} -gt 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Unable to determine OBJNAME substitution based on TAG [$TAG]!"
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Substituting OBJNAME with the general OBJNAME tagged as ALL = [$ALL_OBJ_NAME]..."
							local OBJ_NAME=$ALL_OBJ_NAME
						else
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Unable to determine OBJNAME substitution based on TAG [$TAG]! Skipping..."
							(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
							continue
						fi
					else
						if [ ${#ALL_OBJ_NAME} -gt 0 ]
						then
							if [ ${#MC_SUB_OBJ_NAME} -gt 0 ]
							then
								local OBJ_NAME="${MC_SUB_OBJ_NAME}|${ALL_OBJ_NAME}"
							else
								local OBJ_NAME="${ALL_OBJ_NAME}"
							fi
						else
							local OBJ_NAME="${MC_SUB_OBJ_NAME}"
						fi
	
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Substituting OBJNAME with value [$OBJ_NAME]..."	
					fi
	
					LINE="$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC"
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Constructing new line = [$LINE]"
					local OBJ_NAME_PROC="true"
				else
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Unable to substitue OBJ_NAME because MANUAL_COLL_OBJNAME is null! Skipping..."
					(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
					continue
				fi
			fi
		fi

		if [ ${#EXECPREP} -gt 0 ] 
		then
			if [ $EXECPREP == "EXECPREP" ]
			then
				if [ ${#MANUAL_COLL_EXECPREP_REFFILE} -gt 0 ] && [ -s $MANUAL_COLL_EXECPREP_REFFILE ]
				then
					local EXECPREP_REF_LINE=
					local EXECPREP_REF_FOUND="false"
	
					while read EXECPREP_REF_LINE
					do
						local EXECPREP_REF_TAG=$(echo "$EXECPREP_REF_LINE" | $AWK -F## '{ print $1 }')
						local EXECPREP_REF_SRC=$(echo "$EXECPREP_REF_LINE" | $AWK -F## '{ print $2 }')
						local EXECPREP_REF_TGT=$(echo "$EXECPREP_REF_LINE" | $AWK -F## '{ print $3 }')

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP_REF_LINE = [$EXECPREP_REF_LINE]"
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP_REF_TAG = [$EXECPREP_REF_TAG]"
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP_REF_SRC = [$EXECPREP_REF_SRC]"
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP_REF_TGT = [$EXECPREP_REF_TGT]"
						fi

						if [ ${#EXECPREP_REF_TAG} -gt 0 ] && [ ${EXECPREP_REF_TAG} == "$TAG" ]
						then
							local EXECPREP_REF_FOUND="true"
	
							if [ "$EXECPREP_REF_SRC" == "bash" ]
							then
								if [ ${#EXECPREP_REF_TGT} -gt 0 ]
								then
									if [ $(echo "$EXECPREP_REF_TGT" | $AWK '{ print NF }') -gt 1 ]
									then
										local EXECPREP_REF_TGT_ARG=$(echo "$EXECPREP_REF_TGT" | $AWK '{ $1=""; print $0 }' | sed 's/^[ ]*//')
									else
										local EXECPREP_REF_TGT_ARG=""
									fi

									local EXECPREP_REF_TGT=$(echo "$EXECPREP_REF_TGT" | $AWK '{ print $1 }')

									if [[ ! $(echo "$EXECPREP_REF_TGT" | $AWK '{ print $1 }') =~ ^/ ]]
									then
										if [ $MANUAL_COLL_CUSTOM_DATA == "false" ]
										then	
											local EXECPREP_REF_TGT=$MUSTGATHER_DIRNAME/config/manualcollect/$PROD_VER/scripts/$EXECPREP_REF_TGT
										else
											local EXECPREP_REF_TGT=$MUSTGATHER_DIRNAME/data/manualcollect/$PROD_VER/scripts/$EXECPREP_REF_TGT

											if [ ! -s $EXECPREP_REF_TGT ]
											then
												local EXECPREP_REF_TGT_ORIG=$(basename $EXECPREP_REF_TGT)
												local EXECPREP_REF_TGT=$MUSTGATHER_DIRNAME/data/manualcollect/scripts/$EXECPREP_REF_TGT_ORIG
											fi
										fi
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Target file setting of EXECPREP [$EXECPREP_REF_LINE] column is empty/null. Skipping..."
									(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
									continue
								fi
										
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP_REF_TGT = [$EXECPREP_REF_TGT] / EXECPREP_REF_TGT_ARG = [$EXECPREP_REF_TGT_ARG]"
								fi

								if [ -s $EXECPREP_REF_TGT ]
								then
									if [ ${#TIMEOUT} -gt 0 ]
									then
										if [ ${#EXECPREP_REF_TGT_ARG} -gt 0 ] 
										then
											local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXECPREP_REF_TGT $EXECPREP_REF_TGT_ARG"	
										else
											local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXECPREP_REF_TGT"	
										fi

										echo "[$(date)] [${FUNCNAME[0]}] Executing EXECPREP script [$CMD]..."
										RESULT=$(eval "$CMD")
										C_EXITSTATUS=$?
					
										if [ $C_EXITSTATUS -eq 124 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP script [$EXECPREP_REF_TGT] timeout after $DEFAULT_TIMEOUT! Skipping..."
											local EXECPREP_REF_FOUND="false"
											# (( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
											continue
										else	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] EXECPREP script file [$EXECPREP_REF_TGT] exits with status [$C_EXITSTATUS]"
											fi
										fi
									else
										local CMD="/bin/bash $EXECPREP_REF_TGT"	
										echo "[$(date)] [${FUNCNAME[0]}] Executing EXECPREP script [$EXECPREP_REF_TGT]..."
										local RESULT=$(eval "$CMD")
									fi

									if [ ${#RESULT} -gt 0 ]
									then
										if [ $MG_DEBUG = "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RESULT = [$RESULT]"
										fi

										local FINAL_RESULT=

										while read RES_LINE
										do
											if [[ "$RES_LINE" =~ ^WRITETO\> ]]
											then
												local WRITETO_EXECPREP_SRC=$(echo "$RES_LINE" | sed 's/^WRITETO>//' | $AWK -F: '{ print $1 }')
												local WRITETO_EXECPREP_TGT=$(echo "$RES_LINE" | sed 's/^WRITETO>//' | $AWK -F: '{ print $2 }')

												if [ ${#WRITETO_EXECPREP_SRC} -eq 0 ] || [ ${#WRITETO_EXECPREP_TGT} -eq 0 ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RES_LINE [$RES_LINE] invalid WRITETO syntax! Skipping..."

													local WRITETO_EXECPREP_SRC=
													local WRITETO_EXECPREP_TGT=

													continue
												else
													if [ -f ${WRITETO_EXECPREP_SRC} ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RES_LINE [$RES_LINE] Source file [$WRITETO_EXECPREP_SRC] exists! Skipping..."

														local WRITETO_EXECPREP_SRC=
														local WRITETO_EXECPREP_TGT=

														continue	
													else
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] WRITETO_EXECPREP_SRC = [$WRITETO_EXECPREP_SRC] / WRITETO_EXECPREP_TGT = [$WRITETO_EXECPREP_TGT]"
													fi
												fi
											else
												if [[ "$RES_LINE" =~ ^OUT\> ]]
												then
													if [ ${#WRITETO_EXECPREP_SRC} -gt 0 ]
													then
														local WRITETO_LINE=$(echo "$RES_LINE" | sed 's/^OUT>//')

														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Writing [$WRITETO_LINE] to EXECPREP_SRC_FILE [$WRITETO_EXECPREP_SRC]..."
														echo "$WRITETO_LINE" >> $WRITETO_EXECPREP_SRC
													else
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] WRITETO_EXECPREP_SRC is not set! Skipping [$RES_LINE]..."
														continue
													fi
												else
													if [[ "$RES_LINE" =~ [a-zA-Z0-9]*=[a-zA-Z0-9]* ]]
													then
														local RES_LINE_VAR=$(echo "$RES_LINE" | $AWK -F= '{ print $1 }')

														if [[ "$RES_LINE_VAR" =~ " " ]]
														then
															echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RES_LINE_VAR [$RES_LINE_VAR] of RES_LINE [$RES_LINE] contains spaces! Skipping..."
														else
															if [ ${#FINAL_RESULT} -eq 0 ]
															then
																local FINAL_RESULT="${RES_LINE}"
															else
																local FINAL_RESULT="${FINAL_RESULT}##${RES_LINE}"
															fi
														fi
													else
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RES_LINE [$RES_LINE] is not in VAR=VAL format! Skipping..."
													fi
												fi
											fi
										done <<< "$RESULT"

										if [ ${#FINAL_RESULT} -gt 0 ]
										then
											if [ ${#MANUAL_COLL_ENV} -gt 0 ]
											then
												local PROC_MANUAL_COLL_TAGNAME_FOUND="false"
												local FINAL_MANUAL_COLL_ENV=

												for PROC_MANUAL_COLL_ENV_PAIRS in $(echo "$MANUAL_COLL_ENV" | sed 's/\^\^/\n/g')
												do
													local PROC_MANUAL_COLL_TAGNAME=$(echo "$PROC_MANUAL_COLL_ENV_PAIRS" | $AWK -F'~>' '{ print $1 }')
													local PROC_MANUAL_COLL_ENVVAR=$(echo "$PROC_MANUAL_COLL_ENV_PAIRS" | $AWK -F'~>' '{ print $2 }')

													if [ "$PROC_MANUAL_COLL_TAGNAME" == "$TAG" ]
													then
														local PROC_MANUAL_COLL_TAGNAME_FOUND="true"
														local NEW_PROC_MANUAL_COLL_ENV_PAIRS="${PROC_MANUAL_COLL_TAGNAME}~>${PROC_MANUAL_COLL_ENVVAR}##${FINAL_RESULT}"
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Updating tag [$PROC_MANUAL_COLL_TAGNAME] to [${PROC_MANUAL_COLL_ENVVAR}##${FINAL_RESULT}]..."
													else
														local NEW_PROC_MANUAL_COLL_ENV_PAIRS="${PROC_MANUAL_COLL_ENV_PAIRS}"
													fi

													if [ ${#FINAL_MANUAL_COLL_ENV} -eq 0 ]
													then
														local FINAL_MANUAL_COLL_ENV="${NEW_PROC_MANUAL_COLL_ENV_PAIRS}"
													else
														local FINAL_MANUAL_COLL_ENV="${FINAL_MANUAL_COLL_ENV}^^${NEW_PROC_MANUAL_COLL_ENV_PAIRS}"
													fi

													if [ $MG_DEBUG == "true" ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] PROC_MANUAL_COLL_ENV_PAIRS = [$PROC_MANUAL_COLL_ENV_PAIRS] / FINAL_MANUAL_COLL_ENV = [$FINAL_MANUAL_COLL_ENV]"
													fi
												done

												if [ $PROC_MANUAL_COLL_TAGNAME_FOUND == "false" ]
												then
													MANUAL_COLL_ENV="${FINAL_MANUAL_COLL_ENV}^^${TAG}~>${FINAL_RESULT}"
												else
													MANUAL_COLL_ENV="${FINAL_MANUAL_COLL_ENV}"
												fi
											else
												MANUAL_COLL_ENV="${TAG}~>${FINAL_RESULT}"
											fi

											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] FINAL_RESULT = [${FINAL_RESULT}]"
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Updated MANUAL_COLL_ENV = [$MANUAL_COLL_ENV]"
										else
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] FINAL_RESULT is empty!"
										fi

										if [ ${#WRITETO_EXECPREP_SRC} -gt 0 ] && [ -s ${WRITETO_EXECPREP_SRC} ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Setting EXECPREP to [${WRITETO_EXECPREP_SRC}:${WRITETO_EXECPREP_TGT}]..."
											local EXECPREP="${WRITETO_EXECPREP_SRC}:${WRITETO_EXECPREP_TGT}"
										else
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP [$EXECPREP_REF_SRC:$EXECPREP_REF_TGT] is bash instruction! Emptying EXECPREP value with value []..."
											local EXECPREP=""
											
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Output of EXECPREP script file [$EXECPREP_REF_TGT] is empty!"
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Target file [$EXECPREP_REF_TGT] does not exist or is zero-sized! Skipping..."
									local EXECPREP_REF_FOUND="false"
									# (( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
									continue
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Replacing EXECPREP value with value [${EXECPREP_REF_SRC}:${EXECPREP_REF_TGT}]..."
								EXECPREP="${EXECPREP_REF_SRC}:${EXECPREP_REF_TGT}"
							fi
	
							LINE="$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC"
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Constructing new line = [$LINE]"

							break
						fi
					done < $MANUAL_COLL_EXECPREP_REFFILE
	
					if [ $EXECPREP_REF_FOUND == "false" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Unable to substitute EXECPREP because no reference line in MANUAL_COLL_EXECPREP_REFFILE [$MANUAL_COLL_EXECPREP_REFFILE] matches TAG [$TAG]! Skipping..."
						(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
						continue
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Unable to substitute EXECPREP because MANUAL_COLL_EXECPREP_REFFILE [$MANUAL_COLL_EXECPREP_REFFILE] does not exist or is zero-sized! Skipping..."
					(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
					continue
				fi
			else
				local EXECPREP_COL_COUNT=$(echo "$EXECPREP" | $AWK -F: '{ print NF }')
		
				if [ ${#EXECPREP_COL_COUNT} -eq 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Unable to process settings of EXECPREP [$EXECPREP] column. Skipping..."
					(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
					continue
				else
					if [ ${EXECPREP_COL_COUNT} -ne 2 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP [$EXECPREP] column is not in valid format of [<sourcefile>:<targetfile>]. Skipping..."
						(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
						continue
					else
						local EXECPREP_COL_SRC=$(echo "$EXECPREP" | $AWK -F: '{ print $1 }')
						local EXECPREP_COL_TGT=$(echo "$EXECPREP" | $AWK -F: '{ print $2 }')
	
						if [ ${#EXECPREP_COL_SRC} -eq 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Source file setting of EXECPREP [$EXECPREP] column is empty/null. Skipping..."
							(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
							continue
						else
							if [[ ! $(echo "$EXECPREP_COL_SRC" | $AWK '{ print $1 }') =~ ^/ ]]
							then
								if [ ! "$EXECPREP_COL_SRC" == "bash" ]
								then
									if [ $MANUAL_COLL_CUSTOM_DATA == "false" ]
									then
										local EXECPREP_COL_SRC=$MUSTGATHER_DIRNAME/config/manualcollect/$PROD_VER/scripts/$EXECPREP_COL_SRC
									else
										local EXECPREP_COL_SRC=$MUSTGATHER_DIRNAME/data/manualcollect/$PROD_VER/scripts/$EXECPREP_COL_SRC

										if [ ! -s $EXECPREP_COL_SRC ]
										then
											local EXECPREP_COL_SRC_ORIG=$(basename $EXECPREP_COL_SRC)
											local EXECPREP_COL_SRC=$MUSTGATHER_DIRNAME/data/manualcollect/scripts/$EXECPREP_COL_SRC_ORIG
										fi
									fi
								fi
							fi
	
							if [ ! "$EXECPREP_COL_SRC" == "bash" ]
							then
								if [ ! -e ${EXECPREP_COL_SRC} ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Source file [$EXECPREP_COL_SRC] of EXECPREP column does not exist. Skipping..."
									(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
									continue
								else
									local EXECPREP="${EXECPREP_COL_SRC}:${EXECPREP_COL_TGT}"
								fi
							else
								if [ ${#EXECPREP_COL_TGT} -gt 0 ] 
								then
									if [ $(echo "$EXECPREP_COL_TGT" | $AWK '{ print NF }') -gt 1 ]
									then
										local EXECPREP_COL_TGT_ARG=$(echo "$EXECPREP_COL_TGT" | $AWK '{ $1=""; print $0 }' | sed 's/^[ ]*//') 
									else
										local EXECPREP_REF_TGT_ARG=""
									fi

									local EXECPREP_COL_TGT=$(echo "$EXECPREP_COL_TGT" | $AWK '{ print $1 }')

									if [[ ! $(echo "$EXECPREP_COL_TGT" | $AWK '{ print $1 }') =~ ^/ ]]
									then
										if [ $MANUAL_COLL_CUSTOM_DATA == "false" ]
										then
											local EXECPREP_COL_TGT=$MUSTGATHER_DIRNAME/config/manualcollect/$PROD_VER/scripts/$EXECPREP_COL_TGT
										else
											local EXECPREP_COL_TGT=$MUSTGATHER_DIRNAME/data/manualcollect/$PROD_VER/scripts/$EXECPREP_COL_TGT

											if [ ! -s $EXECPREP_COL_TGT ]
											then	
												local EXECPREP_COL_TGT_ORIG=$(basename $EXECPREP_COL_TGT)
												local EXECPREP_COL_TGT=$MUSTGATHER_DIRNAME/data/manualcollect/scripts/$EXECPREP_COL_TGT_ORIG
											fi
										fi
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Target file setting of EXECPREP [$EXECPREP] column is empty/null. Skipping..."
									(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
									continue
								fi
							
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP_COL_TGT = [$EXECPREP_COL_TGT] / EXECPREP_COL_TGT_ARG = [$EXECPREP_COL_TGT_ARG]"
								fi

								if [ -s $EXECPREP_COL_TGT ]
								then
									if [ ${#TIMEOUT} -gt 0 ]
									then
										if [ ${#EXECPREP_COL_TGT_ARG} -gt 0 ]
										then
											local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXECPREP_COL_TGT $EXECPREP_COL_TGT_ARG"	
										else
											local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $EXECPREP_COL_TGT"	
										fi

										echo "[$(date)] [${FUNCNAME[0]}] Executing EXECPREP script [$CMD]..."
										RESULT=$(eval "$CMD")
										C_EXITSTATUS=$?
					
										if [ $C_EXITSTATUS -eq 124 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP script [$EXECPREP_COL_TGT] timeout after $DEFAULT_TIMEOUT! Skipping..."
											(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
											continue
										else	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] EXECPREP script file [$EXECPREP_COL_TGT] exits with status [$C_EXITSTATUS]"
											fi
										fi
									else
										local CMD="/bin/bash $EXECPREP_COL_TGT"	
										echo "[$(date)] [${FUNCNAME[0]}] Executing EXECPREP script [$EXECPREP_COL_TGT]..."
										local RESULT=$(eval "$CMD")
									fi

									if [ ${#RESULT} -gt 0 ]
									then
										if [ $MG_DEBUG = "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RESULT = [$RESULT]"
										fi

										local FINAL_RESULT=

										while read RES_LINE
										do
											if [[ "$RES_LINE" =~ ^WRITETO\> ]]
											then
												local WRITETO_EXECPREP_SRC=$(echo "$RES_LINE" | sed 's/^WRITETO>//' | $AWK -F: '{ print $1 }')
												local WRITETO_EXECPREP_TGT=$(echo "$RES_LINE" | sed 's/^WRITETO>//' | $AWK -F: '{ print $2 }')

												if [ ${#WRITETO_EXECPREP_SRC} -eq 0 ] || [ ${#WRITETO_EXECPREP_TGT} -eq 0 ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RES_LINE [$RES_LINE] invalid WRITETO syntax! Skipping..."

													local WRITETO_EXECPREP_SRC=
													local WRITETO_EXECPREP_TGT=

													continue
												else
													if [ -f ${WRITETO_EXECPREP_SRC} ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RES_LINE [$RES_LINE] Source file [$WRITETO_EXECPREP_SRC] exists! Skipping..."

														local WRITETO_EXECPREP_SRC=
														local WRITETO_EXECPREP_TGT=

														continue	
													else
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] WRITETO_EXECPREP_SRC = [$WRITETO_EXECPREP_SRC] / WRITETO_EXECPREP_TGT = [$WRITETO_EXECPREP_TGT]"
													fi
												fi
											else
												if [[ "$RES_LINE" =~ ^OUT\> ]]
												then
													if [ ${#WRITETO_EXECPREP_SRC} -gt 0 ]
													then
														local WRITETO_LINE=$(echo "$RES_LINE" | sed 's/^OUT>//')

														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Writing [$WRITETO_LINE] to EXECPREP_SRC_FILE [$WRITETO_EXECPREP_SRC]..."
														echo "$WRITETO_LINE" >> $WRITETO_EXECPREP_SRC
													else
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] WRITETO_EXECPREP_SRC is not set! Skipping [$RES_LINE]..."
														continue
													fi
												else
													if [[ "$RES_LINE" =~ [a-zA-Z0-9]*=[a-zA-Z0-9]* ]]
													then
														local RES_LINE_VAR=$(echo "$RES_LINE" | $AWK -F= '{ print $1 }')

														if [[ "$RES_LINE_VAR" =~ " " ]]
														then
															echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RES_LINE_VAR [$RES_LINE_VAR] of RES_LINE [$RES_LINE] contains spaces! Skipping..."
														else
															if [ ${#FINAL_RESULT} -eq 0 ]
															then
																local FINAL_RESULT="${RES_LINE}"
															else
																local FINAL_RESULT="${FINAL_RESULT}##${RES_LINE}"
															fi
														fi
													else
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] RES_LINE [$RES_LINE] is not in VAR=VAL format! Skipping..."
													fi
												fi
											fi
										done <<< "$RESULT"

										if [ ${#FINAL_RESULT} -gt 0 ]
										then
											if [ ${#MANUAL_COLL_ENV} -gt 0 ]
											then
												local PROC_MANUAL_COLL_TAGNAME_FOUND="false"
												local FINAL_MANUAL_COLL_ENV=

												for PROC_MANUAL_COLL_ENV_PAIRS in $(echo "$MANUAL_COLL_ENV" | sed 's/\^\^/\n/g')
												do
													local PROC_MANUAL_COLL_TAGNAME=$(echo "$PROC_MANUAL_COLL_ENV_PAIRS" | $AWK -F'~>' '{ print $1 }')
													local PROC_MANUAL_COLL_ENVVAR=$(echo "$PROC_MANUAL_COLL_ENV_PAIRS" | $AWK -F'~>' '{ print $2 }')

													if [ "$PROC_MANUAL_COLL_TAGNAME" == "$TAG" ]
													then
														local MANUAL_COLL_ENV_TAG_EXIST="true"
														local NEW_PROC_MANUAL_COLL_ENV_PAIRS="${PROC_MANUAL_COLL_TAGNAME}~>${PROC_MANUAL_COLL_ENVVAR}##${FINAL_RESULT}"
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Updating tag [$PROC_MANUAL_COLL_TAGNAME] to [${PROC_MANUAL_COLL_ENVVAR}##${FINAL_RESULT}]..."
													else
														local NEW_PROC_MANUAL_COLL_ENV_PAIRS="${PROC_MANUAL_COLL_ENV_PAIRS}"
													fi

													if [ ${#FINAL_MANUAL_COLL_ENV} -eq 0 ]
													then
														local FINAL_MANUAL_COLL_ENV="${NEW_PROC_MANUAL_COLL_ENV_PAIRS}"
													else
														local FINAL_MANUAL_COLL_ENV="${FINAL_MANUAL_COLL_ENV}^^${NEW_PROC_MANUAL_COLL_ENV_PAIRS}"
													fi

													if [ $MG_DEBUG == "true" ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] PROC_MANUAL_COLL_ENV_PAIRS = [$PROC_MANUAL_COLL_ENV_PAIRS] / FINAL_MANUAL_COLL_ENV = [$FINAL_MANUAL_COLL_ENV]"
													fi
												done

												if [ $PROC_MANUAL_COLL_TAGNAME_FOUND == "false" ]
												then
													MANUAL_COLL_ENV="${FINAL_MANUAL_COLL_ENV}^^${TAG}~>${FINAL_RESULT}"
												else
													MANUAL_COLL_ENV="${FINAL_MANUAL_COLL_ENV}"
												fi
											else
												MANUAL_COLL_ENV="${TAG}~>${FINAL_RESULT}"
											fi

											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] FINAL_RESULT = [${FINAL_RESULT}]"
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Updated MANUAL_COLL_ENV = [$MANUAL_COLL_ENV]"
										else
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] FINAL_RESULT is empty!"
										fi

										if [ ${#WRITETO_EXECPREP_SRC} -gt 0 ] && [ -s ${WRITETO_EXECPREP_SRC} ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Setting EXECPREP to [${WRITETO_EXECPREP_SRC}:${WRITETO_EXECPREP_TGT}]..."
											local EXECPREP="${WRITETO_EXECPREP_SRC}:${WRITETO_EXECPREP_TGT}"
										else
											echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] EXECPREP [$EXECPREP_COL_SRC:$EXECPREP_COL_TGT] is bash instruction! Emptying EXECPREP value with value []..."
											local EXECPREP=""
										fi		
									else
										echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Output of EXECPREP script file [$EXECPREP_COL_TGT] is empty!"
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Target file [$EXECPREP_COL_TGT] does not exist or is zero-sized! Skipping..."
									(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
									continue
								fi
							fi
						fi
	
						if [ ${#EXECPREP_COL_TGT} -eq 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Target file setting of EXECPREP [$EXECPREP] column is empty/null. Skipping..."
							(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
							continue
						fi
					fi
				fi
			fi
		fi

		if [ ${#MANUAL_COLL_ENV} -gt 0 ]
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] User input environment variables = [$MANUAL_COLL_ENV]"	
			fi

			IFS=$'\n'
			for PROC_MANUAL_COLL_ENV_PAIRS in $(echo "$MANUAL_COLL_ENV" | sed 's/\^\^/\n/g')
			do
				local PROC_MANUAL_COLL_TAGNAME=$(echo "$PROC_MANUAL_COLL_ENV_PAIRS" | $AWK -F'~>' '{ print $1 }')
				local PROC_MANUAL_COLL_ENVVAR=$(echo "$PROC_MANUAL_COLL_ENV_PAIRS" | $AWK -F'~>' '{ print $2 }')

				if [ "$PROC_MANUAL_COLL_TAGNAME" == "$TAG" ]
				then
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] Environment variables for tag [$PROC_MANUAL_COLL_TAGNAME] = [$PROC_MANUAL_COLL_ENVVAR] [MATCHED]"
					fi
	
					local FINAL_EXPORT_VAR=
					local KEYVAL=
					for KEYVAL in $(echo "$PROC_MANUAL_COLL_ENVVAR" | $AWK -F## '{ for (i=1;i<=NF;i++) { print $i } }')
					do
						local MC_KEY=$(echo "$KEYVAL" | $AWK -F= '{ print $1 }')
						# local MC_VAL=$(echo "$KEYVAL" | $AWK -F= '{ print $2 }')
						local MC_VAL=$(echo "$KEYVAL" | cut -f 2- -d = | sed 's/^"//' | sed 's/"$//')

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] MC_KEY = [$MC_KEY]"
							echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] MC_VAL = [$MC_VAL]"
						fi

						if [[ "$MC_VAL" =~ ^\" ]] && [[ "$MC_VAL" =~ \"$ ]]
						then
							# MC_VAL starts and ends with double quote [remove start/end double quotes for further processing]
							local TMP_MC_VAL=$(echo "$MC_VAL" | sed 's/^"//' | sed 's/"$//')
							echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] Removing start/end double quotes => TMP_MC_VAL = [$TMP_MC_VAL]"
						else
							# MC_VAL starts and ends with single quote [remove start/end single quotes for further processing]
							if [[ "$MC_VAL" =~ ^\' ]] && [[ "$MC_VAL" =~ \'$ ]]
							then
								local TMP_MC_VAL=$(echo "$MC_VAL" | sed "s/^'//" | sed "s/'$//")
								echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] Removing start/end single quotes => TMP_MC_VAL = [$TMP_MC_VAL]"
							else
								local TMP_MC_VAL="$MC_VAL"
							fi
						fi

						# Check whether there's any single/double quotes within the string value
						if echo "$TMP_MC_VAL" | grep '"' > /dev/null
						then
							local FINAL_MC_KEYVAL="$MC_KEY=\"$(echo $TMP_MC_VAL | sed 's/"/\\\\"/g')\""

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] Quoting environment variable [$MC_KEY] => [$FINAL_MC_KEYVAL]"
							fi
						else
							if echo "$TMP_MC_VAL" | grep "'" > /dev/null
							then
								local PROC_MC_VAL=$(echo "$TMP_MC_VAL" | sed "s/'/'\"'\"'/g")
								local FINAL_MC_KEYVAL="$MC_KEY=\"$PROC_MC_VAL\""

								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] Quoting environment variable [$MC_KEY] => [$FINAL_MC_KEYVAL]"
								fi
							else
								local FINAL_MC_KEYVAL="$MC_KEY=\"$TMP_MC_VAL\""

								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] Quoting environment variable [$MC_KEY] => [$FINAL_MC_KEYVAL]"
								fi
							fi
						fi

						if [ ${#FINAL_EXPORT_VAR} -eq 0 ]
						then
							FINAL_EXPORT_VAR="export $FINAL_MC_KEYVAL"
						else
							FINAL_EXPORT_VAR="$FINAL_EXPORT_VAR; export $FINAL_MC_KEYVAL"
						fi
					done

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Constructing new EXECCMD => [$FINAL_EXPORT_VAR; $EXECCMD]..."
					fi

					local EXECCMD="$FINAL_EXPORT_VAR; $EXECCMD"

					break
				else
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$CTR] Environment variables for tag [$PROC_MANUAL_COLL_TAGNAME] = [$PROC_MANUAL_COLL_ENVVAR] [NOT MATCHED]"
					fi
				fi
			done
			IFS=$OLDIFS
		fi

		if [[ $OBJ_NS =~ ^bash( ) ]] || [[ $OBJ_NS =~ ^NS4PROD= ]]
		then
			if [[ $OBJ_NS =~ ^bash( ) ]]
			then
				local NS_SHELL=$(echo "$OBJ_NS" | $AWK '{ print $1 }')	
				local NS_CMD=$(echo "$OBJ_NS" | $AWK '{ $1=""; print $0 }' | sed 's/^[ ]*//')
				local NS_SCRIPT=$(echo "$NS_CMD" | $AWK '{ print $1 }')
	
				if [[ ! $(echo "$NS_SCRIPT" | $AWK '{ print $1 }') =~ ^/ ]]
				then
					local NS_SCRIPT=$MUSTGATHER_DIRNAME/config/manualcollect/$PROD_VER/scripts/$NS_SCRIPT
					local NS_CMD_ARGS=$(echo ${NS_CMD} | $AWK '{ $1=""; print $0 }' | sed 's/^[ ]*//' | sed 's/[ ]*$//')

					if [ ${#NS_CMD_ARGS} -gt 0 ]
					then
						local NS_CMD="$NS_SCRIPT $NS_CMD_ARGS"
					else
						local NS_CMD="$NS_SCRIPT"
					fi
				fi
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] NS_SHELL = [$NS_SHELL] / NS_CMD = [$NS_CMD] / NS_SCRIPT = [$NS_SCRIPT]"
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] To execute script [$OBJ_NS] to determine namespace..."
				fi

				if [ -s $NS_SCRIPT ]
				then
					if [ ${#TIMEOUT} -gt 0 ]
					then
						local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $NS_CMD"	
						echo "[$(date)] [${FUNCNAME[0]}] Executing namespace script [$CMD]..."
						RESULT=$(eval "$CMD")
						C_EXITSTATUS=$?
	
						if [ $C_EXITSTATUS -eq 124 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Namespace script [$NS_SCRIPT] timeout after $DEFAULT_TIMEOUT! Skipping..."
							(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
							continue
						else	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Namespace script file [$NS_SCRIPT] exits with status [$C_EXITSTATUS]"
							fi
						fi
					else
						local CMD="/bin/bash $NS_CMD"	
						echo "[$(date)] [${FUNCNAME[0]}] Executing namespace script [$CMD]..."
						local RESULT=$(eval "$CMD")
					fi

					echo "[$(date)] [${FUNCNAME[0]}] Namespace(s) returned by script file [$NS_SCRIPT] = [$RESULT]"

					for RES in $RESULT
					do
						if toExcludeProdNamespace $RES
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] To exclude namespace [$RES]. Skipping..."
							(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
							continue
						fi

						echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
						if ! checkUserPriv get namespace $RES
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] User [$OC_WHOAMI] does not have '$OC_CMD get' privilege on [namespace] resource in namespace [$RES]. Skipping..."
							(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
							continue
						fi
	
						if $OC_CMD get ns $RES > /dev/null
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Result namespace = $RES"
							local OBJ_NS=$RES
		
							local TO_SKIP="false"
	
							if [ ${#EXECCMD} -gt 0 ]
							then
								local PRIV_CMD="checkUserPriv create pods/exec $OBJ_NS"
									
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] PRIV_CMD = [$PRIV_CMD]"
								fi
	
								# checkUserPriv() failed
								if ! eval "$PRIV_CMD"
								then
									local TO_SKIP="true"
								fi
							else
								for VERB in "get" "list"
								do
									if [ ${#OBJ_TYPE} -eq 0 ]
									then
										local PRIV_CMD="checkUserPriv $VERB all $OBJ_NS"
									else
										local PRIV_CMD="checkUserPriv $VERB $OBJ_TYPE $OBJ_NS"
									fi
										
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] PRIV_CMD = [$PRIV_CMD]"
									fi
		
									# checkUserPriv() failed
									if ! eval "$PRIV_CMD"
									then
										local TO_SKIP="true"
										break
									fi
								done
							fi
	
							if [ $TO_SKIP == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Config line [$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] failed user privilege check! Skipping..."
								(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
								continue
							else
								# If OBJ_NAME is REGEXSCRIPT
								if [ ${#OBJ_NAME} -gt 0 ] && [[ "${OBJ_NAME}" =~ ^bash[[:space:]] ]]
								then
									local REGEXSCRIPT=$(echo "$OBJ_NAME" | $AWK '{ print $2 }')
		
									if [[ ! $(echo "$REGEXSCRIPT" | $AWK '{ print $1 }') =~ ^/ ]]
									then
										local REGEXSCRIPT=$MUSTGATHER_DIRNAME/config/manualcollect/$PROD_VER/scripts/$REGEXSCRIPT
										local REGEXSCRIPT_CMD="$REGEXSCRIPT $(echo "$OBJ_NAME" | $AWK '{ $1=$2=""; print $0 }' | sed 's/^[ ]*//')"
									else
										local REGEXSCRIPT_CMD=$(echo "$OBJ_NAME" | $AWK '{ $1=""; print $0 }' | sed 's/^[ ]*//')
									fi
		
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] REGEXSCRIPT = [$REGEXSCRIPT] / REGEXSCRIPT_CMD = [$REGEXSCRIPT_CMD $OBJ_NS]"
									fi
		
									if [ -s $REGEXSCRIPT ]
									then
										local REGEXSCRIPT_TVALUE="15m"
			
										if [ ${#TIMEOUT} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT_CMD $OBJ_NS]..."
											fi
							
											local CMD="$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT_CMD $OBJ_NS"
											REGEX_CMD_RST=$(eval "$CMD")
											C_EXITSTATUS=$?
												
											if [ $C_EXITSTATUS -eq 124 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT_CMD $OBJ_NS] timeout after $REGEXSCRIPT_TVALUE!"
											fi	
										else
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [/bin/bash $REGEXSCRIPT_CMD $OBJ_NS]..."
											fi
						
											local CMD="/bin/bash $REGEXSCRIPT_CMD $OBJ_NS"
											REGEX_CMD_RST=$(eval "$CMD")
											C_EXITSTATUS=$?
										fi
				
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT_CMD $OBJ_NS] exits with status [$C_EXITSTATUS]"
										fi
			
										if [ $C_EXITSTATUS -ne 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT_CMD $OBJ_NS] failed with exit code [$C_EXITSTATUS]! Skipping..."
											(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
											continue
										else
											echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] Regex script file [$REGEXSCRIPT_CMD $OBJ_NS] = [$REGEX_CMD_RST]"
			
											if [ ${#REGEX_CMD_RST} -gt 0 ]
											then
												local OBJ_NAME="$REGEX_CMD_RST"
												local OBJ_NAME_PROC="true"
											else
												echo "[$(date)] [${FUNCNAME[0]}] REGEX_CMD_RST [$REGEX_CMD_RST] is empty/null! Skipping..."
												(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
												continue
											fi
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] REGEXSCRIPT [$REGEXSCRIPT] does not exist or is zero-sized! Skipping..."
										(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
										continue
									fi

									if [ ${#OBJ_NAME} -gt 0 ]
									then
										for OBJ_NAME_INST in $OBJ_NAME
										do
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Writing new config line [$TAG,$OBJ_NS,$OBJ_TYPE,$OBJ_NAME_INST,$CONTAINER,$EXECPREP,$EXECPREPRMSRC,$EXECCMD,$POSTEXEC] to [$OUTFILE]"
											fi
			
											echo "$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME_INST${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC" >> $OUTFILE
										done
									else
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Writing new config line [$TAG,$OBJ_NS,$OBJ_TYPE,$OBJ_NAME,$CONTAINER,$EXECPREP,$EXECPREPRMSRC,$EXECCMD,$POSTEXEC] to [$OUTFILE]"
										fi
		
										echo "$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC" >> $OUTFILE
									fi
								else
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Writing new config line [$TAG,$OBJ_NS,$OBJ_TYPE,$OBJ_NAME,$CONTAINER,$EXECPREP,$EXECPREPRMSRC,$EXECCMD,$POSTEXEC] to [$OUTFILE]"
									fi
		
									echo "$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC" >> $OUTFILE
								fi

								local OBJ_NS_PROC="true"
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Namespace returned by script [$NS_CMD] is invalid! Skipping..."
							(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
							continue
						fi
					done
				else
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Namespace script [$NS_SCRIPT] does not exist or is zero-sized! Skipping..."
					(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
					continue
				fi
			fi

			if [[ $OBJ_NS =~ ^NS4PROD= ]]
			then
				local PROD_NAME=$(echo "$OBJ_NS" | $AWK -F= '{ print $2 }')

				echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] PROD_NAME = [$PROD_NAME]"

				if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
				then
					local PROD_NAMESPACES=$(getProdToNamespacesMapping $PROD_NAME)
				else
					local PROD_NAMESPACES=$(getProdToNamespacesMapping $PROD_NAME $NS_REFFILE)
				fi

				if [ "$PROD_NAMESPACES" == $PROD_NAMESPACES_INVALID_STR ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Product [$PROD_NAME] namespace [NS=$PROD_NAMESPACES] returned by getProdToNamespacesMapping() is invalid! Skipping..."
					(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
					continue
				else
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] PROD_NAMESPACES = [$PROD_NAMESPACES]"
				fi	

				IFS=$OLDIFS

				for PROD_NS in $PROD_NAMESPACES
				do
					if toExcludeProdNamespace $PROD_NS
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] To exclude namespace [$PROD_NS]. Skipping..."
						(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
						continue
					fi

					local TO_SKIP="false"

					if [ ${#EXECCMD} -gt 0 ]
					then
						local PRIV_CMD="checkUserPriv create pods/exec $PROD_NS"
							
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] PRIV_CMD = [$PRIV_CMD]"
						fi

						# checkUserPriv() failed
						if ! eval "$PRIV_CMD"
						then
							local TO_SKIP="true"
						fi
					else
						for VERB in "get" "list"
						do
							if [ ${#OBJ_TYPE} -eq 0 ]
							then
								local PRIV_CMD="checkUserPriv $VERB all $PROD_NS"
							else
								local PRIV_CMD="checkUserPriv $VERB $OBJ_TYPE $PROD_NS"
							fi
								
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] PRIV_CMD = [$PRIV_CMD]"
							fi
	
							# checkUserPriv() failed
							if ! eval "$PRIV_CMD"
							then
								local TO_SKIP="true"
								break
							fi
						done
					fi

					if [ $TO_SKIP == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Config line [$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] failed user privilege check! Skipping..."
						(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
						continue
					else
						# If OBJ_NAME is REGEXSCRIPT
						if [ ${#OBJ_NAME} -gt 0 ] && [[ "${OBJ_NAME}" =~ ^bash[[:space:]] ]]
						then
							local REGEXSCRIPT=$(echo "$OBJ_NAME" | $AWK '{ print $2 }')

							if [[ ! $(echo "$REGEXSCRIPT" | $AWK '{ print $1 }') =~ ^/ ]]
							then
								local REGEXSCRIPT=$MUSTGATHER_DIRNAME/config/manualcollect/$PROD_VER/scripts/$REGEXSCRIPT
								local REGEXSCRIPT_CMD="$REGEXSCRIPT $(echo "$OBJ_NAME" | $AWK '{ $1=$2=""; print $0 }' | sed 's/^[ ]*//')"
							else
								local REGEXSCRIPT_CMD=$(echo "$OBJ_NAME" | $AWK '{ $1=""; print $0 }' | sed 's/^[ ]*//')
							fi

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] REGEXSCRIPT = [$REGEXSCRIPT] / REGEXSCRIPT_CMD = [$REGEXSCRIPT_CMD $PROD_NS]"
							fi

							if [ -s $REGEXSCRIPT ]
							then
								local REGEXSCRIPT_TVALUE="15m"
	
								if [ ${#TIMEOUT} -gt 0 ]
								then
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT_CMD $PROD_NS]..."
									fi
					
									local CMD="$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT_CMD $PROD_NS"
									REGEX_CMD_RST=$(eval "$CMD")
									C_EXITSTATUS=$?
										
									if [ $C_EXITSTATUS -eq 124 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT_CMD $PROD_NS] timeout after $REGEXSCRIPT_TVALUE!"
									fi	
								else
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [/bin/bash $REGEXSCRIPT_CMD $PROD_NS]..."
									fi
				
									local CMD="/bin/bash $REGEXSCRIPT_CMD $PROD_NS"
									REGEX_CMD_RST=$(eval "$CMD")
									C_EXITSTATUS=$?
								fi
		
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT_CMD $PROD_NS] exits with status [$C_EXITSTATUS]"
								fi
	
								if [ $C_EXITSTATUS -ne 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT_CMD $PROD_NS] failed with exit code [$C_EXITSTATUS]! Skipping..."
									(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
									continue
								else
									echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] Regex script file [$REGEXSCRIPT_CMD $PROD_NS] = [$REGEX_CMD_RST]"
	
									if [ ${#REGEX_CMD_RST} -gt 0 ]
									then
										local OBJ_NAME="$REGEX_CMD_RST"
										local OBJ_NAME_PROC="true"
									else
										echo "[$(date)] [${FUNCNAME[0]}] REGEX_CMD_RST [$REGEX_CMD_RST] is empty/null! Skipping..."
										(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
										continue
									fi
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] REGEXSCRIPT [$REGEXSCRIPT] does not exist or is zero-sized! Skipping..."
								(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
								continue
							fi

							if [ ${#OBJ_NAME} -gt 0 ]
							then
								for OBJ_NAME_INST in $OBJ_NAME
								do
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Writing new config line [$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME_INST${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] to [$OUTFILE]"
									fi
			
									echo "$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME_INST${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC" >> $OUTFILE	
								done
							else
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Writing new config line [$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] to [$OUTFILE]"
								fi
		
								echo "$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC" >> $OUTFILE	
							fi
						else
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Writing new config line [$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] to [$OUTFILE]"
							fi

							echo "$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$PROD_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC" >> $OUTFILE	
						fi

						local OBJ_NS_PROC="true"
					fi
				done
	
				IFS=$'\n'
			fi
		else
			# Hardcoded OBJ_NS
			if toExcludeProdNamespace $OBJ_NS
			then
				echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] To exclude namespace [$OBJ_NS]. Skipping..."
				(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
				continue
			fi

			local TO_SKIP="false"

			if [ ${#EXECCMD} -gt 0 ]
			then
				local PRIV_CMD="checkUserPriv create pods/exec $OBJ_NS"
					
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] PRIV_CMD = [$PRIV_CMD]"
				fi

				# checkUserPriv() failed
				if ! eval "$PRIV_CMD"
				then
					local TO_SKIP="true"
				fi
			else
				IFS=$OLDIFS

				for VERB in "get" "list"
				do
					if [ ${#OBJ_TYPE} -eq 0 ]
					then
						local PRIV_CMD="checkUserPriv $VERB all $OBJ_NS"
					else
						local PRIV_CMD="checkUserPriv $VERB $OBJ_TYPE $OBJ_NS"
					fi
						
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] PRIV_CMD = [$PRIV_CMD]"
					fi
	
					# checkUserPriv() failed
					if ! eval "$PRIV_CMD"
					then
						local TO_SKIP="true"
						break
					fi
				done

				IFS=$'\n'
			fi

			if [ $TO_SKIP == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Config line [$LINE] failed user privilege check! Skipping..."
				(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
				continue
			else
				# If OBJ_NAME is REGEXSCRIPT
				if [ ${#OBJ_NAME} -gt 0 ] && [[ "${OBJ_NAME}" =~ ^bash[[:space:]] ]]
				then
					local REGEXSCRIPT=$(echo "$OBJ_NAME" | $AWK '{ print $2 }')

					if [[ ! $(echo "$REGEXSCRIPT" | $AWK '{ print $1 }') =~ ^/ ]]
					then
						local REGEXSCRIPT=$MUSTGATHER_DIRNAME/config/manualcollect/$PROD_VER/scripts/$REGEXSCRIPT
						local REGEXSCRIPT_CMD="$REGEXSCRIPT $(echo "$OBJ_NAME" | $AWK '{ $1=$2=""; print $0 }' | sed 's/^[ ]*//')"
					else
						local REGEXSCRIPT_CMD=$(echo "$OBJ_NAME" | $AWK '{ $1=""; print $0 }' | sed 's/^[ ]*//')
					fi

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] REGEXSCRIPT = [$REGEXSCRIPT] / REGEXSCRIPT_CMD = [$REGEXSCRIPT_CMD $OBJ_NS]"
					fi

					if [ -s $REGEXSCRIPT ]
					then
						local REGEXSCRIPT_TVALUE="15m"
	
						if [ ${#TIMEOUT} -gt 0 ]
						then
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT_CMD $OBJ_NS]..."
							fi
			
							local CMD="$TIMEOUT $REGEXSCRIPT_TVALUE /bin/bash $REGEXSCRIPT_CMD $OBJ_NS"
							REGEX_CMD_RST=$(eval "$CMD")
							C_EXITSTATUS=$?
								
							if [ $C_EXITSTATUS -eq 124 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT_CMD $OBJ_NS] timeout after $REGEXSCRIPT_TVALUE!"
							fi	
						else
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing regex script file [/bin/bash $REGEXSCRIPT_CMD $OBJ_NS]..."
							fi
		
							local CMD="/bin/bash $REGEXSCRIPT_CMD $OBJ_NS"
							REGEX_CMD_RST=$(eval "$CMD")
							C_EXITSTATUS=$?
						fi

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT_CMD $OBJ_NS] exits with status [$C_EXITSTATUS]"
						fi
	
						if [ $C_EXITSTATUS -ne 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT_CMD $OBJ_NS] failed with exit code [$C_EXITSTATUS]! Skipping..."
							(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
							continue
						else
							echo "[$(date)] [${FUNCNAME[0]}] [OUTPUT] Regex script file [$REGEXSCRIPT_CMD $OBJ_NS] = [$REGEX_CMD_RST]"
	
							if [ ${#REGEX_CMD_RST} -gt 0 ]
							then
								local OBJ_NAME="$REGEX_CMD_RST"
								local OBJ_NAME_PROC="true"
							else
								echo "[$(date)] [${FUNCNAME[0]}] REGEX_CMD_RST [$REGEX_CMD_RST] is empty/null! Skipping..."
								(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
								continue
							fi
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] REGEXSCRIPT [$REGEXSCRIPT] does not exist or is zero-sized! Skipping..."
						(( TOTAL_LINE_SKIP=TOTAL_LINE_SKIP+1 ))
						continue
					fi

					if [ ${#OBJ_NAME} -gt 0 ]
					then
						for OBJ_NAME_INST in $OBJ_NAME
						do
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Writing new config line [$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME_INST${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] to [$OUTFILE]"
							fi
			
							echo "$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME_INST${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC" >> $OUTFILE	
						done
					else
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Writing new config line [$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] to [$OUTFILE]"
						fi
			
						echo "$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC" >> $OUTFILE	
					fi
				else
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Writing new config line [$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC] to [$OUTFILE]"
					fi
		
					echo "$TAG${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NS${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_TYPE${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_NAME${MANUAL_COLL_CFGFILE_DELIMITER}$OBJ_FILTER${MANUAL_COLL_CFGFILE_DELIMITER}$CONTAINER${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREP${MANUAL_COLL_CFGFILE_DELIMITER}$EXECPREPRMSRC${MANUAL_COLL_CFGFILE_DELIMITER}$EXECCMD${MANUAL_COLL_CFGFILE_DELIMITER}$POSTEXEC" >> $OUTFILE	
				fi

				if [ $OBJ_NS_PROC == "false" ] && [ $OBJ_NAME_PROC == "false" ]
				then
					(( TOTAL_LINE_SAME=TOTAL_LINE_SAME+1 ))
				fi
			fi
		fi

		if [ $OBJ_NS_PROC == "true" ] || [ $OBJ_NAME_PROC == "true" ]
		then
			(( TOTAL_LINE_PROC=TOTAL_LINE_PROC+1 ))
		fi
	done < <(sort $INFILE)

	echo "[$(date)] [${FUNCNAME[0]}] TOTAL_LINE_PROC = $TOTAL_LINE_PROC"
	echo "[$(date)] [${FUNCNAME[0]}] TOTAL_LINE_SAME = $TOTAL_LINE_SAME"
	echo "[$(date)] [${FUNCNAME[0]}] TOTAL_LINE_SKIP = $TOTAL_LINE_SKIP"

	(( TOTAL_LINE_FINAL=TOTAL_LINE_PROC+TOTAL_LINE_SAME ))
	echo "[$(date)] [${FUNCNAME[0]}] TOTAL_LINE_FINAL = $TOTAL_LINE_FINAL"

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [INFILE=$INFILE / PRODVER=$PROD_VER]"
	fi
}

doManualCollection()
{
	if [ $MANUAL_COLL -ne 1 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] MANUALCOLLECT mode is disabled [$MANUAL_COLL]! Returning..."
		return 1
	fi

	if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
	then
		while read PROD_VER_LINE
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_VER_LINE = [$PROD_VER_LINE]"
			fi

			local MANUALCOLL_PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')

			if [ ${#RTVAR_MANUALCOLL_PRODVER} -gt 0 ]
			then
				local MANUALCOLL_PRODVER_VALID="false"
	
				for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
				do
					if [ $RTVAR_MANUALCOLL_PRODVER == $VALID_PROD_VERSION ]
					then
						local MANUALCOLL_PRODVER_VALID="true"
						break
					fi
				done	
	
				if [ $MANUALCOLL_PRODVER_VALID == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] MANUALCOLL_PRODVER is set to [$RTVAR_MANUALCOLL_PRODVER]! Setting MANUALCOLL_PROD_VER to [$RTVAR_MANUALCOLL_PRODVER]!"
					local MANUALCOLL_PROD_VER=$RTVAR_MANUALCOLL_PRODVER
				else
					local MANUALCOLL_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
					echo "[$(date)] [${FUNCNAME[0]}] MANUALCOLL_PRODVER [$RTVAR_MANUALCOLL_PRODVER] is invalid or not supported product version! Setting MANUALCOLL_PROD_VER to default [$MANUALCOLL_PROD_VER]!"
				fi	
			else
				local MANUALCOLL_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
			fi

			if [[ ! $MANUAL_COLL_INPUTFILE =~ ^/ ]] && [[ ! $MANUAL_COLL_INPUTFILE =~ ^./ ]]
			then
				if [ $MANUAL_COLL_CUSTOM_DATA == "true" ] 
				then
					if [ $MANUAL_COLL_INPUTFILE == ".listmc_custom" ]
					then
						local MANUAL_COLL_INPUTFILE_FINAL="mc_custom.help"
					else
						local MANUAL_COLL_INPUTFILE_FINAL="$MANUAL_COLL_INPUTFILE"
					fi

					local INPUT_FILE="$MUSTGATHER_DIRNAME/data/manualcollect/$MANUALCOLL_PROD_VER/config/$MANUAL_COLL_INPUTFILE_FINAL"
					echo "[$(date)] [${FUNCNAME[0]}] Locating INPUT_FILE [$INPUT_FILE]..."

					if [ ! -s $INPUT_FILE ]
					then
						local INPUT_FILE="$MUSTGATHER_DIRNAME/data/manualcollect/config/$MANUAL_COLL_INPUTFILE_FINAL"
						echo "[$(date)] [${FUNCNAME[0]}] Locating INPUT_FILE [$INPUT_FILE]..."

						if [ ! -s $INPUT_FILE ]
						then	
							local INPUT_FILE="$MUSTGATHER_DIRNAME/config/manualcollect/$MANUALCOLL_PROD_VER/config/$MANUAL_COLL_INPUTFILE"
							echo "[$(date)] [${FUNCNAME[0]}] Unable to locate custom MANUAL_COLL_INPUTFILE! Setting to default [$INPUT_FILE]..."
						else
							if [ $MANUAL_COLL_INPUTFILE == ".listmc_custom" ]
							then
								local INPUT_FILE="$MUSTGATHER_DIRNAME/data/manualcollect/config/$MANUAL_COLL_INPUTFILE"
							else
								echo "[$(date)] [${FUNCNAME[0]}] INPUT_FILE is overwritten with custom MANUAL_COLL_INPUTFILE [$INPUT_FILE]..."
							fi
						fi
					else
						if [ $MANUAL_COLL_INPUTFILE == ".listmc_custom" ]
						then
							local INPUT_FILE="$MUSTGATHER_DIRNAME/data/manualcollect/$MANUALCOLL_PROD_VER/config/$MANUAL_COLL_INPUTFILE"
						else
							echo "[$(date)] [${FUNCNAME[0]}] INPUT_FILE is overwritten with custom MANUAL_COLL_INPUTFILE [$INPUT_FILE]..."
						fi
					fi

					echo "[$(date)] [${FUNCNAME[0]}] INPUT_FILE = [$INPUT_FILE]"
				else
					local INPUT_FILE="$MUSTGATHER_DIRNAME/config/manualcollect/$MANUALCOLL_PROD_VER/config/$MANUAL_COLL_INPUTFILE"
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] INPUT_FILE is overwritten with user provided MANUAL_COLL_INPUTFILE [$MANUAL_COLL_INPUTFILE]..."
				local INPUT_FILE=$MANUAL_COLL_INPUTFILE
			fi

			if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
			then
				local MANUALCOLL_OUTDIR=$MANUAL_COLL_OUTDIR
			else			
				local MANUALCOLL_OUTDIR=$MANUAL_COLL_OUTDIR/PRODGRP=$MANUALCOLL_PROD_GROUP
			fi

			local MANUALCOLL_PROD_GROUP_NS_REFFILE=${REFFILE_OUTDIR}/${MANUALCOLL_PROD_GROUP}.ns-ref
	
			if [ -f ${MANUALCOLL_PROD_GROUP_NS_REFFILE} ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Calling function getManualCollection() - [INPUT_FILE=$INPUT_FILE ## MANUALCOLL_OUTDIR=$MANUALCOLL_OUTDIR ## MANUALCOLL_PROD_GROUP=$MANUALCOLL_PROD_GROUP ## MANUALCOLL_PROD_VER=$MANUALCOLL_PROD_VER ## MANUALCOLL_PROD_GROUP_NS_REFFILE=$MANUALCOLL_PROD_GROUP_NS_REFFILE"
				getManualCollection "$INPUT_FILE" "$MANUALCOLL_OUTDIR" "$MANUALCOLL_PROD_GROUP" "$MANUALCOLL_PROD_VER" "$MANUALCOLL_PROD_GROUP_NS_REFFILE"
			else
				echo "[$(date)] [${FUNCNAME[0]}] Product group namespace reference file [${REFFILE_OUTDIR}/${MANUALCOLL_PROD_GROUP}.ns-ref] does not exist or is zero-sized! Skipping..."
				continue
			fi
		done < $PROD_VERSIONS_REFFILE_FINAL
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product group namespace reference file [$PROD_VERSIONS_REFFILE_FINAL] does not exist or is zero-sized!"
		echo "[$(date)] [${FUNCNAME[0]}] Falling back to default 'non-product-group' execution..."

		local INPUT_FILE="$MUSTGATHER_DIRNAME/config/manualcollect/$PRODUCT_VERSION/config/mc.cfg"
		local MANUALCOLL_OUTDIR=$MANUAL_COLL_OUTDIR
		local MANUALCOLL_PROD_GROUP="default"
		local MANUALCOLL_PROD_VER=$PRODUCT_VERSION
		local MANUALCOLL_PROD_GROUP_NS_REFFILE=$PROD_NAMESPACES_REFFILE

		echo "[$(date)] [${FUNCNAME[0]}] Calling function getManualCollection() - [INPUT_FILE=$INPUT_FILE ## MANUALCOLL_OUTDIR=$MANUALCOLL_OUTDIR ## MANUALCOLL_PROD_GROUP=$MANUALCOLL_PROD_GROUP ## MANUALCOLL_PROD_VER=$MANUALCOLL_PROD_VER ## MANUALCOLL_PROD_GROUP_NS_REFFILE=$MANUALCOLL_PROD_GROUP_NS_REFFILE"
		getManualCollection "$INPUT_FILE" "$MANUALCOLL_OUTDIR" "$MANUALCOLL_PROD_GROUP" "$MANUALCOLL_PROD_VER" "$MANUALCOLL_PROD_GROUP_NS_REFFILE"
	fi
}

getManualCollection()
{
	local MC_INFILE=$1
	local MC_OUTDIR=$2
	local MC_PROD_GROUP=$3
	local MC_PROD_VER=$4
	local MC_PROD_GROUP_NS_REFFILE=$5

	local MANUAL_COLL_TOTAL_COLS=9

	local POD=
	local XLINE=
	local X_OBJ_NAME=
	local OC_GET_CMD=
	local CONTAINER=
	local TMPFILE=
	local LINE=
	local OBJ_LINE=

	if [ $(basename $MC_INFILE) == ".listmc" ] || [ $(basename $MC_INFILE) == ".listmc_custom" ]
	then
 		echo "[$(date)] [${FUNCNAME[0]}] Executing manual data collection help info..."

		local OLD_MC_INFILE=$MC_INFILE

		if [ $MANUAL_COLL_CUSTOM_DATA == "true" ]		
		then
			local MC_INFILE="$(dirname $MC_INFILE)/mc_custom.cfg"
			local H_INFILE="$(dirname $MC_INFILE)/mc_custom.help"
		else
			local MC_INFILE="$(dirname $MC_INFILE)/mc.cfg"
			local H_INFILE="$(dirname $MC_INFILE)/mc.help"
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Changing MC_INFILE from [$OLD_MC_INFILE] to [$MC_INFILE]..."
			echo "[$(date)] [${FUNCNAME[0]}] Setting H_INFILE to [$H_INFILE]..."
		fi

		if [ -s $H_INFILE ]
		then
			if [ ! -d $MC_OUTDIR ]
			then
				mkdir -p $MC_OUTDIR
			fi

			echo "[PROD_GRP = $MC_PROD_GROUP / PROV_VER = $MC_PROD_VER]" >> $ANALYZE_OUTFILE
			echo "====================================================================================================================================================================================" >> $ANALYZE_OUTFILE
			printf "%-25s %-90s %-60s \n" "TAG" "DESCRIPTION" "EXAMPLE" >> $ANALYZE_OUTFILE
			echo "====================================================================================================================================================================================" >> $ANALYZE_OUTFILE

 			while read LINE	
 			do
				# Skip all lines that start with @ and blank lines
				if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "$MANUAL_COLL_CFGFILE_COMMENT"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi
		
				local H_TAG=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $1 }')
				local H_TAG_EXIST=$($AWK -F${MANUAL_COLL_HELPFILE_DELIMITER} '$1 ~ /^'$H_TAG'$/ { print }' $H_INFILE)

				if [ ${#H_TAG_EXIST} -gt 0 ]
				then
					local H_DESC=$($AWK -F${MANUAL_COLL_HELPFILE_DELIMITER} '$1 ~ /^'$H_TAG'$/ { print $2 }' $H_INFILE)
					local H_EG=$($AWK -F${MANUAL_COLL_HELPFILE_DELIMITER} -v DEL=${MANUAL_COLL_HELPFILE_DELIMITER} '$1 ~ /^'$H_TAG'$/ { for (i=3; i<=NF; i++) { if (length(EG) == 0 ) { EG=$i } else { EG=EG DEL $i } } } END { print EG }' $H_INFILE | sed 's/^[ ]*//')

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] H_TAG = [$H_TAG] / H_DESC = [$H_DESC] / H_EG = [$H_EG]"
					fi

					printf "%-25s %-90s %-60s \n" "$H_TAG" "$H_DESC" "$H_EG" >> $ANALYZE_OUTFILE
				else
					printf "%-25s %-90s %-60s \n" "$H_TAG" "N/A" "N/A" >> $ANALYZE_OUTFILE
				fi
			done < <(sort $MC_INFILE)

			echo >> $ANALYZE_OUTFILE
		
			return 0
		else
			echo "[$(date)] [${FUNCNAME[0]}] MANUALCOLLECT help file [$MC_INFILE] does not exist or is zero-sized! Returning..."
			return 1
		fi	
	else
 		echo "[$(date)] [${FUNCNAME[0]}] Executing manual data collection [input file = $MC_INFILE]..."
	fi

	if [ -f $MC_OUTDIR/$(basename $MC_INFILE) ]
	then
		if [ $MANUAL_COLL_SECRET == "true" ]
		then
			DIFF=$(diff $MC_OUTDIR/$(basename $MC_INFILE) $MC_INFILE 2> /dev/null)

			if [ ${#DIFF} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] MANUAL_COLL_INPUTFILE [$MC_INFILE] failed verification! File content has changed since initial check!"
				cp -p $MC_INFILE $MC_OUTDIR/$(basename $MC_INFILE).suspicious
				return 1
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] MANUAL_COLL_INPUTFILE [$MC_INFILE] is verified! To proceed..."
				fi
			fi
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] The 'manualcollect' data collection mode (-m) is not configured to collect secret. Not verifying file content!"
			fi
		fi
	else
		if [ ! -d $MC_OUTDIR ]
		then
			mkdir -p $MC_OUTDIR
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Copying 'getManualCollection()' input file [$MC_INFILE] to [$MC_OUTDIR]..."
		cp -p $MC_INFILE $MC_OUTDIR
	fi

 	if [ ! -s ${MC_INFILE} ]
 	then
 		echo "[$(date)] [${FUNCNAME[0]}] Input file [$MC_INFILE] for function getManualCollection() is unavailable or zero-sized. Exiting..."
 	else
		local TMPFILE_ARRAY=()

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] MANUAL_COLL_INPUTTAG = $MANUAL_COLL_INPUTTAG"
		fi

		local MANUAL_COLL_CFGLINE_CTR=0

		local MANUAL_COLL_INPUTFILE_PROC=$MC_OUTDIR/FINAL-MANUALCOLLECT-CFG.proc
		if ! processManualCollFile ${MC_INFILE} ${MANUAL_COLL_INPUTFILE_PROC} ${MC_PROD_GROUP_NS_REFFILE} ${MC_PROD_VER}
		then
			return 1
		fi

		if [ $CMD_EXEC_MC_MANUAL == "false" ] && [ ${#CMD_EXEC_RESULT_MCCFG_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_MCCFG_FILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] To process and execute configuration lines passed in by CMDEXEC mode..."
			echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC passed-in configurations lines = [$(cat $CMD_EXEC_RESULT_MCCFG_FILE)]"

			if ! processManualCollFile ${CMD_EXEC_RESULT_MCCFG_FILE} ${MANUAL_COLL_INPUTFILE_PROC} ${MC_PROD_GROUP_NS_REFFILE} ${MC_PROD_VER}
			then
				return 1
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Copying CMD_EXEC_RESULT_MCCFG_FILE [$CMD_EXEC_RESULT_MCCFG_FILE] to directory [$MANUAL_COLL_OUTDIR]..."
				cp -p $CMD_EXEC_RESULT_MCCFG_FILE $MC_OUTDIR
			fi
		fi

		if [ $MG_DEBUG == "true" ]
		then
			local FUNC_START=$(getFuncStartTime)
		fi

		# Backup the OBJNAME reference file
		if [ ${#MANUAL_COLL_OBJNAME_REFFILE} -gt 0 ]
		then
			if [ ! -f $MC_OUTDIR/$(basename $MANUAL_COLL_OBJNAME_REFFILE) ] && [ -f $MANUAL_COLL_OJBNAME_REFFILE ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Backing up OBJNAME reference file [$MANUAL_COLL_OBJNAME_REFFILE] to directory [$MC_OUTDIR]..."
				mv $MANUAL_COLL_OBJNAME_REFFILE $MC_OUTDIR
			fi
		fi

		# Backup the EXECPREP reference file
		if [ ${#MANUAL_COLL_EXECPREP_REFFILE} -gt 0 ]
		then
			if [ ! -f $MC_OUTDIR/$(basename $MANUAL_COLL_EXECPREP_REFFILE) ] && [ -f $MANUAL_COLL_EXECPREP_REFFILE ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Backing up EXECPREP reference file [$MANUAL_COLL_EXECPREP_REFFILE] to directory [$MC_OUTDIR]..."
				mv $MANUAL_COLL_EXECPREP_REFFILE $MC_OUTDIR
			fi
		fi

		if [ ! -s $MANUAL_COLL_INPUTFILE_PROC ]
		then
 			echo "[$(date)] [${FUNCNAME[0]}] Processed input file for function getManualCollection() is unavailable or zero-sized. Exiting..."
			return 1
		else
			echo "[$(date)] [${FUNCNAME[0]}] Final total of processed configuration lines = [$(wc -l ${MANUAL_COLL_INPUTFILE_PROC} | $AWK '{ print $1 }')]"
		fi

 		while read LINE	
 		do
			# Skip all lines that start with @
			if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "$MANUAL_COLL_CFGFILE_COMMENT"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi
			
			local TAG=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $1 }')
			local OBJ_NS=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $2 }')
			local OBJ_TYPE=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print tolower($3) }')
			local OBJ_NAME=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $4 }')
			local OBJ_FILTER=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $5 }')
			local CONTAINER=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $6 }')
			local EXECPREP=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $7 }')
			local EXECPREPRMSRC=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $8 }')
			local EXECCMD=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $9 }')
			local POSTEXEC=$(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print $10 }')

			# local MC_OUTDIR=$MANUAL_COLL_OUTDIR
			
			if [ ! -d $MC_OUTDIR ]
			then
				echo "[$(date)] [${FUNCNAME[0]}]  Making directory [$MC_OUTDIR]..."
				mkdir -p $MC_OUTDIR
			fi

			if [ $(echo "$LINE" | $AWK -F${MANUAL_COLL_CFGFILE_DELIMITER} '{ print NF }') -lt ${MANUAL_COLL_TOTAL_COLS} ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Config line [$LINE] has less than ${MANUAL_COLL_TOTAL_COLS} columns and is invalid. Skipping line..."
				continue
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] TAG=[$TAG] / OBJ_NS=[$OBJ_NS] / OBJ_TYPE=[$OBJ_TYPE] / OBJ_NAME=[$OBJ_NAME] / OBJ_FILTER=[$OBJ_FILTER] / CONTAINER=[$CONTAINER] / EXECPREP=[$EXECPREP] / EXECPREPRMSRC = [$EXECPREPRMSRC] / EXECCMD=[$EXECCMD] / POSTEXEC=[$POSTEXEC]"
				fi
			fi

			(( MANUAL_COLL_CFGLINE_CTR=MANUAL_COLL_CFGLINE_CTR+1 ))

			if [ $(echo "${OBJ_NS}"X | sed 's/[ ]*//') == "X" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Namespace cannot be empty. Skipping line [$LINE]..."
				continue
			else
				if [ $OBJ_NS == "all" ]
				then
					local OBJ_NS_CMD="--all-namespaces"
				else
					local OBJ_NS_CMD="-n $OBJ_NS"
				fi
			fi

			# To support EXECCMD feature
			if [ ${#EXECCMD} -gt 0 ]
			then	
				if [ $OBJ_NS == "all" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] EXECCMD [$EXECCMD] cannot be executed on 'all' namespaces! Skipping..."
					echo "[$(date)] [${FUNCNAME[0]}] CFGLINE = $LINE"
					continue
				fi

				if [ $OBJ_TYPE == "pod" ] || [ $OBJ_TYPE == "po" ] || [ $OBJ_TYPE == "pods" ]
				then
					if [ ! -d $MC_OUTDIR/TAG=$TAG/$OBJ_NS ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Making directory [$MC_OUTDIR/TAG=$TAG/$OBJ_NS]..."
						mkdir -p $MC_OUTDIR/TAG=$TAG/$OBJ_NS
					fi

					if [ $REPORT_ON_SCREEN == "true" ]
					then
						echo "===================================================" >> $ANALYZE_OUTFILE
						echo "[MANUALCOLLECT] OUTPUT OF EXECCMD (PROD_GROUP = $MC_PROD_GROUP / PROD_VER = $MC_PROD_VER) " >> $ANALYZE_OUTFILE
						echo "===================================================" >> $ANALYZE_OUTFILE

						if [ $MG_DEBUG == "true" ]
						then
							echo "[CFGFILE = $MC_INFILE]" >> $ANALYZE_OUTFILE
							echo "[CFGLINE = $LINE]" >> $ANALYZE_OUTFILE
						fi
					fi		

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$MANUAL_COLL_CFGLINE_CTR] = $LINE"
					fi

					if [ ${#OBJ_FILTER} -eq 0 ]
					then
						local GET_POD_LIST="$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_NS_CMD | $AWK '/${OBJ_NAME}/ { print }'"
					else
						local OBJ_FILTER_STATUS=${OBJ_FILTER%:*}
						local OBJ_FILTER_LIMIT=$(echo "$OBJ_FILTER" | $AWK -F: '{ print $NF }')

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_STATUS = [$OBJ_FILTER_STATUS] / OBJ_FILTER_LIMIT = [$OBJ_FILTER_LIMIT]"
						fi

						if [ ${#OBJ_FILTER_STATUS} -eq 0 ] && [ ${#OBJ_FILTER_LIMIT} -eq 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Both OBJ_FILTER_STATUS and OBJ_FILTER_LIMIT are empty! No object filter will be applied!"
							local GET_POD_LIST="$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_NS_CMD | $AWK '/${OBJ_NAME}/ { print }'"
						else
							if [ ${#OBJ_FILTER_STATUS} -gt 0 ] 
							then
								local OBJ_FILTER_FIELD_SELECTOR="--field-selector $OBJ_FILTER_STATUS"
							fi

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_FIELD_SELECTOR = [$OBJ_FILTER_FIELD_SELECTOR]"
							fi

							if [ ${#OBJ_FILTER_LIMIT} -eq 0 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_LIMIT [$OBJ_FILTER_LIMIT] is empty! Setting to default [ALL]"
								local GET_POD_LIST="$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD | $AWK '/${OBJ_NAME}/ { print }'"
							else
								if [[ $OBJ_FILTER_LIMIT =~ ^[0-9]+$ ]]
								then
									echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_LIMIT is set to [$OBJ_FILTER_LIMIT]!"
									local GET_POD_LIST="$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD | $AWK '/${OBJ_NAME}/ { print }' | head -$OBJ_FILTER_LIMIT"
								else
									echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_LIMIT [$OBJ_FILTER_LIMIT] is not a number! Setting to default [ALL]"
									local GET_POD_LIST="$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD | $AWK '/${OBJ_NAME}/ { print }'"
								fi
							fi	
						fi
					fi

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Executing command '$GET_POD_LIST'"
					fi

					local PRI_SHELL="bash"	
					local SEC_SHELL="sh"	
				
					local POD_LIST=$(eval "$GET_POD_LIST")	

					if [ ${#POD_LIST} -eq 0 ]
					then
						if [ $REPORT_ON_SCREEN == "true" ]
						then
							echo >> $ANALYZE_OUTFILE
						fi

						echo "[$(date)] [${FUNCNAME[0]}] No pod matching regex [$OBJ_NAME] found. Skipping..."
						continue
					fi

					local POD_CTR=1
						
					for POD in ${POD_LIST}
					do
						local POD_STATUS_CMD="$OC_CMD get pod $POD $OBJ_NS_CMD | grep -v '^NAME' | $AWK '{ print \$3 }'"

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$POD_STATUS_CMD'"
						fi

						local POD_STATUS=$(eval "$POD_STATUS_CMD")

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Status of pod [$POD] = $POD_STATUS"
						fi

						if [ ${POD_STATUS} != "Running" ]
						then
							if [ $REPORT_ON_SCREEN == "true" ]
							then
								echo >> $ANALYZE_OUTFILE
							fi

							echo "[$(date)] [${FUNCNAME[0]}] Pod [$POD] is not in RUNNING state [$POD_STATUS]. Skipping..."	
							continue
						fi

						if [[ ${EXECCMD} =~ ^\".*\"$ ]]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Removing starting and trailing double quotes from EXECCMD [$EXECCMD]..."
							local EXECCMD="${EXECCMD%\"}"
							local EXECCMD="${EXECCMD#\"}"
							echo "[$(date)] [${FUNCNAME[0]}] EXECCMD = [$EXECCMD]"
						fi

						if [[ ${EXECCMD} =~ ^\'.*\'$ ]]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Removing starting and trailing single quotes from EXECCMD [$EXECCMD]..."
							local EXECCMD="${EXECCMD%\'}"
							local EXECCMD="${EXECCMD#\'}"
							echo "[$(date)] [${FUNCNAME[0]}] EXECCMD = [$EXECCMD]"
						fi

						# To copy EXECPREP file into container
						if [ ${#EXECPREP} -gt 0 ]
						then
							local EXEC_SRC_FILE=$(echo "$EXECPREP" | $AWK -F: '{ print $1 }')
							local EXEC_TGT_FILE=$(echo "$EXECPREP" | $AWK -F: '{ print $2 }')

							if [ -e ${EXEC_SRC_FILE} ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									local EXEC_SRC_FILE_LEN=$(wc -l $EXEC_SRC_FILE | $AWK '{ print $1 }')

									echo "[$(date)] [${FUNCNAME[0]}] Content of EXEC_SRC_FILE [$EXEC_SRC_FILE] [Length=$EXEC_SRC_FILE_LEN] =>"

									if [ $EXEC_SRC_FILE_LEN -gt $MANUALCOLLECT_EXECPREP_SRC_MAXLINE ]
									then	
										head -$MANUALCOLLECT_EXECPREP_SRC_MAXLINE $EXEC_SRC_FILE
										echo "..."
									else
										cat $EXEC_SRC_FILE
									fi

									echo "***** END OF EXEC_SRC_FILE [$EXEC_SRC_FILE] *****"
								fi

								# Check if target file/directory exists
								if [ ${#CONTAINER} -gt 0 ]
								then
									local EXEC_TARGET_CHECK=$($OC_CMD exec $POD -n $OBJ_NS -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- test -e $EXEC_TGT_FILE; echo $?)
								else
									local EXEC_TARGET_CHECK=$($OC_CMD exec $POD -n $OBJ_NS --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- test -e $EXEC_TGT_FILE; echo $?)
								fi

								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [DIRECTORY] EXEC_TARGET_CHECK = [$EXEC_TARGET_CHECK]"
								fi

								if [ ${#EXEC_TARGET_CHECK} -eq 0 ]
								then
									if [ ${#CONTAINER} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Target file/directory [$EXEC_TGT_FILE] check on pod [$POD / $CONTAINER] in namespace [$OBJ_NS] failed! Skipping..."
									else
										echo "[$(date)] [${FUNCNAME[0]}] Target file/irectory [$EXEC_TGT_FILE] check on pod [$POD] in namespace [$OBJ_NS] failed! Skipping..."
									fi

									if [ $REPORT_ON_SCREEN == "true" ]
									then
										echo >> $ANALYZE_OUTFILE
									fi

									continue
								else
									if [ ${EXEC_TARGET_CHECK} -eq 0 ]
									then
										if [ ${#CONTAINER} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Target file/directory [$EXEC_TGT_FILE] exists on pod [$POD / $CONTAINER] in namespace [$OBJ_NS]! Skipping..."
										else
											echo "[$(date)] [${FUNCNAME[0]}] Target file/directory [$EXEC_TGT_FILE] exists on pod [$POD] in namespace [$OBJ_NS]! Skipping..."
										fi

										if [ $REPORT_ON_SCREEN == "true" ]
										then
											echo >> $ANALYZE_OUTFILE
										fi

										continue
									else
										if [ ${EXEC_TARGET_CHECK} -eq 1 ]
										then
											if [ ${#CONTAINER} -gt 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Target file/directory [$EXEC_TGT_FILE] does not exist on pod [$POD / $CONTAINER] in namespace [$OBJ_NS]! Proceeding..."
											else
												echo "[$(date)] [${FUNCNAME[0]}] Target file/directory [$EXEC_TGT_FILE] does not exist on pod [$POD] in namespace [$OBJ_NS]! Proceeding..."
											fi
										else
											echo "[$(date)] [${FUNCNAME[0]}] Undetermined exit status code EXEC_TARGET_CHECK = [$EXEC_TARGET_CHECK]. Skipping..."

											if [ $REPORT_ON_SCREEN == "true" ]
											then
												echo >> $ANALYZE_OUTFILE
											fi

											continue
										fi
									fi
								fi

								if [ ${#CONTAINER} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Copying EXECPREP source file [$EXEC_SRC_FILE] into container [$POD / $CONTAINER] at target [$EXEC_TGT_FILE] in namespace [$OBJ_NS]..."
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD cp $EXEC_SRC_FILE $POD:$EXEC_TGT_FILE -c $CONTAINER -n $OBJ_NS'..."
									$OC_CMD cp $EXEC_SRC_FILE $POD:$EXEC_TGT_FILE -c $CONTAINER -n $OBJ_NS

									if [ $? -ne 0 ]
									then
										local EXEC_SRC_FILE_TYPE=$(file $EXEC_SRC_FILE | grep -E -i 'ASCII text|Unicode text')

										if [ ${#EXEC_SRC_FILE_TYPE} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] File type EXEC_SRC_FILE [$EXEC_SRC_FILE] = [$EXEC_SRC_FILE_TYPE]"
											fi

											if grep "'" $EXEC_SRC_FILE > /dev/null
											then 
												local EXEC_SRC_FILE_CONTENT=$(cat $EXEC_SRC_FILE | sed 's/\"/\\"/g' | sed "s/'/'\"'\"'/g" | sed 's/\$/\\\$/g')
											else
												local EXEC_SRC_FILE_CONTENT=$(cat $EXEC_SRC_FILE | sed 's/\"/\\"/g' | sed 's/\$/\\\$/g')
											fi

											local TO_EXEC="$OC_CMD exec $POD -n $OBJ_NS -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'echo \"$EXEC_SRC_FILE_CONTENT\" > $EXEC_TGT_FILE'"
											echo "[$(date)] [${FUNCNAME[0]}] Attempting to create EXECPREP source file [$EXEC_SRC_FILE] manually to target [$EXEC_TGT_FILE] in namespace [$OBJ_NS]..."

											if [ $(wc -l ${EXEC_SRC_FILE} | $AWK '{ print $1 }') -lt 10 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$TO_EXEC'..."
											fi

											eval "$TO_EXEC"	

											if [ $MG_DEBUG == "true" ]
											then
												local CHECK_LINES=15

												echo "[$(date)] [${FUNCNAME[0]}] Original file content [$EXEC_TGT_FILE] (limited to first $CHECK_LINES lines) => [$(head -$CHECK_LINES $EXEC_SRC_FILE)]"
												echo "[$(date)] [${FUNCNAME[0]}] Processed file content [$EXEC_TGT_FILE] (limited to first $CHECK_LINES lines) => [$(echo -e "$EXEC_SRC_FILE_CONTENT" | head -$CHECK_LINES)]"
												echo "$EXEC_SRC_FILE_CONTENT" > $MANUAL_COLL_ROOT_DEBUG_OUTDIR/$(basename ${EXEC_SRC_FILE}).manualcp
												echo "[$(date)] [${FUNCNAME[0]}] Target file content [$EXEC_TGT_FILE] (limited to first $CHECK_LINES lines) => [$($OC_CMD exec $POD -n $OBJ_NS -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- head -$CHECK_LINES $EXEC_TGT_FILE)]"
												cp -p $EXEC_SRC_FILE $MANUAL_COLL_ROOT_DEBUG_OUTDIR
											fi	
										else
											echo "[$(date)] [${FUNCNAME[0]}] Failed to copy EXECPREP source file [$EXEC_SRC_FILE] to target [$EXEC_TGT_FILE] in namespace [$OBJ_NS]..."
											echo "[$(date)] [${FUNCNAME[0]}] Skipping config line [$LINE] for POD [$POD / $CONTAINER]..."

											continue
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] EXECPREP source file [$EXEC_SRC_FILE] was copied to target [$EXEC_TGT_FILE] in namespace [$OBJ_NS] successfully..."
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Copying EXECPREP source file [$EXEC_SRC_FILE] into pod [$POD] at target [$EXEC_TGT_FILE] in namespace [$OBJ_NS]..."
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD cp $EXEC_SRC_FILE $POD:$EXEC_TGT_FILE -n $OBJ_NS'..."
									$OC_CMD cp $EXEC_SRC_FILE $POD:$EXEC_TGT_FILE -n $OBJ_NS

									if [ $? -ne 0 ]
									then
										local EXEC_SRC_FILE_TYPE=$(file $EXEC_SRC_FILE | grep -E -i 'ASCII text|Unicode text')

										if [ ${#EXEC_SRC_FILE_TYPE} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] File type EXEC_SRC_FILE [$EXEC_SRC_FILE] = [$EXEC_SRC_FILE_TYPE]"
											fi

											if grep "'" $EXEC_SRC_FILE > /dev/null
											then 
												local EXEC_SRC_FILE_CONTENT=$(cat $EXEC_SRC_FILE | sed 's/\"/\\"/g' | sed "s/'/'\"'\"'/g" | sed 's/\$/\\\$/g')
											else
												local EXEC_SRC_FILE_CONTENT=$(cat $EXEC_SRC_FILE | sed 's/\"/\\"/g' | sed 's/\$/\\\$/g')
											fi

											local TO_EXEC="$OC_CMD exec $POD -n $OBJ_NS --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'echo \"$EXEC_SRC_FILE_CONTENT\" > $EXEC_TGT_FILE'"
											echo "[$(date)] [${FUNCNAME[0]}] Attempting to create EXECPREP source file [$EXEC_SRC_FILE] manually to target [$EXEC_TGT_FILE] in namespace [$OBJ_NS]..."

											if [ $(wc -l ${EXEC_SRC_FILE} | $AWK '{ print $1 }') -lt 10 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$TO_EXEC'..."
											fi

											eval "$TO_EXEC"

											if [ $MG_DEBUG == "true" ]
											then
												local CHECK_LINES=15

												echo "[$(date)] [${FUNCNAME[0]}] Original file content [$EXEC_TGT_FILE] (limited to first $CHECK_LINES lines) => [$(head -$CHECK_LINES $EXEC_SRC_FILE)]"
												echo "[$(date)] [${FUNCNAME[0]}] Processed file content [$EXEC_TGT_FILE] (limited to first $CHECK_LINES lines) => [$(echo -e "$EXEC_SRC_FILE_CONTENT" | head -$CHECK_LINES)]"
												echo "$EXEC_SRC_FILE_CONTENT" > $MANUAL_COLL_ROOT_DEBUG_OUTDIR/$(basename ${EXEC_SRC_FILE}).manualcp
												echo "[$(date)] [${FUNCNAME[0]}] Target file content [$EXEC_TGT_FILE] (limited to first $CHECK_LINES lines) => [$($OC_CMD exec $POD -n $OBJ_NS --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- head -$CHECK_LINES $EXEC_TGT_FILE)]"
												cp -p $EXEC_SRC_FILE $MANUAL_COLL_ROOT_DEBUG_OUTDIR
											fi	
										else
											echo "[$(date)] [${FUNCNAME[0]}] Failed to copy EXECPREP source file [$EXEC_SRC_FILE] to target [$EXEC_TGT_FILE] in namespace [$OBJ_NS]..."
											echo "[$(date)] [${FUNCNAME[0]}] Skipping config line [$LINE] for POD [$POD]..."

											continue
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] EXECPREP source file [$EXEC_SRC_FILE] was copied to target [$EXEC_TGT_FILE] in namespace [$OBJ_NS] successfully..."
									fi
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] EXECPREP source file [$EXEC_SRC_FILE] does not exist or is zero-sized! Skipping..."

								if [ $REPORT_ON_SCREEN == "true" ]
								then
									echo >> $ANALYZE_OUTFILE
								fi

								continue
							fi
						fi

						if [ ${#CONTAINER} -gt 0 ]
						then
							local EXEC_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD~$CONTAINER.$PRI_SHELL.exec
							local EXEC_ERRFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD~$CONTAINER.$PRI_SHELL.err
							local EXEC_TMPFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD~$CONTAINER.$PRI_SHELL.tmp

							if [ -f $EXEC_OUTFILE ]
							then
								local EXEC_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD~$CONTAINER.$PRI_SHELL.exec.$(date +%s)
							fi

							# echo "[$(date)] [${FUNCNAME[0]}] Executing command '$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD'' => $EXEC_OUTFILE"

							if [ ${#TIMEOUT} -gt 0 ]
							then
								if [ ${#EXEC_TGT_FILE} -gt 0 ]
								then
									if [ ${#POSTEXEC} -gt 0 ]
									then
										if [ $MG_DEBUG == "true" ]
										then
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										else
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										fi
									else
										local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
									fi
								else
									if [ ${#POSTEXEC} -gt 0 ]
									then
										if [ $MG_DEBUG == "true" ]
										then
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										else
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										fi
									else
										local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
									fi
								fi
							else
								if [ ${#EXEC_TGT_FILE} -gt 0 ]
								then
									if [ ${#POSTEXEC} -gt 0 ]
									then
										if [ $MG_DEBUG == "true" ]
										then
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										else
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										fi
									else
										local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
									fi
								else
									if [ ${#POSTEXEC} -gt 0 ]
									then
										if [ $MG_DEBUG == "true" ]
										then
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										else
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										fi
									else
										local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
									fi
								fi
							fi
						else
							local EXEC_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD.$PRI_SHELL.exec
							local EXEC_ERRFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD.$PRI_SHELL.err
							local EXEC_TMPFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD.$PRI_SHELL.tmp

							if [ -f $EXEC_OUTFILE ]
							then
								local EXEC_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD.$PRI_SHELL.exec.$(date +%s)
							fi

							if [ ${#TIMEOUT} -gt 0 ]
							then
								if [ ${#EXEC_TGT_FILE} -gt 0 ]
								then
									if [ ${#POSTEXEC} -gt 0 ]
									then
										if [ $MG_DEBUG == "true" ]
										then
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										else
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										fi
									else
										local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
									fi
								else
									if [ ${#POSTEXEC} -gt 0 ]
									then
										if [ $MG_DEBUG == "true" ]
										then
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										else
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										fi
									else
										local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
									fi
								fi
							else
								if [ ${#EXEC_TGT_FILE} -gt 0 ]
								then
									if [ ${#POSTEXEC} -gt 0 ]
									then
										if [ $MG_DEBUG == "true" ]
										then
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										else
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										fi
									else
										local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
									fi
								else
									if [ ${#POSTEXEC} -gt 0 ]
									then
										if [ $MG_DEBUG == "true" ]
										then
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										else
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
										fi
									else
										local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
									fi
								fi
							fi
						fi

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] TO_EXEC = $TO_EXEC"	
						fi

						eval "$TO_EXEC"
						EXEC_EVAL_EXITCODE=$?

						echo "[$(date)] [${FUNCNAME[0]}] [$PRI_SHELL] EXECCMD [$TAG] exit status = [$EXEC_EVAL_EXITCODE]"

						if [ $REPORT_ON_SCREEN == "true" ]
						then
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$POD_CTR] [COMMAND = $TO_EXEC]" >> $ANALYZE_OUTFILE
								echo "[$POD_CTR] [OUTFILE = $EXEC_OUTFILE]" >> $ANALYZE_OUTFILE
	
								if [ ${#CONTAINER} -gt 0 ]
								then
									echo "[$POD_CTR] [POD = $POD / CONTAINER = $CONTAINER]" >> $ANALYZE_OUTFILE
								else
									echo "[$POD_CTR] [POD = $POD]" >> $ANALYZE_OUTFILE
								fi
							fi

							echo "[$POD_CTR] [OUTPUT]" >> $ANALYZE_OUTFILE

							if [ -s $EXEC_OUTFILE ]
							then
								cat $EXEC_OUTFILE >> $ANALYZE_OUTFILE
							else
								echo "<N/A>" >> $ANALYZE_OUTFILE
							fi

							echo >> $ANALYZE_OUTFILE

							if [ -s $EXEC_ERRFILE ]
							then
								echo "[$POD_CTR] [ERROR]" >> $ANALYZE_OUTFILE
								cat $EXEC_ERRFILE >> $ANALYZE_OUTFILE
								echo >> $ANALYZE_OUTFILE
							fi

							echo "***********************************************" >> $ANALYZE_OUTFILE
						fi

						if [ $EXEC_EVAL_EXITCODE -ne 0 ]
						then
							if [ ${#CONTAINER} -gt 0 ]
							then
								local EXEC_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD~$CONTAINER.$SEC_SHELL.exec
								local EXEC_ERRFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD~$CONTAINER.$SEC_SHELL.err
								local EXEC_TMPFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD~$CONTAINER.$SEC_SHELL.tmp

								if [ -f $EXEC_OUTFILE ]
								then
									local EXEC_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD~$CONTAINER.$SEC_SHELL.exec.$(date +%s)
								fi

								if [ ${#TIMEOUT} -gt 0 ]
								then
									if [ ${#EXEC_TGT_FILE} -gt 0 ]
									then
										if [ ${#POSTEXEC} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then 
												local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											else
												local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											fi
										else
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
										fi
									else
										if [ ${#POSTEXEC} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then 
												local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											else
												local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											fi
										else
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
										fi
									fi
								else
									if [ ${#EXEC_TGT_FILE} -gt 0 ]
									then
										if [ ${#POSTEXEC} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then 
												local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											else
												local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											fi
										else
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
										fi
									else
										if [ ${#POSTEXEC} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then 
												local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											else
												local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											fi
										else
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
										fi
									fi
								fi
							else
								local EXEC_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD.$SEC_SHELL.exec
								local EXEC_ERRFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD.$SEC_SHELL.err
								local EXEC_TMPFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD.$SEC_SHELL.tmp

								if [ -f $EXEC_OUTFILE ]
								then
									local EXEC_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$POD.$SEC_SHELL.exec.$(date +%s)
								fi

								# echo "[$(date)] [${FUNCNAME[0]}] Executing command '$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD'' => $EXEC_OUTFILE 2>&1"
				
								if [ ${#TIMEOUT} -gt 0 ]
								then
									if [ ${#EXEC_TGT_FILE} -gt 0 ]
									then
										if [ ${#POSTEXEC} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then 
												local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											else
												local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											fi
										else
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
										fi
									else
										if [ ${#POSTEXEC} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then 
												local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											else
												local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											fi
										else
											local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
										fi
									fi
								else
									if [ ${#EXEC_TGT_FILE} -gt 0 ]
									then
										if [ ${#POSTEXEC} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then 
												local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											else
												local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											fi
										else
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c 'MC_PREP_FILE=$EXEC_TGT_FILE; $EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
										fi
									else
										if [ ${#POSTEXEC} -gt 0 ]
										then
											if [ $MG_DEBUG == "true" ]
											then 
												local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | tee -a $EXEC_TMPFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											else
												local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' 2> $EXEC_ERRFILE | $POSTEXEC > $EXEC_OUTFILE 2>> $EXEC_ERRFILE"
											fi
										else
											local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$EXECCMD' > $EXEC_OUTFILE 2> $EXEC_ERRFILE"
										fi
									fi
								fi
							fi

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] TO_EXEC = $TO_EXEC"	
							fi

							eval "$TO_EXEC"
							EXEC_EVAL_EXITCODE=$?

							echo "[$(date)] [${FUNCNAME[0]}] [$SEC_SHELL] EXECCMD [$TAG] exit status = [$EXEC_EVAL_EXITCODE]"

							if [ ${#EXEC_TGT_FILE} -gt 0 ]
							then
								# Expect EXEC_SRC_FILE to reveal whether it is a file or directory!
								if [ -d $EXEC_SRC_FILE ]
								then
									local RM_CMD="rm -r"
								else
									local RM_CMD="rm"
								fi
	
								if [ ${#CONTAINER} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Removing EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD / $CONTAINER]..."

									if [ ${#TIMEOUT} -gt 0 ]
									then
										local TO_EXEC_RM="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$RM_CMD $EXEC_TGT_FILE' > $EXEC_OUTFILE 2>&1"
									else
										local TO_EXEC_RM="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$RM_CMD $EXEC_TGT_FILE' > $EXEC_OUTFILE 2>&1"
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Removing EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD]..."

									if [ ${#TIMEOUT} -gt 0 ]
									then
										local TO_EXEC_RM="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$RM_CMD $EXEC_TGT_FILE' > $EXEC_OUTFILE 2>&1"
									else
										local TO_EXEC_RM="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $SEC_SHELL -c '$RM_CMD $EXEC_TGT_FILE' > $EXEC_OUTFILE 2>&1"
									fi
								fi

								echo "[$(date)] [${FUNCNAME[0]}] Executing '$TO_EXEC_RM'..."
								eval "$TO_EXEC_RM"
								EXEC_RM_STATUS=$?

								if [ ${#EXEC_RM_STATUS} -eq 0 ]
								then
									if [ ${#CONTAINER} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Removal status of EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD / $CONTAINER] = [UNKNOWN]"
									else
										echo "[$(date)] [${FUNCNAME[0]}] Removal status of EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD] = [UNKNOWN]"
									fi
								else
									if [ ${#CONTAINER} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Removal status of EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD / $CONTAINER] = [$EXEC_RM_STATUS]"
									else
										echo "[$(date)] [${FUNCNAME[0]}] Removal status of EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD] = [$EXEC_RM_STATUS]"
									fi
								fi	
							fi

							if [ $REPORT_ON_SCREEN == "true" ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$POD_CTR] [COMMAND = $TO_EXEC]" >> $ANALYZE_OUTFILE
									echo "[$POD_CTR] [OUTFILE = $EXEC_OUTFILE]" >> $ANALYZE_OUTFILE
	
									if [ ${#CONTAINER} -gt 0 ]
									then
										echo "[$POD_CTR] [POD = $POD / CONTAINER = $CONTAINER]" >> $ANALYZE_OUTFILE
									else
										echo "[$POD_CTR] [POD = $POD]" >> $ANALYZE_OUTFILE
									fi
								fi

								echo "[$POD_CTR] [OUTPUT]" >> $ANALYZE_OUTFILE

								if [ -s $EXEC_OUTFILE ]
								then
									cat $EXEC_OUTFILE >> $ANALYZE_OUTFILE
								else
									echo "<N/A>" >> $ANALYZE_OUTFILE
								fi

								echo >> $ANALYZE_OUTFILE

								if [ -s $EXEC_ERRFILE ]
								then
									echo "[$POD_CTR] [ERROR]" >> $ANALYZE_OUTFILE
									cat $EXEC_ERRFILE >> $ANALYZE_OUTFILE
									echo >> $ANALYZE_OUTFILE
								fi

								echo "***********************************************" >> $ANALYZE_OUTFILE
							fi
						else
							if [ ${#EXECPREP} -gt 0 ] && [ ${#EXEC_TGT_FILE} -gt 0 ]
							then
								# Expect EXEC_SRC_FILE to reveal whether it is a file or directory!
								if [ -d $EXEC_SRC_FILE ]
								then
									local RM_CMD="rm -r"
								else
									local RM_CMD="rm"
								fi
	
								if [ ${#CONTAINER} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Removing EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD / $CONTAINER]..."

									if [ ${#TIMEOUT} -gt 0 ]
									then
										local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$RM_CMD $EXEC_TGT_FILE'"
									else
										local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD -c $CONTAINER --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$RM_CMD $EXEC_TGT_FILE'"
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Removing EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD]..."

									if [ ${#TIMEOUT} -gt 0 ]
									then
										local TO_EXEC="$TIMEOUT $MANUAL_COLL_EXEC_TIMEOUT $OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$RM_CMD $EXEC_TGT_FILE'"
									else
										local TO_EXEC="$OC_CMD exec -n $OBJ_NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $PRI_SHELL -c '$RM_CMD $EXEC_TGT_FILE'"
									fi
								fi

								echo "[$(date)] [${FUNCNAME[0]}] Executing '$TO_EXEC'..."
								eval "$TO_EXEC"
								EXEC_RM_STATUS=$?

								if [ ${#EXEC_RM_STATUS} -eq 0 ]
								then
									if [ ${#CONTAINER} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Removal status of EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD / $CONTAINER] = [UNKNOWN]"
									else
										echo "[$(date)] [${FUNCNAME[0]}] Removal status of EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD] = [UNKNOWN]"
									fi
								else
									if [ ${#CONTAINER} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Removal status of EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD / $CONTAINER] = [$EXEC_RM_STATUS]"
									else
										echo "[$(date)] [${FUNCNAME[0]}] Removal status of EXECPREP target file [$EXEC_TGT_FILE] from pod [$POD] = [$EXEC_RM_STATUS]"
									fi
								fi	
							fi
						fi

						(( POD_CTR=POD_CTR+1 ))
					done

					if [ ${#EXEC_SRC_FILE} -gt 0 ] && [ -e $EXEC_SRC_FILE ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							if [ ! -d $MANUAL_COLL_ROOT_DEBUG_OUTDIR/execprep ]
							then
								mkdir -p $MANUAL_COLL_ROOT_DEBUG_OUTDIR/execprep 
							fi

							echo "[$(date)] [${FUNCNAME[0]}] Backing up EXECPREP source file/directory [$EXEC_SRC_FILE] to directory [$MANUAL_COLL_ROOT_DEBUG_OUTDIR/execprep]..."
							cp -rp ${EXEC_SRC_FILE} $MANUAL_COLL_ROOT_DEBUG_OUTDIR/execprep
						fi

						if [ ${#EXECPREPRMSRC} -gt 0 ] 
						then
							if [ ${EXECPREPRMSRC} == "true" ]
							then
								if [ ${#RTVAR_EXECPREP_RMSRC} -eq 0 ] 
								then
									echo "[$(date)] [${FUNCNAME[0]}] Removing EXECPREP source file/directory [$EXEC_SRC_FILE]..."
									rm -r ${EXEC_SRC_FILE}
								else
									if [ ${RTVAR_EXECPREP_RMSRC} == "false" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] RTVAR_EXECPREP_RMSRC = [$RTVAR_EXECPREP_RMSRC] - Not removing source file/directory [$EXEC_SRC_FILE]..."
									fi
								fi
							fi
						else
							if [ ${#RTVAR_EXECPREP_RMSRC} -gt 0 ] && [ ${RTVAR_EXECPREP_RMSRC} == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] RTVAR_EXECPREP_RMSRC = [$RTVAR_EXECPREP_RMSRC] - Removing EXECPREP source file/directory [$EXEC_SRC_FILE]..."
								rm -r ${EXEC_SRC_FILE}
							fi
						fi
					fi

					if [ $REPORT_ON_SCREEN == "true" ]
					then
						echo >> $ANALYZE_OUTFILE
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] EXECCMD cannot be executed on object that is not 'pod' or 'po'!"
					echo "[$(date)] [${FUNCNAME[0]}] CFGLINE = $LINE"
				fi

				continue
			fi

			# Not EXECCMD - Normal data collection
			if [ $(echo "${OBJ_TYPE}"X | sed 's/[ ]*//') == "X" ]
			then
				local OBJ_TYPE="all"
			fi

			if isRestrictedData "$OBJ_TYPE"
			then
				echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $LINE] Skipping..."
				continue
			else
				if isSensitiveData "$OBJ_TYPE"
				then
					if [ $MANUAL_COLL_SECRET == "false" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] CFGLINE = $LINE [MANUAL_COLL_SECRET = $MANUAL_COLL_SECRET]. Skipping..."
						continue
					else
						echo "[$(date)] [${FUNCNAME[0]}] [$MANUAL_COLL_CFGLINE_CTR] [LINE = $LINE] MANUAL_COLL_SECRET is set to [$MANUAL_COLL_SECRET]. Proceeding..."
					fi	
				fi
			fi

			local TMP_FILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS-$OBJ_TYPE.$$

			if [ ! -d $MC_OUTDIR/TAG=$TAG ]
			then
				mkdir -p $MC_OUTDIR/TAG=$TAG
			fi

			local CLUSTER_OBJ=""

			# To check whether object type is cluster OR namespace-scoped
			local IS_CLUSTER_OBJ="false"

			echo "[$(date)] [${FUNCNAME[0]}] CFGLINE[$MANUAL_COLL_CFGLINE_CTR] = $LINE [$OBJ_NS / $OBJ_TYPE / $OBJ_NAME / $OBJ_NS_CMD]"
	
			echo "[$(date)] [${FUNCNAME[0]}] Checking whether object type [$OBJ_TYPE] is cluster scoped..."

			if [ $OBJ_TYPE == "all" ]
			then
				# Delay check because config line wants ALL resource types
				if [ $OBJ_NS == "all" ] || [ $OBJ_NS == "all-namespaces" ]
				then
					if [ ${#OBJ_NAME} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Due to overwhelming volume of data, data collection for ALL object types in ALL namespaces is not supported! Skipping..."
						continue
					else
						# oc get all -A => search for OBJ_NAME
						echo "[$(date)] [${FUNCNAME[0]}] [OBJ_NS=[$OBJ_NS] / OBJ_TYPE=[$OBJ_TYPE] Resource-type scope determination is delayed!"
						local IS_CLUSTER_OBJ="delayed"
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Resource type [$OBJ_TYPE] is assumed as namespace-scoped, because data collection for ALL resource type at cluster wide is not supported!"
					local IS_CLUSTER_OBJ="delayed"
				fi
			else
				local OC_API_IS_NAMESPACED=$(isNamespaced $OBJ_TYPE)	
	
				if [ ${#OC_API_IS_NAMESPACED} -gt 0 ]
				then
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] OC_API_IS_NAMESPACED [$OBJ_TYPE] = [$OC_API_IS_NAMESPACED]"
					fi
	
					if [ $OC_API_IS_NAMESPACED -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Object type [$OBJ_TYPE] is namespace-scoped!"
					else
						echo "[$(date)] [${FUNCNAME[0]}] Object type [$OBJ_TYPE] is cluster-scoped!"
		
						echo "[$(date)] [${FUNCNAME[0]}] Changing namespace option from [$OBJ_NS_CMD] to blank!"
						local OBJ_NS_CMD=""
						echo "[$(date)] [${FUNCNAME[0]}] Changing namespace from [$OBJ_NS] to [all-namespaces]!"
						local OBJ_NS="all-namespaces"
						local IS_CLUSTER_OBJ="true"
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Unable to determine scope for object [$OBJ_TYPE]! Skipping..."
					continue
				fi
			fi
			
			if [ ! -d $MC_OUTDIR/TAG=$TAG/$OBJ_NS ]
			then	
				echo "[$(date)] [${FUNCNAME[0]}] Making directory [$MC_OUTDIR/TAG=$TAG/$OBJ_NS]..."
				mkdir -p $MC_OUTDIR/TAG=$TAG/$OBJ_NS
			fi

			local OC_GET_CMD_ARRAY=()
			local OUTFILE_ARRAY=()
			local NS_ARRAY=()
			local OBJNAME_ARRAY=()
			local OBJFILTER_ARRAY=()

			local OBJ_FILTER_FIELD_SELECTOR=""
			local OBJ_FILTER_LIMIT_FINAL=""
			local OBJ_FILTER_ENABLED="false"

			# If OBJ_FILTER is set, to create OBJ_FILTER_FIELD_SELECTOR and OBJ_FILTER_LIMIT_FINAL
			if [ ${#OBJ_FILTER} -gt 0 ]
			then
				local OBJ_FILTER_STATUS=${OBJ_FILTER%:*}
				local OBJ_FILTER_LIMIT=$(echo "$OBJ_FILTER" | $AWK -F: '{ print $NF }')

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_STATUS = [$OBJ_FILTER_STATUS] / OBJ_FILTER_LIMIT = [$OBJ_FILTER_LIMIT]"
				fi

				if [ ${#OBJ_FILTER_STATUS} -eq 0 ] && [ ${#OBJ_FILTER_LIMIT} -eq 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Both OBJ_FILTER_STATUS and OBJ_FILTER_LIMIT are empty! No object filter will be applied!"
					local OBJ_FILTER_FIELD_SELECTOR=""
					local OBJ_FILTER_LIMIT_FINAL=""
					local OBJ_FILTER_ENABLED="false"
				else
					if [ ${#OBJ_FILTER_STATUS} -gt 0 ] 
					then
						local OBJ_FILTER_FIELD_SELECTOR="--field-selector $OBJ_FILTER_STATUS"
					fi
					
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_FIELD_SELECTOR = [$OBJ_FILTER_FIELD_SELECTOR]"
					fi

					if [ ${#OBJ_FILTER_LIMIT} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_LIMIT [$OBJ_FILTER_LIMIT] is empty! Setting to default [ALL]"
						local OBJ_FILTER_LIMIT_FINAL=""
					else
						if [[ $OBJ_FILTER_LIMIT =~ ^[0-9]+$ ]]
						then
							echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_LIMIT is set to [$OBJ_FILTER_LIMIT]!"
							local OBJ_FILTER_LIMIT_FINAL="| head -$OBJ_FILTER_LIMIT"
						else
							echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_LIMIT [$OBJ_FILTER_LIMIT] is not a number! Setting to default [ALL]"
							local OBJ_FILTER_LIMIT_FINAL=""
						fi
					fi	

					local OBJ_FILTER_ENABLED="true"
				fi

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] OBJ_FILTER_FIELD_SELECTOR = [$OBJ_FILTER_FIELD_SELECTOR] / OBJ_FILTER_LIMIT_FINAL = [$OBJ_FILTER_LIMIT_FINAL]"
				fi
			fi

			if [ ${#OBJ_NAME} -eq 0 ]
			then
				if [ $OBJ_FILTER_ENABLED == "false" ]
				then
					local OC_GET_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/oc_${OBJ_TYPE}.out
				else
					local OC_GET_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/oc_${OBJ_TYPE}.out-filtered
				fi
			fi

			# To provide "$OC_CMD get" output
			if [[ ( $OBJ_NS == "all" || $OBJ_NS == "all-namespaces" ) && ${#OBJ_NAME} -gt 0 ]]
			then
				# (1) Namespace-scoped resource type at clusiter level (-A/--all-namespaces) OR cluster-scoped resource type
				# (2) OBJ_NAME column must be defined (not null)
				if [ $IS_CLUSTER_OBJ == "false" ]
				then
					# Namespace-scoped resource at cluster level (-A / --all-namespaces)
					local FILTER_CMD="$OC_CMD get $OBJ_TYPE $OBJ_NS_CMD --no-headers $OBJ_FILTER_FIELD_SELECTOR | $AWK '\$2 ~ /${OBJ_NAME}/ { print \$1 \"/\" \$2 }' $OBJ_FILTER_LIMIT_FINAL"
					echo "[$(date)] [${FUNCNAME[0]}] Executing '$FILTER_CMD'"
				
					for XLINE in $(eval "$FILTER_CMD")
					do
						local X_OBJ_NS=$(echo "$XLINE" | $AWK -F/ '{ print $1 }')
						local X_OBJ_NAME=$(echo "$XLINE" | $AWK -F/ '{ print $2 }')
						local OC_GET_OUTFILE=$MC_OUTDIR/TAG=$TAG/$X_OBJ_NS/oc_${OBJ_TYPE}-${X_OBJ_NAME}.out

						if [ ! -d $MC_OUTDIR/TAG=$TAG/$X_OBJ_NS ]
						then
							mkdir -p $MC_OUTDIR/TAG=$TAG/$X_OBJ_NS
						fi

						echo "[$(date)] [${FUNCNAME[0]}] [0] Executing '$OC_CMD get $OBJ_TYPE $X_OBJ_NAME -n $X_OBJ_NS' => $OC_GET_OUTFILE"
						local MY_OC_CMD="$OC_CMD get $OBJ_TYPE $X_OBJ_NAME -n $X_OBJ_NS"
						eval "$MY_OC_CMD" > $OC_GET_OUTFILE 2>&1

						if [ -s ${OC_GET_OUTFILE} ]
						then
							local OC_GET_CMD_ARRAY[${#OC_GET_CMD_ARRAY[@]}]="$OC_CMD get $OBJ_TYPE $X_OBJ_NAME -n $X_OBJ_NS --no-headers"
							local OUTFILE_ARRAY[${#OUTFILE_ARRAY[@]}]="$MC_OUTDIR/TAG=$TAG/$X_OBJ_NS/$OBJ_TYPE~$X_OBJ_NAME.$$"
							local NS_ARRAY[${#NS_ARRAY[@]}]=$X_OBJ_NS
							local OBJNAME_ARRAY[${#OBJNAME_ARRAY[@]}]=${OBJ_NAME}
							local OBJFILTER_ARRAY[${#OBJFILTER_ARRAY[@]}]=${OBJ_FILTER_ENABLED}
						fi
					done
				else
					if [ $IS_CLUSTER_OBJ == "true" ]
					then
						# Cluster-scoped resource type
						local FILTER_CMD="$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD | $AWK '/${OBJ_NAME}/ { print }' $OBJ_FILTER_LIMIT_FINAL"
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$FILTER_CMD'"
					
						for X_OBJ_NAME in $(eval "$FILTER_CMD")
						do
							local OC_GET_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/oc_${OBJ_TYPE}-${X_OBJ_NAME}.out
	
							echo "[$(date)] [${FUNCNAME[0]}] [1] Executing '$OC_CMD get $OBJ_TYPE $X_OBJ_NAME $OBJ_NS_CMD' => $OC_GET_OUTFILE"
							local MY_OC_CMD="$OC_CMD get $OBJ_TYPE $X_OBJ_NAME $OBJ_NS_CMD"
							eval "$MY_OC_CMD" > $OC_GET_OUTFILE 2>&1
	
							if [ -s ${OC_GET_OUTFILE} ]
							then
								local OC_GET_CMD_ARRAY[${#OC_GET_CMD_ARRAY[@]}]="$OC_CMD get $OBJ_TYPE $X_OBJ_NAME $OBJ_NS_CMD --no-headers"
								local OUTFILE_ARRAY[${#OUTFILE_ARRAY[@]}]="$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$OBJ_TYPE~$X_OBJ_NAME.$$"
								local NS_ARRAY[${#NS_ARRAY[@]}]=$OBJ_NS
								local OBJNAME_ARRAY[${#OBJNAME_ARRAY[@]}]=${OBJ_NAME}
								local OBJFILTER_ARRAY[${#OBJFILTER_ARRAY[@]}]=${OBJ_FILTER_ENABLED}
							fi
						done
					else
						if [ $IS_CLUSTER_OBJ == "delayed" ]
						then	
							# All resource type in all namespaces with OBJ_NAME filtering
							local FILTER_CMD="$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.namespace}}{{\"/\"}}{{.kind}}{{\"/\"}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD | $AWK -F/ '\$3 ~ /${OBJ_NAME}/ { print }' $OBJ_FILTER_LIMIT_FINAL"
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$FILTER_CMD'"
	
							for XLINE in $(eval "$FILTER_CMD")
							do
								local X_OBJ_NS=$(echo "$XLINE" | $AWK -F/ '{ print $1 }')
								local X_OBJ_TYPE=$(echo "$XLINE" | $AWK -F/ '{ print tolower($2) }')
								local X_OBJ_NAME=$(echo "$XLINE" | $AWK -F/ '{ print $3 }')
								local OC_GET_OUTFILE=$MC_OUTDIR/TAG=$TAG/$X_OBJ_NS/oc_${X_OBJ_TYPE}-${X_OBJ_NAME}.out

								if [ ! -d $MC_OUTDIR/TAG=$TAG/$X_OBJ_NS ]
								then
									mkdir -p $MC_OUTDIR/TAG=$TAG/$X_OBJ_NS
								fi

								echo "[$(date)] [${FUNCNAME[0]}] [2] Executing '$OC_CMD get $X_OBJ_TYPE $X_OBJ_NAME -n $X_OBJ_NS' => $OC_GET_OUTFILE"
								local MY_OC_CMD="$OC_CMD get $X_OBJ_TYPE $X_OBJ_NAME -n $X_OBJ_NS"
								eval "$MY_OC_CMD" > $OC_GET_OUTFILE 2>&1
		
								if [ -s ${OC_GET_OUTFILE} ]
								then
									local OC_GET_CMD_ARRAY[${#OC_GET_CMD_ARRAY[@]}]="$OC_CMD get $X_OBJ_TYPE $X_OBJ_NAME -n $X_OBJ_NS --no-headers"
									local OUTFILE_ARRAY[${#OUTFILE_ARRAY[@]}]="$MC_OUTDIR/TAG=$TAG/$X_OBJ_NS/$X_OBJ_TYPE~$X_OBJ_NAME.$$"
									local NS_ARRAY[${#NS_ARRAY[@]}]=$X_OBJ_NS
									local OBJNAME_ARRAY[${#OBJNAME_ARRAY[@]}]=${OBJ_NAME}
									local OBJFILTER_ARRAY[${#OBJFILTER_ARRAY[@]}]=${OBJ_FILTER_ENABLED}
								fi
							done
						else
							echo "[$(date)] [${FUNCNAME[0]}] ERROR: IS_CLUSTER_OBJ = [$IS_CLUSTER_OBJ]"
							continue
						fi
					fi
				fi
			else
				# Namespace-scoped resource type OR cluster-scoped resource type with OR without OBJ_NAME
				if [ $IS_CLUSTER_OBJ == "delayed" ]
				then
					# OBJ_TYPE = all
					local OC_ALL_EXNS_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/oc_all.out
					$OC_CMD get all -n $OBJ_NS > $OC_ALL_EXNS_OUTFILE
					local OC_ALL_RESTYPE_LIST=$(getAllResTypeFromOcAll $OC_ALL_EXNS_OUTFILE)	

					IFS=$OLDIFS
					for OC_ALL_OBJTYPE in $OC_ALL_RESTYPE_LIST
					do
						if [ ${#OBJ_NAME} -gt 0 ]
						then
							local FILTER_CMD="$OC_CMD get $OC_ALL_OBJTYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD | $AWK '/${OBJ_NAME}/ { print }' $OBJ_FILTER_LIMIT_FINAL"
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$FILTER_CMD'"
		
							for X_OBJ_NAME in $(eval "$FILTER_CMD")
							do
								local OC_GET_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/oc_${OC_ALL_OBJTYPE}-${X_OBJ_NAME}.out
		
								echo "[$(date)] [${FUNCNAME[0]}] [3] Executing '$OC_CMD get $OC_ALL_OBJTYPE $X_OBJ_NAME $OBJ_NS_CMD' => $OC_GET_OUTFILE"
								local MY_OC_CMD="$OC_CMD get $OC_ALL_OBJTYPE $X_OBJ_NAME $OBJ_NS_CMD"
								eval "$MY_OC_CMD" > $OC_GET_OUTFILE 2>&1
		
								if [ -s ${OC_GET_OUTFILE} ]
								then
									local OC_GET_CMD_ARRAY[${#OC_GET_CMD_ARRAY[@]}]="$OC_CMD get $OC_ALL_OBJTYPE $X_OBJ_NAME $OBJ_NS_CMD --no-headers"
									local OUTFILE_ARRAY[${#OUTFILE_ARRAY[@]}]="$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$OC_ALL_OBJTYPE~$X_OBJ_NAME.$$"
									local NS_ARRAY[${#NS_ARRAY[@]}]=$OBJ_NS
									local OBJNAME_ARRAY[${#OBJNAME_ARRAY[@]}]=${OBJ_NAME}
									local OBJFILTER_ARRAY[${#OBJFILTER_ARRAY[@]}]=${OBJ_FILTER_ENABLED}
								fi
							done
						else
							if [ $OBJ_FILTER_ENABLED == "false" ]
							then
								local OC_GET_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/oc_${OC_ALL_OBJTYPE}.out
							else
								local OC_GET_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/oc_${OC_ALL_OBJTYPE}.out-filtered
							fi

							echo "[$(date)] [${FUNCNAME[0]}] [4] Executing '$OC_CMD get $OC_ALL_OBJTYPE --no-headers $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD $OBJ_FILTER_LIMIT_FINAL' => $OC_GET_OUTFILE"
							local MY_OC_CMD="$OC_CMD get $OC_ALL_OBJTYPE --no-headers $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD $OBJ_FILTER_LIMIT_FINAL"
							eval "$MY_OC_CMD" > $OC_GET_OUTFILE 2>&1
		
							if [ -s $OC_GET_OUTFILE ]
							then
								local OC_GET_CMD_ARRAY[${#OC_GET_CMD_ARRAY[@]}]="$OC_CMD get $OC_ALL_OBJTYPE --no-headers $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD $OBJ_FILTER_LIMIT_FINAL"
								local OUTFILE_ARRAY[${#OUTFILE_ARRAY[@]}]="$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$OC_ALL_OBJTYPE.$$"
								local NS_ARRAY[${#NS_ARRAY[@]}]=$OBJ_NS
								local OBJNAME_ARRAY[${#OBJNAME_ARRAY[@]}]=${OBJ_NAME}
								local OBJFILTER_ARRAY[${#OBJFILTER_ARRAY[@]}]=${OBJ_FILTER_ENABLED}
							fi
						fi	
					done
					IFS=$'\n'

					if [ ${#OBJ_NAME} -gt 0 ]
					then
						if [ ${#OC_ALL_EXNS_OUTFILE} -gt 0 ] && [ -f $OC_ALL_EXNS_OUTFILE ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Removing file [$OC_ALL_EXNS_OUTFILE]..."
							rm $OC_ALL_EXNS_OUTFILE
						fi
					fi
				else
					if [ ${#OBJ_NAME} -gt 0 ]
					then
						local FILTER_CMD="$OC_CMD get $OBJ_TYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD | $AWK '/${OBJ_NAME}/ { print }' $OBJ_FILTER_LIMIT_FINAL"
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$FILTER_CMD'"
	
						for X_OBJ_NAME in $(eval "$FILTER_CMD")
						do
							local OC_GET_OUTFILE=$MC_OUTDIR/TAG=$TAG/$OBJ_NS/oc_${OBJ_TYPE}-${X_OBJ_NAME}.out
	
							echo "[$(date)] [${FUNCNAME[0]}] [5] Executing '$OC_CMD get $OBJ_TYPE $X_OBJ_NAME $OBJ_NS_CMD' => $OC_GET_OUTFILE"
							local MY_OC_CMD="$OC_CMD get $OBJ_TYPE $X_OBJ_NAME $OBJ_NS_CMD"
							eval "$MY_OC_CMD" > $OC_GET_OUTFILE 2>&1
	
							if [ -s ${OC_GET_OUTFILE} ]
							then
								local OC_GET_CMD_ARRAY[${#OC_GET_CMD_ARRAY[@]}]="$OC_CMD get $OBJ_TYPE $X_OBJ_NAME $OBJ_NS_CMD --no-headers"
								local OUTFILE_ARRAY[${#OUTFILE_ARRAY[@]}]="$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$OBJ_TYPE~$X_OBJ_NAME.$$"
								local NS_ARRAY[${#NS_ARRAY[@]}]=$OBJ_NS
								local OBJNAME_ARRAY[${#OBJNAME_ARRAY[@]}]=${OBJ_NAME}
								local OBJFILTER_ARRAY[${#OBJFILTER_ARRAY[@]}]=${OBJ_FILTER_ENABLED}
							fi
						done
					else
						echo "[$(date)] [${FUNCNAME[0]}] [6] Executing '$OC_CMD get $OBJ_TYPE --no-headers $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD $OBJ_FILTER_LIMIT_FINAL' => $OC_GET_OUTFILE"
						local MY_OC_CMD="$OC_CMD get $OBJ_TYPE --no-headers $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD $OBJ_FILTER_LIMIT_FINAL"
						eval "$MY_OC_CMD" > $OC_GET_OUTFILE 2>&1
	
						if [ -s $OC_GET_OUTFILE ]
						then
							local OC_GET_CMD_ARRAY[${#OC_GET_CMD_ARRAY[@]}]="$OC_CMD get $OBJ_TYPE --no-headers $OBJ_FILTER_FIELD_SELECTOR $OBJ_NS_CMD $OBJ_FILTER_LIMIT_FINAL"
							local OUTFILE_ARRAY[${#OUTFILE_ARRAY[@]}]="$MC_OUTDIR/TAG=$TAG/$OBJ_NS/$OBJ_TYPE.$$"
							local NS_ARRAY[${#NS_ARRAY[@]}]=$OBJ_NS
							local OBJNAME_ARRAY[${#OBJNAME_ARRAY[@]}]=${OBJ_NAME}
							local OBJFILTER_ARRAY[${#OBJFILTER_ARRAY[@]}]=${OBJ_FILTER_ENABLED}
						fi
					fi
				fi
			fi

			if [ ${#OC_GET_CMD_ARRAY[@]} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] '$OC_CMD get' commands array is empty! Please check the '$OC_CMD get' command shown above! Continue to next config line..."
				continue
			else
				if [ $MG_DEBUG == "true" ]
				then
					local ARRAY_LEN=${#OC_GET_CMD_ARRAY[@]}
			    	  	echo "[$(date)] [${FUNCNAME[0]}] Listing '$OC_CMD get' commands [TOTAL=$ARRAY_LEN]..."

					for (( i=0; i<$ARRAY_LEN; i++ ))
					do
						echo "[$(date)] [${FUNCNAME[0]}] OC_GET_CMD[$i] = ${OC_GET_CMD_ARRAY[$i]}"
					done
				fi	
			fi

			if [ $OC_DESC_ON == "false" ] && [ $COLLECT_YAML == "false" ] && [ $COLLECT_JSON == "false" ] && [ $GET_POD_LOGS == "false" ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] '$OC_CMD describe', '$OC_CMD get -o yaml', '$OC_CMD get -o json' and '$OC_CMD logs' are all disabled. Skipping..."
				fi
	
				continue	
			fi
		
			# To provide "$OC_CMD describe" and "$OC_CMD logs" output 
			local CMD_CTR=0

			IFS=$'\n'

			for OC_GET_CMD in ${OC_GET_CMD_ARRAY[@]}
			do
				local SRC_FILE=${OUTFILE_ARRAY[$CMD_CTR]}				
				local TMP_OBJNS=${NS_ARRAY[$CMD_CTR]}

				echo "[$(date)] [${FUNCNAME[0]}] Executing command '$OC_GET_CMD' => $SRC_FILE"
				eval "$OC_GET_CMD" > $SRC_FILE
				local TMPFILE_ARRAY[${#TMPFILE_ARRAY[@]}]=$SRC_FILE

				# Flag to decide whether to perform bulk 'oc describe'
				local OBJNAME_ARRAY_VAL=${OBJNAME_ARRAY[$CMD_CTR]}
				local OBJFILTER_ARRAY_VAL=${OBJFILTER_ARRAY[$CMD_CTR]}

				if [ ${#OBJNAME_ARRAY_VAL} -gt 0 ]
				then
					local IS_OBJNAME_NULL="false"
				else
					local IS_OBJNAME_NULL="true"
				fi

				if [ $BASH_V4 == "true" ]
				then
					unset MC_API_DETAILS_CACHE
					declare -A MC_API_DETAILS_CACHE

					unset MC_TO_PROCEED_CACHE
					declare -A MC_TO_PROCEED_CACHE

					unset MC_FAST_OC_YAML_PREREQ_CACHE
					declare -A MC_FAST_OC_YAML_PREREQ_CACHE
				fi

				(( CMD_CTR=CMD_CTR+1 ))

				while read OBJ_LINE
				do
					local SUB_TMP_OBJNS=

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] OBJ_LINE = [$OBJ_LINE]"
					fi

					if [ $TMP_OBJNS == "all" ]
					then
						if [ ${OBJ_TYPE} == "all" ]
						then
							# Eg. all,,
							local SUB_TMP_OBJNS=$(echo "$OBJ_LINE" | $AWK '{ print tolower($1) }')
							local TMP_OBJTYPE=$(echo "$OBJ_LINE" | $AWK '{ print tolower($2) }' | $AWK -F'/' '{ print $1 }')
							local TMP_OBJNAME=$(echo "$OBJ_LINE" | $AWK '{ print tolower($2) }' | $AWK -F'/' '{ print $2 }')
						else
							# Eg. all,secret,
							local TMP_OBJTYPE=$OBJ_TYPE
	
							if [ $IS_CLUSTER_OBJ == "false" ]
							then
								local SUB_TMP_OBJNS=$(echo "$OBJ_LINE" | $AWK '{ print tolower($1) }')
								local TMP_OBJNAME=$(echo "$OBJ_LINE" | $AWK '{ print tolower($2) }')
							else
								TMP_OBJNAME=$(echo "$OBJ_LINE" | $AWK '{ print tolower($1) }')
							fi
						fi
					else
						if [ ${OBJ_TYPE} == "all" ]
						then
							# Eg. rook-ceph,,
							# local TMP_OBJTYPE=$(echo "$OBJ_LINE" | $AWK '{ print tolower($1) }' | $AWK -F'/' '{ print $1 }')
							# local TMP_OBJNAME=$(echo "$OBJ_LINE" | $AWK '{ print tolower($1) }' | $AWK -F'/' '{ print $2 }')
							local TMP_OBJTYPE=$(echo "$OC_GET_CMD" | $AWK '{ print tolower($3) }')
							local TMP_OBJNAME=$(echo "$OBJ_LINE" | $AWK '{ print tolower($1) }')
						else
							# Eg. rook-ceph,secret,
							local TMP_OBJTYPE=$OBJ_TYPE
							local TMP_OBJNAME=$(echo "$OBJ_LINE" | $AWK '{ print tolower($1) }')
						fi
					fi
	
					local LC_OBJTYPE=$(echo "$TMP_OBJTYPE" | $AWK '{ print tolower($0) }')

					if [ $BASH_V4 == "true" ] && [ ${#MC_API_DETAILS_CACHE[@]} -gt 0 ]
					then
						if [ ${MC_API_DETAILS_CACHE["$TMP_OBJTYPE"]+_} ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Value retrieved from MC_API_DETAILS_CACHE for key [$TMP_OBJTYPE] = [${MC_API_DETAILS_CACHE[$TMP_OBJTYPE]}]"
							local TO_PROCEED_API="false"

							local OC_APIVERSION_NAME=$(echo "${MC_API_DETAILS_CACHE[$TMP_OBJTYPE]}" | $AWK -F${MANUAL_COLL_APICACHE_DELIMITER} '{ print $1 }')
							local OC_API_NAME=$(echo "${MC_API_DETAILS_CACHE[$TMP_OBJTYPE]}" | $AWK -F${MANUAL_COLL_APICACHE_DELIMITER} '{ print $2 }')
							local OC_API_KIND=$(echo "${MC_API_DETAILS_CACHE[$TMP_OBJTYPE]}" | $AWK -F${MANUAL_COLL_APICACHE_DELIMITER} '{ print $3 }')
						else
							local TO_PROCEED_API="true"
						fi	
					else
						local TO_PROCEED_API="true"
					fi

					if [ $TO_PROCEED_API == "true" ]
					then
						local OC_APIVERSION_NAME=$(getApiVersionName $TMP_OBJTYPE)
						local OC_API_NAME=$(getApiName $TMP_OBJTYPE)
						local OC_API_KIND=$(getApiKind $TMP_OBJTYPE)
			
						if [ $BASH_V4 == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Adding [$TMP_OBJTYPE] with value [$OC_APIVERSION_NAME${MANUAL_COLL_APICACHE_DELIMITER}$OC_API_NAME${MANUAL_COLL_APICACHE_DELIMITER}$OC_API_KIND] into array MC_API_DETAILS_CACHE..."
							local MC_API_DETAILS_CACHE["$TMP_OBJTYPE"]="$OC_APIVERSION_NAME${MANUAL_COLL_APICACHE_DELIMITER}$OC_API_NAME${MANUAL_COLL_APICACHE_DELIMITER}$OC_API_KIND"
						fi
					fi

					if [ ${#SUB_TMP_OBJNS} -gt 0 ]
					then
						local TMP_OUTDIR=$MC_OUTDIR/TAG=$TAG/$SUB_TMP_OBJNS/$TMP_OBJTYPE
						local FAST_OC_DESC_WORKFILE=$MC_OUTDIR/TAG=$TAG/fast_oc_desc.$LC_OBJTYPE.tmp
						local FAST_OC_YAML_WORKFILE=$MC_OUTDIR/TAG=$TAG/fast_oc_yaml.$LC_OBJTYPE.tmp
						local OC_API_OBJNS=$SUB_TMP_OBJNS
					else
						local TMP_OUTDIR=$MC_OUTDIR/TAG=$TAG/$TMP_OBJNS/$TMP_OBJTYPE
						local FAST_OC_DESC_WORKFILE=$TMP_OUTDIR/fast_oc_desc.$LC_OBJTYPE.tmp
						local FAST_OC_YAML_WORKFILE=$TMP_OUTDIR/fast_oc_yaml.$LC_OBJTYPE.tmp
						local OC_API_OBJNS=$TMP_OBJNS
					fi
	
					if [ ! -d $TMP_OUTDIR ]
					then	
						echo "[$(date)] [${FUNCNAME[0]}] Making directory [$TMP_OUTDIR]..."
						mkdir -p $TMP_OUTDIR
					fi
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] TMP_OBJNS = [$TMP_OBJNS] / TMP_OBJTYPE = [$TMP_OBJTYPE] / TMP_OBJNAME = [$TMP_OBJNAME] / OBJNAME_ARRAY_VAL = [$OBJNAME_ARRAY_VAL] / OBJFILTER_ARRAY_VAL = [$OBJFILTER_ARRAY_VAL] / IS_OBJNAME_NULL = [$IS_OBJNAME_NULL] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME] / OC_API_NAME = [$OC_API_NAME] / OC_API_KIND = [$OC_API_KIND] / FAST_OC_DESC_WORKFILE = [$FAST_OC_DESC_WORKFILE] / FAST_OC_YAML_WORKFILE = [$FAST_OC_YAML_WORKFILE]"
					fi

					if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ] || [ $GET_POD_LOGS == "true" ]
					then
						if [ $BASH_V4 == "true" ] && [ ${#MC_TO_PROCEED_CACHE[@]} -gt 0 ]
						then
							if [ ${MC_TO_PROCEED_CACHE["$TMP_OBJNS/$LC_OBJTYPE"]+_} ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Value retrieved from MC_TO_PROCEED_CACHE for key [$TMP_OBJNS/$LC_OBJTYPE] = [${MC_TO_PROCEED_CACHE[$TMP_OBJNS/$LC_OBJTYPE]}]"
								local TO_PROCEED_CHECK="false"

								local TO_PROCEED_YAML=${MC_TO_PROCEED_CACHE["$TMP_OBJNS/$LC_OBJTYPE"]}
								local TO_PROCEED_JSON=${MC_TO_PROCEED_CACHE["$TMP_OBJNS/$LC_OBJTYPE"]}
								local TO_PROCEED_LOGS=${MC_TO_PROCEED_CACHE["$TMP_OBJNS/$LC_OBJTYPE"]}
							else
								local TO_PROCEED_CHECK="true"
							fi
						else
							local TO_PROCEED_CHECK="true"
						fi

						if [ $TO_PROCEED_CHECK == "true" ]
						then
							local TO_PROCEED_YAML="false"
							local TO_PROCEED_JSON="false"
							local TO_PROCEED_LOGS="false"
					
							if isSensitiveData "$LC_OBJTYPE"
							then
								if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
								then		
									if [ $MANUAL_COLL_SENSITIVE_DATA_OVERRIDE == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] User agreed to collection of sensitive data [$LC_OBJTYPE] through MANUAL_COLL_SENSITIVE_DATA_OVERRIDE [$MANUAL_COLL_SENSITIVE_DATA_OVERRIDE]!"
	
										local TO_PROCEED_YAML="true"
										local TO_PROCEED_JSON="true"
										local TO_PROCEED_LOGS="true"
									else
										echo "[$(date)] [${FUNCNAME[0]}] getManualCollection() function does not support '$OC_CMD get -o yaml/json' of [$LC_OBJTYPE] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [$LC_OBJTYPE]!"
									local TO_PROCEED_YAML="true"
									local TO_PROCEED_JSON="true"
									local TO_PROCEED_LOGS="true"
								fi
							else
								local TO_PROCEED_YAML="true"
								local TO_PROCEED_JSON="true"
								local TO_PROCEED_LOGS="true"
							fi

							if [ $BASH_V4 == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Adding [$TMP_OBJNS/$LC_OBJTYPE] with value [$TO_PROCEED_YAML] into array MC_TO_PROCEED_CACHE..."
								local MC_TO_PROCEED_CACHE["$TMP_OBJNS/$LC_OBJTYPE"]="$TO_PROCEED_YAML"
							fi
						fi
					fi

					if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_YAML == "true" ]
					then
						if [ $BASH_V4 == "true" ] && [ ${#MC_FAST_OC_YAML_PREREQ_CACHE[@]} -gt 0 ]
						then
							if [ ${MC_FAST_OC_YAML_PREREQ_CACHE["$TMP_OBJNS/$LC_OBJTYPE"]+_} ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Value retrieved from MC_FAST_OC_YAML_PREREQ_CACHE for key [$TMP_OBJNS/$LC_OBJTYPE] = [${MC_FAST_OC_YAML_PREREQ_CACHE[$TMP_OBJNS/$LC_OBJTYPE]}]"
								local TO_PROCEED_CHECK="false"

								local FAST_OC_YAML_WORTHY=${MC_FAST_OC_YAML_PREREQ_CACHE["$TMP_OBJNS/$LC_OBJTYPE"]}
							else
								local TO_PROCEED_CHECK="true"
							fi
						else
							local TO_PROCEED_CHECK="true"
						fi

						if [ $TO_PROCEED_CHECK == "true" ]
						then
							if [ $OBJFILTER_ARRAY_VAL == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Since OBJFILTER_ARRAY_VAL is [$OBJFILTER_ARRAY_VAL], setting FAST_OC_YAML_WORTHY to [false]..."
								local FAST_OC_YAML_WORTHY="false"

								if [ $BASH_V4 == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Since OBJFILTER_ARRAY_VAL is [$OBJFILTER_ARRAY_VAL], adding [$TMP_OBJNS/$LC_OBJTYPE] with value [false] into array MC_FAST_OC_YAML_PREREQ_CACHE..."
									local MC_FAST_OC_YAML_PREREQ_CACHE["$TMP_OBJNS/$LC_OBJTYPE"]="false"
								fi
							else
								local TOTAL_OBJ=$(wc -l < $SRC_FILE)
								local OBJ_TYPE_STR=$(echo "$OC_GET_CMD" | $AWK '{ print $3 }')
					
								if [ ${TOTAL_OBJ} -ge ${FAST_OC_YAML_PREREQ} ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$OBJ_TYPE_STR] has met minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
									local FAST_OC_YAML_WORTHY="true"
								else
									echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$OBJ_TYPE_STR] did not meet minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
									local FAST_OC_YAML_WORTHY="false"
								fi
	
								if [ $BASH_V4 == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Adding [$TMP_OBJNS/$LC_OBJTYPE] with value [$FAST_OC_YAML_WORTHY] into array MC_FAST_OC_YAML_PREREQ_CACHE..."
									local MC_FAST_OC_YAML_PREREQ_CACHE["$TMP_OBJNS/$LC_OBJTYPE"]="$FAST_OC_YAML_WORTHY"
								fi
							fi
						fi
					fi
		
					if [ $TMP_OBJNS == "all-namespaces" ]
					then
						# Cluster-scoped resource
						if [ $OC_DESC_ON == "true" ]
						then
							if [ $FAST_OC_DESC == "true" ]
							then
								if [ $IS_OBJNAME_NULL == "true" ] && [ $OBJFILTER_ARRAY_VAL == "false" ]
								then
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [1] Writing new line [##$TMP_OBJTYPE##$TMP_OUTDIR] => $FAST_OC_DESC_WORKFILE"
									fi

									echo "##$TMP_OBJTYPE##$TMP_OUTDIR" >> $FAST_OC_DESC_WORKFILE 
								else
									echo "[$(date)] [${FUNCNAME[0]}] [1] Executing '$OC_CMD describe $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.desc"
									$OC_CMD describe $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.desc 2>&1
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] [1] Executing '$OC_CMD describe $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.desc"
								$OC_CMD describe $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.desc 2>&1
							fi
						fi
	
						if [ $COLLECT_YAML == "true" ]
						then
							if [ $TO_PROCEED_YAML == "true" ]
							then
								if [ ${FAST_OC_YAML} == "true" ] && [ $IS_OBJNAME_NULL == "true" ] && [ ${FAST_OC_YAML_WORTHY} == "true" ]
								then
									if [ $FAST_OC == "true" ] 
									then
										if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
										then
											local YAML_CURL_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$TMP_OBJNAME"
										else
											local YAML_CURL_CMD=""
										fi
									else
										local YAML_CURL_CMD=""
									fi

									# To create fallback reference file for FAST_OC_YAML
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Writing new line [##$TMP_OBJTYPE##$TMP_OBJNAME##$TMP_OUTDIR##$YAML_CURL_CMD] => $FAST_OC_YAML_WORKFILE"
									fi
							
									echo "##$TMP_OBJTYPE##$TMP_OBJNAME##$TMP_OUTDIR##$YAML_CURL_CMD" >> $FAST_OC_YAML_WORKFILE
								else
									if [ $FAST_OC == "true" ] 
									then
										if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$TMP_OBJNAME"
											eval "$YAML_CMD" > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
		
											if [ -s $TMP_OUTDIR/$TMP_OBJNAME.yaml ]
											then
												if ( [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.yaml) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $TMP_OUTDIR/$TMP_OBJNAME.yaml) =~ \"paths\": ]] ) || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.yaml) =~ ^404 ]] || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.yaml) =~ "Moved Permanently" ]]
												then
													echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
		
													if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
													then
														echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
														$OC_CMD get -o yaml --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
													else
														echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
														$OC_CMD get -o yaml $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
													fi
												fi
											else
												if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
												then
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
													$OC_CMD get -o yaml --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
												else
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
													$OC_CMD get -o yaml $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
												fi
											fi
										else
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
												$OC_CMD get -o yaml --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
											else
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
												$OC_CMD get -o yaml $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
											fi
										fi
									else
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
											$OC_CMD get -o yaml --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
											$OC_CMD get -o yaml $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
										fi
									fi
								fi
							fi
						fi

						if [ $COLLECT_JSON == "true" ]
						then
							if [ $TO_PROCEED_JSON == "true" ]
							then
								if [ $FAST_OC == "true" ] 
								then
									if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$TMP_OBJNAME"
										eval "$JSON_CMD" > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
	
										if [ -s $TMP_OUTDIR/$TMP_OBJNAME.json ]
										then
											if ( [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.json) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $TMP_OUTDIR/$TMP_OBJNAME.json) =~ \"paths\": ]] ) || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.json) =~ ^404 ]] || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.json) =~ "Moved Permanently" ]]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
	
												if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
												then
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
													$OC_CMD get -o json --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
												else
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
													$OC_CMD get -o json $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
												fi
											fi
										else
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
												$OC_CMD get -o json --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
											else
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
												$OC_CMD get -o json $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
											fi
										fi
									else
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
											$OC_CMD get -o json --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
											$OC_CMD get -o json $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
										fi
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
										$OC_CMD get -o json --show-managed-fields $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
										$OC_CMD get -o json $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
									fi
								fi
							fi
						fi
					else
						# Namespace-scoped resource
						if [ $OC_DESC_ON == "true" ]
						then
							if [ $FAST_OC_DESC == "true" ]
							then
								if [ $IS_OBJNAME_NULL == "true" ] && [ $OBJFILTER_ARRAY_VAL == "false" ]
								then
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [2] Writing new line [$OC_API_OBJNS##$TMP_OBJTYPE##$TMP_OUTDIR] => $FAST_OC_DESC_WORKFILE"
									fi

									echo "$OC_API_OBJNS##$TMP_OBJTYPE##$TMP_OUTDIR" >> $FAST_OC_DESC_WORKFILE 
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.desc"
									$OC_CMD describe -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.desc 2>&1
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.desc"
								$OC_CMD describe -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.desc 2>&1
							fi
						fi
	
						if [ $COLLECT_YAML == "true" ]
						then
							if [ $TO_PROCEED_YAML == "true" ]
							then
								if [ ${FAST_OC_YAML} == "true" ] && [ $IS_OBJNAME_NULL == "true" ] && [ ${FAST_OC_YAML_WORTHY} == "true" ]
								then
									if [ $FAST_OC == "true" ] 
									then
										if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
										then
											local YAML_CURL_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/$OC_API_NAME"
										else
											local YAML_CURL_CMD=""
										fi
									else
										local YAML_CURL_CMD=""
									fi

									# To create fallback reference file for FAST_OC_YAML
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$OC_API_OBJNS##$TMP_OBJTYPE##$TMP_OBJNAME##$TMP_OUTDIR##$YAML_CURL_CMD] => $FAST_OC_YAML_WORKFILE"
									fi
							
									echo "$OC_API_OBJNS##$TMP_OBJTYPE##$TMP_OBJNAME##$TMP_OUTDIR##$YAML_CURL_CMD" >> $FAST_OC_YAML_WORKFILE
								else
									if [ $FAST_OC == "true" ] 
									then
										if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/namespaces/$OC_API_OBJNS/$TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/$OC_API_NAME/$TMP_OBJNAME"
											eval "$YAML_CMD" > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
		
											if [ -s $TMP_OUTDIR/$TMP_OBJNAME.yaml ]
											then
												if ( [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.yaml) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $TMP_OUTDIR/$TMP_OBJNAME.yaml) =~ \"paths\": ]] ) || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.yaml) =~ ^404 ]] || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.yaml) =~ "Moved Permanently" ]]
												then
													echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
		
													if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
													then
														echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
														$OC_CMD get -o yaml --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
													else
														echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
														$OC_CMD get -o yaml -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
													fi
												fi
											else
												if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
												then
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
													$OC_CMD get -o yaml --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
												else
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
													$OC_CMD get -o yaml -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
												fi
											fi
										else
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
												$OC_CMD get -o yaml --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
											else
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
												$OC_CMD get -o yaml -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
											fi
										fi
									else
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
											$OC_CMD get -o yaml --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.yaml"
											$OC_CMD get -o yaml -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.yaml 2>&1
										fi
									fi
								fi
							fi
						fi

						if [ $COLLECT_JSON == "true" ]
						then
							if [ $TO_PROCEED_JSON == "true" ]
							then
								if [ $FAST_OC == "true" ] 
								then
									if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/namespaces/$OC_API_OBJNS/$TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/$OC_API_NAME/$TMP_OBJNAME"
										eval "$JSON_CMD" > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
	
										if [ -s $TMP_OUTDIR/$TMP_OBJNAME.json ]
										then
											if ( [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.json) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $TMP_OUTDIR/$TMP_OBJNAME.json) =~ \"paths\": ]] ) || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.json) =~ ^404 ]] || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME.json) =~ "Moved Permanently" ]]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
	
												if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
												then
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
													$OC_CMD get -o json --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
												else
													echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
													$OC_CMD get -o json -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
												fi
											fi
										else
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
												$OC_CMD get -o json --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
											else
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
												$OC_CMD get -o json -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
											fi
										fi
									else
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
											$OC_CMD get -o json --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
											$OC_CMD get -o json -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
										fi
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]	
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
										$OC_CMD get -o json --show-managed-fields -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o json -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME' => $TMP_OUTDIR/$TMP_OBJNAME.json"
										$OC_CMD get -o json -n $OC_API_OBJNS $TMP_OBJTYPE $TMP_OBJNAME > $TMP_OUTDIR/$TMP_OBJNAME.json 2>&1
									fi
								fi
							fi
						fi
					fi
	
					if [ $GET_POD_LOGS == "true" ] && [ $TO_PROCEED_LOGS == "true" ]
					then
						if [ $TMP_OBJTYPE == "pod" ] || [ $TMP_OBJTYPE == "pods" ] || [ $TMP_OBJTYPE == "po" ]
						then
							IFS=$OLDIFS

							for INIT_CONTAINER in $($OC_CMD get pod -n $OC_API_OBJNS $TMP_OBJNAME -o=jsonpath="{.spec.initContainers[*].name}")
							do 
								if [ $FAST_OC == "true" ] 
								then
									if [ ${#OC_APIVERSION_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/pods/$TMP_OBJNAME/log?container=${INIT_CONTAINER}${POD_LOG_TAILLINES_CURL_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log"
										local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/pods/$TMP_OBJNAME/log?container=${INIT_CONTAINER}${POD_LOG_TAILLINES_CURL_STR}'"
										eval "$CMD" > $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log 2>&1

										if [ ! -f $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log ] || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log) =~ ^"404 page not found" ]] || ( [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log | wc -l) -gt 0 ] ) 
										then
											echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log"
											$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log 2>&1
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log"
										$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log 2>&1
									fi
	
									if [ $COLL_PREV_LOGS == "true" ]
									then
										if [ ${#OC_APIVERSION_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/pods/$TMP_OBJNAME/log?container=${INIT_CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev"
											local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/pods/$TMP_OBJNAME/log?container=${INIT_CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}'"
											eval "$CMD" > $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev 2>&1

											if [ ! -f $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev ] || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev) =~ ^"404 page not found" ]] || ( [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev | wc -l) -gt 0 ] ) 
											then
												echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev"
												$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev 2>&1
											fi
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev"
											$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev 2>&1
										fi
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log"
									$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log 2>&1
		
									if [ $COLL_PREV_LOGS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev"
										$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$INIT_CONTAINER.log.prev 2>&1
									fi
								fi
							done
	
							for CONTAINER in $($OC_CMD get pod -n $OC_API_OBJNS $TMP_OBJNAME -o=jsonpath="{.spec.containers[*].name}")
							do 
								if [ $FAST_OC == "true" ] 
								then
									if [ ${#OC_APIVERSION_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/pods/$TMP_OBJNAME/log?container=${CONTAINER}${POD_LOG_TAILLINES_CURL_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log"
										local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/pods/$TMP_OBJNAME/log?container=${CONTAINER}${POD_LOG_TAILLINES_CURL_STR}'"
										eval "$CMD" > $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log 2>&1

										if [ ! -f $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log ] || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log) =~ ^"404 page not found" ]] || ( [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log | wc -l) -gt 0 ] ) 
										then
											echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log"
											$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log 2>&1
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log"
										$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log 2>&1
									fi
	
									if [ $COLL_PREV_LOGS == "true" ]
									then
										if [ ${#OC_APIVERSION_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/pods/$TMP_OBJNAME/log?container=${CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev"
											local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$OC_API_OBJNS/pods/$TMP_OBJNAME/log?container=${CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}'"
											eval "$CMD" > $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev 2>&1

											if [ ! -f $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev ] || [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev) =~ ^"404 page not found" ]] || ( [[ $(head -1 $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev | wc -l) -gt 0 ] ) 
											then
												echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev"
												$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev 2>&1
											fi
										else
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev"
											$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev 2>&1
										fi
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log"
									$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log 2>&1
		
									if [ $COLL_PREV_LOGS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev"
										$OC_CMD logs -n $OC_API_OBJNS $TMP_OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $TMP_OUTDIR/$TMP_OBJNAME~$CONTAINER.log.prev 2>&1
									fi
								fi
							done

							IFS=$'\n'
						fi
					fi
				done < $SRC_FILE

				if [ $FAST_OC_DESC == "true" ]
				then
					if [ -s $FAST_OC_DESC_WORKFILE ]
					then
						for LINE in $(cat $FAST_OC_DESC_WORKFILE | sort | uniq)
						do
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] LINE = [$LINE]"
							fi

							local FAST_OC_DESC_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
							local FAST_OC_DESC_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
							local FAST_OC_DESC_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')
		
							if [ ${#FAST_OC_DESC_NS} -gt 0 ]
							then
								local FAST_OC_DESC_TMPFILE=$FAST_OC_DESC_OUTDIR/fast_oc_desc.$FAST_OC_DESC_OBJTYPE.desc-all
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe $FAST_OC_DESC_OBJTYPE -n $FAST_OC_DESC_NS' => $FAST_OC_DESC_TMPFILE"
								$OC_CMD describe $FAST_OC_DESC_OBJTYPE -n $FAST_OC_DESC_NS > $FAST_OC_DESC_TMPFILE
							else
								local FAST_OC_DESC_TMPFILE=$FAST_OC_DESC_OUTDIR/fast_oc_desc.$FAST_OC_DESC_OBJTYPE.desc-all
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe $FAST_OC_DESC_OBJTYPE' => $FAST_OC_DESC_TMPFILE"
								$OC_CMD describe $FAST_OC_DESC_OBJTYPE > $FAST_OC_DESC_TMPFILE
							fi
			
							if [ -s $FAST_OC_DESC_TMPFILE ]
							then
								local RECORD_SEPARATOR_KEYWORD=$(head -1 $FAST_OC_DESC_TMPFILE | $AWK -F':' '{ print $1 }' | sed 's/[ ]*$//')
			
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] RECORD_SEPARATOR_KEYWORD = [$RECORD_SEPARATOR_KEYWORD]"
								fi
							
								if [ ${#RECORD_SEPARATOR_KEYWORD} ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing [sed '/^$/N;/^\n$/D;s/\(^\n\)${RECORD_SEPARATOR_KEYWORD}:/\1#@@@%@@@#\n${RECORD_SEPARATOR_KEYWORD}:/' $FAST_OC_DESC_TMPFILE | $AWK -v OUTDIR=$FAST_OC_DESC_OUTDIR 'BEGIN { RS=\"#@@@%@@@#\n\"; FS=\"\n\" } { OBJNAME=substr(\$1, index(\$1, \":\")+1); gsub(/^[ \t]*/, \"\", OBJNAME); gsub(/[\n]*$/, \"\", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR\"/\"OBJNAME\".desc\") } }]"
									sed '/^$/N;/^\n$/D;s/\(^\n\)'${RECORD_SEPARATOR_KEYWORD}':/\1#@@@%@@@#\n'${RECORD_SEPARATOR_KEYWORD}':/' $FAST_OC_DESC_TMPFILE | $AWK -v OUTDIR=$FAST_OC_DESC_OUTDIR 'BEGIN { RS="#@@@%@@@#\n"; FS="\n" } { OBJNAME=substr($1, index($1, ":")+1); gsub(/^[ \t]*/, "", OBJNAME); gsub(/[\n]*$/, "", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR"/"OBJNAME".desc") } }'
								else
									echo "[$(date)] [${FUNCNAME[0]}] Unable to determine RECORD_SEPARATOR_KEYWORD for resource type [$RESTYPE] in namespace [$NAMESPACE]!"
								fi
			
								local TMP_DESC_ALL_KEEP="false"
								local SOURCE_COUNT=$(grep '^'$RECORD_SEPARATOR_KEYWORD':' $FAST_OC_DESC_TMPFILE | $AWK -F: 'NF>=2' | wc -l)
								local DESC_FILE_COUNT=$(ls -l $FAST_OC_DESC_OUTDIR/*.desc | wc -l)
		
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] DESC_FILE_COUNT = [$DESC_FILE_COUNT] / SOURCE_COUNT = [$SOURCE_COUNT]"
								fi
				
								if [ ${#DESC_FILE_COUNT} -gt 0 ] && [ ${#SOURCE_COUNT} -gt 0 ]
								then
									if [ $DESC_FILE_COUNT -ne $SOURCE_COUNT ]
									then
										local TMP_DESC_ALL_KEEP="true"
									fi
								else
									local TMP_DESC_ALL_KEEP="true"
								fi

								if [ $MG_DEBUG == "true" ]
								then
									local TMP_CMD="echo $FAST_OC_DESC_TMPFILE | sed 's#$MANUAL_COLL_OUTDIR##'"
									local SUBDIR=$(eval "$TMP_CMD")
									local TMPFILE_OUTDIR=$MANUAL_COLL_ROOT_DEBUG_OUTDIR/$(dirname $SUBDIR)

									if [ ! -d $TMPFILE_OUTDIR ]
									then
										mkdir -p $TMPFILE_OUTDIR
									fi
			
									echo "[$(date)] [${FUNCNAME[0]}] File listing (*.desc) on output directory [$FAST_OC_DESC_OUTDIR] => [$(ls -l $FAST_OC_DESC_OUTDIR/*.desc)]"
									echo "[$(date)] [${FUNCNAME[0]}] File count (*.desc) on output directory [$FAST_OC_DESC_OUTDIR] => [$DESC_FILE_COUNT] [SOURCE_COUNT=$SOURCE_COUNT]"

									echo "[$(date)] [${FUNCNAME[0]}] TMP_DESC_ALL_KEEP = [$TMP_DESC_ALL_KEEP]"

									if [ $TMP_DESC_ALL_KEEP == "false" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Moving [$FAST_OC_DESC_TMPFILE] to directory [$TMPFILE_OUTDIR]..."
										mv $FAST_OC_DESC_TMPFILE $TMPFILE_OUTDIR
									else
										echo "[$(date)] [${FUNCNAME[0]}] Copying [$FAST_OC_DESC_TMPFILE] to directory [$TMPFILE_OUTDIR]..."
										cp -p $FAST_OC_DESC_TMPFILE $TMPFILE_OUTDIR
									fi
								else
									if [ $TMP_DESC_ALL_KEEP == "false" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_DESC_TMPFILE]..."
										rm $FAST_OC_DESC_TMPFILE
									fi
								fi
							else
								if [ ${#FAST_OC_DESC_NS} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC - '$OC_CMD describe $FAST_OC_DESC_OBJTYPE -n $FAST_OC_DESC_NS' output file [$FAST_OC_DESC_TMPFILE] does not exist or is zero-sized!"
								else
									echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC - '$OC_CMD describe $FAST_OC_DESC_OBJTYPE' output file [$FAST_OC_DESC_TMPFILE] does not exist or is zero-sized!"
								fi
							fi
						done
			
						if [ $MG_DEBUG == "true" ]
						then
							local TMP_CMD="echo $FAST_OC_DESC_WORKFILE | sed 's#$MANUAL_COLL_OUTDIR##'"
							local SUBDIR=$(eval "$TMP_CMD")
							local TMPFILE_OUTDIR=$MANUAL_COLL_ROOT_DEBUG_OUTDIR/$(dirname $SUBDIR)

							if [ ! -d $TMPFILE_OUTDIR ]
							then
								mkdir -p $TMPFILE_OUTDIR
							fi
			
							mv $FAST_OC_DESC_WORKFILE $TMPFILE_OUTDIR
						else
							rm $FAST_OC_DESC_WORKFILE
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC_WORKFILE [$FAST_OC_DESC_WORKFILE] does not exist or is zero-sized!"
					fi
				fi

				if [ $COLLECT_YAML == "true" ]
				then
					if [ ${FAST_OC_YAML} == "true" ]
					then
						if [ -s $FAST_OC_YAML_WORKFILE ]
						then
							local FAST_OC_YAML_FAILED="false"
	
							for LINE in $($AWK -F## '{ print $1 "##" $2 "##" $4 }' $FAST_OC_YAML_WORKFILE | sort | uniq)
							do
								local FAST_OC_YAML_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
								local FAST_OC_YAML_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
								local FAST_OC_YAML_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')
	
								local FAST_OC_YAML_OUTFILE=$FAST_OC_YAML_OUTDIR/fast_oc_yaml.$FAST_OC_YAML_OBJTYPE.yaml-all

								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_NS = [$FAST_OC_YAML_NS] / FAST_OC_YAML_OBJTYPE = [$FAST_OC_YAML_OBJTYPE] / FAST_OC_YAML_OUTDIR = [$FAST_OC_YAML_OUTDIR] / FAST_OC_YAML_OUTFILE = [$FAST_OC_YAML_OUTFILE]"
								fi
	
								if [ ${#FAST_OC_YAML_NS} -gt 0 ]
								then
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
										local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE"
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
										local BULK_YAML_CMD="$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE"
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
										local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE"
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
										local BULK_YAML_CMD="$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE"
									fi
								fi
	
								eval "$BULK_YAML_CMD" > $FAST_OC_YAML_OUTFILE
	
								if [ -s $FAST_OC_YAML_OUTFILE ]
								then
									sed $(( $(wc -l <$FAST_OC_YAML_OUTFILE)-3+1 ))',$ d; 1,2d; s/^-[ ]/#@@@%@@@#\'$'\n/g; s/^[ ]\{2\}//' $FAST_OC_YAML_OUTFILE | sed '1d' | $AWK -v OUTDIR=$FAST_OC_YAML_OUTDIR 'BEGIN { RS="#@@@%@@@#\n"; FS="\n" } { METADATA_FOUND="false"; OBJNAME=""; for (i=1; i<=NF; i++) { if ( $i ~ /^metadata:/  ){ METADATA_FOUND="true" } else { if ( $i ~ /^[ ]{2}name: / && METADATA_FOUND == "true" ) { OBJNAME=substr($i, index($i, ":")+1); gsub(/^[ \t]*/, "", OBJNAME); gsub(/[\n]*$/, "", $0); break } } }; if ( length(OBJNAME) > 0 ) { print > (OUTDIR"/"OBJNAME".yaml") } }'
	
									local TMP_YAML_ALL_KEEP="false"
									local SOURCE_COUNT=$(grep '^- ' $FAST_OC_YAML_OUTFILE | wc -l)
									local YAML_FILE_COUNT=$(ls -l $FAST_OC_YAML_OUTDIR/*.yaml | wc -l)
			
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] YAML_FILE_COUNT = [$YAML_FILE_COUNT] / SOURCE_COUNT = [$SOURCE_COUNT]"
									fi
							
									if [ ${#YAML_FILE_COUNT} -gt 0 ] && [ ${#SOURCE_COUNT} -gt 0 ]
									then
										if [ $YAML_FILE_COUNT -ne $SOURCE_COUNT ]
										then
											local TMP_YAML_ALL_KEEP="true"
										fi
									else
										local TMP_YAML_ALL_KEEP="true"
									fi
	
									if [ $MG_DEBUG == "true" ]
									then
										local TMP_CMD="echo $FAST_OC_YAML_OUTFILE | sed 's#$MANUAL_COLL_OUTDIR##'"
										local SUBDIR=$(eval "$TMP_CMD")
										local TMPFILE_OUTDIR=$MANUAL_COLL_ROOT_DEBUG_OUTDIR/$(dirname $SUBDIR)

										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] SUBDIR = [$SUBDIR] / TMPFILE_OUTDIR = [$TMPFILE_OUTDIR]"
										fi

										if [ ! -d $TMPFILE_OUTDIR ]
										then
											mkdir -p $TMPFILE_OUTDIR
										fi
		
										echo "[$(date)] [${FUNCNAME[0]}] File listing (*.yaml) on output directory [$FAST_OC_YAML_OUTDIR] => [$(ls -l $FAST_OC_YAML_OUTDIR/*.yaml)]"
										echo "[$(date)] [${FUNCNAME[0]}] File count (*.yaml) on output directory [$FAST_OC_YAML_OUTDIR] => [$YAML_FILE_COUNT] [SOURCE_COUNT=$SOURCE_COUNT]"
			
										echo "[$(date)] [${FUNCNAME[0]}] TMP_YAML_ALL_KEEP = [$TMP_YAML_ALL_KEEP]"
									
										if [ $TMP_YAML_ALL_KEEP == "false" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Moving FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] to directory [$TMPFILE_OUTDIR]..."
											mv $FAST_OC_YAML_OUTFILE $TMPFILE_OUTDIR
										else
											echo "[$(date)] [${FUNCNAME[0]}] Copying FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] to directory [$TMPFILE_OUTDIR]..."
											cp -p $FAST_OC_YAML_OUTFILE $TMPFILE_OUTDIR
										fi
									else	
										if [ $TMP_DESC_ALL_KEEP == "false" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_YAML_OUTFILE]..."
											rm $FAST_OC_YAML_OUTFILE
										fi
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] does not exist or is zero-sized!"
									local FAST_OC_YAML_FAILED="true"
								fi
							done
	
							if [ ${FAST_OC_YAML_FAILED} == "true" ]
							then	
								while read LINE
								do
									local FAST_OC_YAML_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
									local FAST_OC_YAML_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
									local FAST_OC_YAML_OBJNAME=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')
									local FAST_OC_YAML_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $4 }')
									local FAST_OC_YAML_CURL_CMD=$(echo "$LINE" | $AWK -F'##' '{ print $5 }')
	
									if [ ${#FAST_OC_YAML_CURL_CMD} -gt 0 ]
									then
										local BULK_YAML_CMD="$FAST_OC_YAML_CURL_CMD"
									else
										if [ ${#FAST_OC_YAML_NS} -gt 0 ]
										then
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
												local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
											else
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
												local BULK_YAML_CMD="$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
											fi
										else
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
												local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
											else
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
												local BULK_YAML_CMD="$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
											fi
										fi
									fi
	
									echo "[$(date)] [${FUNCNAME[0]}] [RETRY] Executing '$BULK_YAML_CMD' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
									eval "$BULK_YAML_CMD" > $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml
								done < $FAST_OC_YAML_WORKFILE
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								local TMP_CMD="echo $FAST_OC_YAML_WORKFILE | sed 's#$MANUAL_COLL_OUTDIR##'"
								local SUBDIR=$(eval "$TMP_CMD")
								local TMPFILE_OUTDIR=$MANUAL_COLL_ROOT_DEBUG_OUTDIR/$(dirname $SUBDIR)

								echo "[$(date)] [${FUNCNAME[0]}] Moving FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE] to directory [$TMPFILE_OUTDIR]..."
								mv $FAST_OC_YAML_WORKFILE $TMPFILE_OUTDIR
							else
								echo "[$(date)] [${FUNCNAME[0]}] Deleting FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE]..."
								rm $FAST_OC_YAML_WORKFILE
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE] does not exist or is zero-sized!"
						fi
					fi
				fi
			done
 		done < $MANUAL_COLL_INPUTFILE_PROC

		echo "[$(date)] [${FUNCNAME[0]}] Total config lines processed = $MANUAL_COLL_CFGLINE_CTR"
		
		if [ $MANUAL_COLL_CFGLINE_CTR -eq 0 ] && [ ${#MANUAL_COLL_INPUTTAG} -gt 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] MANUAL_COLL_INPUTTAG [$MANUAL_COLL_INPUTTAG] does not exist in input file [$MANUAL_COLL_INPUTFILE_PROC]!"
		fi

		if [ $MG_DEBUG != "true" ] && [ -f $MANUAL_COLL_INPUTFILE_PROC ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Removing file MANUAL_COLL_INPUTFILE_PROC [$MANUAL_COLL_INPUTFILE_PROC]..."
			rm $MANUAL_COLL_INPUTFILE_PROC
		fi

		for TMPFILE in ${TMPFILE_ARRAY[@]}
		do
			if [ -f $TMPFILE ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					local TMP_CMD="echo $TMPFILE | sed 's#$MANUAL_COLL_OUTDIR##'"
					local SUBDIR=$(eval "$TMP_CMD")
					local TMPFILE_OUTDIR=$MANUAL_COLL_ROOT_DEBUG_OUTDIR/$(dirname $SUBDIR)

					if [ ! -d $TMPFILE_OUTDIR ]
					then
						mkdir -p $TMPFILE_OUTDIR
					fi

					echo "[$(date)] [${FUNCNAME[0]}] Copying temp file [$TMPFILE] to directory [$TMPFILE_OUTDIR]..."
					cp -p $TMPFILE $TMPFILE_OUTDIR
				fi

				echo "[$(date)] [${FUNCNAME[0]}] Removing temp file [$TMPFILE]..."
				rm $TMPFILE
			fi
		done
 	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [PRODGRP=$MC_PROD_GROUP / PRODVER=$MC_PROD_VER]"
	fi
}

runCmdExec()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local DEF_ENV=
	local NS=
	local ENVLINE=
	local VARVALUE=

	echo "[$(date)] [${FUNCNAME[0]}] Entering manual command execution module!" 

	local CMD_EXEC_INPUT_DIR=$CMD_EXEC_OUTDIR/input
	local CMD_EXEC_OUTPUT_DIR=$CMD_EXEC_OUTDIR/output
	local CMD_EXEC_OUTFILE=$CMD_EXEC_OUTPUT_DIR/cmdexec.out
	local CMD_EXEC_ERRFILE=$CMD_EXEC_OUTPUT_DIR/cmdexec.err

	if [ ! -d $CMD_EXEC_INPUT_DIR ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Making directory [$CMD_EXEC_INPUT_DIR]..."
		mkdir -p $CMD_EXEC_INPUT_DIR
	fi

	if [ ! -d $CMD_EXEC_OUTPUT_DIR ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Making directory [$CMD_EXEC_OUTPUT_DIR]..."
		mkdir -p $CMD_EXEC_OUTPUT_DIR
	fi

	if [ $CMD_EXEC_CMD == ".listcmd" ] || [ $CMD_EXEC_CMD == ".listcmd_custom" ]
	then
		local CMD_EXEC_LISTCMD_TMPFILE=$CMD_EXEC_OUTPUT_DIR/cmdexec.tmp

		if [ $REPORT_ON_SCREEN == "false" ]
		then
			echo "[$(date)] [$(basename "$0")] Setting REPORT_ON_SCREEN to [true]..."

			REPORT_ON_SCREEN="true" 
			REPORT_ON_SCREEN_SUMMARY_FILE=$ROOT_OUTDIR/${ANALYZE_OUTFILE##*/}.$$
		fi

		if [ ${#RTVAR_CMDEXEC_PRODVER} -gt 0 ]
		then
			local CMD_EXEC_PRODVER_VALID="false"

			for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
			do
				if [ $RTVAR_CMDEXEC_PRODVER == $VALID_PROD_VERSION ]
				then
					local CMD_EXEC_PRODVER_VALID="true"
					break
				fi
			done	

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] RTVAR_CMDEXEC_PRODVER = [$RTVAR_CMDEXEC_PRODVER] / CMD_EXEC_PRODVER_VALID = [$CMD_EXEC_PRODVER_VALID]"
			fi
	
			if [ ${CMD_EXEC_PRODVER_VALID} == "true" ]
			then
				if [ $CMD_EXEC_CMD == ".listcmd" ]
				then	
					local CMD_EXEC_PROD_DIR="$MUSTGATHER_DIRNAME/config/cmdexec/$RTVAR_CMDEXEC_PRODVER"
					local CMD_EXEC_PROD_HELPFILE="$MUSTGATHER_DIRNAME/config/cmdexec/$RTVAR_CMDEXEC_PRODVER/.cmdexec.help"
				else
					local CMD_EXEC_CUSTOM_DIR="$MUSTGATHER_DIRNAME/data/cmdexec/$RTVAR_CMDEXEC_PRODVER"
					local CMD_EXEC_CUSTOM_HELPFILE="$MUSTGATHER_DIRNAME/data/cmdexec/$RTVAR_CMDEXEC_PRODVER/.cmdexec.help"
					local CMD_EXEC_CUSTOM_GEN_DIR="$MUSTGATHER_DIRNAME/data/cmdexec"
					local CMD_EXEC_CUSTOM_GEN_HELPFILE="$MUSTGATHER_DIRNAME/data/cmdexec/.cmdexec.help"
				fi

				local CMD_EXEC_PROD_VERSION=$RTVAR_CMDEXEC_PRODVER
			else
				if [ $CMD_EXEC_CMD == ".listcmd" ]
				then	
					local CMD_EXEC_PROD_DIR="$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION"
					local CMD_EXEC_PROD_HELPFILE="$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION/.cmdexec.help"
				else
					local CMD_EXEC_CUSTOM_DIR="$MUSTGATHER_DIRNAME/data/cmdexec/$PRODUCT_VERSION"
					local CMD_EXEC_CUSTOM_HELPFILE="$MUSTGATHER_DIRNAME/data/cmdexec/$PRODUCT_VERSION/.cmdexec.help"
					local CMD_EXEC_CUSTOM_GEN_DIR="$MUSTGATHER_DIRNAME/data/cmdexec"
					local CMD_EXEC_CUSTOM_GEN_HELPFILE="$MUSTGATHER_DIRNAME/data/cmdexec/.cmdexec.help"
				fi

				local CMD_EXEC_PROD_VERSION=$PRODUCT_VERSION
			fi
		else
			if [ $CMD_EXEC_CMD == ".listcmd" ]
			then	
				local CMD_EXEC_PROD_DIR="$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION"
				local CMD_EXEC_PROD_HELPFILE="$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION/.cmdexec.help"
			else
				local CMD_EXEC_CUSTOM_DIR="$MUSTGATHER_DIRNAME/data/cmdexec/$PRODUCT_VERSION"
				local CMD_EXEC_CUSTOM_HELPFILE="$MUSTGATHER_DIRNAME/data/cmdexec/$PRODUCT_VERSION/.cmdexec.help"
				local CMD_EXEC_CUSTOM_GEN_DIR="$MUSTGATHER_DIRNAME/data/cmdexec"
				local CMD_EXEC_CUSTOM_GEN_HELPFILE="$MUSTGATHER_DIRNAME/data/cmdexec/.cmdexec.help"
			fi

			local CMD_EXEC_PROD_VERSION=$PRODUCT_VERSION
		fi

		if [ $MG_DEBUG == "true" ]
		then
			if [ $CMD_EXEC_CMD == ".listcmd" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_PROD_DIR = [$CMD_EXEC_PROD_DIR] / CMD_EXEC_PROD_HELPFILE = [$CMD_EXEC_PROD_HELPFILE]"
			else
				echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_CUSTOM_DIR = [$CMD_EXEC_CUSTOM_DIR] / CMD_EXEC_CUSTOM_HELPFILE = [$CMD_EXEC_CUSTOM_HELPFILE] / CMD_EXEC_CUSTOM_GEN_DIR = [$CMD_EXEC_CUSTOM_GEN_DIR] / CMD_EXEC_CUSTOM_GEN_HELPFILE = [$CMD_EXEC_CUSTOM_GEN_HELPFILE]"
			fi
		fi

		if [ $CMD_EXEC_CMD == ".listcmd" ]
		then
			local CMD_EXEC_SYS_DIR="$MUSTGATHER_DIRNAME/cmdexec"
			local CMD_EXEC_SYS_HELPFILE="$MUSTGATHER_DIRNAME/cmdexec/.cmdexec.help"

			local CMD_EXEC_PROD_CTR=0
			local CMD_EXEC_SYS_CTR=0
	
			if [ -d $CMD_EXEC_PROD_DIR ]
			then
				for CMD_EXEC_PROD_SCRIPT in $(ls $CMD_EXEC_PROD_DIR)
				do
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Processing product script [$CMD_EXEC_PROD_DIR/$CMD_EXEC_PROD_SCRIPT]..."
					fi
		
					if [ -s $CMD_EXEC_PROD_HELPFILE ]
					then
						local CMD_EXEC_PROD_SCRIPT_DESC=$(grep -E -v '^[ ]*'${CMD_EXEC_HELPFILE_COMMENT} $CMD_EXEC_PROD_HELPFILE | $AWK -F${CMD_EXEC_HELPFILE_DELIMITER} '$1 ~ /^'$CMD_EXEC_PROD_SCRIPT'$/ { print $2 }')
						local CMD_EXEC_PROD_SCRIPT_EXAMPLE=$(grep -E -v '^[ ]*'${CMD_EXEC_HELPFILE_COMMENT} $CMD_EXEC_PROD_HELPFILE | $AWK -F${CMD_EXEC_HELPFILE_DELIMITER} '$1 ~ /^'$CMD_EXEC_PROD_SCRIPT'$/ { print $3 }')
					else
						local CMD_EXEC_PROD_SCRIPT_DESC="N/A"
						local CMD_EXEC_PROD_SCRIPT_EXAMPLE="N/A"
					fi
		
					printf "%-25s %-95s %-60s \n" "$CMD_EXEC_PROD_SCRIPT" "${CMD_EXEC_PROD_SCRIPT_DESC:=N/A}" "${CMD_EXEC_PROD_SCRIPT_EXAMPLE:=N/A}" >> $CMD_EXEC_LISTCMD_TMPFILE
	
					(( CMD_EXEC_PROD_CTR=CMD_EXEC_PROD_CTR+1 ))
				done
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Directory [$CMD_EXEC_PROD_DIR] doest not exist!"
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				if [ -d $CMD_EXEC_PROD_DIR ] && [ $CMD_EXEC_PROD_CTR -eq 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] There is no CMDEXEC script in product directory [$CMD_EXEC_PROD_DIR]!"
				fi
			fi
	
			if [ -d $CMD_EXEC_SYS_DIR ]
			then
				for CMD_EXEC_SYS_SCRIPT in $(ls $CMD_EXEC_SYS_DIR)
				do
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Processing system script [$CMD_EXEC_SYS_DIR/$CMD_EXEC_SYS_SCRIPT]..."
					fi
		
					if [ -s $CMD_EXEC_SYS_HELPFILE ]
					then
						local CMD_EXEC_SYS_SCRIPT_DESC=$(grep -E -v '^[ ]*'${CMD_EXEC_HELPFILE_COMMENT} $CMD_EXEC_SYS_HELPFILE | $AWK -F${CMD_EXEC_HELPFILE_DELIMITER} '$1 ~ /^'$CMD_EXEC_SYS_SCRIPT'$/ { print $2 }')
						local CMD_EXEC_SYS_SCRIPT_EXAMPLE=$(grep -E -v '^[ ]*'${CMD_EXEC_HELPFILE_COMMENT} $CMD_EXEC_SYS_HELPFILE | $AWK -F${CMD_EXEC_HELPFILE_DELIMITER} '$1 ~ /^'$CMD_EXEC_SYS_SCRIPT'$/ { print $3 }')
					else
						local CMD_EXEC_SYS_SCRIPT_DESC="N/A"
						local CMD_EXEC_SYS_SCRIPT_EXAMPLE="N/A"
					fi
		
					printf "%-25s %-95s %-60s \n" "$CMD_EXEC_SYS_SCRIPT" "${CMD_EXEC_SYS_SCRIPT_DESC:=N/A}" "${CMD_EXEC_SYS_SCRIPT_EXAMPLE:=N/A}" >> $CMD_EXEC_LISTCMD_TMPFILE
	
					(( CMD_EXEC_SYS_CTR=CMD_EXEC_SYS_CTR+1 ))
				done
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Directory [$CMD_EXEC_SYS_DIR] doest not exist!"
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				if [ -d $CMD_EXEC_SYS_DIR ] && [ $CMD_EXEC_SYS_CTR -eq 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] There is no CMDEXEC script in system directory [$CMD_EXEC_SYS_DIR]!"
				fi
			fi
		else
			local CMD_EXEC_CUSTOM_CTR=0
			local CMD_EXEC_CUSTOM_GEN_CTR=0

			if [ -d $CMD_EXEC_CUSTOM_DIR ]
			then
				for CMD_EXEC_CUSTOM_SCRIPT in $(ls $CMD_EXEC_CUSTOM_DIR)
				do
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Processing product script [$CMD_EXEC_CUSTOM_DIR/$CMD_EXEC_CUSTOM_SCRIPT]..."
					fi
		
					if [ -s $CMD_EXEC_CUSTOM_HELPFILE ]
					then
						local CMD_EXEC_CUSTOM_SCRIPT_DESC=$(grep -E -v '^[ ]*'${CMD_EXEC_HELPFILE_COMMENT} $CMD_EXEC_CUSTOM_HELPFILE | $AWK -F${CMD_EXEC_HELPFILE_DELIMITER} '$1 ~ /^'$CMD_EXEC_CUSTOM_SCRIPT'$/ { print $2 }')
						local CMD_EXEC_CUSTOM_SCRIPT_EXAMPLE=$(grep -E -v '^[ ]*'${CMD_EXEC_HELPFILE_COMMENT} $CMD_EXEC_CUSTOM_HELPFILE | $AWK -F${CMD_EXEC_HELPFILE_DELIMITER} '$1 ~ /^'$CMD_EXEC_CUSTOM_SCRIPT'$/ { print $3 }')
					else
						local CMD_EXEC_CUSTOM_SCRIPT_DESC="N/A"
						local CMD_EXEC_CUSTOM_SCRIPT_EXAMPLE="N/A"
					fi
		
					printf "%-25s %-95s %-60s \n" "$CMD_EXEC_CUSTOM_SCRIPT" "${CMD_EXEC_CUSTOM_SCRIPT_DESC:=N/A}" "${CMD_EXEC_CUSTOM_SCRIPT_EXAMPLE:=N/A}" >> $CMD_EXEC_LISTCMD_TMPFILE

					(( CMD_EXEC_CUSTOM_CTR=CMD_EXEC_CUSTOM_CTR+1 ))
				done
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Directory [$CMD_EXEC_CUSTOM_DIR] doest not exist!"
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				if [ -d $CMD_EXEC_CUSTOM_DIR ] && [ $CMD_EXEC_CUSTOM_CTR -eq 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] There is no CMDEXEC script in custom product directory [$CMD_EXEC_CUSTOM_DIR]!"
				fi
			fi

			if [ -d $CMD_EXEC_CUSTOM_GEN_DIR ]
			then
				for CMD_EXEC_CUSTOM_GEN_SCRIPT in $(ls $CMD_EXEC_CUSTOM_GEN_DIR)
				do
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Processing product script [$CMD_EXEC_CUSTOM_GEN_DIR/$CMD_EXEC_CUSTOM_GEN_SCRIPT]..."
					fi
		
					if [ -s $CMD_EXEC_CUSTOM_GEN_HELPFILE ]
					then
						local CMD_EXEC_CUSTOM_GEN_SCRIPT_DESC=$(grep -E -v '^[ ]*'${CMD_EXEC_HELPFILE_COMMENT} $CMD_EXEC_CUSTOM_GEN_HELPFILE | $AWK -F${CMD_EXEC_HELPFILE_DELIMITER} '$1 ~ /^'$CMD_EXEC_CUSTOM_GEN_SCRIPT'$/ { print $2 }')
						local CMD_EXEC_CUSTOM_GEN_SCRIPT_EXAMPLE=$(grep -E -v '^[ ]*'${CMD_EXEC_HELPFILE_COMMENT} $CMD_EXEC_CUSTOM_GEN_HELPFILE | $AWK -F${CMD_EXEC_HELPFILE_DELIMITER} '$1 ~ /^'$CMD_EXEC_CUSTOM_GEN_SCRIPT'$/ { print $3 }')
					else
						local CMD_EXEC_CUSTOM_GEN_SCRIPT_DESC="N/A"
						local CMD_EXEC_CUSTOM_GEN_SCRIPT_EXAMPLE="N/A"
					fi
		
					printf "%-25s %-95s %-60s \n" "$CMD_EXEC_CUSTOM_GEN_SCRIPT" "${CMD_EXEC_CUSTOM_GEN_SCRIPT_DESC:=N/A}" "${CMD_EXEC_CUSTOM_GEN_SCRIPT_EXAMPLE:=N/A}" >> $CMD_EXEC_LISTCMD_TMPFILE

					(( CMD_EXEC_CUSTOM_GEN_CTR=CMD_EXEC_CUSTOM_GEN_CTR+1 ))
				done
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Directory [$CMD_EXEC_CUSTOM_GEN_DIR] doest not exist!"
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				if [ -d $CMD_EXEC_CUSTOM_GEN_DIR ] && [ $CMD_EXEC_CUSTOM_GEN_CTR -eq 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] There is no CMDEXEC script in custom general directory [$CMD_EXEC_CUSTOM_GEN_DIR]!"
				fi
			fi
		fi

		if [ -f $CMD_EXEC_LISTCMD_TMPFILE ]
		then
			echo "====================================================================================================================================================================================" >> $ANALYZE_OUTFILE
			printf "%-25s %-95s %-60s \n" "SCRIPT" "DESCRIPTION" "EXAMPLE" >> $ANALYZE_OUTFILE
			echo "====================================================================================================================================================================================" >> $ANALYZE_OUTFILE

			sort $CMD_EXEC_LISTCMD_TMPFILE >> $ANALYZE_OUTFILE
			echo >> $ANALYZE_OUTFILE

			rm $CMD_EXEC_LISTCMD_TMPFILE
		fi

		return 0
	fi

	if [ -f $CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_FILE) ]
	then
		local DIFF=$(diff $CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_FILE) $CMD_EXEC_FILE 2> /dev/null)
		
		if [ ${#DIFF} -gt 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_FILE [$CMD_EXEC_FILE] failed verification! File content has changed since user acceptance!"
			cp -p $CMD_EXEC_FILE $CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_FILE).suspicious
			return 1
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_FILE [$CMD_EXEC_FILE] is verified! To proceed..."
			fi
		fi

		if [ $MG_DEBUG == "false" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] MG_DEBUG = [$MG_DEBUG] - Deleting file [$CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_FILE)]..."
			rm $CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_FILE)
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Input file [$CMD_EXEC_FILE] was not backup to directory [$CMD_EXEC_INPUT_DIR]. Security verification cannot proceed! Exiting..."
		return 1
	fi

	if [ ${#CMD_EXEC_ENVFILE} -gt 0 ] && [ -f $CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_ENVFILE) ]
	then
		local DIFF=$(diff $CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_ENVFILE) $CMD_EXEC_ENVFILE 2> /dev/null)
		
		if [ ${#DIFF} -gt 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_ENVFILE [$CMD_EXEC_ENVFILE] failed verification! File content has changed since user acceptance!"
			cp -p $CMD_EXEC_ENVFILE $CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_ENVFILE).suspicious
			return 1
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_ENVFILE [$CMD_EXEC_ENVFILE] is verified! To proceed..."
			fi
		fi

		if [ $MG_DEBUG == "false" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] MG_DEBUG = [$MG_DEBUG] - Deleting file [$CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_ENVFILE)]..."
			rm $CMD_EXEC_INPUT_DIR/$(basename $CMD_EXEC_ENVFILE)
		fi
	else
		if [ ${#CMD_EXEC_ENVFILE} -gt 0 ] 
		then
			echo "[$(date)] [${FUNCNAME[0]}] Input environment file [$CMD_EXEC_FILE] was not backup to directory [$CMD_EXEC_INPUT_DIR]. Security verification cannot proceed! Exiting..."
			return 1
		fi
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Exporting default environment variables/functions to external shell script..."

	local CMD_EXEC_PRODUCT_NSFILE=$CMD_EXEC_INPUT_DIR/product.ns.$$
	echo "[$(date)] [${FUNCNAME[0]}] Providing a copy of PROD_NAMESPACES_REFFILE_FINAL to CMDEXEC custom script at location [$CMD_EXEC_PRODUCT_NSFILE]..."
	cp -p $PROD_NAMESPACES_REFFILE_FINAL $CMD_EXEC_PRODUCT_NSFILE
	
	CMD_EXEC_RESULT_MCCFG_FILE=$CMD_EXEC_OUTPUT_DIR/cmdexec-mccfg.cfg
	CMD_EXEC_RESULT_EXTRANS_FILE=$CMD_EXEC_OUTPUT_DIR/cmdexec-extrans.cfg
	CMD_EXEC_RESULT_CPFILES_FILE=$CMD_EXEC_OUTPUT_DIR/cmdexec-cpfiles.cfg
	CMD_EXEC_RESULT_MISSINGOBJ_FILE=$CMD_EXEC_OUTPUT_DIR/cmdexec-missingobj.cfg
	CMD_EXEC_RESULT_PLUGINS_FILE=$CMD_EXEC_OUTPUT_DIR/cmdexec-plugins.cfg
	CMD_EXEC_RESULT_PLUGINS_PARAM_FILE=$CMD_EXEC_OUTPUT_DIR/cmdexec-plugins.param
	CMD_EXEC_RESULT_COMPLIANCE_FILE=$CMD_EXEC_OUTPUT_DIR/cmdexec-compliance.cfg
	CMD_EXEC_RESULT_SNAPSHOTS_FILE=$CMD_EXEC_OUTPUT_DIR/cmdexec-snapshots.cfg

	local DEF_ENV_ARR=("CMD_EXEC_INPUT_DIR" "CMD_EXEC_OUTPUT_DIR" "CMD_EXEC_ROOT_DEBUG_OUTDIR" "CMD_EXEC_PRODUCT_NSFILE" "CMD_EXEC_OUTFILE" "CMD_EXEC_ERRFILE" "CMD_EXEC_RESULT_MCCFG_FILE" "CMD_EXEC_RESULT_EXTRANS_FILE" "CMD_EXEC_RESULT_CPFILES_FILE" "CMD_EXEC_RESULT_MISSINGOBJ_FILE" "CMD_EXEC_RESULT_PLUGINS_FILE" "CMD_EXEC_RESULT_PLUGINS_PARAM_FILE" "CMD_EXEC_RESULT_COMPLIANCE_FILE" "CMD_EXEC_RESULT_SNAPSHOTS_FILE" "RTVAR_EXCL_PROD_NS" "CMD_EXEC_PLUGINS_PARAM_COLUMN_DELIMITER" "CMD_EXEC_PLUGINS_PARAM_FIELD_DELIMITER" "MANUAL_COLL_CFGFILE_DELIMITER" "MISSINGOBJ_CFGFILE_DELIMITER" "COMPLIANCE_CFGFILE_DELIMITER" "SNAPSHOTS_CFGFILE_DELIMITER" "CPFILES_CFGFILE_DELIMITER" "-f toExcludeProdNamespace")

	local CMDEXEC_USER_INPUT_ENV=$(compgen -A variable | grep -E '^RTVAR_CMDEXEC_' | tr '\n' ' ')

	if [ ${#CMDEXEC_USER_INPUT_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for USER_INPUT_ENV in $CMDEXEC_USER_INPUT_ENV
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$USER_INPUT_ENV] into DEF_ENV_ARR..."
			fi

			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$USER_INPUT_ENV"
		done	
	fi

	local GMGFVAR_ENV=$(compgen -A variable | grep -E '^RTVAR_GMGFVAR_' | tr '\n' ' ')

	if [ ${#GMGFVAR_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for GMGFVAR in $GMGFVAR_ENV
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$GMGFVAR] into DEF_ENV_ARR..."
			fi

			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$GMGFVAR"
		done	
	fi

	IFS=$'\n'
	for DEF_ENV in ${DEF_ENV_ARR[@]}
	do
		if [[ $DEF_ENV =~ ^-f ]]
		then
			local CMD_EXEC_FUNCNAME=$(echo "$DEF_ENV" | $AWK '{ print $2 }')

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment function [$CMD_EXEC_FUNCNAME]..."
			fi

			export -f $CMD_EXEC_FUNCNAME
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$DEF_ENV = ${!DEF_ENV}]"
			fi

			export $DEF_ENV
		fi
	done

	if [ ${#CMD_EXEC_ENVFILE} -gt 0 ] && [ -s $CMD_EXEC_ENVFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Exporting variable from file [$CMD_EXEC_ENVFILE]..."
		
		while read ENVLINE
		do
			if [[ $(echo "$ENVLINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$ENVLINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] ENVLINE = [$ENVLINE]"
			fi

			local ENV_VARNAME=$(echo "$ENVLINE" | $AWK -F= '{ print $1 }')
			# local ENV_VARVAL=$(echo "$ENVLINE" | $AWK -F= '{ print $2 }' | sed 's/^"//' | sed 's/"$//')
			local ENV_VARVAL=$(echo "$ENVLINE" | cut -f 2- -d = | sed 's/^"//' | sed 's/"$//')

			if [ ${#ENV_VARNAME} -gt 0 ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Environment variable [$ENV_VARNAME = $ENV_VARVAL]"
				fi

				export $ENV_VARNAME="$ENV_VARVAL"
			else
				echo "[$(date)] [${FUNCNAME[0]}] ENVLINE = [$ENVLINE] is invalid!"
			fi
		done < $CMD_EXEC_ENVFILE
	fi

	if [ ${#CMD_EXEC_ENV} -gt 0 ]
	then
		local ENV_OUTFILE=$CMD_EXEC_OUTDIR/input/envfile.txt.$$
		echo "$CMD_EXEC_ENV" | $AWK 'BEGIN{RS="##"} {$1=$1}1' > $ENV_OUTFILE

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] User input environment variable string = [$CMD_EXEC_ENV]"
		fi

		while read VARVALUE
		do
			local VAR=$(echo "$VARVALUE" | $AWK -F= '{ print $1 }')
			local VALUE=$(echo "$VARVALUE" | cut -f 2- -d = | sed 's/^"//' | sed 's/"$//')

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Environment variable [$VAR = $VALUE]"
			fi

			export $VAR="$VALUE"
		done < $ENV_OUTFILE

		if [ $MG_DEBUG != "true" ]
		then
			if [ -f $ENV_OUTFILE ]
			then
				rm $ENV_OUTFILE
			fi
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then
		local CMD_EXEC_RUNTIME_ENV=$CMD_EXEC_OUTPUT_DIR/cmdexec.env

		if [ ${#TIMEOUT} -gt 0 ]
		then
			local TO_EXEC_CMD="$TIMEOUT $CMD_EXEC_TVALUE /bin/bash -c env"
		else
			local TO_EXEC_CMD="/bin/bash -c env"
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Getting environment details [$TO_EXEC_CMD]..."
		eval "$TO_EXEC_CMD" > $CMD_EXEC_RUNTIME_ENV 2>&1
	fi

	# Duplicating stdin, stdout and stderr for subshell to write to
	echo "[$(date)] [${FUNCNAME[0]}] Duplicating stdin(7), stdout(8) and stderr(9) for subshell to write to..."
	exec 7>&0
	exec 8>&1
	exec 9>&2

	if [ ${#TIMEOUT} -gt 0 ]
	then
		if [ ${#RTVAR_CMDEXEC_TIMEOUT} -gt 0 ] && [ ${RTVAR_CMDEXEC_TIMEOUT} == "false" ]
		then
			local TO_EXEC_CMD="/bin/bash $CMD_EXEC_CMD"
			echo "[$(date)] [${FUNCNAME[0]}] Executing command file [$TO_EXEC_CMD]..."
			eval "$TO_EXEC_CMD" > $CMD_EXEC_OUTFILE 2> >(tee -a $CMD_EXEC_ERRFILE >&2)
			CMD_EXEC_EXIT_STATUS=$?
		else
			local TO_EXEC_CMD="$TIMEOUT $CMD_EXEC_TVALUE /bin/bash $CMD_EXEC_CMD"
			echo "[$(date)] [${FUNCNAME[0]}] Executing command file [$TO_EXEC_CMD]..."
			eval "$TO_EXEC_CMD" > $CMD_EXEC_OUTFILE 2> >(tee -a $CMD_EXEC_ERRFILE >&2)
			CMD_EXEC_EXIT_STATUS=$?
			
			if [ $CMD_EXEC_EXIT_STATUS -eq 124 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Command execution [$CMD_EXEC_FILE] timeout after $CMD_EXEC_TVALUE!"
			fi	
		fi
	else
		local TO_EXEC_CMD="/bin/bash $CMD_EXEC_CMD"
		echo "[$(date)] [${FUNCNAME[0]}] Executing command file [$TO_EXEC_CMD]..."
		eval "$TO_EXEC_CMD" > $CMD_EXEC_OUTFILE 2> >(tee -a $CMD_EXEC_ERRFILE >&2)
		CMD_EXEC_EXIT_STATUS=$?
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Closing duplicated stdin(7), stdout(8) and stderr(9)..."
	exec 7>&-
	exec 8>&-
	exec 9>&-

	echo "[$(date)] [${FUNCNAME[0]}] Command file [$CMD_EXEC_FILE] executed. Exit status = [$CMD_EXEC_EXIT_STATUS]"
	echo "[$(date)] [${FUNCNAME[0]}] Please check [$CMD_EXEC_OUTFILE] for output!"

	if [ ${#CMD_EXEC_RESULT_MCCFG_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_MCCFG_FILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_RESULT_MCCFG_FILE = [$(cat ${CMD_EXEC_RESULT_MCCFG_FILE})]"

		if ! validateManualCollection $CMD_EXEC_RESULT_MCCFG_FILE
		then
			echo "[$(date)] [$(basename "$0")] Input file for function getManualCollection() [$CMD_EXEC_RESULT_MCCFG_FILE] does not contain any configuration. Exiting..."
		fi

		if [ $MANUAL_COLL -ne 1 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Manually turning on MANUALCOLLECT data collection mode..."
			MANUAL_COLL=1
			echo "[$(date)] [${FUNCNAME[0]}] Setting MANUAL_COLL_INPUTFILE to [$CMD_EXEC_RESULT_MCCFG_FILE]..."
			MANUAL_COLL_INPUTFILE=$CMD_EXEC_RESULT_MCCFG_FILE
			echo "[$(date)] [${FUNCNAME[0]}] Setting MANUAL_COLL_INPUTTAG to [ALL]..."
			MANUAL_COLL_INPUTTAG="ALL"
			CMD_EXEC_MC_MANUAL="true"
		fi
	fi

	if [ ${#CMD_EXEC_RESULT_EXTRANS_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_EXTRANS_FILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_RESULT_EXTRANS_FILE = [$(cat ${CMD_EXEC_RESULT_EXTRANS_FILE})]"

		local EXTRANS=

		for NS in $(cat $CMD_EXEC_RESULT_EXTRANS_FILE)
		do
			if [ ${#EXTRANS} -eq 0 ]
			then
				local EXTRANS=$NS
			else
				local EXTRANS="$EXTRANS,$NS"
			fi
		done

		if [ ${EXTRA_NAMESPACES}x != "x" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Adding additional namespace(s) to EXTRA_NAMESPACES..."	
			echo "[$(date)] [${FUNCNAME[0]}] From [$EXTRA_NAMESPACES] to [${EXTRA_NAMESPACES},$EXTRANS]..."
			EXTRA_NAMESPACES="${EXTRA_NAMESPACES},$EXTRANS"
		else
			echo "[$(date)] [${FUNCNAME[0]}] Manually turning on EXTRA data collection mode..."
			echo "[$(date)] [${FUNCNAME[0]}] Setting EXTRA_NAMESPACES to [$EXTRANS]..."
			EXTRA_NAMESPACES="$EXTRANS"
		fi
	fi

	if [ ${#CMD_EXEC_RESULT_CPFILES_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_CPFILES_FILE ]
	then
		CPFILES_ENABLED="true"
	fi

	if [ ${#CMD_EXEC_RESULT_MISSINGOBJ_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_MISSINGOBJ_FILE ]
	then
		if [ $GET_MISS_OBJ != "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Setting CMD_EXEC_MISSINGOBJ_ONLY to ["true"]..."
			CMD_EXEC_MISSINGOBJ_ONLY="true"
		fi
	
		GET_MISS_OBJ="true"
	fi

	if [ ${#CMD_EXEC_RESULT_PLUGINS_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_PLUGINS_FILE ]
	then
		local CMD_EXEC_PLUGINS=$($AWK -vORS=, '{$1=$1;print}' $CMD_EXEC_RESULT_PLUGINS_FILE | sed 's/,$/\n/')
		echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_PLUGINS = [$CMD_EXEC_PLUGINS]"

		local ORIG_PLUGINS="$PLUGINS"
		echo "[$(date)] [${FUNCNAME[0]}] Original PLUGINS = [$PLUGINS]"

		if [ ${#PLUGINS} -gt 0 ]
		then
			PLUGINS=$(echo "${PLUGINS},${CMD_EXEC_PLUGINS}" | tr ',' '\n' | grep -v ^$ | sort | uniq | tr '\n' ',' | sed 's/,$//')
			echo "[$(date)] [${FUNCNAME[0]}] Merged PLUGINS = [$PLUGINS]"
		else
			PLUGINS="$CMD_EXEC_PLUGINS"
			echo "[$(date)] [${FUNCNAME[0]}] Latest PLUGINS = [$PLUGINS]"
		fi

		if ! checkPlugins
		then
			echo "[$(date)] [${FUNCNAME[0]}] CMD_EXEC_RESULT_PLUGINS_FILE contains invalid plugin! Skipping..."	
			PLUGINS="$ORIG_PLUGINS"	
		else
			if [ ${#CMD_EXEC_RESULT_PLUGINS_PARAM_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_PLUGINS_PARAM_FILE ]
			then
				for C_PLUGIN in $(echo "$CMD_EXEC_PLUGINS" | sed 's/,/ /g')
				do
					local C_PLUGIN_LINE=$($AWK -F${CMD_EXEC_PLUGINS_PARAM_COLUMN_DELIMITER} '$1 ~ /^'$C_PLUGIN'$/' $CMD_EXEC_RESULT_PLUGINS_PARAM_FILE)

					if [ ${#C_PLUGIN_LINE} -gt 0 ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] C_PLUGIN_LINE = [$C_PLUGIN_LINE]"
						fi

						local C_PLUGIN_NAME=$(echo "$C_PLUGIN_LINE" | $AWK -F${CMD_EXEC_PLUGINS_PARAM_COLUMN_DELIMITER} '{ print $1 }')
						local C_PLUGIN_ACTION=$(echo "$C_PLUGIN_LINE" | $AWK -F${CMD_EXEC_PLUGINS_PARAM_COLUMN_DELIMITER} '{ print $2 }')
						local C_PLUGIN_PARAM=$(echo "$C_PLUGIN_LINE" | $AWK -F${CMD_EXEC_PLUGINS_PARAM_COLUMN_DELIMITER} '{ print $3 }')
						local C_PLUGIN_ENVFILE=$PLUGINS_ROOT_OUTDIR/$C_PLUGIN.$C_PLUGIN_ACTION.userenv

						if [ ${#C_PLUGIN_NAME} -eq 0 ] || [ ${#C_PLUGIN_ACTION} -eq 0 ] || [ ${#C_PLUGIN_PARAM} -eq 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Invalid C_PLUGIN_LINE! No column can be empty/null! Skipping..."
							continue
						else
							if [ $C_PLUGIN_ACTION != "data" ] && [ $C_PLUGIN_ACTION != "fix" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Invalid C_PLUGIN_ACTION [$C_PLUGIN_ACTION]! Value can only be 'data' or 'fix'! Skipping..."
								continue
							else
								local PARAM_ALL_GOOD="true"
								local PARAM_CTR=0

								for PARAM in $(echo "$C_PLUGIN_PARAM" | sed 's/'$CMD_EXEC_PLUGINS_PARAM_FIELD_DELIMITER'/\n/g')
								do
									(( PARAM_CTR=PARAM_CTR+1 ))

									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$PARAM_CTR] PARAM = [$PARAM]"
									fi

									if [[ "$PARAM" =~ ^.+[[:space:]]+= ]] || [[ "$PARAM" =~ ^.+=[[:space:]]+ ]]
									then
										local PARAM_ALL_GOOD="false"
										echo "[$(date)] [${FUNCNAME[0]}] Invalid PARAM [$PARAM]! Format must be KEY=VAL! Skipping..."
										break
									fi
								done

								if [ $PARAM_ALL_GOOD == "false" ]
								then
									continue
								fi
							fi
						fi

						if [ ! -f $C_PLUGIN_ENVFILE ] && [ ! -d $(dirname $C_PLUGIN_ENVFILE) ]
						then
							mkdir -p $(dirname $C_PLUGIN_ENVFILE)
						fi

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] C_PLUGIN_NAME = [$C_PLUGIN_NAME] / C_PLUGIN_ACTION = [$C_PLUGIN_ACTION] / C_PLUGIN_PARAM = [$C_PLUGIN_PARAM] / C_PLUGIN_ENVFILE = [$C_PLUGIN_ENVFILE]"
						fi

						echo "[$(date)] [${FUNCNAME[0]}] Writing C_PLUGIN_PARAM to file [$C_PLUGIN_ENVFILE]..."
						echo "$C_PLUGIN_PARAM" | sed 's/'${CMD_EXEC_PLUGINS_PARAM_FIELD_DELIMITER}'/\n/g' >> $C_PLUGIN_ENVFILE
					else
						echo "[$(date)] [${FUNCNAME[0]}] C_PLUGIN [$C_PLUGIN] does not have any user specified parameters..."
					fi
				done
			fi
		fi
	fi


	if [ ${#CMD_EXEC_RESULT_COMPLIANCE_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_COMPLIANCE_FILE ]
	then
		if [ $GET_COMPLIANCE != "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Setting CMD_EXEC_COMPLIANCE_ONLY to ["true"]..."
			CMD_EXEC_COMPLIANCE_ONLY="true"

			mkdir -p $COMPLIANCE_OUTDIR
			COMPLIANCE_REPORT=$ANALYZE_OUTDIR/COMPLIANCE_REPORT.log

			if [ $REPORT_ON_SCREEN == "true" ]
			then
				REPORT_ON_SCREEN_COMPLIANCE_FILE=$ROOT_OUTDIR/${COMPLIANCE_REPORT##*/}.$$
			fi
		fi

		GET_COMPLIANCE="true"	
	fi

	if [ ${#CMD_EXEC_RESULT_SNAPSHOTS_FILE} -gt 0 ] && [ -f $CMD_EXEC_RESULT_SNAPSHOTS_FILE ]
	then
		if [ $DIFF_SNAPSHOTS != "true" ]
		then
			SNAPSHOTS_OUTDIR=$MUSTGATHER_DIRNAME/data/snapshots
			SNAPSHOTS_CFGFILE=$MUSTGATHER_DIRNAME/snapshots/.snapshots.cfg	
			SNAPSHOTS_REPORT=$ANALYZE_OUTDIR/SNAPSHOTS_REPORT.log

			if [ ${#SNAPSHOTS_REPORT} -gt 0 ]
			then
				REPORT_ON_SCREEN_SNAPSHOTS_FILE=$ROOT_OUTDIR/${SNAPSHOTS_REPORT##*/}.$$
			fi
		fi

		DIFF_SNAPSHOTS="true"	
	fi

	if [ $REPORT_ON_SCREEN == "true" ]
	then
		echo "===================================================" >> $ANALYZE_OUTFILE
		echo "[CMDEXEC] OUTPUT OF SCRIPT:" >> $ANALYZE_OUTFILE
		echo "$CMD_EXEC_FILE" >> $ANALYZE_OUTFILE
		
		local OUTFILE_MAX_LINE=200
		local OUTFILE_NUM_LINE=$(wc -l $CMD_EXEC_OUTFILE | $AWK '{ print $1 }') 

		if [ -s $CMD_EXEC_OUTFILE ]
		then
			if [ $OUTFILE_NUM_LINE -gt $OUTFILE_MAX_LINE ]
			then
				echo "WARNING: Output file [$CMD_EXEC_OUTFILE] has [$OUTFILE_NUM_LINE] lines. Showing the first [$OUTFILE_MAX_LINE] lines!" >> $ANALYZE_OUTFILE
				echo "===================================================" >> $ANALYZE_OUTFILE
				echo "[OUTPUT FILE = $CMD_EXEC_OUTFILE]" >> $ANALYZE_OUTFILE
				head -$OUTFILE_MAX_LINE $CMD_EXEC_OUTFILE >> $ANALYZE_OUTFILE
				echo "..." >> $ANALYZE_OUTFILE
			else
				echo "===================================================" >> $ANALYZE_OUTFILE
				echo "[OUTPUT FILE = $CMD_EXEC_OUTFILE]" >> $ANALYZE_OUTFILE
				cat $CMD_EXEC_OUTFILE >> $ANALYZE_OUTFILE
			fi
		else
			echo "===================================================" >> $ANALYZE_OUTFILE
			echo "<N/A>" >> $ANALYZE_OUTFILE
		fi

		local OUTFILE_NUM_LINE=$(wc -l $CMD_EXEC_ERRFILE | $AWK '{ print $1 }') 

		if [ -s $CMD_EXEC_ERRFILE ]
		then
			echo >> $ANALYZE_OUTFILE

			if [ $OUTFILE_NUM_LINE -gt $OUTFILE_MAX_LINE ]	
			then
				if [ -s $CMD_EXEC_OUTFILE ]
				then
					echo "===================================================" >> $ANALYZE_OUTFILE
				fi
				echo "WARNING: Error file [$CMD_EXEC_ERRFILE] has [$OUTFILE_NUM_LINE] lines. Showing the first [$OUTFILE_MAX_LINE] lines!" >> $ANALYZE_OUTFILE
				echo "===================================================" >> $ANALYZE_OUTFILE
				echo "[ERROR FILE = $CMD_EXEC_ERRFILE]" >> $ANALYZE_OUTFILE
				head -$OUTFILE_MAX_LINE $CMD_EXEC_ERRFILE >> $ANALYZE_OUTFILE
				echo "..." >> $ANALYZE_OUTFILE
			else
				echo "===================================================" >> $ANALYZE_OUTFILE
				echo "[ERROR FILE = $CMD_EXEC_ERRFILE]" >> $ANALYZE_OUTFILE
				cat $CMD_EXEC_ERRFILE >> $ANALYZE_OUTFILE
			fi
		fi

		echo >> $ANALYZE_OUTFILE
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [SCRIPT=$CMD_EXEC_FILE]"
	fi
}

getResourceInstances()
{
	# Valid OBJSTATUS = Running / Succeeded (Completed) / Pending / Failed / Unknown
	local OBJTYPE=$1
	local OBJNAME_REGEX=$2
	local OBJNS=$3
	local OBJSTATUS=$4

	if [ ${#OBJTYPE} -eq 0 ] || [ ${#OBJNAME_REGEX} -eq 0 ]
	then
		echo 
		return 1
	fi

	if [ ${#OBJNS} -eq 0 ]
	then
		local OBJNS_CMD="-A"
		local OBJNS="all"
	else
		local OBJNS_CMD="-n $OBJNS"
	fi

	if [ ${#OBJSTATUS} -gt 0 ]
	then
		case $OBJSTATUS in
			Running) 		;;
			Succeeded)	;;
			Pending) 		;;
			Failed)		;;
			Unknown)		;;
			*)	echo "[$(date)] [${FUNCNAME[0]}] User provided OBJSTATUS [$OBJSTATUS] is invalid! Setting to default [Running]..."
				OBJSTATUS="Running"
				;;		
		esac
	fi

	if ! checkUserPriv get $OBJTYPE $OBJNS > /dev/null
	then
		echo 
		return 1
	fi

	if [ "$OBJNS" == "all" ]
	then
		if [ ${#OBJSTATUS} -gt 0 ]
		then
			local FILTER_CMD="$OC_CMD get $OBJTYPE --field-selector status.phase=$OBJSTATUS --template '{{range .items}}{{.metadata.namespace}}{{\"/\"}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJNS_CMD | $AWK -F/ '\$2 ~ /${OBJNAME_REGEX}/ { print }'"	
		else
			local FILTER_CMD="$OC_CMD get $OBJTYPE --template '{{range .items}}{{.metadata.namespace}}{{\"/\"}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJNS_CMD | $AWK -F/ '\$2 ~ /${OBJNAME_REGEX}/ { print }'"	
		fi
	else
		if [ ${#OBJSTATUS} -gt 0 ]
		then
			local FILTER_CMD="$OC_CMD get $OBJTYPE --field-selector status.phase=$OBJSTATUS --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJNS_CMD | $AWK '/${OBJNAME_REGEX}/ { print }'"
		else
			local FILTER_CMD="$OC_CMD get $OBJTYPE --template '{{range .items}}{{.metadata.name}}{{\""'\n'"\"}}{{end}}' $OBJNS_CMD | $AWK '/${OBJNAME_REGEX}/ { print }'"
		fi
	fi

	RI_RESULT=$(eval "$FILTER_CMD")
	CMD_EXIT_STATUS=$?

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] FILTER_CMD = [$FILTER_CMD] / RI_RESULT = [$RI_RESULT] / CMD_EXIT_STATUS = [$CMD_EXIT_STATUS]" >&2
	fi

	if [ ${#RI_RESULT} -eq 0 ] || [ $CMD_EXIT_STATUS -ne 0 ]
	then
		echo 
		return 1
	else
		echo "$RI_RESULT"
		return 0
	fi
}

getOcEvent()
{
	local OC_EVENT_OUTFILE=$1
	local OC_EVENT_GET_ALLNS=$2
	local OC_EVENT_GET_ALLEVENT=$3

	local NS=
	
	# If OC_EVENT_GET_ALLNS="true", will gather events from all namespaces. Otherwise, limit to product namespaces.
	# If OC_EVENT_GET_ALLEVENT="true", will gather all events (limited to namespace scoping above). Otherwise, limit to events that are not normal.

	if [ ${#OC_EVENT_GET_ALLNS} -eq 0 ]
	then
		OC_EVENT_GET_ALLNS="false"
	fi

	if [ ${#OC_EVENT_GET_ALLEVENT} -eq 0 ]
	then
		OC_EVENT_GET_ALLEVENT="false"
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

	if [ $OC_EVENT_GET_ALLNS == "true" ]
	then
		if ! checkUserPriv get events all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have cluster-admin privilege. Limiting event data collection to product namespaces!"
		fi
	else
		for NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			if ! checkUserPriv get events $NS
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have [get event] privilege in namespace [$NS]! Returning..." 
				return 1
			fi
		done
	fi

	if [ ${#OC_EVENT_OUTFILE} -eq 0 ]
	then
		local OC_EVENT_OUTFILE=$CLUSTER_DATA_OUTDIR/oc_event.log
	else
		if [ ! -d $(dirname $OC_EVENT_OUTFILE) ]
		then
			mkdir -p $(dirname $OC_EVENT_OUTFILE)
		fi
	fi

	if [ $OC_EVENT_GET_ALLNS == "true" ]
	then
		if [ $OC_EVENT_GET_ALLEVENT == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get event --all-namespaces' => $OC_EVENT_OUTFILE"
			$OC_CMD get event --all-namespaces > $OC_EVENT_OUTFILE 2>&1
		else
			echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get event --all-namespaces --field-selector type!=Normal' => $OC_EVENT_OUTFILE"
			$OC_CMD get event --all-namespaces --field-selector type!=Normal > $OC_EVENT_OUTFILE 2>&1
		fi
	else
		for NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			echo [NAMESPACE = $NS] >> $OC_EVENT_OUTFILE

			if [ $OC_EVENT_GET_ALLEVENT == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get event -n $NS' => $OC_EVENT_OUTFILE"
				$OC_CMD get event -n $NS >> $OC_EVENT_OUTFILE 2>&1
			else
				echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get event -n $NS --field-selector type!=Normal' => $OC_EVENT_OUTFILE"
				$OC_CMD get event -n $NS --field-selector type!=Normal >> $OC_EVENT_OUTFILE 2>&1
			fi

			echo >> $OC_EVENT_OUTFILE
		done
	fi
}

getApiResources()
{
	local OC_APIRESOURCES_OUTFILE=$1

	if [ ${#OC_APIRESOURCES_OUTFILE} -eq 0 ]
	then
		local OC_APIRESOURCES_OUTFILE=$CLUSTER_DATA_OUTDIR/oc_apiresources.out
	else
		if [ ! -d $(dirname $OC_APIRESOURCES_OUTFILE) ]
		then
			mkdir -p $(dirname $OC_APIRESOURCES_OUTFILE)
		fi
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD api-resources -o wide' => $OC_APIRESOURCES_OUTFILE"
	$OC_CMD api-resources -o wide > $OC_APIRESOURCES_OUTFILE 2>&1
}

getApiVersions()
{
	local OC_APIVERSIONS_OUTFILE=$1

	if [ ${#OC_APIVERSIONS_OUTFILE} -eq 0 ]
	then
		local OC_APIVERSIONS_OUTFILE=$CLUSTER_DATA_OUTDIR/oc_apiversions.out
	else
		if [ ! -d $(dirname $OC_APIVERSIONS_OUTFILE) ]
		then
			mkdir -p $(dirname $OC_APIVERSIONS_OUTFILE)
		fi
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD api-versions' => $OC_APIVERSIONS_OUTFILE"
	$OC_CMD api-versions > $OC_APIVERSIONS_OUTFILE 2>&1
}

setIncident()
{
	# OBJECT_TYPE, DATA_TYPE and INFO must be one-liner (cannot contain carriage return)
	local OBJECT_TYPE=$1 
	local OBJECT_NAME=$2
	local DATA_TYPE=$3
	local DATA_INFO=$4
	# DATA can be multiple lines
	local DATA=$5

	local DELIMITER="##@@##"

	local INCIDENT_LINE="${OBJECT_TYPE}\n${OBJECT_NAME}\n${DATA_TYPE}\n${DATA_INFO}\n${DATA}\n${DELIMITER}"
	
	if [ $# -lt 5 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Input arguments are less than 5. Invalid data. Discarding incident [$INCIDENT_LINE]"
	fi

	if [ ${#OBJECT_TYPE} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Mandatory field OBJECT_TYPE is empty. Discarding incident [$INCIDENT_LINE]"
	fi

	if [ ${#DATA_TYPE} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Mandatory field DATA_TYPE is empty. Discarding incident [$INCIDENT_LINE]"
	fi

	if [ ${#DATA} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Mandatory field DATA is empty. Discarding incident [$INCIDENT_LINE]"
	fi

	if [ $INCIDENT_REPORT_ENABLED == "true" ]
	then
		if [ -s $INCIDENT_REPORT_CTRFILE ]
		then
			local INCIDENT_REPORT_CTR=$(cat $INCIDENT_REPORT_CTRFILE)
			(( INCIDENT_REPORT_CTR=INCIDENT_REPORT_CTR+1 ))
			echo "$INCIDENT_REPORT_CTR" > $INCIDENT_REPORT_CTRFILE
		else
			local INCIDENT_REPORT_CTR=1
			echo "$INCIDENT_REPORT_CTR" > $INCIDENT_REPORT_CTRFILE
		fi

		echo -e "[$(date)] [${FUNCNAME[0]}] Logging incident [$INCIDENT_REPORT_CTR] [$INCIDENT_LINE]"
		echo -e "$INCIDENT_LINE" >> $INCIDENT_REPORT_TMPFILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] INCIDENT_REPORT_ENABLED = [$INCIDENT_REPORT_ENABLED] / Discarding incident [$INCIDENT_LINE]"
	fi
}

analyzeIncident()
{
	local DEF_ENV=
	local ANALYZE_SCRIPT=
	local INCIDENT_LINE=
	local PREPROC_ENV_LINE=
	local ENV_LINE=

	if [ -s $INCIDENT_REPORT_TMPFILE ]
	then
		echo "===================================================" >> $INCIDENT_REPORT_OUTFILE
		echo "MUSTGATHER - INCIDENT ANALYSIS REPORT" >> $INCIDENT_REPORT_OUTFILE
		echo "NOTE: The analysis report is provided as-is and for reference only. It is best to engage IBM Support for problem resolution." >> $INCIDENT_REPORT_OUTFILE
		echo "===================================================" >> $INCIDENT_REPORT_OUTFILE
		echo >> $INCIDENT_REPORT_OUTFILE

		local DELIMITER="##@@##"
		local LINE_CTR=0
		local REC_CTR=0
		local FIELD_CTR=0

		echo "[$(date)] [${FUNCNAME[0]}] Total reported incidents = [$(grep "$DELIMITER" $INCIDENT_REPORT_TMPFILE | wc -l)]"

		while read INCIDENT_LINE
		do
			(( FIELD_CTR=FIELD_CTR+1 ))

			if [ ${FIELD_CTR} -lt 5 ]
			then
				case "$FIELD_CTR" in
					1) local INCIDENT_OBJECT_TYPE=$INCIDENT_LINE
					   local IN_DATA=""
						;;	
					2) local INCIDENT_OBJECT_NAME=$INCIDENT_LINE
						;;
					3) local INCIDENT_DATA_TYPE=$INCIDENT_LINE
						;;
					4) local INCIDENT_DATA_INFO=$INCIDENT_LINE
						;;
				esac				
			else
				if [[ ${INCIDENT_LINE} =~ $DELIMITER ]]
				then
					# All raw data lines gathered, can start to process!
					FIELD_CTR=0
					(( REC_CTR=REC_CTR+1 ))

					local INCIDENT_DATA=$(echo -e "$IN_DATA")

					echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] INCIDENT = [INCIDENT_OBJECT_TYPE=$INCIDENT_OBJECT_TYPE / INCIDENT_OBJECT_NAME=$INCIDENT_OBJECT_NAME / INCIDENT_DATA_TYPE=$INCIDENT_DATA_TYPE / INCIDENT_DATA_INFO=$INCIDENT_DATA_INFO]"
					echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] INCIDENT = [INCIDENT_DATA=$INCIDENT_DATA]"

					# Pre-processing script (raw data manipulation layer)
					local PREPROC_SCRIPT=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE/preproc.sh
					local PREPROC_ENVFILE=$ENGINE_DATA_OUTDIR/${REC_CTR}_preproc.out

					IFS=$'\n'
					local DEF_ENV_ARR=("INCIDENT_OBJECT_TYPE" "INCIDENT_OBJECT_NAME" "INCIDENT_DATA_TYPE" "INCIDENT_DATA_INFO" "INCIDENT_DATA")
					
					for DEF_ENV in ${DEF_ENV_ARR[@]}
					do
						if [[ $DEF_ENV =~ ^-f ]]
						then
							local INCIDENT_FUNCNAME=$(echo "$DEF_ENV" | $AWK '{ print $2 }')

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Exporting environment function [$INCIDENT_FUNCNAME]..."
							fi

							export -f $INCIDENT_FUNCNAME
						else
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Exporting environment variable [$DEF_ENV = ${!DEF_ENV}]"
							fi

							export $DEF_ENV
						fi
					done

					local PRERPOC_MODE=""
					local GENERIC_SCRIPT_TOEXEC="false"

					if [ ${#INCIDENT_OBJECT_NAME} -eq 0 ]
					then
						local SCRIPT_DIR=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE
						local PREPROC_MODE="NO_OBJNAME"
						local GENERIC_SCRIPT_TOEXEC="true"
					else
						if [ -d $ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE/$INCIDENT_OBJECT_NAME ]
						then
							if [ -d $ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE/$INCIDENT_OBJECT_NAME ]
							then
								local SCRIPT_DIR=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE/$INCIDENT_OBJECT_NAME
								local GENERIC_SCRIPT_TOEXEC="false"
							else
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] INCIDENT_OBJECT_NAME [$INCIDENT_OBJECT_NAME] does not have its own script directory [$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE/$INCIDENT_OBJECT_NAME]"
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] INCIDENT_OBJECT_NAME [$INCIDENT_OBJECT_NAME] - Setting to default directory [$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE]"
								local SCRIPT_DIR=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE
								local GENERIC_SCRIPT_TOEXEC="true"
							fi

							local PREPROC_MODE="YES_OBJNAME"
						else
							local SCRIPT_DIR=""
							local PREPROC_MODE="PROC_OBJNAME"
							local GENERIC_SCRIPT_TOEXEC="false"
						fi
					fi	

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] PREPROC_MODE = [$PREPROC_MODE]"
					fi

					if [ -s $PREPROC_SCRIPT ]
					then
						local NEW_OBJECT_TYPE=
						local NEW_OBJECT_NAME=
						local NEW_DATA_TYPE=
						local NEW_DATA_INFO=
						local NEW_DATA=

						echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Executing pre-processing script [$PREPROC_SCRIPT] in preproc mode [$PREPROC_MODE] on incident..."

						if [ ${#TIMEOUT} -gt 0 ]
						then
							$TIMEOUT $ENGINE_TVALUE /bin/bash $PREPROC_SCRIPT "$PREPROC_MODE" > $PREPROC_ENVFILE
							local ENGINE_ANALYZE_PREPROC_SCRIPT_EXIT_STATUS=$?
							
							if [ $ENGINE_ANALYZE_PREPROC_SCRIPT_EXIT_STATUS -eq 124 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Execution of pre-processing script [$PREPROC_SCRIPT] timeout after $ENGINE_TVALUE!"
								continue
							fi	
						else
							/bin/bash $PREPROC_SCRIPT "$PREPROC_MODE" > $PREPROC_ENVFILE
							local ENGINE_ANALYZE_PREPROC_SCRIPT_EXIT_STATUS=$?
						fi

						echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Pre-processing script [$PREPROC_SCRIPT] executed. Exit status = [$ENGINE_ANALYZE_PREPROC_SCRIPT_EXIT_STATUS]"

						if [ $ENGINE_ANALYZE_PREPROC_SCRIPT_EXIT_STATUS -ne 0 ]
						then
							case $PREPROC_MODE in
								NO_OBJNAME) ;;
								YES_OBJNAME) ;;
								PROC_OBJNAME) 
									local SCRIPT_DIR=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE
									local GENERIC_SCRIPT_TOEXEC="true"
									echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Pre-processing setting SCRIPT_DIR to [$SCRIPT_DIR]..."
									;;	
							esac
						else
							if [ -s $PREPROC_ENVFILE ]
							then
								# 1st line = enriched/original INCIDENT_OBJECT_TYPE
								# 2nd line = enriched/original INCIDENT_OBJECT_NAME 
								# 3rd line = enriched/original INCIDENT_DATA_TYPE
								# 4th line = enriched/original INCIDENT_DATA_INFO
								# 5th line onwards = enriched/original INCIDENT_DATA

								local TMP_DATA=""
								local PREPROC_ENV_FIELD_CTR=0
								local PREPROC_ENV_LINE=
								local PREPROC_ENV_TOTAL_FIELDS=5
								local PREPROC_ENV_NEW="false"

								while read PREPROC_ENV_LINE
								do
									(( PREPROC_ENV_FIELD_CTR=PREPROC_ENV_FIELD_CTR+1 ))
						
									if [ ${PREPROC_ENV_FIELD_CTR} -lt ${PREPROC_ENV_TOTAL_FIELDS} ]
									then
										case "$PREPROC_ENV_FIELD_CTR" in
											1) if [ "$INCIDENT_OBJECT_TYPE" != "$PREPROC_ENV_LINE" ]
											   then
												echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) INCIDENT_OBJECT_TYPE changed from [$INCIDENT_OBJECT_TYPE] to [$PREPROC_ENV_LINE]"
												local PREPROC_ENV_NEW="true"
											   fi

											   local NEW_OBJECT_TYPE=$PREPROC_ENV_LINE
											   echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) Setting new variable NEW_OBJECT_TYPE to [$NEW_OBJECT_TYPE]..."
												;;	
											2) if [ "$INCIDENT_OBJECT_NAME" != "$PREPROC_ENV_LINE" ]
											   then
												echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) INCIDENT_OBJECT_NAME changed from [$INCIDENT_OBJECT_NAME] to [$PREPROC_ENV_LINE]"
												local PREPROC_ENV_NEW="true"
											   fi

											   local NEW_OBJECT_NAME=$PREPROC_ENV_LINE
											   echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) Setting new variable NEW_OBJECT_NAME to [$NEW_OBJECT_NAME]..."
												;;	
											3) if [ "$INCIDENT_DATA_TYPE" != "$PREPROC_ENV_LINE" ]
											   then
												echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) INCIDENT_DATA_TYPE changed from [$INCIDENT_DATA_TYPE] to [$PREPROC_ENV_LINE]"
												local PREPROC_ENV_NEW="true"
											   fi

											   local NEW_DATA_TYPE=$PREPROC_ENV_LINE
											   echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) Setting new variable NEW_DATA_TYPE to [$NEW_DATA_TYPE]..."
												;;
											4) if [ "$INCIDENT_DATA_INFO" != "$PREPROC_ENV_LINE" ]
											   then
												echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) INCIDENT_DATA_INFO changed from [$INCIDENT_DATA_INFO] to [$PREPROC_ENV_LINE]"
												local PREPROC_ENV_NEW="true"
											   fi

											   local NEW_DATA_INFO=$PREPROC_ENV_LINE
											   echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) Setting new variable NEW_DATA_INFO to [$NEW_DATA_INFO]..."
												;;
										esac				
									else
										if [ ${#TMP_DATA} -eq 0 ]
										then
											TMP_DATA="$PREPROC_ENV_LINE"
										else
											TMP_DATA="${TMP_DATA}\n$PREPROC_ENV_LINE"
										fi	
									fi
								done < $PREPROC_ENVFILE

								local XDATA=$(echo -e "$TMP_DATA")

								if [ "$INCIDENT_DATA" != "$XDATA" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) INCIDENT_DATA has changed!"
									local PREPROC_ENV_NEW="true"
								else
									echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) INCIDENT_DATA has not changed!"
								fi

								local NEW_DATA="$XDATA"

								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) Original INCIDENT = [INCIDENT_OBJECT_TYPE=${INCIDENT_OBJECT_TYPE} / INCIDENT_OBJECT_NAME=${INCIDENT_OBJECT_NAME} / INCIDENT_DATA_TYPE=${INCIDENT_DATA_TYPE} / INCIDENT_DATA_INFO=${INCIDENT_DATA_INFO}]"
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) Original INCIDENT = [INCIDENT_DATA=${INCIDENT_DATA}]"

								if [ $PREPROC_ENV_NEW == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) Enriched INCIDENT = [NEW_OBJECT_TYPE=${NEW_OBJECT_TYPE} / NEW_OBJECT_NAME=${NEW_OBJECT_NAME} / NEW_DATA_TYPE=${NEW_DATA_TYPE} / NEW_DATA_INFO=${NEW_DATA_INFO}]"
									echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) Enriched INCIDENT = [NEW_DATA=${NEW_DATA}]"
								else
									echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (preproc.sh) Incident data did not change!"
								fi
		
								local ORIG_SCRIPT_DIR=$SCRIPT_DIR

								# Constructing SCRIPT_DIR to locate analytic scripts
								if [ ${#NEW_OBJECT_TYPE} -eq 0 ]
								then
									local SCRIPT_DIR=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE
								else
									local SCRIPT_DIR=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$NEW_OBJECT_TYPE
								fi

								if [ ${#NEW_DATA_TYPE} -eq 0 ]
								then
									local SCRIPT_DIR=$SCRIPT_DIR/$INCIDENT_DATA_TYPE
								else
									local SCRIPT_DIR=$SCRIPT_DIR/$NEW_DATA_TYPE
								fi

								if [ ${#NEW_OBJECT_NAME} -eq 0 ]
								then
									local SCRIPT_DIR=$SCRIPT_DIR
									local GENERIC_SCRIPT_TOEXEC="true"
								else
									local SCRIPT_DIR=$SCRIPT_DIR/$NEW_OBJECT_NAME
									local GENERIC_SCRIPT_TOEXEC="false"
								fi

								if [ ! -d $SCRIPT_DIR ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Constructed SCRIPT_DIR [$SCRIPT_DIR] does not exists!"

									if [ ${#ORIG_SCRIPT_DIR} -gt 0 ]
									then
										local SCRIPT_DIR=$ORIG_SCRIPT_DIR
									else
										local SCRIPT_DIR=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE
									fi

									echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Reseting SCRIPT_DIR to [$SCRIPT_DIR]. To proceed to execute 'generic.sh'..."

									local GENERIC_SCRIPT_TOEXEC="true"
								fi
							else
								case $PREPROC_MODE in
									NO_OBJNAME) ;;
									YES_OBJNAME) ;;
									PROC_OBJNAME) 
										local SCRIPT_DIR=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE
										local GENERIC_SCRIPT_TOEXEC="true"
										echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] PREPROC_ENVFILE [$PREPROC_ENVFILE] does not exist or is zero-sized. Setting SCRIPT_DIR to [$SCRIPT_DIR]]..."
										;;
								esac
							fi	
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] PREPROC_SCRIPT [$PREPROC_SCRIPT] does not exist or is zero-sized!"

						case $PREPROC_MODE in
							NO_OBJNAME) ;;
							YES_OBJNAME) ;;
							PROC_OBJNAME) 
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] INCIDENT_OBJECT_NAME [$INCIDENT_OBJECT_NAME] is set, but SCRIPT_DIR [$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE/$INCIDENT_OBJECT_NAME] does not exist!"
								local SCRIPT_DIR=$ENGINE_ANALYZE_SCRIPT_DIR/$PRODUCT_VERSION/$INCIDENT_OBJECT_TYPE/$INCIDENT_DATA_TYPE
								local GENERIC_SCRIPT_TOEXEC="true"
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Setting SCRIPT_DIR to [$SCRIPT_DIR]..."
								;;
						esac
					fi

					if [ $GENERIC_SCRIPT_TOEXEC == "true" ]
					then
						local GENERIC_SCRIPT=$SCRIPT_DIR/generic.sh

						if [ -s $GENERIC_SCRIPT ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] (generic.sh) Starting generic analysis on incident..."
	
							if [ ${#TIMEOUT} -gt 0 ]
							then
								local TO_EXEC_CMD="$TIMEOUT $ENGINE_TVALUE /bin/bash $GENERIC_SCRIPT"
							else
								local TO_EXEC_CMD="/bin/bash $GENERIC_SCRIPT"
							fi
	
							echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Executing generic analyze script [$TO_EXEC_CMD]..."
	
							echo "[$REC_CTR] SCRIPT = [$GENERIC_SCRIPT]" >> $INCIDENT_REPORT_OUTFILE
							echo "[$REC_CTR] INCIDENT = [INCIDENT_OBJECT_TYPE=$INCIDENT_OBJECT_TYPE / INCIDENT_OBJECT_NAME=$INCIDENT_OBJECT_NAME / INCIDENT_DATA_TYPE=$INCIDENT_DATA_TYPE / INCIDENT_DATA_INFO=$INCIDENT_DATA_INFO]" >> $INCIDENT_REPORT_OUTFILE
							echo "[$REC_CTR] INCIDENT = [INCIDENT_DATA=$INCIDENT_DATA]" >> $INCIDENT_REPORT_OUTFILE
							echo "[$REC_CTR] ANALYSIS: " >> $INCIDENT_REPORT_OUTFILE
							eval "$TO_EXEC_CMD" >> $INCIDENT_REPORT_OUTFILE 2>&1
							local ENGINE_GENERIC_SCRIPT_EXIT_STATUS=$?
							echo >> $INCIDENT_REPORT_OUTFILE
							echo "===================================================" >> $INCIDENT_REPORT_OUTFILE
							
							if [ $ENGINE_GENERIC_SCRIPT_EXIT_STATUS -eq 124 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Execution of generic analyze script [$GENERIC_SCRIPT] timeout after $ENGINE_TVALUE!"
								continue
							fi
		
							echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Generic analyze script [$GENERIC_SCRIPT] exits with status [$ENGINE_GENERIC_SCRIPT_EXIT_STATUS]..."
						else
							echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] GENERIC_SCRIPT [$GENERIC_SCRIPT] does not exist or is zero-sized!"
						fi
					else
						if [ ! -d $SCRIPT_DIR ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] SCRIPT_DIR [$SCRIPT_DIR] does not exist! Skipping object specific analysis..."
							continue
						fi
	
						# Object-specific analysis
						local LS_CMD="ls $SCRIPT_DIR | grep -E -v 'preproc.sh|generic.sh' | sort"
	
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] LS_CMD = [$LS_CMD]"
						fi
		
						local ANALYZE_SCRIPT_CTR=0
			
						for ANALYZE_SCRIPT in $(eval "$LS_CMD")
						do
							if [ -d $SCRIPT_DIR/$ANALYZE_SCRIPT ]
							then
								continue
							fi
	
							(( ANALYZE_SCRIPT_CTR=ANALYZE_SCRIPT_CTR+1 ))
	
							local ANALYZE_SCRIPT_ENVFILE=$ENGINE_DATA_OUTDIR/${REC_CTR}_$(basename $ANALYZE_SCRIPT).out
							echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] ANALYZE_SCRIPT = [$SCRIPT_DIR/$ANALYZE_SCRIPT]" 
							echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] ANALYZE_SCRIPT_ENVFILE = [$ANALYZE_SCRIPT_ENVFILE]"
	
							if [ -s "$ANALYZE_SCRIPT_ENVFILE" ]
							then
								local EXPORT_ENV="export ANALYZE_SCRIPT_ENVFILE"
							fi
	
							if [ $ANALYZE_SCRIPT_CTR -eq 1 ] 
							then
								local PREV_ANALYZE_SCRIPT_ENVFILE="/dummy/env/file/that/should/not/exist"
							else
								local PREV_ANALYZE_SCRIPT_ENVFILE_CMD="ls $ENGINE_DATA_OUTDIR/${REC_CTR}_$ANALYZE_SCRIPT_*.out"
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] PREV_ANALYZE_SCRIPT_ENVFILE_CMD = [$PREV_ANALYZE_SCRIPT_ENVFILE_CMD]"
								local PREV_ANALYZE_SCRIPT_ENVFILE=$(eval "$PREV_ANALYZE_SCRIPT_ENVFILE_CMD")
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] PREV_ANALYZE_SCRIPT_ENVFILE = [$PREV_ANALYZE_SCRIPT_ENVFILE]"
							fi
			
							if [ -s "${PREV_ANALYZE_SCRIPT_ENVFILE}" ]
							then
								while read ENV_LINE
								do
									if [ ${#EXPORT_ENV} -eq 0 ]
									then
										local EXPORT_ENV="export ${ENV_LINE}"
									else
										local EXPORT_ENV="$EXPORT_ENV;export ${ENV_LINE}"
									fi
								done < "${PREV_ANALYZE_SCRIPT_ENVFILE}"
			
								if [ $MG_DEBUG == "true" ]
								then
									local INCIDENT_REPORT_DEBUG_DIR=$DEBUG_OUTDIR/incident
					
									if [ ! -d $INCIDENT_REPORT_DEBUG_DIR ]
									then
										mkdir -p $INCIDENT_REPORT_DEBUG_DIR
									fi
								
									echo "[$(date)] [${FUNCNAME[0]}] Backing up analyze env file [$PREV_ANALYZE_SCRIPT_ENVFILE] to directory [$INCIDENT_REPORT_DEBUG_DIR]..."
									cp -p "${PREV_ANALYZE_SCRIPT_ENVFILE}" $INCIDENT_REPORT_DEBUG_DIR
								fi
			
								rm "${PREV_ANALYZE_SCRIPT_ENVFILE}"
							fi
							
							if [ ${#TIMEOUT} -gt 0 ]
							then
								if [ ${#EXPORT_ENV} -gt 0 ]
								then
									local TO_EXEC_CMD="$EXPORT_ENV; $TIMEOUT $ENGINE_TVALUE /bin/bash $SCRIPT_DIR/$ANALYZE_SCRIPT"
								else
									local TO_EXEC_CMD="$TIMEOUT $ENGINE_TVALUE /bin/bash $SCRIPT_DIR/$ANALYZE_SCRIPT"
								fi
	
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Executing engine analyze script [$TO_EXEC_CMD]..."
								echo "[$REC_CTR] SCRIPT = [$SCRIPT_DIR/$ANALYZE_SCRIPT]" >> $INCIDENT_REPORT_OUTFILE
								echo "[$REC_CTR] INCIDENT = [INCIDENT_OBJECT_TYPE=$INCIDENT_OBJECT_TYPE / INCIDENT_OBJECT_NAME=$INCIDENT_OBJECT_NAME / INCIDENT_DATA_TYPE=$INCIDENT_DATA_TYPE / INCIDENT_DATA_INFO=$INCIDENT_DATA_INFO]" >> $INCIDENT_REPORT_OUTFILE
								echo "[$REC_CTR] INCIDENT = [INCIDENT_DATA=$INCIDENT_DATA]" >> $INCIDENT_REPORT_OUTFILE
								echo "[$REC_CTR] ANALYSIS: " >> $INCIDENT_REPORT_OUTFILE
								eval "$TO_EXEC_CMD" >> $INCIDENT_REPORT_OUTFILE 2>&1
								local ENGINE_ANALYZE_SCRIPT_EXIT_STATUS=$?
								
								if [ $ENGINE_ANALYZE_SCRIPT_EXIT_STATUS -eq 124 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Execution of engine analyze script [$SCRIPT_DIR/$ANALYZE_SCRIPT] timeout after $ENGINE_TVALUE!"
									continue
								fi	
							else
								if [ ${#EXPORT_ENV} -gt 0 ]
								then
									local TO_EXEC_CMD="$EXPORT_ENV; /bin/bash $SCRIPT_DIR/$ANALYZE_SCRIPT"
								else
									local TO_EXEC_CMD="/bin/bash $SCRIPT_DIR/$ANALYZE_SCRIPT"
								fi
	
								echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Executing engine analyze script [$TO_EXEC_CMD]..."
								echo "[$REC_CTR] SCRIPT = [$SCRIPT_DIR/$ANALYZE_SCRIPT]" >> $INCIDENT_REPORT_OUTFILE
								echo "[$REC_CTR] INCIDENT = [INCIDENT_OBJECT_TYPE=$INCIDENT_OBJECT_TYPE / INCIDENT_OBJECT_NAME=$INCIDENT_OBJECT_NAME / INCIDENT_DATA_TYPE=$INCIDENT_DATA_TYPE / INCIDENT_DATA_INFO=$INCIDENT_DATA_INFO]" >> $INCIDENT_REPORT_OUTFILE
								echo "[$REC_CTR] INCIDENT = [INCIDENT_DATA=$INCIDENT_DATA]" >> $INCIDENT_REPORT_OUTFILE
								echo "[$REC_CTR] ANALYSIS: " >> $INCIDENT_REPORT_OUTFILE
								eval "$TO_EXEC_CMD" >> $INCIDENT_REPORT_OUTFILE 2>&1
								local ENGINE_ANALYZE_SCRIPT_EXIT_STATUS=$?
							fi
						
							echo >> $INCIDENT_REPORT_OUTFILE
							echo "===================================================" >> $INCIDENT_REPORT_OUTFILE
							echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] Engine analyze script [$SCRIPT_DIR/$ANALYZE_SCRIPT] executed. Exit status = [$ENGINE_ANALYZE_SCRIPT_EXIT_STATUS]"
						done
					fi
		
#					if [ $OBJ_SPEC_SCRIPT_AVAIL == "false" ]
#					then
#						echo "[$(date)] [${FUNCNAME[0]}] [$REC_CTR] No analytic script is available!"
#
#						echo "[$REC_CTR] INCIDENT = [OBJECT_TYPE=$OBJECT_TYPE / OBJECT_NAME=$OBJECT_NAME / DATA_TYPE=$DATA_TYPE / DATA_INFO=$DATA_INFO]" >> $INCIDENT_REPORT_ERRFILE
#						echo "[$REC_CTR] INCIDENT = [DATA=$DATA]" >> $INCIDENT_REPORT_ERRFILE
#						echo "[$REC_CTR] SCRIPT: N/A" >> $INCIDENT_REPORT_ERRFILE
#						echo >> $INCIDENT_REPORT_ERRFILE
#						echo "===================================================" >> $INCIDENT_REPORT_ERRFILE
#					fi
				else
					if [ ${#IN_DATA} -eq 0 ]
					then
						local IN_DATA="$INCIDENT_LINE"
					else
						local IN_DATA="${IN_DATA}\n${INCIDENT_LINE}"
					fi	
				fi
			fi

			(( LINE_CTR=LINE_CTR+1 ))
		done < $INCIDENT_REPORT_TMPFILE

		if [ $MG_DEBUG == "true" ]
		then
			local INCIDENT_REPORT_DEBUG_DIR=$DEBUG_OUTDIR/incident

			if [ ! -d $INCIDENT_REPORT_DEBUG_DIR ]
			then
				mkdir -p $INCIDENT_REPORT_DEBUG_DIR
			fi
			
			echo "[$(date)] [${FUNCNAME[0]}] Backing up incident report file [$INCIDENT_REPORT_TMPFILE] to directory [$INCIDENT_REPORT_DEBUG_DIR]..."
			cp -p $INCIDENT_REPORT_TMPFILE $INCIDENT_REPORT_DEBUG_DIR
			echo "[$(date)] [${FUNCNAME[0]}] Backing up incident counter file [$INCIDENT_REPORT_CTRFILE] to directory [$INCIDENT_REPORT_DEBUG_DIR]..."
			cp -p $INCIDENT_REPORT_CTRFILE $INCIDENT_REPORT_DEBUG_DIR
		fi

		rm $INCIDENT_REPORT_TMPFILE
		rm $INCIDENT_REPORT_CTRFILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] Incident report file [$INCIDENT_REPORT_TMPFILE] does not exist or is zero-sized!"
		echo "[$(date)] [${FUNCNAME[0]}] NOTE: It's very likely that there is no incident to analyze!"
	fi	
}

# getOutFile()
# {
#	GZIP_OUTFILE="$ROOT_OUTDIR/$(echo "$PRODUCT_NAME" | $AWK '{ print tolower($0) }')-$MUSTGATHER_OPT-$MG_TIMESTAMP.tar.gz"
# }

gzipData()
{
	# Calculate elapsed time
	local END_TIME=$(date +%s)
	local EXEC_TIME=$(( END_TIME - START_TIME ))

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] START_TIME = [$START_TIME] / END_TIME = [$END_TIME]"
	fi
	
	if [ $IS_MACOS == "true" ]
	then
		local ELAPSED=$(eval "printf '%02d hr %02d min %02d sec' $((EXEC_TIME/3600)) $((EXEC_TIME%3600/60)) $((EXEC_TIME%60))")
	else	
		local ELAPSED=$(eval "echo $(date -ud "@$EXEC_TIME" +'%H hr %M min %S sec')")
	fi

	echo "[$(date)] [${FUNCNAME[0]}] The mustgather script took [$ELAPSED] to execute..."
	sync; sleep 1

	# Perform total file and size count
	local MG_FINAL_FILE_COUNT=$(find $OUTDIR -type f | wc -l)
	local MG_FINAL_SIZE_COUNT=$(du -sh $OUTDIR | $AWK '{ print $1 }')
	echo "[$(date)] [${FUNCNAME[0]}] Total files produced = [$MG_FINAL_FILE_COUNT] [SIZE = $MG_FINAL_SIZE_COUNT]"

	for FILEDIR in $(find $OUTDIR -maxdepth 1 -mindepth 1 -exec basename {} \; | sort)
	do
		if [ -d $OUTDIR/$FILEDIR ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] >>> [DIR: $FILEDIR] = $(find $OUTDIR/$FILEDIR -type f | wc -l) ($(du -sh $OUTDIR/$FILEDIR | $AWK '{ print $1 }'))"
		else
			# File (not directory)
			echo "[$(date)] [${FUNCNAME[0]}] >>> [FILE: $FILEDIR] = 1 ($(du -sh $OUTDIR/$FILEDIR | $AWK '{ print $1 }'))"
		fi
	done

	if [ $REPORT_ON_SCREEN == "true" ]
	then
		if [ -s $ANALYZE_OUTFILE ]
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Copying SUMMARY.log file [$ANALYZE_OUTFILE] to [$REPORT_ON_SCREEN_SUMMARY_FILE]"
			fi
	
			cp -p $ANALYZE_OUTFILE $REPORT_ON_SCREEN_SUMMARY_FILE
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] SUMMARY.log file [$ANALYZE_OUTFILE] does not exist or is zero-sized! Unable to copy!"
			fi
		fi

		if [ ${GET_COMPLIANCE} == "true" ] 
		then
			if [ -s $COMPLIANCE_REPORT ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying COMPLIANCE_REPORT.log file [$COMPLIANCE_REPORT] to [$REPORT_ON_SCREEN_COMPLIANCE_FILE]"
				fi
	
				cp -p $COMPLIANCE_REPORT $REPORT_ON_SCREEN_COMPLIANCE_FILE
			else
				if [ $MG_DEBUG == "true" ]
				then
					if [ $COMPLIANCE_INPUTTAG != ".listcompliance" ] && [ $COMPLIANCE_INPUTTAG != ".listcompliance_custom" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_REPORT.log file [$COMPLIANCE_REPORT] does not exist or is zero-sized! Unable to copy!"
					fi
				fi
			fi
		fi

		if [ $DIFF_SNAPSHOTS == "true" ] 
		then
			if [ -s $SNAPSHOTS_REPORT ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Copying SNAPSHOTS_REPORT.log file [$SNAPSHOTS_REPORT] to [$REPORT_ON_SCREEN_SNAPSHOTS_FILE]"
				fi
		
				cp -p $SNAPSHOTS_REPORT $REPORT_ON_SCREEN_SNAPSHOTS_FILE
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] SNAPSHOTS_REPORT.log file [$SNAPSHOTS_REPORT] does not exist or is zero-sized! Unable to copy!"
				fi
			fi
		fi
	fi

	cd $ROOT_OUTDIR
	# local GZIP_DIR=$(echo $(basename $GZIP_OUTFILE) | $AWK -F'.' '{ print $1 }')
	local GZIP_DIR=$(basename $OUTDIR)

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] GZIP_DIR = [$GZIP_DIR] / GZIP_OUTFILE = [$GZIP_OUTFILE]"
	fi
	
	echo "[$(date)] [${FUNCNAME[0]}] Creating gzipped tarball [$GZIP_OUTFILE] of directory [$OUTDIR]"
	tar czf $GZIP_OUTFILE $GZIP_DIR
	echo "[$(date)] [${FUNCNAME[0]}] Gzipped tarball [$GZIP_OUTFILE] of directory [$OUTDIR] created"
}

cleanUpDataDir()
{
	if [ ${#OUTDIR} -gt 0 ]
	then
		if [ $OUTDIR != $ROOT_OUTDIR ]
		then
			if [ -d $OUTDIR ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Removing data directory [$OUTDIR]"
				rm -r $OUTDIR >> $RUNTIME_LOGFILE 2>&1
			else
				echo "[$(date)] [${FUNCNAME[0]}] OUTDIR [$OUTDIR] does not exist!"
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] OUTDIR [$OUTDIR] is set to ROOT_OUTDIR [$ROOT_OUTDIR] - NOT removing data directory [$OUTDIR]!"
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] OUTDIR [$OUTDIR] is not set - NOT removing data directory!"
	fi

	if [ ${#MANUAL_COLL_OBJNAME_REFFILE} -gt 0 ] && [ -f $MANUAL_COLL_OBJNAME_REFFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Removing temporary work file MANUAL_COLL_OBJNAME_REFFILE [$MANUAL_COLL_OBJNAME_REFFILE]..."
		rm $MANUAL_COLL_OBJNAME_REFFILE
	fi

	if [ ${#MANUAL_COLL_EXECPREP_REFFILE} -gt 0 ] && [ -f $MANUAL_COLL_EXECPREP_REFFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Removing temporary work file MANUAL_COLL_EXECPREP_REFFILE [$MANUAL_COLL_EXECPREP_REFFILE]..."
		rm $MANUAL_COLL_EXECPREP_REFFILE
	fi

	if [ -f $TMP_LOGFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Removing temporary log file [$TMP_LOGFILE]..."
		rm $TMP_LOGFILE
	fi

	if [ $OC_PROXY_SUCC == "true" ] && [ ${#OC_PROXY_PID} -gt 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Stopping proxy server at [$OC_APISVR][PID=$OC_PROXY_PID]..."
		kill -9 $OC_PROXY_PID 
		wait $OC_PROXY_PID 2> /dev/null
	fi
}

checkModules()
{
	# Check validity of module name
	
	local MOD=
	local VMOD=
	IFS=$OLDIFS

	for MOD in $(echo "$MODULES" | sed 's/,/\n/g' | sort | uniq)
	do
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Checking validity of user-input module [$MOD]..."
		fi

		local VALID_MODULE="false"

		for VMOD in ${VALID_MODULES[@]}
		do
			local LMOD=$(echo "$MOD" | $AWK '{ print tolower($0) }')

			if [ $LMOD == $VMOD ]
			then
				local VALID_MODULE="true"
				echo "[$(date)] [${FUNCNAME[0]}] Module [$MOD] is valid!"		
				CLEAN_MODULES[${#CLEAN_MODULES[@]}]="$LMOD"

				break
			fi
		done

		if [ $VALID_MODULE == "false" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Module [$MOD] is invalid! Skipping..."		
		fi
	done

	IFS=$'\n'

	if [ ${#CLEAN_MODULES[@]} -gt 0 ]
	then
		return 0
	else
		return 1
	fi
}

getAllExtraNS()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local NS=$1

	local EXNS=$(echo "$NS" | sed 's/^[ ]*//' | sed 's/[ ]*$//' | sed 's/[ ]*,[ ]*/ /g')
	local EXNS_PROC
	local IN_NS=
	local VERB=
	local DEF_OBJ=
	local LINE=
	
	IFS=$OLDIFS

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing data collection for namespace(s) = [$EXNS]"
	fi

	# If NS4PROD is found, expand the namespace(s)
	for IN_NS in $EXNS
	do
		local TMP_NUM_COL=$(echo "$IN_NS" | $AWK -F: '{ print NF }')
		
		if [ $TMP_NUM_COL -eq 2 ]
		then
			local TMP_NAMESPACE=$(echo "$IN_NS" | $AWK -F: '{ print $1 }')
			local TMP_NS_EXTRA_OBJ_LIST=$(echo "$IN_NS" | $AWK -F: '{ print $2 }')
		else
			if [ $TMP_NUM_COL -eq 1 ]
			then
				local TMP_NAMESPACE=$(echo "$IN_NS" | $AWK -F: '{ print $1 }')
				local TMP_NS_EXTRA_OBJ_LIST=
			else
				echo "[$(date)] [${FUNCNAME[0]}] Invalid configuration [$IN_NS]! Skipping..."	
				continue
			fi
		fi

		if [ ${#TMP_NAMESPACE} -gt 0 ]
		then
			if [[ "$TMP_NAMESPACE" =~ ^NS4PROD= ]]
			then
				local PROD_NAME=$(echo "$TMP_NAMESPACE" | $AWK -F= '{ print $2 }')
		
				echo "[$(date)] [${FUNCNAME[0]}] [IN_NS = $IN_NS] Attempting to retrieve namespace for product [$PROD_NAME]..."
				local PROD_NAMESPACES=$(getProdToNamespacesMapping $PROD_NAME)
				echo "[$(date)] [${FUNCNAME[0]}] [IN_NS = $IN_NS] Namespace retrieved for product [$PROD_NAME] = [$PROD_NAMESPACES]"
		
				if [ "$PROD_NAMESPACES" == $PROD_NAMESPACES_INVALID_STR ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [IN_NS = $IN_NS] Unable to determine namespace! Skipping..."
					continue
				else
					for PROD_NS in $PROD_NAMESPACES	
					do
						echo "[$(date)] [${FUNCNAME[0]}] [IN_NS = $IN_NS] Adding product namespace [$PROD_NS]..."

						if [ ${#EXNS_PROC} -eq 0 ]
						then
							if [ ${#TMP_NS_EXTRA_OBJ_LIST} -gt 0 ]
							then
								local EXNS_PROC="$PROD_NS:$TMP_NS_EXTRA_OBJ_LIST"
							else
								local EXNS_PROC="$PROD_NS"
							fi
						else
							if [ ${#TMP_NS_EXTRA_OBJ_LIST} -gt 0 ]
							then
								local EXNS_PROC="$EXNS_PROC $PROD_NS:$TMP_NS_EXTRA_OBJ_LIST"
							else
								local EXNS_PROC="$EXNS_PROC $PROD_NS"
							fi
						fi
					done
				fi
			else
				if [ "$TMP_NAMESPACE" == "ALLNS" ]
				then
					if ! checkUserPriv get ns all
					then
						echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have [get] privilege on resource [namespace] at cluster scope! Skipping..."
						echo "[$(date)] [${FUNCNAME[0]}] Skipping namespace [$IN_NS]..."
						continue
					fi

					if [ ${#TMP_NS_EXTRA_OBJ_LIST} -gt 0 ] 
					then
						local EXT_NS=

						for NS in $($OC_CMD get ns --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}')
						do
							if [ ${#EXT_NS} -eq 0 ]
							then
								local EXT_NS="$NS:$TMP_NS_EXTRA_OBJ_LIST"
							else
								local EXT_NS="$EXT_NS $NS:$TMP_NS_EXTRA_OBJ_LIST"
							fi	
						done
					else
						local EXT_NS=$($OC_CMD get ns --template '{{range .items}}{{.metadata.name}}{{" "}}{{end}}')
					fi

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Namespace [$IN_NS] is expanded into [$EXT_NS]..."
					fi

					if [ ${#EXNS_PROC} -eq 0 ]
					then
						local EXNS_PROC="$EXT_NS"
					else
						local EXNS_PROC="$EXNS_PROC $EXT_NS"
					fi
				else
					if [ ${#EXNS_PROC} -eq 0 ]
					then
						if [ ${#TMP_NS_EXTRA_OBJ_LIST} -gt 0 ]
						then
							local EXNS_PROC="$TMP_NAMESPACE:$TMP_NS_EXTRA_OBJ_LIST"
						else
							local EXNS_PROC="$TMP_NAMESPACE"
						fi
					else
						if [ ${#TMP_NS_EXTRA_OBJ_LIST} -gt 0 ]
						then
							local EXNS_PROC="$EXNS_PROC $TMP_NAMESPACE:$TMP_NS_EXTRA_OBJ_LIST"
						else
							local EXNS_PROC="$EXNS_PROC $TMP_NAMESPACE"
						fi
					fi
				fi
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] Empty configuration [$IN_NS]! Skipping..."	
			continue
		fi
	done

	if [ ${#EXNS_PROC} -gt 0 ]
	then
		local EXNS_PROC=$(echo "$EXNS_PROC" | tr ' ' '\n' | grep -v '^$' | sort | uniq)
	fi

	local TOTAL_EXNS_PROC=$(echo "$EXNS_PROC" | wc -l)

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] EXNS_PROC = [$EXNS_PROC] [TOTAL NS = $TOTAL_EXNS_PROC]"
	fi

	for IN_NS in $EXNS_PROC
	do
		local NUM_COL=$(echo "$IN_NS" | $AWK -F: '{ print NF }')
		
		if [ $NUM_COL -eq 2 ]
		then
			local NAMESPACE=$(echo "$IN_NS" | $AWK -F: '{ print $1 }')
			local NS_EXTRA_OBJ_LIST=$(echo "$IN_NS" | $AWK -F: '{ print $2 }')
		else
			if [ $NUM_COL -eq 1 ]
			then
				local NAMESPACE=$(echo "$IN_NS" | $AWK -F: '{ print $1 }')
				local NS_EXTRA_OBJ_LIST=
			else
				echo "[$(date)] [${FUNCNAME[0]}] Invalid configuration [$IN_NS]! Skipping..."	
				continue
			fi
		fi

		if toIgnoreAddOnNS $NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] Skipping data extraction for namespace [$NAMESPACE]..."
			continue
		else
			if toExcludeProdNamespace $NAMESPACE
			then
				echo "[$(date)] [${FUNCNAME[0]}] To exclude namespace [$NAMESPACE]..."
				continue
			fi

			echo "[$(date)] [${FUNCNAME[0]}] Starting data collection for namespace [$NAMESPACE]..."
		fi

		local TO_SKIP="false"	

		echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

		for VERB in "get" "list"
		do
			local PRIV_CMD="checkUserPriv $VERB all $NAMESPACE"
				
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PRIV_CMD = [$PRIV_CMD]"
			fi

			# checkUserPriv() failed
			if ! eval "$PRIV_CMD"
			then
				local TO_SKIP="true"
				break
			fi
		done

		if [ $TO_SKIP == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Extra namespace [$NAMESPACE] failed user privilege check! Skipping..."
			continue
		fi
		
		if ! $OC_CMD get namespace $NAMESPACE > /dev/null
		then
			echo "[$(date)] [${FUNCNAME[0]}] Extra namespace [$NAMESPACE] is invalid. Skipping..."
			continue
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Executing 'extra' data collection ($OC_CMD get) for namespace [$NAMESPACE]..."

		if ! $OC_CMD get namespace $NAMESPACE > /dev/null
		then
			echo "[$(date)] [${FUNCNAME[0]}] Namespace [$NAMESPACE] is invalid. Skipping..."
			continue
		fi

		if [ ! -d $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Making directory [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE]..."
			mkdir -p $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE
		fi

		# $OC_CMD get all
		local OC_ALL_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_all.out
		getOcAll $NAMESPACE $OC_ALL_EXNS_OUTFILE

		if [ $GET_POD_LOGS == "true" ]
		then
			descAll $NAMESPACE $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_all.out $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE logs
		else
			descAll $NAMESPACE $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_all.out $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE none
		fi

		analyzeOcAll $NAMESPACE $OC_ALL_EXNS_OUTFILE $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE

		if [ ${#NS_EXTRA_OBJ_LIST} -gt 0 ]
		then	
			if [ ${NS_EXTRA_OBJ_LIST} == "ALL" ]
			then
				# Collect ALL resource types
				echo "[$(date)] [${FUNCNAME[0]}] Executing data collection for all resource types for namespace [$NAMESPACE]..."
	               echo "[$(date)] [${FUNCNAME[0]}] Retrieving all resource types covered by 'oc get all' in namespace [$NAMESPACE]..."
	               local OC_ALL_RESTYPE_LIST=$(getAllResTypeFromOcAll $OC_ALL_EXNS_OUTFILE)
	
	               echo "[$(date)] [${FUNCNAME[0]}] Retrieving all resource types associated with namespace [$NAMESPACE]..."
	               local NS_ALL_RESTYPE=$(getAllResTypeForNS $NAMESPACE)
	
	               if [ $MG_DEBUG == "true" ]
	               then
	                    echo "[$(date)] [${FUNCNAME[0]}] [$NS] OC_ALL_RESTYPE_LIST = [$OC_ALL_RESTYPE_LIST] [TOTAL="$(echo "$OC_ALL_RESTYPE_LIST" | $AWK '{ print NF }')"]"
	                    echo "[$(date)] [${FUNCNAME[0]}] [$NS] NS_ALL_RESTYPE = [$NS_ALL_RESTYPE] [TOTAL="$(echo "$NS_ALL_RESTYPE" | $AWK '{ print NF }')"]"
	               fi
	
	               IFS=$OLDIFS
				local RES_LONGNAME=
	
	               for RES_LONGNAME in $NS_ALL_RESTYPE
	               do
					local RESTYPE=$(getApiResName "$RES_LONGNAME")
	                    local RESTYPE_FOUND="false"
					IFS=$OLDIFS

	                    for OC_ALL_RESTYPE in $OC_ALL_RESTYPE_LIST
	                    do
						# echo "$RES_LONGNAME == $OC_ALL_RESTYPE"
	                         if [ $RES_LONGNAME == $OC_ALL_RESTYPE ]
	                         then
	                              echo "[$(date)] [${FUNCNAME[0]}] Resource type [$RES_LONGNAME] was handled by 'getOcAll()'! Skipping..."
	                              local RESTYPE_FOUND="true"
	                              break
	                         fi
	                    done
	
	                    if [ $RESTYPE_FOUND == "false" ]
	                    then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Resource type long name [$RES_LONGNAME] => [$RESTYPE]"
						fi

	                         ocGet $RESTYPE $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_$RESTYPE.out $NAMESPACE
	                         ocDesc $RESTYPE $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/$RESTYPE $NAMESPACE
	                    fi
	               done
			else
				# Pre-defined resource types + user-defined
				echo "[$(date)] [${FUNCNAME[0]}] Executing data collection for pre-defined resource types plus user-defined resource types for namespace [$NAMESPACE]..."

				# $OC_CMD get secret
				local OC_SECRET_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_secrets.out
				ocGet secrets $OC_SECRET_EXNS_OUTFILE $NAMESPACE
				ocDesc secrets $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/secrets $NAMESPACE
				
				# $OC_CMD get configmap
				local OC_CM_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_configmaps.out
				ocGet configmaps $OC_CM_EXNS_OUTFILE $NAMESPACE
				ocDesc configmaps $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/configmaps $NAMESPACE
				
				# $OC_CMD get pvc
				local OC_PVC_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_pvc.out
				ocGet pvc $OC_PVC_EXNS_OUTFILE $NAMESPACE
				ocDesc pvc $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc $NAMESPACE
		
				# $OC_CMD get sa
				local OC_SA_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_serviceaccounts.out
				ocGet serviceaccounts $OC_SA_EXNS_OUTFILE $NAMESPACE
				ocDesc serviceaccounts $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/serviceaccounts $NAMESPACE

				if [[ ! $NS_EXTRA_OBJ_LIST =~ ^/ ]] && [[ ! $NS_EXTRA_OBJ_LIST =~ ^./ ]]
				then
					local DEF_NS_EXTRA_DIR=$MUSTGATHER_DIRNAME/extra
					echo "[$(date)] [${FUNCNAME[0]}] User provided extra-object input file [$NS_EXTRA_OBJ_LIST] is relative and will be use with default directory [$DEF_NS_EXTRA_DIR/$NS_EXTRA_OBJ_LIST]..."
					local NS_EXTRA_OBJ_LIST=$DEF_NS_EXTRA_DIR/$NS_EXTRA_OBJ_LIST	
				fi
	
				if [ -s $NS_EXTRA_OBJ_LIST ]
				then
					local EXNS_DEBUGDIR="$EXTRA_NAMESPACES_ROOT_DEBUG_OUTDIR/${FUNCNAME[0]}"
					local DEFAULT_EXNS_OBJ=(secret secrets configmap configmaps cm persistentvolumeclaim persistentvolumeclaims pvc serviceaccount serviceaccounts sa)
					
					if [ ! -d $EXNS_DEBUGDIR ]	
					then
						mkdir -p $EXNS_DEBUGDIR
					fi
	
					while read LINE
					do
						if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
						then
							continue
						fi
	
						local EXTRA_OBJTYPE=$(echo "$LINE" | $AWK '{ print tolower($1) }')
						local TO_PROCESS="true"
	
						# Skip if already collected by getAllExtraNS()
						for DEF_OBJ in ${DEFAULT_EXNS_OBJ[@]}
						do
							if [ "$EXTRA_OBJTYPE" == "$DEF_OBJ" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Data of object [$EXTRA_OBJTYPE] has been collected by getAllExtraNS() function. Skipping..."
								local TO_PROCESS="false"	
								break
							fi
						done
	
						if [ $TO_PROCESS == "false" ]
						then
							continue
						fi
	
						if [ ${#EXTRA_OBJTYPE} -gt 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Processing user provided extra-object [$EXTRA_OBJTYPE] from file [$NS_EXTRA_OBJ_LIST]..."
							local OC_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_${EXTRA_OBJTYPE}.out
							local OC_EXNS_OUTDIR=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE

							ocGet $EXTRA_OBJTYPE $OC_EXNS_OUTFILE $NAMESPACE
							ocDesc $EXTRA_OBJTYPE $OC_EXNS_OUTDIR/$EXTRA_OBJTYPE $NAMESPACE
						else
							echo "[$(date)] [${FUNCNAME[0]}] Configuration line is empty! Skipping..."
						fi
					done < $NS_EXTRA_OBJ_LIST
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Backing up user provided extra-object input file [$NS_EXTRA_OBJ_LIST] to directory [$EXNS_DEBUGDIR]..."
						cp -p $NS_EXTRA_OBJ_LIST $EXNS_DEBUGDIR	
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] User provided extra-object input file [$NS_EXTRA_OBJ_LIST] does not exist or is zero-sized! Skipping..."
				fi
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] Executing data collection for pre-defined resource types for namespace [$NAMESPACE]..."

			# $OC_CMD get secret
			local OC_SECRET_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_secrets.out
			ocGet secrets $OC_SECRET_EXNS_OUTFILE $NAMESPACE
			ocDesc secrets $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/secrets $NAMESPACE
				
			# $OC_CMD get configmap
			local OC_CM_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_configmaps.out
			ocGet configmaps $OC_CM_EXNS_OUTFILE $NAMESPACE
			ocDesc configmaps $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/configmaps $NAMESPACE
				
			# $OC_CMD get pvc
			local OC_PVC_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_pvc.out
			ocGet pvc $OC_PVC_EXNS_OUTFILE $NAMESPACE
			ocDesc pvc $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc $NAMESPACE
		
			# $OC_CMD get sa
			local OC_SA_EXNS_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_serviceaccounts.out
			ocGet serviceaccounts $OC_SA_EXNS_OUTFILE $NAMESPACE
			ocDesc serviceaccounts $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/serviceaccounts $NAMESPACE
		fi

		if [	$GET_PVC_USAGE == "true" ]
		then
			if [ -s $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_pvc.out ] || [ -s $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_persistentvolumeclaim.out ] || [ -s $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_persistentvolumeclaims.out ]
			then
				if [ -s $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_pvc.out ]
				then
					local EXTRA_PVC_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_pvc.out
				else
					if [ -s $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_persistentvolumeclaim.out ]
					then
						local EXTRA_PVC_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_persistentvolumeclaim.out
					else
						if [ -s $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_persistentvolumeclaims.out ]
						then
							local EXTRA_PVC_OUTFILE=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/oc_persistentvolumeclaims.out
						fi
					fi
				fi 

				if [ -d $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc ] || [ -d $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/persistentvolumeclaim ] || [ -d $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/persistentvolumeclaims ]
				then
					if [ -d $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc ]
					then
						local EXTRA_PVC_DESC_DIR=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/pvc
					else
						if [ -d $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/persistentvolumeclaim ]
						then
							local EXTRA_PVC_DESC_DIR=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/persistentvolumeclaim
						else
							if [ -d $EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/persistentvolumeclaims ]
							then
								local EXTRA_PVC_DESC_DIR=$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE/persistentvolumeclaims
							fi
						fi
					fi					

					analyzeOcPvc $NAMESPACE $EXTRA_PVC_OUTFILE $EXTRA_PVC_DESC_DIR
				else
					echo "[$(date)] [${FUNCNAME[0]}] GET_PVC_USAGE=[true] / Unable to locate 'oc desc' output subdirectory in directory [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE]!"
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] GET_PVC_USAGE=[true] / Unable to locate 'oc get' output file in directory [$EXTRA_NAMESPACES_OUTDIR/$NAMESPACE]!"
			fi
		fi
	done

	IFS=$'\n'

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [NS=$NAMESPACE]"
	fi
}

isProdNamespace()
{
	local IN_NS=$1
	local PROD_NS=

	for PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
	do
		if [ $PROD_NS == $IN_NS ]
		then
			return 0
		fi
	done

	return 1
}

isNamespaced()
{
	# 'echo' value:
	# 0 = OBJ_TYPE is namespaced (can exist in namespace)
	# 1 = OBJ_TYPE is cluster scoped 
	
	# Return value:
	# 0 = function call is successful 
	# 1 = function call failed
	# 2 = RES_LIST_PROCFILE does not exists or is zero-sized

	local IN_API_RES=$(echo "$1" | $AWK '{ print tolower($0) }')
	local IN_API_RES_FOUND=1

	if [ -s $RES_LIST_PROCFILE ]
	then
		local PROC_CMD="$AWK -F'|' 'BEGIN { MATCH_FOUND=\"false\" } { API_NAME=\$1; API_LONGNAMES=\$2; API_SHORTNAMES=\$3; API_KIND=\$4; API_KIND_ORIG=\$5; API_NAMESPACED=\$6; if ( API_NAME ~ /^"$IN_API_RES"$/ || API_KIND ~ /^"$IN_API_RES"$/ ) { if ( API_NAMESPACED == \"true\" ) { print 0 } else { print 1 } MATCH_FOUND=\"true\"; exit 0 } else { split(API_SHORTNAMES, SN, \",\"); for (i in SN) { if ( SN[i] ~ /^"$IN_API_RES"$/ ) { if ( API_NAMESPACED == \"true\" ) { print 0 } else { print 1 } MATCH_FOUND=\"true\"; exit 0 } }; split(API_LONGNAMES, LN, \",\"); for (i in LN) { if ( LN[i] ~ /^"$IN_API_RES"$/ ) { if ( API_NAMESPACED == \"true\" ) { print 0 } else { print 1 } MATCH_FOUND=\"true\"; exit 0 } } } } END { if ( MATCH_FOUND == \"false\" ) { print 1; exit 1 } } ' $RES_LIST_PROCFILE"

 		if [ $MG_DEBUG == "true" ]
 		then
 			echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD = [$PROC_CMD]" >&2
 		fi

		eval "$PROC_CMD"
		return $?
	else
		return 2
	fi
}

getApiVersionName()
{
	# Return value:
	# 0 = function call is successful 
	# 1 = function call failed
	# 2 = RES_LIST_PROCFILE does not exists or is zero-sized

	local IN_API_RES=$(echo "$1" | $AWK '{ print tolower($0) }')
	local IN_API_RES_FOUND=1

	if [ -s $RES_LIST_PROCFILE ]
	then
		local PROC_CMD="$AWK -F'|' 'BEGIN { MATCH_FOUND=\"false\" } { API_NAME=\$1; API_LONGNAMES=\$2; API_SHORTNAMES=\$3; API_KIND=\$4; API_KIND_ORIG=\$5; API_NAMESPACED=\$6; API_GROUPNAME=\$7; if ( API_NAME ~ /^"$IN_API_RES"$/ || API_KIND ~ /^"$IN_API_RES"$/ ) { print API_GROUPNAME; MATCH_FOUND=\"true\"; exit 0 } else { split(API_SHORTNAMES, SN, \",\"); for (i in SN) { if ( SN[i] ~ /^"$IN_API_RES"$/ ) { print API_GROUPNAME; MATCH_FOUND=\"true\"; exit 0 } }; split(API_LONGNAMES, LN, \",\"); for (i in LN) { if ( LN[i] ~ /^"$IN_API_RES"$/ ) { print API_GROUPNAME; MATCH_FOUND=\"true\"; exit 0 } } } } END { if ( MATCH_FOUND == \"false\" ) { print \"\"; exit 1 } } ' $RES_LIST_PROCFILE"

		API_VER_TMP_RESULT=$(eval "$PROC_CMD")
		API_VER_EXIT_CODE=$?
		
 		if [ $MG_DEBUG == "true" ]
 		then
 			echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] PROC_CMD = [$PROC_CMD]" >&2
			echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] API_VER_TMP_RESULT = [$API_VER_TMP_RESULT] / API_VER_EXIT_CODE = [$API_VER_EXIT_CODE]" >&2
 		fi

#		# For test only
#		if [ $(echo "$API_VER_TMP_RESULT" | $AWK -F/ '{ print NF }') -gt 1 ]
#		then
#			API_VER_TMP_RESULT=$(echo "$API_VER_TMP_RESULT" | sed 's#/.*##')
#		else
#			if [[ "$API_VER_TMP_RESULT" =~ ^v[0-9]+$ ]]
#			then
#				API_VER_TMP_RESULT=""
#
#				if [ $IN_API_RES == "pod" ]
#				then
#					echo "abc123"
#					return 0
#				fi
#			fi 
#		fi
#
#		echo "[$(date)] [${FUNCNAME[0]}] [TEST] API_VER_TMP_RESULT = [$API_VER_TMP_RESULT]" >&2

		if [ ${#API_VER_TMP_RESULT} -gt 0 ]
		then
			if [ $(echo "$API_VER_TMP_RESULT" | $AWK -F/ '{ print NF }') -gt 1 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Return value = [apis/$API_VER_TMP_RESULT]" >&2
				echo "apis/$API_VER_TMP_RESULT"
			else
				if [[ "$API_VER_TMP_RESULT" =~ ^v[0-9]+$ ]] 
				then
					echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Return value = [api/$API_VER_TMP_RESULT]" >&2
					echo "api/$API_VER_TMP_RESULT"
				else
					if [ $CREATE_API_LIST == "true" ]
					then
						# Try best effort to determine API group's prefix and version
						local PROC_CMD="$AWK -F'|' 'BEGIN { MATCH_FOUND=\"false\" } { API_NAME=\$1; API_LONGNAMES=\$2; API_SHORTNAMES=\$3; API_KIND=\$4; API_KIND_ORIG=\$5; API_NAMESPACED=\$6; API_GROUPNAME=\$7; API_PRIORITY=\$8; if ( API_NAME ~ /^"$IN_API_RES"$/ || API_KIND ~ /^"$IN_API_RES"$/ ) { print API_PRIORITY; MATCH_FOUND=\"true\"; exit 0 } else { split(API_SHORTNAMES, SN, \",\"); for (i in SN) { if ( SN[i] ~ /^"$IN_API_RES"$/ ) { print API_PRIORITY; MATCH_FOUND=\"true\"; exit 0 } }; split(API_LONGNAMES, LN, \",\"); for (i in LN) { if ( LN[i] ~ /^"$IN_API_RES"$/ ) { print API_PRIORITY; MATCH_FOUND=\"true\"; exit 0 } } } } END { if ( MATCH_FOUND == \"false\" ) { print \"\"; exit 1 } } ' $RES_LIST_PROCFILE"
						local APIGROUP_PRIORITY=$(eval "$PROC_CMD")
			
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] APIGROUP_PRIORITY = [$APIGROUP_PRIORITY]" >&2
						fi
			
						if [ ${#APIGROUP_PRIORITY} -eq 0 ]
						then
							# Best effort failed!
							echo "$API_VER_TMP_RESULT"
							return 1
						else
							if [ ${APIGROUP_PRIORITY} -eq 0 ]
							then
								# Common k8s resource types (eg. pods)
								local APIGROUP_GREP_PATTERN="_api[_.]"
							else
								local APIGROUP_GREP_PATTERN="$API_VER_TMP_RESULT"
							fi
						fi
			
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] APIGROUP_GREP_PATTERN = [$APIGROUP_GREP_PATTERN]" >&2
						fi
			
						local APIGROUP_LARGEST_FILE=
						local APIGROUP_LARGEST_FILESIZE=
			
						# Dumb method to decide which reference file to pick (we pick the largest file!)
						for APIGROUP in $(ls $RES_LIST_OUTDIR | grep "$APIGROUP_GREP_PATTERN")
						do
							if [ ${APIGROUP_PRIORITY} -ne 0 ]
							then
								local APIGROUP_MATCH=$(echo "$APIGROUP" | sed 's/.out$//' | $AWK -F_ '{ print $3 }')
	
								if [ "$APIGROUP_MATCH" != "$API_VER_TMP_RESULT" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] File [$APIGROUP] does not match API group [$API_VER_TMP_RESULT] [MATCH PATTERN = $APIGROUP_MATCH]! Skipping..." >&2
									continue
								fi
							fi
	
							local APIGROUP_FILESIZE=$(ls -l $RES_LIST_OUTDIR/$APIGROUP | $AWK '{ print $5 }')
			
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] File size of [$RES_LIST_OUTDIR/$APIGROUP] = [$APIGROUP_FILESIZE]" >&2
							fi
			
							if [ ${#APIGROUP_FILESIZE} -gt 0 ] && [[ $APIGROUP_FILESIZE =~ ^[0-9]+$ ]]
							then
								if [ ${#APIGROUP_LARGEST_FILE} -eq 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Setting file [$APIGROUP] as largest file..." >&2
									local APIGROUP_LARGEST_FILE=$APIGROUP
									local APIGROUP_LARGEST_FILESIZE=$APIGROUP_FILESIZE
								else
									if [ $APIGROUP_FILESIZE -gt $APIGROUP_LARGEST_FILESIZE ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Setting file [$APIGROUP] as largest file..." >&2
										local APIGROUP_LARGEST_FILE=$APIGROUP
										local APIGROUP_LARGEST_FILESIZE=$APIGROUP_FILESIZE
									fi
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Invalid fils size [$APIGROUP_FILESIZE] for file [$RES_LIST_OUTDIR/$APIGROUP]! Skipping..." >&2
							fi
						done
	
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] APIGROUP_LARGEST_FILE = [$APIGROUP_LARGEST_FILE] / APIGROUP_LARGEST_FILESIZE = [$APIGROUP_LARGEST_FILESIZE]" >&2
						fi
			
						if [ ${#APIGROUP_LARGEST_FILE} -eq 0 ]
						then
							# Best effort failed!
							echo "$API_VER_TMP_RESULT"
							return 1
						else
							if [ $APIGROUP_PRIORITY -eq 0 ]
							then
								local APIGROUP_PREFIX=$(echo "$APIGROUP_LARGEST_FILE" | sed 's/.out$//' | $AWK -F_ '{ print $2 }')
								local APIGROUP_VERSION==$(echo "$APIGROUP_LARGEST_FILE" | sed 's/.out$//' | $AWK -F_ '{ print $3 }')
							else
								local APIGROUP_PREFIX=$(echo "$APIGROUP_LARGEST_FILE" | sed 's/.out$//' | $AWK -F_ '{ print $2 }')
								local APIGROUP_VERSION=$(echo "$APIGROUP_LARGEST_FILE" | sed 's/.out$//' | $AWK -F_ '{ print $4 }')
							fi
			
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Priority for resource [$IN_API_RES] = [$APIGROUP_PRIORITY]" >&2
	
								if [ $APIGROUP_PRIORITY -eq 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] APIGROUP_PREFIX = [$APIGROUP_PREFIX] / APIGROUP_VERSION = [$APIGROUP_VERSION]" >&2
								else
									echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] APIGROUP_PREFIX = [$APIGROUP_PREFIX] / APIGROUP_NAME = [${API_VER_TMP_RESULT}] / APIGROUP_VERSION = [$APIGROUP_VERSION]" >&2
								fi
							fi
								
							if [ ${#APIGROUP_PREFIX} -eq 0 ] || [ ${#APIGROUP_VERSION} -eq 0 ]
							then
								# Best effort failed!
								echo "$API_VER_TMP_RESULT"
								return 1
							else
								if [ $APIGROUP_PRIORITY -eq 0 ]
								then
									echo "${APIGROUP_PREFIX}/${APIGROUP_VERSION}"
								else
									echo "${APIGROUP_PREFIX}/${API_VER_TMP_RESULT}/${APIGROUP_VERSION}"
								fi
			
								return 0
							fi
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] CREATE_API_LIST is disabled [$CREATE_API_LIST]! Returning value [$API_VER_TMP_RESULT]..." >&2
						echo "$API_VER_TMP_RESULT"
						return 1
					fi
				fi
			fi	
		else
			if [ $CREATE_API_LIST == "true" ]
			then
				# Assume the empty API_GROUPNAME means common k8s resource types (eg. pods)
				local APIGROUP_LARGEST_FILE=
				local APIGROUP_LARGEST_FILESIZE=
	
				# Dumb method to decide which reference file to pick (we pick the largest file!)
				for APIGROUP in $(ls $RES_LIST_OUTDIR | grep '_api[_.]')
				do
					local APIGROUP_FILESIZE=$(ls -l $RES_LIST_OUTDIR/$APIGROUP | $AWK '{ print $5 }')
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] File size of [$RES_LIST_OUTDIR/$APIGROUP] = [$APIGROUP_FILESIZE]" >&2
					fi
	
					if [ ${#APIGROUP_FILESIZE} -gt 0 ] && [[ $APIGROUP_FILESIZE =~ ^[0-9]+$ ]]
					then
						if [ ${#APIGROUP_LARGEST_FILE} -eq 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Setting file [$APIGROUP] as largest file..." >&2
							local APIGROUP_LARGEST_FILE=$APIGROUP
							local APIGROUP_LARGEST_FILESIZE=$APIGROUP_FILESIZE
						else
							if [ $APIGROUP_FILESIZE -gt $APIGROUP_LARGEST_FILESIZE ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Setting file [$APIGROUP] as largest file..." >&2
								local APIGROUP_LARGEST_FILE=$APIGROUP
								local APIGROUP_LARGEST_FILESIZE=$APIGROUP_FILESIZE
							fi
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Invalid fils size [$APIGROUP_FILESIZE] for file [$RES_LIST_OUTDIR/$APIGROUP]! Skipping..." >&2
					fi
				done
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] APIGROUP_LARGEST_FILE = [$APIGROUP_LARGEST_FILE] / APIGROUP_LARGEST_FILESIZE = [$APIGROUP_LARGEST_FILESIZE]" >&2
				fi
	
				if [ ${#APIGROUP_LARGEST_FILE} -eq 0 ]
				then
					# Best effort failed!
					echo "$API_VER_TMP_RESULT"
					return 1
				else
					local APIGROUP_PREFIX=$(echo "$APIGROUP_LARGEST_FILE" | sed 's/.out$//' | $AWK -F_ '{ print $2 }')
					local APIGROUP_VERSION=$(echo "$APIGROUP_LARGEST_FILE" | sed 's/.out$//' | $AWK -F_ '{ print $3 }')
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] Priority for resource [$IN_API_RES] = [$APIGROUP_PRIORITY]" >&2
						echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] APIGROUP_PREFIX = [$APIGROUP_PREFIX] / APIGROUP_VERION = [$APIGROUP_VERSION]" >&2
					fi
								
					if [ ${#APIGROUP_PREFIX} -eq 0 ] || [ ${#APIGROUP_VERSION} -eq 0 ]
					then
						# Best effort failed!
						echo "$API_VER_TMP_RESULT"
						return 1
					else
						echo "${APIGROUP_PREFIX}/${APIGROUP_VERSION}"
						return 0
					fi
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] [IN_API_RES=$IN_API_RES] CREATE_API_LIST is disabled [$CREATE_API_LIST]! Returning value [$API_VER_TMP_RESULT]..." >&2
				echo "$API_VER_TMP_RESULT"
				return 1
			fi
		fi

		return $API_VER_EXIT_CODE
	else
		return 2
	fi
}

getApiName()
{
	# Return value:
	# 0 = function call is successful 
	# 1 = function call failed
	# 2 = RES_LIST_PROCFILE does not exists or is zero-sized

	local IN_API_RES=$(echo "$1" | $AWK '{ print tolower($0) }')
	local IN_API_RES_FOUND=1

	if [ -s $RES_LIST_PROCFILE ]
	then
		local PROC_CMD="$AWK -F'|' 'BEGIN { MATCH_FOUND=\"false\" } { API_NAME=\$1; API_LONGNAMES=\$2; API_SHORTNAMES=\$3; API_KIND=\$4; API_KIND_ORIG=\$5; API_NAMESPACED=\$6; API_GROUPNAME=\$7; if ( API_NAME ~ /^"$IN_API_RES"$/ || API_KIND ~ /^"$IN_API_RES"$/ ) { print API_NAME; MATCH_FOUND=\"true\"; exit 0 } else { split(API_SHORTNAMES, SN, \",\"); for (i in SN) { if ( SN[i] ~ /^"$IN_API_RES"$/ ) { print API_NAME; MATCH_FOUND=\"true\"; exit 0 } }; split(API_LONGNAMES, LN, \",\"); for (i in LN) { if ( LN[i] ~ /^"$IN_API_RES"$/ ) { print API_NAME; MATCH_FOUND=\"true\"; exit 0 } } } } END { if ( MATCH_FOUND == \"false\" ) { print \"\"; exit 1 } } ' $RES_LIST_PROCFILE"

 		if [ $MG_DEBUG == "true" ]
 		then
 			echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD = [$PROC_CMD]" >&2
 		fi

		eval "$PROC_CMD"
		return $?
	else
		return 2
	fi
}

getApiKind()
{
	# Return value:
	# 0 = function call is successful 
	# 1 = function call failed
	# 2 = RES_LIST_PROCFILE does not exists or is zero-sized

	local IN_API_RES=$(echo "$1" | $AWK '{ print tolower($0) }')
	local IN_API_RES_FOUND=1

	if [ -s $RES_LIST_PROCFILE ]
	then
		local PROC_CMD="$AWK -F'|' 'BEGIN { MATCH_FOUND=\"false\" } { API_NAME=\$1; API_LONGNAMES=\$2; API_SHORTNAMES=\$3; API_KIND=\$4; API_KIND_ORIG=\$5; API_NAMESPACED=\$6; API_GROUPNAME=\$7; if ( API_NAME ~ /^"$IN_API_RES"$/ || API_KIND ~ /^"$IN_API_RES"$/ ) { print API_KIND_ORIG; MATCH_FOUND=\"true\"; exit 0 } else { split(API_SHORTNAMES, SN, \",\"); for (i in SN) { if ( SN[i] ~ /^"$IN_API_RES"$/ ) { print API_KIND_ORIG; MATCH_FOUND=\"true\"; exit 0 } }; split(API_LONGNAMES, LN, \",\"); for (i in LN) { if ( LN[i] ~ /^"$IN_API_RES"$/ ) { print API_KIND_ORIG; MATCH_FOUND=\"true\"; exit 0 } } } } END { if ( MATCH_FOUND == \"false\" ) { print \"\"; exit 1 } } ' $RES_LIST_PROCFILE"

 		if [ $MG_DEBUG == "true" ]
 		then
 			echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD = [$PROC_CMD]" >&2
 		fi

		eval "$PROC_CMD"
		return $?
	else
		return 2
	fi
}

ocGet()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local OBJTYPE=$1
	local OC_OUTFILE=$2
	local NAMESPACE=$3

	if [ ! -d $(dirname $OC_OUTFILE) ]
	then
		mkdir -p $(dirname $OC_OUTFILE)
	fi

	if [ ${#NAMESPACE} -gt 0 ] 
	then
		if [ $NAMESPACE == "ALLNS" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

			if ! checkUserPriv get $OBJTYPE all
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have verb [get] permission on resource [$OBJTYPE] in all namespaces! Skipping..."
				return 1
			fi

			local NS_CMD="-A"
		else
			echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

			if ! checkUserPriv get $OBJTYPE $NAMESPACE
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have verb [get] permission on resource [$OBJTYPE] in namespace [$NAMESPACE]! Skipping..."
				return 1
			fi

			local NS_CMD="-n $NAMESPACE"
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

		if ! checkUserPriv get $OBJTYPE all
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have verb [get] permission on resource [$OBJTYPE] in all namespaces! Skipping..."
			return 1
		fi
	fi

	if [ ${#NAMESPACE} -gt 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get $OBJTYPE -o wide $NS_CMD' => $OC_OUTFILE"
		local CMD="$OC_CMD get $OBJTYPE -o wide $NS_CMD" 
		eval "$CMD" > $OC_OUTFILE 2>&1
	else
		# For cluster scope objects
		echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get $OBJTYPE -o wide' => $OC_OUTFILE"
		$OC_CMD get $OBJTYPE -o wide > $OC_OUTFILE 2>&1
	fi

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [NS=$NAMESPACE / OBJTYPE=$OBJTYPE]"
	fi
}

ocDesc()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	if [ $OC_DESC_ON == "false" ] && [ $COLLECT_YAML == "false" ] && [ $COLLECT_JSON == "false" ] && [ $GET_POD_LOGS == "false" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] '$OC_CMD describe', '$OC_CMD get -o yaml', '$OC_CMD get -o json' and '$OC_CMD logs' are disabled. Returning..."
		return 1
	fi

	# For namespace-scoped resource, provide OBJTYPE, F_OUTDIR and NAMESPACE
	# For cluster-scoped resource, provide OBJTYPE and F_OUTDIR
	# To collect data for namespace-scoped resource in ALL namespaces, provide OBJTYPE, F_OUTDIR and set NAMESPACE="ALLNS"
	local OBJTYPE=$1
	local F_OUTDIR=$2
	local NAMESPACE=$3
	local OUTFILE=$F_OUTDIR/ocDesc_$OBJTYPE.$$.tmp
	local CONTAINER=
	local LINE=

	if isRestrictedData "$OBJTYPE"
	then
		echo "[$(date)] [${FUNCNAME[0]}] Resource type [$OBJTYPE] is restricteded! Returning..."
		return 1
	fi

	if [[ ! "$F_OUTDIR" =~ "$OUTDIR" ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] User input F_OUTDIR [$F_OUTDIR] is not available under OUTDIR [$OUTDIR]! Returning..."
		return 1
	fi
		
	# Do not perform 'oc describe' on resource 'events/event/ev'
	local OBJTYPE_LC=$(echo "$OBJTYPE" | $AWK '{ print tolower($0) }')
		
	if [ $OBJTYPE_LC == "events" ] || [ $OBJTYPE_LC == "event" ] || [ $OBJTYPE_LC == "ev" ] || [ $OBJTYPE_LC == "event.events.k8s.io" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] OBJTYPE is [$OBJTYPE]. Operation 'oc describe' is not supported. Returning..."
		return 1
	fi

	if [ ${#NAMESPACE} -gt 0 ] 
	then
		if [ $NAMESPACE == "ALLNS" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

			if ! checkUserPriv get $OBJTYPE all
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have verb [get] permission on resource [$OBJTYPE] in all namespaces! Skipping..."
				return 1
			fi

			local NS_CMD="-A"
			local NAMESPACE_STR="all-namespaces"
		else
			echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

			if ! checkUserPriv get $OBJTYPE $NAMESPACE
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have verb [get] permission on resource [$OBJTYPE] in namespace [$NAMESPACE]! Skipping..."
				return 1
			fi

			local NS_CMD="-n $NAMESPACE"
			local NAMESPACE_STR="$NAMESPACE"
		fi

		local EXEC_CMD="$OC_CMD get $OBJTYPE $NS_CMD"
	else
		local EXEC_CMD="$OC_CMD get $OBJTYPE" 
		local NAMESPACE_STR=""
	fi

	if [ ! -d $F_OUTDIR ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Making directory [$F_OUTDIR]..."
		mkdir -p $F_OUTDIR
	fi

	# To determine whether OBJTYPE is sensitive data
	if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ] || [ $GET_POD_LOGS == "true" ]
	then
		local TO_PROCEED_YAML="false"
		local TO_PROCEED_JSON="false"
		local TO_PROCEED_LOGS="false"

		if isSensitiveData "$OBJTYPE"
		then
			if [	$IS_SENSITIVE_DATA_ALLOWED != "true" ]
			then		
				if [ $OBJTYPE == "po" ] || [ $OBJTYPE == "pod" ] || [ $OBJTYPE == "pods" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] ocDesc() function does not support '$OC_CMD get -o yaml/json' and '$OC_CMD logs' of [$OBJTYPE] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				else	
					echo "[$(date)] [${FUNCNAME[0]}] ocDesc() function does not support '$OC_CMD get -o yaml/json' of [$OBJTYPE] without explicit approval IS_SENSITIVE_DATA_ALLOWED (-S)!"
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] Explicit approval IS_SENSITIVE_DATA_ALLOWED (-S) is enabled for resource type [$OBJTYPE]!"
				local TO_PROCEED_YAML="true"
				local TO_PROCEED_JSON="true"
				local TO_PROCEED_LOGS="true"
			fi
		else
			local TO_PROCEED_YAML="true"
			local TO_PROCEED_JSON="true"
			local TO_PROCEED_LOGS="true"
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing command '$EXEC_CMD' to obtain resource instances..."
	fi

	eval "$EXEC_CMD" > $OUTFILE

	if [ -s $OUTFILE ]
	then
		local FIRSTLINE="true"
		local NAMESPACE_OUTPUT="false"
		local LC_OBJTYPE=$(echo "$OBJTYPE" | $AWK '{ print tolower($0) }')
		local OC_APIVERSION_NAME=$(getApiVersionName $OBJTYPE)
		local OC_API_NAME=$(getApiName $OBJTYPE)
		local OC_API_KIND=$(getApiKind $OBJTYPE)
		local OC_API_IS_NAMESPACED=$(isNamespaced $OBJTYPE)
		local FAST_OC_DESC_WORKFILE=$F_OUTDIR/fast_oc_desc.$LC_OBJTYPE.tmp
		local FAST_OC_YAML_WORKFILE=$F_OUTDIR/fast_oc_yaml.$LC_OBJTYPE.tmp

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] LC_OBJTYPE = [$LC_OBJTYPE] / OC_API_NAME = [$OC_API_NAME] / OC_API_KIND = [$OC_API_KIND] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME] / OC_API_IS_NAMESPACED = [$OC_API_IS_NAMESPACED]"
		fi

		if [ $COLLECT_YAML == "true" ] && [ $FAST_OC_YAML == "true" ]
		then
			local TOTAL_OBJ=$(grep -v '^NAME' $OUTFILE | grep -E -vi '^I051|throttling request' | wc -l)

			if [ ${TOTAL_OBJ} -ge ${FAST_OC_YAML_PREREQ} ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$OBJTYPE] has met minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
				local FAST_OC_YAML_WORTHY="true"
			else
				echo "[$(date)] [${FUNCNAME[0]}] TOTAL_OBJ [$TOTAL_OBJ] for resource type [$OBJTYPE] did not meet minimum FAST_OC_YAML requirement [$FAST_OC_YAML_PREREQ]!"
				local FAST_OC_YAML_WORTHY="false"
			fi
		fi
	
		grep -E -vi '^I051|throttling request' $OUTFILE | while read LINE 
		do
			if [ $FIRSTLINE == "true" ] && [[ ! $LINE =~ ^NAME ]]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Command [$EXEC_CMD] output [LINE = $LINE] is invalid! Returning..."
				return 1
			fi

			if [ $FIRSTLINE == "true" ]
			then
				if [ $(echo "$LINE" | $AWK '{ print $1 }') == "NAMESPACE" ]
				then
					local NAMESPACE_OUTPUT="true"
				fi

				local FIRSTLINE="false"
			else
				if [ $NAMESPACE_OUTPUT == "true" ]
				then
					local NSNAME=$(echo "$LINE" | $AWK '{ print $1 }')
					local OBJNAME=$(echo "$LINE" | $AWK '{ print $2 }')	
					local NAMESPACE_CMD="-n $NSNAME"
					local MY_OUTDIR=$F_OUTDIR/$NSNAME
				else
					if [ ${#NAMESPACE} -gt 0 ]
					then
						if [ $NAMESPACE == "ALLNS" ]
						then
							local NSNAME=""
							local OBJNAME=$(echo "$LINE" | $AWK '{ print $1 }')	
							local NAMESPACE_CMD=""
							local MY_OUTDIR=$F_OUTDIR
						else
							local NSNAME=$NAMESPACE
							local OBJNAME=$(echo "$LINE" | $AWK '{ print $1 }')	
							local NAMESPACE_CMD="-n $NSNAME"
							local MY_OUTDIR=$F_OUTDIR
						fi
					else
						local NSNAME=""
						local OBJNAME=$(echo "$LINE" | $AWK '{ print $1 }')	
						local NAMESPACE_CMD=""
						local MY_OUTDIR=$F_OUTDIR
					fi
				fi				

				if [ ! -d $MY_OUTDIR ]
				then
					mkdir -p $MY_OUTDIR
				fi

				if [ $OC_DESC_ON == "true" ]
				then
					if [ $FAST_OC_DESC == "true" ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$NSNAME##$OBJTYPE##$MY_OUTDIR] => $FAST_OC_DESC_WORKFILE"
						fi

						echo "$NSNAME##$OBJTYPE##$MY_OUTDIR" >> $FAST_OC_DESC_WORKFILE 
					else
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe $NAMESPACE_CMD $OBJTYPE $OBJNAME' => $MY_OUTDIR/$OBJNAME.desc"
						local DESC_CMD="$OC_CMD describe $NAMESPACE_CMD $OBJTYPE $OBJNAME"
						eval "$DESC_CMD" > $MY_OUTDIR/$OBJNAME.desc 2>&1
					fi
				fi

				if [ $COLLECT_YAML == "true" ] && [ $TO_PROCEED_YAML == "true" ]
				then
					if [ ${FAST_OC_YAML} == "true" ] && [ ${FAST_OC_YAML_WORTHY} == "true" ]
					then
						if [ $FAST_OC == "true" ] 
						then
							if [ $OC_API_IS_NAMESPACED -eq 0 ]
							then
								if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
								then
									local YAML_CURL_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/$OC_API_NAME/$OBJNAME"
								else
									local YAML_CURL_CMD=""
								fi
							else
								if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
								then
									local YAML_CURL_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$OBJNAME"
								else
									local YAML_CURL_CMD=""
								fi
							fi
						else
							local YAML_CURL_CMD=""
						fi

						# To create fallback reference file for FAST_OC_YAML
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Writing new line [$NSNAME##$OBJTYPE##$OBJNAME##$MY_OUTDIR##$YAML_CURL_CMD] => $FAST_OC_YAML_WORKFILE"
						fi
				
						echo "$NSNAME##$OBJTYPE##$OBJNAME##$MY_OUTDIR##$YAML_CURL_CMD" >> $FAST_OC_YAML_WORKFILE
					else
						if [ $FAST_OC == "true" ] 
						then
							if [ ${#OC_API_IS_NAMESPACED} -gt 0 ]
							then
								if [ $OC_API_IS_NAMESPACED -eq 0 ]
								then
									case $OBJTYPE in
										cm|configmap|configmaps)		
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/configmaps/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/configmaps/$OBJNAME'"
											;;	
										deploy|deployment|deployments|deployment.apps)
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/deployments/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/deployments/$OBJNAME'"
											;;
										role|roles|role.rbac.authorization.k8s.io|roles.rbac.authorization.k8s.io)	
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/roles/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/roles/$OBJNAME'"
											;;
										rolebinding|rolebindings|rolebinding.rbac.authorization.k8s.io|rolebindings.rbac.authorization.k8s.io)
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/rolebindings/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/rolebindings/$OBJNAME'"
											;;
										sa|serviceaccount|serviceaccounts)
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/serviceaccounts/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/serviceaccounts/$OBJNAME'"
											;;
										po|pod|pods)
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/pods/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/pods/$OBJNAME'"
											;;
										pvc|persistentvolumeclaim|persistentvolumeclaims)
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/persistentvolumeclaims/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/persistentvolumeclaims/$OBJNAME'"
											;;
										route|routes|route.route.openshift.io)
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/routes/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/routes/$OBJNAME'"
											;;
										rs|replicaset|replicasets|replicaset.apps)
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/replicasets/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/replicasets/$OBJNAME'"
											;;
										sts|statefulset|statefulsets|statefulset.apps)
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/statefulsets/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/statefulsets/$OBJNAME'"
											;;
										svc|service|services)
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/services/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
											local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/services/$OBJNAME'"
											;;
										*)		
											if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/$OC_API_NAME/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
												local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/$OC_API_NAME/$OBJNAME"
											else
												if [ $MG_DEBUG == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] OBJTYPE = [$OBJTYPE] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME] / OC_API_NAME = [$OC_API_NAME]"
												fi
		
												if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
												then
													local YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
												else
													local YAML_CMD="$OC_CMD get -o yaml $NAMESPACE_CMD $OBJTYPE $OBJNAME"
												fi
					
												echo "[$(date)] [${FUNCNAME[0]}] Executing '$YAML_CMD' => $MY_OUTDIR/$OBJNAME.yaml"
											fi
											;;
									esac
								else
									if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$OBJNAME' => $MY_OUTDIR/$OBJNAME.yaml"
										local YAML_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_YAML_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$OBJNAME"
									else
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] OBJTYPE = [$OBJTYPE] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME] / OC_API_NAME = [$OC_API_NAME]"
										fi
		
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
										then
											local YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
										else
											local YAML_CMD="$OC_CMD get -o yaml $NAMESPACE_CMD $OBJTYPE $OBJNAME"
										fi
									fi
								fi
		
								eval "$YAML_CMD" > $MY_OUTDIR/$OBJNAME.yaml 2>&1
	
								if [ -s $MY_OUTDIR/$OBJNAME.yaml ]
								then
									if ( [[ $(head -1 $MY_OUTDIR/$OBJNAME.yaml) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $MY_OUTDIR/$OBJNAME.yaml) =~ \"paths\": ]] ) || [[ $(head -1 $MY_OUTDIR/$OBJNAME.yaml) =~ ^404 ]] || [[ $(head -1 $MY_OUTDIR/$OBJNAME.yaml) =~ "Moved Permanently" ]] 
									then
										echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
	
										if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
										then
											local YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
										else
											local YAML_CMD="$OC_CMD get -o yaml $NAMESPACE_CMD $OBJTYPE $OBJNAME"
										fi
					
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$YAML_CMD' => $MY_OUTDIR/$OBJNAME.yaml"
										eval "$YAML_CMD" > $MY_OUTDIR/$OBJNAME.yaml 2>&1
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										local YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
									else
										local YAML_CMD="$OC_CMD get -o yaml $NAMESPACE_CMD $OBJTYPE $OBJNAME"
									fi
					
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$YAML_CMD' => $MY_OUTDIR/$OBJNAME.yaml"
									eval "$YAML_CMD" > $MY_OUTDIR/$OBJNAME.yaml 2>&1
								fi	
							else
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] OBJTYPE = [$OBJTYPE] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME] / OC_API_NAME = [$OC_API_NAME]"
								fi
	
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
								then
									local YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
								else
									local YAML_CMD="$OC_CMD get -o yaml $NAMESPACE_CMD $OBJTYPE $OBJNAME"
								fi
			
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$YAML_CMD' => $MY_OUTDIR/$OBJNAME.yaml"
								eval "$YAML_CMD" > $MY_OUTDIR/$OBJNAME.yaml 2>&1
							fi	
						else
							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
							then
								local YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
							else
								local YAML_CMD="$OC_CMD get -o yaml $NAMESPACE_CMD $OBJTYPE $OBJNAME"
							fi
	
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$YAML_CMD' => $MY_OUTDIR/$OBJNAME.yaml"
							eval "$YAML_CMD" > $MY_OUTDIR/$OBJNAME.yaml 2>&1
						fi
					fi
				fi

				if [ $COLLECT_JSON == "true" ] && [ $TO_PROCEED_JSON == "true" ]
				then
					if [ $FAST_OC == "true" ] 
					then
						if [ ${#OC_API_IS_NAMESPACED} -gt 0 ]
						then
							if [ $OC_API_IS_NAMESPACED -eq 0 ]
							then
								case $OBJTYPE in
									cm|configmap|configmaps)		
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/configmaps/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/configmaps/$OBJNAME'"
										;;	
									deploy|deployment|deployments|deployment.apps)
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/deployments/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/deployments/$OBJNAME'"
										;;
									role|roles|role.rbac.authorization.k8s.io|roles.rbac.authorization.k8s.io)	
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/roles/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/roles/$OBJNAME'"
										;;
									rolebinding|rolebindings|rolebinding.rbac.authorization.k8s.io|rolebindings.rbac.authorization.k8s.io)
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/rolebindings/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/rolebindings/$OBJNAME'"
										;;
									sa|serviceaccount|serviceaccounts)
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/serviceaccounts/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/serviceaccounts/$OBJNAME'"
										;;
									po|pod|pods)
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/pods/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/pods/$OBJNAME'"
										;;
									pvc|persistentvolumeclaim|persistentvolumeclaims)
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/persistentvolumeclaims/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/persistentvolumeclaims/$OBJNAME'"
										;;
									route|routes|route.route.openshift.io)
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/routes/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/routes/$OBJNAME'"
										;;
									rs|replicaset|replicasets|replicaset.apps)
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/replicasets/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/replicasets/$OBJNAME'"
										;;
									sts|statefulset|statefulsets|statefulset.apps)
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/statefulsets/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/statefulsets/$OBJNAME'"
										;;
									svc|service|services)
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/services/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
										local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/services/$OBJNAME'"
										;;
									*)		
										if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/$OC_API_NAME/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
											local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NSNAME/$OC_API_NAME/$OBJNAME"
										else
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] OBJTYPE = [$OBJTYPE] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME] / OC_API_NAME = [$OC_API_NAME]"
											fi
	
											if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
											then
												local JSON_CMD="$OC_CMD get -o json --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
											else
												local JSON_CMD="$OC_CMD get -o json $NAMESPACE_CMD $OBJTYPE $OBJNAME"
											fi
				
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$JSON_CMD' => $MY_OUTDIR/$OBJNAME.json"
										fi
										;;
								esac
							else
								if [ ${#OC_APIVERSION_NAME} -gt 0 ] && [ ${#OC_API_NAME} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$OBJNAME' => $MY_OUTDIR/$OBJNAME.json"
									local JSON_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_JSON_HEADER $OC_HEADER $OC_APISVR/$OC_APIVERSION_NAME/$OC_API_NAME/$OBJNAME"
								else
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] OBJTYPE = [$OBJTYPE] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME] / OC_API_NAME = [$OC_API_NAME]"
									fi
	
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										local JSON_CMD="$OC_CMD get -o json --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
									else
										local JSON_CMD="$OC_CMD get -o json $NAMESPACE_CMD $OBJTYPE $OBJNAME"
									fi
								fi
							fi
	
							eval "$JSON_CMD" > $MY_OUTDIR/$OBJNAME.json 2>&1

							if [ -s $MY_OUTDIR/$OBJNAME.yaml ]
							then
								if ( [[ $(head -1 $MY_OUTDIR/$OBJNAME.json) =~ ^\{ ]] && [[ $($AWK 'NR==2 { print }' $MY_OUTDIR/$OBJNAME.json) =~ \"paths\": ]] ) || [[ $(head -1 $MY_OUTDIR/$OBJNAME.json) =~ ^404 ]] || [[ $(head -1 $MY_OUTDIR/$OBJNAME.json) =~ "Moved Permanently" ]]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."

									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										local JSON_CMD="$OC_CMD get -o json --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
									else
										local JSON_CMD="$OC_CMD get -o json $NAMESPACE_CMD $OBJTYPE $OBJNAME"
									fi
				
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$JSON_CMD' => $MY_OUTDIR/$OBJNAME.json"
									eval "$JSON_CMD" > $MY_OUTDIR/$OBJNAME.json 2>&1
								fi
							else
								if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
								then
									local JSON_CMD="$OC_CMD get -o json --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
								else
									local JSON_CMD="$OC_CMD get -o json $NAMESPACE_CMD $OBJTYPE $OBJNAME"
								fi
				
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$JSON_CMD' => $MY_OUTDIR/$OBJNAME.json"
								eval "$JSON_CMD" > $MY_OUTDIR/$OBJNAME.json 2>&1
							fi
						else
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] OBJTYPE = [$OBJTYPE] / OC_APIVERSION_NAME = [$OC_APIVERSION_NAME] / OC_API_NAME = [$OC_API_NAME]"
							fi

							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
							then
								local JSON_CMD="$OC_CMD get -o json --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
							else
								local JSON_CMD="$OC_CMD get -o json $NAMESPACE_CMD $OBJTYPE $OBJNAME"
							fi
		
							echo "[$(date)] [${FUNCNAME[0]}] Executing '$JSON_CMD' => $MY_OUTDIR/$OBJNAME.json"
							eval "$JSON_CMD" > $MY_OUTDIR/$OBJNAME.json 2>&1
						fi	
					else
						if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
						then
							local JSON_CMD="$OC_CMD get -o json --show-managed-fields $NAMESPACE_CMD $OBJTYPE $OBJNAME"
						else
							local JSON_CMD="$OC_CMD get -o json $NAMESPACE_CMD $OBJTYPE $OBJNAME"
						fi
	
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$JSON_CMD' => $MY_OUTDIR/$OBJNAME.json"
						eval "$JSON_CMD" > $MY_OUTDIR/$OBJNAME.json 2>&1
					fi
				fi

				if [ $OBJTYPE == "po" ] || [ $OBJTYPE == "pod" ] || [ $OBJTYPE == "pods" ]
				then
					if [ $GET_POD_LOGS == "true" ] && [ $TO_PROCEED_LOGS == "true" ]
					then	
						local INIT_CONTAINER=
						local CONTAINER=

						IFS=$OLDIFS
						for INIT_CONTAINER in $($OC_CMD get pod $OBJNAME $NAMESPACE_CMD -o=jsonpath="{.spec.initContainers[*].name}")
						do 
							if [ $FAST_OC == "true" ] 
							then
								if [ ${#OC_APIVERSION_NAME} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$OBJNAME/log?container=${INIT_CONTAINER}${POD_LOG_TAILLINES_CURL_STR}' => $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log"
									local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$OBJNAME/log?container=${INIT_CONTAINER}${POD_LOG_TAILLINES_CURL_STR}'"
									eval "$CMD" > $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log 2>&1

									if [ ! -f $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log ] || [[ $(head -1 $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log) =~ ^"404 page not found" ]] || ( [[ $(head -1 $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log | wc -l) -gt 0 ] )
									then
										echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log"
										$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log 2>&1
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log"
									$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log 2>&1
								fi

								if [ $COLL_PREV_LOGS == "true" ]
								then
									if [ ${#OC_APIVERSION_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$OBJNAME/log?container=${INIT_CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}' => $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log.prev"
										local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$OBJNAME/log?container=${INIT_CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}'"
										eval "$CMD" > $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log.prev 2>&1

										if [ ! -f $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log.prev ] || [[ $(head -1 $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log.prev) =~ ^"404 page not found" ]] || ( [[ $(head -1 $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log.prev) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log.prev | wc -l) -gt 0 ] )
										then
											echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$$OBJNAME~$INIT_CONTAINER.log.prev"
											$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log.prev 2>&1
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$$OBJNAME~$INIT_CONTAINER.log.prev"
										$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log.prev 2>&1
									fi
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log"
								$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log 2>&1
			
								if [ $COLL_PREV_LOGS == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$$OBJNAME~$INIT_CONTAINER.log.prev"
									$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $INIT_CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$INIT_CONTAINER.log.prev 2>&1
								fi
							fi
						done

						for CONTAINER in $($OC_CMD get pod $OBJNAME $NAMESPACE_CMD -o=jsonpath="{.spec.containers[*].name}")
						do 
							if [ $FAST_OC == "true" ] 
							then
								if [ ${#OC_APIVERSION_NAME} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$OBJNAME/log?container=${CONTAINER}${POD_LOG_TAILLINES_CURL_STR}' => $MY_OUTDIR/$OBJNAME~$CONTAINER.log"
									local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$OBJNAME/log?container=${CONTAINER}${POD_LOG_TAILLINES_CURL_STR}'"
									eval "$CMD" > $MY_OUTDIR/$OBJNAME~$CONTAINER.log 2>&1

									if [ ! -f $MY_OUTDIR/$OBJNAME~$CONTAINER.log ] || [[ $(head -1 $MY_OUTDIR/$OBJNAME~$CONTAINER.log) =~ ^"404 page not found" ]] || ( [[ $(head -1 $MY_OUTDIR/$OBJNAME~$CONTAINER.log) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $MY_OUTDIR/$OBJNAME~$CONTAINER.log | wc -l) -gt 0 ] )
									then
										echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$OBJNAME~$CONTAINER.log"
										$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$CONTAINER.log 2>&1
									fi
								else
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$OBJNAME~$CONTAINER.log"
									$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$CONTAINER.log 2>&1
								fi

								if [ $COLL_PREV_LOGS == "true" ]
								then
									if [ ${#OC_APIVERSION_NAME} -gt 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER_FOR_ECHO $OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$OBJNAME/log?container=${CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}' => $MY_OUTDIR/$OBJNAME~$CONTAINER.log.prev"
										local CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER '$OC_APISVR/$OC_APIVERSION_NAME/namespaces/$NAMESPACE/pods/$OBJNAME/log?container=${CONTAINER}&previous=true${POD_LOG_TAILLINES_CURL_STR}'"
										eval "$CMD" > $MY_OUTDIR/$OBJNAME~$CONTAINER.log.prev 2>&1

										if [ ! -f $MY_OUTDIR/$OBJNAME~$CONTAINER.log.prev ] || [[ $(head -1 $MY_OUTDIR/$OBJNAME~$CONTAINER.log.prev) =~ ^"404 page not found" ]] || ( [[ $(head -1 $MY_OUTDIR/$OBJNAME~$CONTAINER.log.prev) =~ ^\{ ]] && [ $(grep 'message.*the server could not find the requested resource' $MY_OUTDIR/$OBJNAME~$CONTAINER.log.prev | wc -l) -gt 0 ] )
										then
											echo "[$(date)] [${FUNCNAME[0]}] Direct API call failed! Executing equivalent conventional '$OC_CMD' command..."
											echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$$OBJNAME~$CONTAINER.log.prev"
											$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$CONTAINER.log.prev 2>&1
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$$OBJNAME~$CONTAINER.log.prev"
										$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$CONTAINER.log.prev 2>&1
									fi
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$OBJNAME~$CONTAINER.log"
								$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$CONTAINER.log 2>&1
				
								if [ $COLL_PREV_LOGS == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR}' => $MY_OUTDIR/$$OBJNAME~$CONTAINER.log.prev"
									$OC_CMD logs $NAMESPACE_CMD $OBJNAME -c $CONTAINER -p ${POD_LOG_TAILLINES_OC_STR} > $MY_OUTDIR/$OBJNAME~$CONTAINER.log.prev 2>&1
								fi
							fi
						done
						IFS=$'\n'
					fi
				fi
			fi
		done 

		if [ $OC_DESC_ON == "true" ] && [ $FAST_OC_DESC == "true" ]
		then
			if [ -s $FAST_OC_DESC_WORKFILE ]
			then
				for LINE in $(cat $FAST_OC_DESC_WORKFILE | sort | uniq)
				do
					local FAST_OC_DESC_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
					local FAST_OC_DESC_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
					local FAST_OC_DESC_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')

					if [ ${#FAST_OC_DESC_NS} -gt 0 ]
					then
						local FAST_OC_DESC_TMPFILE=$FAST_OC_DESC_OUTDIR/fast_oc_desc.$FAST_OC_DESC_OBJTYPE.desc-all
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe $FAST_OC_DESC_OBJTYPE -n $FAST_OC_DESC_NS' => $FAST_OC_DESC_TMPFILE"
						$OC_CMD describe $FAST_OC_DESC_OBJTYPE -n $FAST_OC_DESC_NS > $FAST_OC_DESC_TMPFILE
					else
						local FAST_OC_DESC_TMPFILE=$FAST_OC_DESC_OUTDIR/fast_oc_desc.$FAST_OC_DESC_OBJTYPE.desc-all
						echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD describe $FAST_OC_DESC_OBJTYPE' => $FAST_OC_DESC_TMPFILE"
						$OC_CMD describe $FAST_OC_DESC_OBJTYPE > $FAST_OC_DESC_TMPFILE
					fi
	
					if [ -s $FAST_OC_DESC_TMPFILE ]
					then
						local RECORD_SEPARATOR_KEYWORD=$(head -1 $FAST_OC_DESC_TMPFILE | $AWK -F':' '{ print $1 }' | sed 's/[ ]*$//')
	
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] RECORD_SEPARATOR_KEYWORD = [$RECORD_SEPARATOR_KEYWORD]"
						fi
					
						if [ ${#RECORD_SEPARATOR_KEYWORD} ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Executing [sed '/^$/N;/^\n$/D;s/\(^\n\)${RECORD_SEPARATOR_KEYWORD}:/\1#@@@%@@@#\n${RECORD_SEPARATOR_KEYWORD}:/' $FAST_OC_DESC_TMPFILE | $AWK -v OUTDIR=$FAST_OC_DESC_OUTDIR 'BEGIN { RS=\"#@@@%@@@#\n\"; FS=\"\n\" } { OBJNAME=substr(\$1, index(\$1, \":\")+1); gsub(/^[ \t]*/, \"\", OBJNAME); gsub(/[\n]*$/, \"\", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR\"/\"OBJNAME\".desc\") } }]"
							sed '/^$/N;/^\n$/D;s/\(^\n\)'${RECORD_SEPARATOR_KEYWORD}':/\1#@@@%@@@#\n'${RECORD_SEPARATOR_KEYWORD}':/' $FAST_OC_DESC_TMPFILE | $AWK -v OUTDIR=$FAST_OC_DESC_OUTDIR 'BEGIN { RS="#@@@%@@@#\n"; FS="\n" } { OBJNAME=substr($1, index($1, ":")+1); gsub(/^[ \t]*/, "", OBJNAME); gsub(/[\n]*$/, "", $0); if ( length(OBJNAME) > 0 ) { print > (OUTDIR"/"OBJNAME".desc") } }'
						else
							echo "[$(date)] [${FUNCNAME[0]}] Unable to determine RECORD_SEPARATOR_KEYWORD for resource type [$RESTYPE] in namespace [$NAMESPACE]!"
						fi
	
						local TMP_DESC_ALL_KEEP="false"
						local SOURCE_COUNT=$(grep '^'$RECORD_SEPARATOR_KEYWORD':' $FAST_OC_DESC_TMPFILE | $AWK -F: 'NF>=2' | wc -l)
						local DESC_FILE_COUNT=$(ls -l $FAST_OC_DESC_OUTDIR/*.desc | wc -l)

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] DESC_FILE_COUNT = [$DESC_FILE_COUNT] / SOURCE_COUNT = [$SOURCE_COUNT]"
						fi
				
						if [ ${#DESC_FILE_COUNT} -gt 0 ] && [ ${#SOURCE_COUNT} -gt 0 ]
						then
							if [ $DESC_FILE_COUNT -ne $SOURCE_COUNT ]
							then
								local TMP_DESC_ALL_KEEP="true"
							fi
						else
							local TMP_DESC_ALL_KEEP="true"
						fi

						if [ $MG_DEBUG == "true" ]
						then
							if [ ${#FAST_OC_DESC_NS} -eq 0 ]
							then
								local FAST_OC_DESC_NS="all-namespaces"
							fi

							if [ ! -d $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS ]
							then
								mkdir -p $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS
							fi
	
							echo "[$(date)] [${FUNCNAME[0]}] File listing (*.desc) on output directory [$FAST_OC_DESC_OUTDIR] => [$(ls -l $FAST_OC_DESC_OUTDIR/*.desc)]"
							echo "[$(date)] [${FUNCNAME[0]}] File count (*.desc) on output directory [$FAST_OC_DESC_OUTDIR] => [$DESC_FILE_COUNT] [SOURCE_COUNT=$SOURCE_COUNT]"

							echo "[$(date)] [${FUNCNAME[0]}] TMP_DESC_ALL_KEEP = [$TMP_DESC_ALL_KEEP]"
						
							if [ $TMP_DESC_ALL_KEEP == "false" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Moving [$FAST_OC_DESC_TMPFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS]..."
								mv $FAST_OC_DESC_TMPFILE $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS
							else
								echo "[$(date)] [${FUNCNAME[0]}] Copying [$FAST_OC_DESC_TMPFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS]..."
								cp -p $FAST_OC_DESC_TMPFILE $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS
							fi
						else	
							if [ $TMP_DESC_ALL_KEEP == "false" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_DESC_TMPFILE]..."
								rm $FAST_OC_DESC_TMPFILE
							fi
						fi
					else
						if [ ${#FAST_OC_DESC_NS} -gt 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC - '$OC_CMD describe $FAST_OC_DESC_OBJTYPE -n $FAST_OC_DESC_NS' output file [$FAST_OC_DESC_TMPFILE] does not exist or is zero-sized!"
						else
							echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC - '$OC_CMD describe $FAST_OC_DESC_OBJTYPE' output file [$FAST_OC_DESC_TMPFILE] does not exist or is zero-sized!"
						fi
					fi
				done
	
				if [ $MG_DEBUG == "true" ]
				then
					if [ ${#FAST_OC_DESC_NS} -eq 0 ]
					then
						local FAST_OC_DESC_NS="all-namespaces"
					fi

					if [ ! -d $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS ]
					then
						mkdir -p $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS
					fi
	
					echo "[$(date)] [${FUNCNAME[0]}] Moving FAST_OC_DESC_WORKFILE [$FAST_OC_DESC_WORKFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS]..."
					mv $FAST_OC_DESC_WORKFILE $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_DESC_NS
				else
					echo "[$(date)] [${FUNCNAME[0]}] Deleting FAST_OC_DESC_WORKFILE [$FAST_OC_DESC_WORKFILE]..."
					rm $FAST_OC_DESC_WORKFILE
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_DESC_WORKFILE [$FAST_OC_DESC_WORKFILE] does not exist or is zero-sized!"
			fi
		fi

		if [ $COLLECT_YAML == "true" ]
		then
			if [ ${FAST_OC_YAML} == "true" ] 
			then
				if [ -s $FAST_OC_YAML_WORKFILE ]
				then
					local FAST_OC_YAML_FAILED="false"

					for LINE in $($AWK -F## '{ print $1 "##" $2 "##" $4 }' $FAST_OC_YAML_WORKFILE | sort | uniq)
					do
						local FAST_OC_YAML_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
						local FAST_OC_YAML_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
						local FAST_OC_YAML_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')

						local FAST_OC_YAML_OUTFILE=$FAST_OC_YAML_OUTDIR/fast_oc_yaml.$FAST_OC_YAML_OBJTYPE.yaml-all

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_NS = [$FAST_OC_YAML_NS] / FAST_OC_YAML_OBJTYPE = [$FAST_OC_YAML_OBJTYPE] / FAST_OC_YAML_OUTDIR = [$FAST_OC_YAML_OUTDIR] / FAST_OC_YAML_OUTFILE = [$FAST_OC_YAML_OUTFILE]"
						fi

						if [ ${#FAST_OC_YAML_NS} -gt 0 ]
						then
							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
								local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE"
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
								local BULK_YAML_CMD="$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE"
							fi
						else
							if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
								local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE"
							else
								echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE' => $FAST_OC_YAML_OUTFILE"
								local BULK_YAML_CMD="$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE"
							fi
						fi

						eval "$BULK_YAML_CMD" > $FAST_OC_YAML_OUTFILE

						if [ -s $FAST_OC_YAML_OUTFILE ]
						then
							sed $(( $(wc -l <$FAST_OC_YAML_OUTFILE)-3+1 ))',$ d; 1,2d; s/^-[ ]/#@@@%@@@#\'$'\n/g; s/^[ ]\{2\}//' $FAST_OC_YAML_OUTFILE | sed '1d' | $AWK -v OUTDIR=$FAST_OC_YAML_OUTDIR 'BEGIN { RS="#@@@%@@@#\n"; FS="\n" } { METADATA_FOUND="false"; OBJNAME=""; for (i=1; i<=NF; i++) { if ( $i ~ /^metadata:/  ){ METADATA_FOUND="true" } else { if ( $i ~ /^[ ]{2}name: / && METADATA_FOUND == "true" ) { OBJNAME=substr($i, index($i, ":")+1); gsub(/^[ \t]*/, "", OBJNAME); gsub(/[\n]*$/, "", $0); break } } }; if ( length(OBJNAME) > 0 ) { print > (OUTDIR"/"OBJNAME".yaml") } }'

							local TMP_YAML_ALL_KEEP="false"
							local SOURCE_COUNT=$(grep '^- ' $FAST_OC_YAML_OUTFILE | wc -l)
							local YAML_FILE_COUNT=$(ls -l $FAST_OC_YAML_OUTDIR/*.yaml | wc -l)
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] YAML_FILE_COUNT = [$YAML_FILE_COUNT] / SOURCE_COUNT = [$SOURCE_COUNT]"
							fi
					
							if [ ${#YAML_FILE_COUNT} -gt 0 ] && [ ${#SOURCE_COUNT} -gt 0 ]
							then
								if [ $YAML_FILE_COUNT -ne $SOURCE_COUNT ]
								then
									local TMP_YAML_ALL_KEEP="true"
								fi
							else
								local TMP_YAML_ALL_KEEP="true"
							fi

							if [ $MG_DEBUG == "true" ]
							then
								if [ ${#FAST_OC_YAML_NS} -eq 0 ]
								then
									local FAST_OC_YAML_NS="all-namespaces"
								fi
	
								if [ ! -d $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS ]
								then
									mkdir -p $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS
								fi
		
								echo "[$(date)] [${FUNCNAME[0]}] File listing (*.yaml) on output directory [$FAST_OC_YAML_OUTDIR] => [$(ls -l $FAST_OC_YAML_OUTDIR/*.yaml)]"
								echo "[$(date)] [${FUNCNAME[0]}] File count (*.yaml) on output directory [$FAST_OC_YAML_OUTDIR] => [$YAML_FILE_COUNT] [SOURCE_COUNT=$SOURCE_COUNT]"
	
								echo "[$(date)] [${FUNCNAME[0]}] TMP_YAML_ALL_KEEP = [$TMP_YAML_ALL_KEEP]"
							
								if [ $TMP_YAML_ALL_KEEP == "false" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Moving FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS]..."
									mv $FAST_OC_YAML_OUTFILE $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS
								else
									echo "[$(date)] [${FUNCNAME[0]}] Copying FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS]..."
									cp -p $FAST_OC_YAML_OUTFILE $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS
								fi
							else	
								if [ $TMP_DESC_ALL_KEEP == "false" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Removing file [$FAST_OC_YAML_OUTFILE]..."
									rm $FAST_OC_YAML_OUTFILE
								fi
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_OUTFILE [$FAST_OC_YAML_OUTFILE] does not exist or is zero-sized!"
							local FAST_OC_YAML_FAILED="true"
						fi
					done

					if [ ${FAST_OC_YAML_FAILED} == "true" ]
					then	
						while read LINE
						do
							local FAST_OC_YAML_NS=$(echo "$LINE" | $AWK -F'##' '{ print $1 }')
							local FAST_OC_YAML_OBJTYPE=$(echo "$LINE" | $AWK -F'##' '{ print $2 }')
							local FAST_OC_YAML_OBJNAME=$(echo "$LINE" | $AWK -F'##' '{ print $3 }')
							local FAST_OC_YAML_OUTDIR=$(echo "$LINE" | $AWK -F'##' '{ print $4 }')
							local FAST_OC_YAML_CURL_CMD=$(echo "$LINE" | $AWK -F'##' '{ print $5 }')

							if [ ${#FAST_OC_YAML_CURL_CMD} -gt 0 ]
							then
								local BULK_YAML_CMD="$FAST_OC_YAML_CURL_CMD"
							else
								if [ ${#FAST_OC_YAML_NS} -gt 0 ]
								then
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
										local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
										local BULK_YAML_CMD="$OC_CMD get -o yaml -n $FAST_OC_YAML_NS $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
									fi
								else
									if [ ${#SHOW_MANAGED_FIELDS} -gt 0 ] && [ $SHOW_MANAGED_FIELDS == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
										local BULK_YAML_CMD="$OC_CMD get -o yaml --show-managed-fields $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
									else
										echo "[$(date)] [${FUNCNAME[0]}] Executing '$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
										local BULK_YAML_CMD="$OC_CMD get -o yaml $FAST_OC_YAML_OBJTYPE $FAST_OC_YAML_OBJNAME"
									fi
								fi
							fi

							echo "[$(date)] [${FUNCNAME[0]}] [RETRY] Executing '$BULK_YAML_CMD' => $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml"
							eval "$BULK_YAML_CMD" > $FAST_OC_YAML_OUTDIR/$FAST_OC_YAML_OBJNAME.yaml
						done < $FAST_OC_YAML_WORKFILE
					fi

					if [ $MG_DEBUG == "true" ]
					then
						if [ ${#FAST_OC_YAML_NS} -eq 0 ]
						then
							local FAST_OC_YAML_NS="all-namespaces"
						fi
	
						if [ ! -d $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS ]
						then
							mkdir -p $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS
						fi
		
						echo "[$(date)] [${FUNCNAME[0]}] Moving FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE] to directory [$MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS]..."
						mv $FAST_OC_YAML_WORKFILE $MAIN_ROOT_DEBUG_OUTDIR/ocDesc/$FAST_OC_YAML_NS
					else
						echo "[$(date)] [${FUNCNAME[0]}] Deleting FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE]..."
						rm $FAST_OC_YAML_WORKFILE
					fi
				else
					if [ $FAST_OC_YAML_WORTHY != "true" ] || [ $TO_PROCEED_YAML != "true" ]
					then
						if [ $FAST_OC_YAML_WORTHY != "true" ]
						then
							if [ ${#NAMESPACE_STR} -gt 0 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_WORTHY = [$FAST_OC_YAML_WORTHY] / TOTAL_OBJ = [$TOTAL_OBJ]! YAML files for resource type [$OBJTYPE] in namespace [$NAMESPACE_STR] were produced with alternative non-bulk method..."
							else
								echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_WORTHY = [$FAST_OC_YAML_WORTHY] / TOTAL_OBJ = [$TOTAL_OBJ]! YAML files for resource type [$OBJTYPE] were produced with alternative non-bulk method..."
							fi
						fi

						if [ $TO_PROCEED_YAML != "true" ] 
						then
							echo "[$(date)] [${FUNCNAME[0]}] TO_PROCEED_YAML = [$TO_PROCEED_YAML]! Previous check determined YAML files collection for resource type [$OBJTYPE] is not allowed..."
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] FAST_OC_YAML_WORKFILE [$FAST_OC_YAML_WORKFILE] does not exist or is zero-sized!"
					fi
				fi
			fi
		fi

		rm $OUTFILE

		if [ $MG_DEBUG == "true" ]
		then	
			local FUNC_END=$(getFuncEndTime)
			getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [NS=$NAMESPACE / OBJTYPE=$OBJTYPE]"
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Command '$EXEC_CMD' failed! Output file [$OUTFILE] does not exist or is zero-sized!"
		echo "[$(date)] [${FUNCNAME[0]}] Removing directory [$F_OUTDIR]..."
		rm -r $F_OUTDIR
		return 1
	fi
}

getNodeLogs()
{
	# descNode
	getNodesData

	if [ ${CMD_EXEC} == "true" ]
	then
		runCmdExec	
	fi

	if [ ${MANUAL_COLL} -eq 1 ]
	then
		doManualCollection
	fi

	if [ ${EXTRA_NAMESPACES}x != "x" ]
	then
		getAllExtraNS $EXTRA_NAMESPACES
	fi

	if [ ${GET_MISS_OBJ} == "true" ]
	then
		# getMissingObjects
		doMissingObjects
	fi

	if [ ${GET_COMPLIANCE} == "true" ]
	then
		doCompliance
	fi

	if [ ${#PLUGINS} -gt 0 ]
	then
		doPlugins
	fi

	if [ ${CPFILES_ENABLED} == "true" ]
	then
		doCpFiles
	fi

	if [ ${#GREP_PATTERN} -gt 0 ]
	then
		grepPattern
	fi

	if [ $DIFF_SNAPSHOTS == "true" ]
	then	
		doSnapshots
	fi

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getCmdExec()
{
	if [ ${CMD_EXEC} == "true" ]
	then
		runCmdExec	
	fi

	if [ ${MANUAL_COLL} -eq 1 ]
	then
		doManualCollection
	fi

	if [ ${EXTRA_NAMESPACES}x != "x" ]
	then
		getAllExtraNS $EXTRA_NAMESPACES
	fi

	if [ ${GET_MISS_OBJ} == "true" ]
	then
		# getMissingObjects
		doMissingObjects
	fi

	if [ ${GET_COMPLIANCE} == "true" ]
	then
		doCompliance
	fi

	if [ ${#PLUGINS} -gt 0 ]
	then
		doPlugins
	fi

	if [ ${CPFILES_ENABLED} == "true" ]
	then
		doCpFiles
	fi

	if [ ${#GREP_PATTERN} -gt 0 ] && ( [ ${MANUAL_COLL} -eq 1 ] || [ ${EXTRA_NAMESPACES}x != "x" ] ) 
	then
		grepPattern
	fi

	if [ $DIFF_SNAPSHOTS == "true" ]
	then	
		doSnapshots
	fi	

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS 
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getManual()
{
	doManualCollection

	if [ ${EXTRA_NAMESPACES}x != "x" ]
	then
		getAllExtraNS $EXTRA_NAMESPACES
	fi

	if [ ${GET_MISS_OBJ} == "true" ]
	then
		# getMissingObjects
		doMissingObjects
	fi

	if [ ${GET_COMPLIANCE} == "true" ]
	then
		doCompliance
	fi

	if [ ${#PLUGINS} -gt 0 ]
	then
		doPlugins
	fi

	if [ ${CPFILES_ENABLED} == "true" ]
	then
		doCpFiles
	fi

	if [ ${#GREP_PATTERN} -gt 0 ] 
	then
		grepPattern
	fi

	if [ $DIFF_SNAPSHOTS == "true" ]
	then	
		doSnapshots
	fi	

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS 
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getExtra()
{
	if [ ${EXTRA_NAMESPACES}x != "x" ]
	then
		getAllExtraNS $EXTRA_NAMESPACES
	fi

	if [ ${GET_MISS_OBJ} == "true" ]
	then
		# getMissingObjects
		doMissingObjects
	fi

	if [ ${GET_COMPLIANCE} == "true" ]
	then
		doCompliance
	fi

	if [ ${#PLUGINS} -gt 0 ]
	then
		doPlugins
	fi

	if [ ${CPFILES_ENABLED} == "true" ]
	then
		doCpFiles
	fi

	if [ ${#GREP_PATTERN} -gt 0 ]
	then
		grepPattern
	fi

	if [ $DIFF_SNAPSHOTS == "true" ]
	then	
		doSnapshots
	fi	

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS 
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getMissingObj()
{
	if [ ${GET_MISS_OBJ} == "true" ]
	then
		# getMissingObjects
		doMissingObjects
	fi

	if [ ${GET_COMPLIANCE} == "true" ]
	then
		doCompliance
	fi

	if [ ${#PLUGINS} -gt 0 ]
	then
		doPlugins
	fi

	if [ ${CPFILES_ENABLED} == "true" ]
	then
		doCpFiles

		if [ ${#GREP_PATTERN} -gt 0 ]
		then
			grepPattern
		fi
	fi

	if [ $DIFF_SNAPSHOTS == "true" ]
	then	
		doSnapshots
	fi	

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getCompliance()
{
	if [ ${GET_COMPLIANCE} == "true" ]
	then
		doCompliance	
	fi

	if [ ${#PLUGINS} -gt 0 ]
	then
		doPlugins
	fi

	if [ ${CPFILES_ENABLED} == "true" ]
	then
		doCpFiles

		if [ ${#GREP_PATTERN} -gt 0 ]
		then
			grepPattern
		fi
	fi

	if [ $DIFF_SNAPSHOTS == "true" ]
	then	
		doSnapshots
	fi	

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getPluginExec()
{
	if [ ${#PLUGINS} -gt 0 ]
	then
		doPlugins
	fi

	if [ ${CPFILES_ENABLED} == "true" ]
	then
		doCpFiles

		if [ ${#GREP_PATTERN} -gt 0 ]
		then
			grepPattern
		fi
	fi

	if [ $DIFF_SNAPSHOTS == "true" ]
	then	
		doSnapshots
	fi	

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS 
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getCpFiles()
{
	doCpFiles 

	if [ ${#GREP_PATTERN} -gt 0 ]
	then
		grepPattern
	fi

	if [ $DIFF_SNAPSHOTS == "true" ]
	then	
		doSnapshots
	fi	

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getSnapshots()
{
	if [ $DIFF_SNAPSHOTS == "true" ]
	then
		doSnapshots	
	fi

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getCustomModuleAgreement()
{
	# Backup custom module script
	if [ $MG_DEBUG == "true" ]
	then	
		local CM_BACKUP_DIR=$MAIN_ROOT_DEBUG_OUTDIR/custom-module

		if [ ! -d $CM_BACKUP_DIR ]
		then
			mkdir -p $CM_BACKUP_DIR
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Backing up custom module script [$MODULES] to directory [$CM_BACKUP_DIR]..." | tee -a $RUNTIME_LOGFILE
		cp -p $MODULES $CM_BACKUP_DIR
	fi

	# User acceptance
	local TOTAL_LINES_FILE=$(wc -l $MODULES | $AWK '{ print $1 }')
	# local MAX_DISPLAY_LINES=50

	echo "[$(date)] [${FUNCNAME[0]}] Custom module script file to be executed: " | tee -a $RUNTIME_LOGFILE

	if [ ${#TOTAL_LINES_FILE} -gt 0 ]
	then	
		if [ $TOTAL_LINES_FILE -le $MAX_DISPLAY_LINES ]
		then
			cat $MODULES | tee -a $RUNTIME_LOGFILE
		else
			printf "${BOLD}${RED}WARNING: Custom module script [$MODULES][$TOTAL_LINES_FILE] exceeds [$MAX_DISPLAY_LINES] lines. Displaying up to [$MAX_DISPLAY_LINES] lines!${NEWLINE}${NORMAL}"	
			echo "[$(date)] [${FUNCNAME[0]}] WARNING: Custom module script [$CMD_EXEC_FILE][$TOTAL_LINES_FILE] exceeds [$MAX_DISPLAY_LINES] lines. Displaying up to [$MAX_DISPLAY_LINES] lines!" >> $RUNTIME_LOGFILE
			head -$MAX_DISPLAY_LINES $MODULES | tee -a $RUNTIME_LOGFILE
			echo "..." | tee -a $RUNTIME_LOGFILE
		fi
	
		echo | tee -a $RUNTIME_LOGFILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] FATAL: Unable to determine total lines in custom module script [$MODULES]!"
	fi

	local CHECK_OC_DELETE="grep -E -i '$OC_CMD[ ]+delete|$OC_CMD[ ]+patch' $MODULES"
	
	if [ $(eval "$CHECK_OC_DELETE" | wc -l) -gt 0 ]
	then
		printf "${BOLD}${RED}WARNING: Custom module script contains '$OC_CMD delete/patch' commands!${NEWLINE}${NORMAL}"
		echo "[$(date)] [${FUNCNAME[0]}] WARNING: Custom module script contains '$OC_CMD delete/patch' commands!" >> $RUNTIME_LOGFILE
		grep -E -in "$OC_CMD[ ]+delete|$OC_CMD[ ]+patch" $MODULES | tee -a $RUNTIME_LOGFILE
	fi 

	local ASK_USER_AGREEMENT=1

	while [ $ASK_USER_AGREEMENT -eq 1 ]
	do
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Are you sure you want to proceed (y/n)? ${NORMAL}"	
		echo -n "[$(date)] [${FUNCNAME[0]}] Are you sure you want to proceed (y/n)? " >> $RUNTIME_LOGFILE

		if [ $AUTO_YES == "true" ]
		then
			CUSTOM_MODULE_AGREEMENT="y"
			echo "$CUSTOM_MODULE_AGREEMENT" | tee -a $RUNTIME_LOGFILE
			echo "[$(date)] [${FUNCNAME[0]}] Option [-Y] is set! Auto answering [y]..." | tee -a $RUNTIME_LOGFILE
		else
			if [ $MG_TTY == "false" ]
			then
				CUSTOM_MODULE_AGREEMENT="n"
				echo "$CUSTOM_MODULE_AGREEMENT" | tee -a $RUNTIME_LOGFILE
				echo "[$(date)] [${FUNCNAME[0]}] In non-TTY mode, auto answering [n]..." | tee -a $RUNTIME_LOGFILE
			else
				read -t $DEFAULT_USERINPUT_TIMEOUT CUSTOM_MODULE_AGREEMENT
				local EXIT_STATUS=$?
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] EXIT_STATUS = [$EXIT_STATUS]"
				fi
				
				if [ $EXIT_STATUS -gt 128 ]
				then
					echo | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [${FUNCNAME[0]}] Timeout waiting for user input. Auto answer [N]..." | tee -a $RUNTIME_LOGFILE
					CUSTOM_MODULE_AGREEMENT="N"
				else
					echo "$CUSTOM_MODULE_AGREEMENT" >> $RUNTIME_LOGFILE
				fi
			fi
		fi
	
		if [ ${#CUSTOM_MODULE_AGREEMENT} -gt 0 ]
		then
			if [ ${CUSTOM_MODULE_AGREEMENT} == "n" ] || [ ${CUSTOM_MODULE_AGREEMENT} == "N" ]
			then
				echo "User input [$CUSTOM_MODULE_AGREEMENT]. To skip execution of custom module script [$MODULES]..."  | tee -a $RUNTIME_LOGFILE
				return 1	
			else
				if [ ${CUSTOM_MODULE_AGREEMENT} == "y" ] || [ ${CUSTOM_MODULE_AGREEMENT} == "Y" ]
				then
					echo "User input [$CUSTOM_MODULE_AGREEMENT]. To proceed..." | tee -a $RUNTIME_LOGFILE
					return 0
				else
					echo "Invalid user input [$CUSTOM_MODULE_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
				fi
			fi
		else
			echo "Invalid user input [$CUSTOM_MODULE_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
		fi
	done
}

getCmdExecAgreement()
{
	echo "[$(date)] [${FUNCNAME[0]}] Manual command execution (cmdexec) is selected..." | tee -a $RUNTIME_LOGFILE

	if [ ! -s $CMD_EXEC_FILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Invalid script file [$CMD_EXEC_FILE]!" | tee -a $RUNTIME_LOGFILE
		return 1
	fi	

	# Backup CMD_EXEC_FILE	
	local CMD_EXEC_INPUT_DIR=$CMD_EXEC_OUTDIR/input

	if [ ! -d $CMD_EXEC_INPUT_DIR ]
	then
		mkdir -p $CMD_EXEC_INPUT_DIR
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Backing up CMD_EXEC_FILE [$CMD_EXEC_FILE] to directory [$CMD_EXEC_INPUT_DIR]..." | tee -a $RUNTIME_LOGFILE
	cp -p $CMD_EXEC_FILE $CMD_EXEC_INPUT_DIR

	if [ ${#CMD_EXEC_ENVFILE} -gt 0 ] && [ -s $CMD_EXEC_ENVFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Backing up CMD_EXEC_ENVFILE [$CMD_EXEC_ENVFILE] to directory [$CMD_EXEC_INPUT_DIR]..." | tee -a $RUNTIME_LOGFILE
		cp -p $CMD_EXEC_ENVFILE $CMD_EXEC_INPUT_DIR
	fi

	# User acceptance
	local TOTAL_LINES_FILE=$(wc -l $CMD_EXEC_FILE | $AWK '{ print $1 }')
	# local MAX_DISPLAY_LINES=50

	echo "[$(date)] [${FUNCNAME[0]}] Script file to be executed: " | tee -a $RUNTIME_LOGFILE

	if [ ${#TOTAL_LINES_FILE} -gt 0 ]
	then	
		if [ $TOTAL_LINES_FILE -le $MAX_DISPLAY_LINES ]
		then
			cat $CMD_EXEC_FILE | tee -a $RUNTIME_LOGFILE
		else
			printf "${BOLD}${RED}WARNING: Custom script [$CMD_EXEC_FILE][$TOTAL_LINES_FILE] exceeds [$MAX_DISPLAY_LINES] lines. Displaying up to [$MAX_DISPLAY_LINES] lines!${NEWLINE}${NORMAL}"	
			echo "[$(date)] [${FUNCNAME[0]}] WARNING: Custom script [$CMD_EXEC_FILE][$TOTAL_LINES_FILE] exceeds [$MAX_DISPLAY_LINES] lines. Displaying up to [$MAX_DISPLAY_LINES] lines!" >> $RUNTIME_LOGFILE
			head -$MAX_DISPLAY_LINES $CMD_EXEC_FILE | tee -a $RUNTIME_LOGFILE
			echo "..." | tee -a $RUNTIME_LOGFILE
		fi
	
		echo | tee -a $RUNTIME_LOGFILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] FATAL: Unable to determine total lines in custom script [$CMD_EXEC_FILE]!"
	fi

	if [ ${#CMD_EXEC_ENVFILE} -gt 0 ] && [ -s $CMD_EXEC_ENVFILE ]
	then
		echo "[ENVIRONMENT FILE]: " | tee -a $RUNTIME_LOGFILE
		cat $CMD_EXEC_ENVFILE | tee -a $RUNTIME_LOGFILE
		echo | tee -a $RUNTIME_LOGFILE
	fi

	local CHECK_OC_DELETE="grep -E -i '$OC_CMD[ ]+delete|$OC_CMD[ ]+patch' $CMD_EXEC_FILE"
	
	if [ $(eval "$CHECK_OC_DELETE" | wc -l) -gt 0 ]
	then
		printf "${BOLD}${RED}WARNING: Custom script contains '$OC_CMD delete/patch' commands!${NEWLINE}${NORMAL}"
		echo "[$(date)] [${FUNCNAME[0]}] WARNING: Custom script contains '$OC_CMD delete/patch' commands!" >> $RUNTIME_LOGFILE
		grep -E -i "$OC_CMD[ ]+delete|$OC_CMD[ ]+patch" $CMD_EXEC_FILE | tee -a $RUNTIME_LOGFILE
	fi 

	local ASK_USER_AGREEMENT=1

	while [ $ASK_USER_AGREEMENT -eq 1 ]
	do
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Are you sure you want to proceed (y/n)? ${NORMAL}"	
		echo -n "[$(date)] [${FUNCNAME[0]}] Are you sure you want to proceed (y/n)? " >> $RUNTIME_LOGFILE

		if [ $AUTO_YES == "true" ]
		then
			CMD_EXEC_AGREEMENT="y"
			echo "$CMD_EXEC_AGREEMENT" | tee -a $RUNTIME_LOGFILE
			echo "[$(date)] [${FUNCNAME[0]}] Option [-Y] is set! Auto answering [y]..." | tee -a $RUNTIME_LOGFILE
		else
			if [ $MG_TTY == "false" ]
			then
				CMD_EXEC_AGREEMENT="n"
				echo "$CMD_EXEC_AGREEMENT" | tee -a $RUNTIME_LOGFILE
				echo "[$(date)] [${FUNCNAME[0]}] In non-TTY mode, auto answering [n]..." | tee -a $RUNTIME_LOGFILE
			else
				read -t $DEFAULT_USERINPUT_TIMEOUT CMD_EXEC_AGREEMENT
				local EXIT_STATUS=$?
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] EXIT_STATUS = [$EXIT_STATUS]"
				fi
				
				if [ $EXIT_STATUS -gt 128 ]
				then
					echo | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [${FUNCNAME[0]}] Timeout waiting for user input. Auto answer [N]..." | tee -a $RUNTIME_LOGFILE
					CMD_EXEC_AGREEMENT="N"
				else
					echo "$CMD_EXEC_AGREEMENT" >> $RUNTIME_LOGFILE
				fi
			fi
		fi
	
		if [ ${#CMD_EXEC_AGREEMENT} -gt 0 ]
		then
			if [ ${CMD_EXEC_AGREEMENT} == "n" ] || [ ${CMD_EXEC_AGREEMENT} == "N" ]
			then
				echo "User input [$CMD_EXEC_AGREEMENT]. To skip 'cmdexec' module..."  | tee -a $RUNTIME_LOGFILE
				return 1	
			else
				if [ ${CMD_EXEC_AGREEMENT} == "y" ] || [ ${CMD_EXEC_AGREEMENT} == "Y" ]
				then
					echo "User input [$CMD_EXEC_AGREEMENT]. To proceed..." | tee -a $RUNTIME_LOGFILE
					return 0
				else
					echo "Invalid user input [$CMD_EXEC_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
				fi
			fi
		else
			echo "Invalid user input [$CMD_EXEC_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
		fi
	done
}

printSummaryLog()
{
	if [ $REPORT_ON_SCREEN == "true" ]
	then
		if [ -s $REPORT_ON_SCREEN_SUMMARY_FILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Displaying SUMMARY.log [$REPORT_ON_SCREEN_SUMMARY_FILE] on screen..."
			echo
			cat $REPORT_ON_SCREEN_SUMMARY_FILE
			rm $REPORT_ON_SCREEN_SUMMARY_FILE
		else
			echo "[$(date)] [${FUNCNAME[0]}] SUMMARY.log [$REPORT_ON_SCREEN_SUMMARY_FILE] does not exist or is zero-sized!"
		fi

		if [ ${#REPORT_ON_SCREEN_COMPLIANCE_FILE} -gt 0 ] 
		then
			if [ -s $REPORT_ON_SCREEN_COMPLIANCE_FILE ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Displaying COMPLIANCE_REPORT.log [$REPORT_ON_SCREEN_COMPLIANCE_FILE] on screen..."
				echo
				cat $REPORT_ON_SCREEN_COMPLIANCE_FILE
				rm $REPORT_ON_SCREEN_COMPLIANCE_FILE
			else
				if [ $COMPLIANCE_INPUTTAG != ".listcompliance" ] && [ $COMPLIANCE_INPUTTAG != ".listcompliance_custom" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] COMPLIANCE_REPORT.log [$REPORT_ON_SCREEN_COMPLIANCE_FILE] does not exist or is zero-sized!"
				fi
			fi
		fi

		if [ ${#REPORT_ON_SCREEN_SNAPSHOTS_FILE} -gt 0 ] 
		then
			if [ -s $REPORT_ON_SCREEN_SNAPSHOTS_FILE ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Displaying SNAPSHOTS_REPORT.log [$REPORT_ON_SCREEN_SNAPSHOTS_FILE] on screen..."
				echo
				cat $REPORT_ON_SCREEN_SNAPSHOTS_FILE
				rm $REPORT_ON_SCREEN_SNAPSHOTS_FILE
			else
				echo "[$(date)] [${FUNCNAME[0]}] SNAPSHOTS_REPORT.log [$REPORT_ON_SCREEN_SNAPSHOTS_FILE] does not exist or is zero-sized!"
			fi
		fi
	fi
}

getTest()
{
	analyzeOcAll cp4aiops $PRODUCT_DATA_OUTDIR/cp4aiops/oc_all.out $PRODUCT_DATA_OUTDIR/cp4aiops
}

checkInputFile()
{
	local INPUTFILE=$1
	
	if [[ $(echo "$INPUTFILE" | $AWK -F'/' '{ print NF }') -eq 1 ]]
	then
		local INPUTFILE=$PWD/$INPUTFILE
	fi
	
	if [ -d $INPUTFILE ] || [ ! -s $INPUTFILE ]
	then
		return 1
	fi

	return 0
}

validateManualCollection()
{
	local INPUTFILE=$1

	if [[ $(echo "$INPUTFILE" | $AWK -F'/' '{ print NF }') -eq 1 ]]
	then
		local INPUTFILE=$PWD/$INPUTFILE
	fi

	local VALIDFILE=1
	local LINE=
	
	while read LINE	
 	do
		# Skip all lines that start with @
		if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "$MANUAL_COLL_CFGFILE_COMMENT"* ]]
		then
			continue
		fi

		if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "" ]]
		then
			continue
		fi

		return 0	
	done < $INPUTFILE

	return $VALIDFILE
}

checkJournalSize()
{
	if [ $MUSTGATHER_OPT == "clusternodes" ] || [ $MUSTGATHER_OPT == "all" ] || [ $GET_NODES_DATA == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Checking user input JOURNAL_SIZE [$JOURNAL_SIZE]..." | tee -a $RUNTIME_LOGFILE
	
		if ! [[ "$JOURNAL_SIZE" =~ ^[-+]?[0-9]+$ ]]
		then
			echo "[$(date)] [${FUNCNAME[0]}] JOURNAL_SIZE parameter value [$JOURNAL_SIZE] not a number! Maintaining JOURNAL_SIZE at [default=$JOURNAL_SIZE_DEFAULT]..." | tee -a $RUNTIME_LOGFILE
			return 1	
		else
			if [[ ${JOURNAL_SIZE} -le 0 ]]
			then
				echo "[$(date)] [${FUNCNAME[0]}] JOURNAL_SIZE parameter value [$JOURNAL_SIZE] is equal to or less than zero! Maintaining JOURNAL_SIZE at [default=$JOURNAL_SIZE_DEFAULT]..." | tee -a $RUNTIME_LOGFILE
				return 1	
			else
				if [[ ${JOURNAL_SIZE} -gt $JOURNAL_SIZE_WARN_LIMIT ]]
				then
					local JOURNAL_SIZE_WARN=1
					
					while [ $JOURNAL_SIZE_WARN -eq 1 ]
					do	
						echoJournalSizeWarning | tee -a $RUNTIME_LOGFILE

						if [ $AUTO_YES == "true" ]
						then
							local JOURNALSIZE_TO_CONTINUE="y"
							echo "$JOURNALSIZE_TO_CONTINUE" | tee -a $RUNTIME_LOGFILE
							echo "[$(date)] [${FUNCNAME[0]}] Option [-Y] is set! Auto answering [y]..." | tee -a $RUNTIME_LOGFILE
						else
							if [ $MG_TTY == "false" ]
							then
								local JOURNALSIZE_TO_CONTINUE="n"
								echo "$JOURNALSIZE_TO_CONTINUE" | tee -a $RUNTIME_LOGFILE
								echo "[$(date)] [${FUNCNAME[0]}] In non-TTY mode, auto answering [n]..." | tee -a $RUNTIME_LOGFILE
							else
								read -t $DEFAULT_USERINPUT_TIMEOUT JOURNALSIZE_TO_CONTINUE
								local EXIT_STATUS=$?
	
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] EXIT_STATUS = [$EXIT_STATUS]"
								fi
	
								if [ $EXIT_STATUS -gt 128 ]
								then
									echo | tee -a $RUNTIME_LOGFILE
									echo "[$(date)] [${FUNCNAME[0]}] Timeout waiting for user input. Auto answer [N]..." | tee -a $RUNTIME_LOGFILE
									JOURNALSIZE_TO_CONTINUE="N"
								else
									echo "$JOURNALSIZE_TO_CONTINUE" >> $RUNTIME_LOGFILE
								fi
							fi
						fi
		
						if [ ${JOURNALSIZE_TO_CONTINUE} == "n" ] || [ ${JOURNALSIZE_TO_CONTINUE} == "N" ]
						then
							echo "User input [$JOURNALSIZE_TO_CONTINUE]. Maintaining JOURNAL_SIZE at [default=$JOURNAL_SIZE_DEFAULT]..." | tee -a $RUNTIME_LOGFILE
							return 1
						else
							if [ ${JOURNALSIZE_TO_CONTINUE} == "y" ] || [ ${JOURNALSIZE_TO_CONTINUE} == "Y" ]
							then
								echo "User input [$JOURNALSIZE_TO_CONTINUE]. To proceed..." | tee -a $RUNTIME_LOGFILE
								return 0
							else
								echo "Invalid user input [$JOURNALSIZE_TO_CONTINUE]! Please retry..." | tee -a $RUNTIME_LOGFILE
							fi
						fi
					done
				fi
			fi
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] WARNING: Data collection mode [$MUSTGATHER_OPT] is selected. Data collection from cluster node is not supported. User input JOURNAL_SIZE [$JOURNAL_SIZE] will be ignored!"
	fi
}

appendtoAnalyzeOutfile()
{
	local INPUT=

	while read INPUT
	do
		echo "$INPUT" >> $ANALYZE_OUTFILE
	done
}

appendtoRuntimeLogfile()
{
	local INPUT=

	while read INPUT
	do
		echo "$INPUT" >> $RUNTIME_LOGFILE
	done
}

checkPlugins()
{
	local USERINPUT=
	local VALID_PLUGIN=
	local VALID_ACTION=

	if [[ -z ${PLUGINS_VALID+x} ]] || [ ${#PLUGINS_VALID[@]} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] No valid plugin is defined!"
		return 1	
	else
		# To check whether PLUGINS_VALID is declared as a normal variable (not array)
		if [ ${#PLUGINS_VALID[@]} -eq 1 ]
		then
			if [ ${#PLUGINS_VALID[0]} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] No valid plugin is defined!"
				return 1	
			fi
		fi
	fi

	IFS=$OLDIFS

	for USERINPUT in $(echo "$PLUGINS" | sed 's/,/\n/g' | sort | uniq)
	do
		# IS_SUPPORTED="false"
		local IS_VALID_PLUGIN="false"
		local IS_VALID_ACTION="false"

		local USERINPUT_PLUGIN=$(echo "$USERINPUT" | $AWK -F: '{ print $1 }')
		local USERINPUT_ACTION=$(echo "$USERINPUT" | $AWK -F: '{ print $2 }')
	
		if [ $USERINPUT_PLUGIN == ".listparams" ]
		then
			# To list supported parameters of all plugins
			IFS=$'\n'
			return 0
		fi

		for VALID_PLUGIN in ${PLUGINS_VALID[@]} 
		do
			if [ $VALID_PLUGIN == $USERINPUT_PLUGIN ]
			then	
				local IS_VALID_PLUGIN="true"
				break
			fi
		done

		if [ $IS_VALID_PLUGIN == "false" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] User input plugin [$USERINPUT_PLUGIN] is not a valid plugin!"	
			echo "[$(date)] [${FUNCNAME[0]}] Valid plugins = [${PLUGINS_VALID[@]}]"

			return 1
		fi

		if [ ${#USERINPUT_ACTION} -gt 0 ]
		then
			for VALID_ACTION in ${PLUGINS_VALID_ACTION[@]} 
			do
				if [ $VALID_ACTION == $USERINPUT_ACTION ]
				then	
					local IS_VALID_ACTION="true"
					break
				fi
			done
	
			if [ $IS_VALID_ACTION == "false" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] User input plugin action [$USERINPUT_ACTION] is not a valid plugin action!"	
				echo "[$(date)] [${FUNCNAME[0]}] Valid plugin actions = [${PLUGINS_VALID_ACTION[@]}]"
	
				return 1
			fi
		fi
	done

	IFS=$'\n'

	return 0
}

doPlugins()
{
	if [ ${#PRODUCT_VERSION} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] PRODUCT_VERSION is null. Returning..."
		return 1
	fi

	local PLG=
	local NS=

	for PLG in $(echo "$PLUGINS" | sed 's/,/\n/g' | sort | uniq)
	do
		if [ $MG_DEBUG == "true" ]
		then
			local FUNC_START=$(getFuncStartTime)
		fi
	
		local PLUGIN=$(echo "$PLG" | $AWK -F: '{ print $1 }')
		local PLUGIN_ACTION=$(echo "$PLG" | $AWK -F: '{ print $2 }')
	
		if [ ${#PLUGIN_ACTION} -eq 0 ]
		then
			local PLUGIN_ACTION=$PLUGINS_DEFAULT_ACTION
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] PLUGIN = [$PLUGIN] / PLUGIN_ACTION = [$PLUGIN_ACTION]"
		fi

		IFS=$OLDIFS
		
		if [ "$PLUGIN" == ".listparams" ]
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Listing defined parameters of all plugins for action [$PLUGIN_ACTION]..."
			fi

			if [ $REPORT_ON_SCREEN == "false" ]
			then
				echo "[$(date)] [$(basename "$0")] Setting REPORT_ON_SCREEN to [true]..." 
	
				REPORT_ON_SCREEN="true" 
				REPORT_ON_SCREEN_SUMMARY_FILE=$ROOT_OUTDIR/${ANALYZE_OUTFILE##*/}.$$
			fi

			local VALID_PLUGIN_FOUND="false"

			for CUR_PLUGIN in $(ls $MUSTGATHER_DIRNAME/config/plugins)
			do
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] CUR_PLUGIN = [$CUR_PLUGIN]"
				fi

				local VALID_PLUGIN_FOUND="true"

				local PROD_NAMESPACES=$(getProdToNamespacesMapping $CUR_PLUGIN) 
		
				if [ "$PROD_NAMESPACES" == $PROD_NAMESPACES_INVALID_STR ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Unable to determine namespace for product plugin [$CUR_PLUGIN]! Skipping..."
					continue
				else
					for NS in $PROD_NAMESPACES
					do
						if toExcludeProdNamespace $NS
						then
							echo "[$(date)] [${FUNCNAME[0]}] To exclude namespace [$NS]. Skipping..."
							continue
						fi	
		
						for TGT_PRODGRP in $(getProdGroupThruNamespace $CUR_PLUGIN $NS)
						do
							if [ ${#RTVAR_PLUGINS_PRODVER} -gt 0 ]
							then
								local PLUGINS_PRODVER_VALID="false"
					
								for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
								do
									if [ $RTVAR_PLUGINS_PRODVER == $VALID_PROD_VERSION ]
									then
										local PLUGINS_PRODVER_VALID="true"
										break
									fi
								done	
					
								if [ $PLUGINS_PRODVER_VALID == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] PLUGINS_PRODVER is set to [$RTVAR_PLUGINS_PRODVER]! Setting TGT_VERSION to [$RTVAR_PLUGINS_PRODVER]!"
									local TGT_VERSION=$RTVAR_PLUGINS_PRODVER
								else
									local TGT_VERSION=$(getProdVersionThruProdGroup $TGT_PRODGRP)	
									echo "[$(date)] [${FUNCNAME[0]}] PLUGINS_PRODVER [$RTVAR_PLUGIN_PRODVER] is invalid or not supported product version! Setting PLUGIN_PROD_VER to default [$TGT_VERSION]!"
								fi
							else
								local TGT_VERSION=$(getProdVersionThruProdGroup $TGT_PRODGRP)	
							fi
		
							if [ ${#TGT_VERSION} -gt 0 ]
							then
								local TGT_VERSION_SHORT=$(echo "$TGT_VERSION" | sed 's/\.//g')
								local TGT_PARAM_FILE="$MUSTGATHER_DIRNAME/config/plugins/$CUR_PLUGIN/$PLUGIN_ACTION/plugin-$CUR_PLUGIN-$PLUGIN_ACTION-${TGT_VERSION_SHORT}.param"	
								# Exporting user defined variables in PLUGINS_PARAM_FILE
								if [ -s $TGT_PARAM_FILE ]
								then
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Plugin [$CUR_PLUGIN] parameter file = [$TGT_PARAM_FILE]"
									fi
	
									echo "=============================================================================================================================================================================" >> $ANALYZE_OUTFILE
									echo "PLUGIN = [$CUR_PLUGIN]" >> $ANALYZE_OUTFILE
									echo "PARAM_FILE = [$TGT_PARAM_FILE]" >> $ANALYZE_OUTFILE
									echo "=============================================================================================================================================================================" >> $ANALYZE_OUTFILE
									echo >> $ANALYZE_OUTFILE
							
									# Execute in a subshell to NOT interfere with the current shell
									local PLUGIN_ENV_CMD="bash -c '. $TGT_PARAM_FILE; getParams'"
									local PLUGIN_ENV_RES=$(eval "$PLUGIN_ENV_CMD")
	
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] PLUGIN_ENV_RES = [$PLUGIN_ENV_RES]" 
									fi	

									if [ ${#PLUGIN_ENV_RES} -gt 0 ]
									then
										echo "$PLUGIN_ENV_RES" >> $ANALYZE_OUTFILE
									else
										echo "<< Unable to list defined parameters! >>" >> $ANALYZE_OUTFILE
									fi
				
									echo >> $ANALYZE_OUTFILE
								else
									echo "[$(date)] [${FUNCNAME[0]}] Parameter file [$TGT_PARAM_FILE] does not exist or is zero-sized!"
									continue
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] Unable to determine product version of plugin [$CUR_PLUGIN] in namespace [$NS]!"
								continue
							fi
						done
					done		
				fi
			done

			if [ $VALID_PLUGIN_FOUND == "false" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] No valid plugin is found in directory [$MUSTGATHER_DIRNAME/config/plugins]! Returning..."
				return 1
			else
				return 0
			fi
		else
			local PROD_NAMESPACES=$(getProdToNamespacesMapping $PLUGIN) 
	
			if [ "$PROD_NAMESPACES" == $PROD_NAMESPACES_INVALID_STR ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Unable to determine namespace for product plugin [$PLUGIN]! Skipping..."
				continue
			else
				for NS in $PROD_NAMESPACES
				do
					if toExcludeProdNamespace $NS
					then
						echo "[$(date)] [${FUNCNAME[0]}] To exclude namespace [$NS]. Skipping..."
						continue
					fi	
	
					for TGT_PRODGRP in $(getProdGroupThruNamespace $PLUGIN $NS)
					do
						if [ ${#RTVAR_PLUGINS_PRODVER} -gt 0 ]
						then
							local PLUGINS_PRODVER_VALID="false"
				
							for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
							do
								if [ $RTVAR_PLUGINS_PRODVER == $VALID_PROD_VERSION ]
								then
									local PLUGINS_PRODVER_VALID="true"
									break
								fi
							done	
				
							if [ $PLUGINS_PRODVER_VALID == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] PLUGINS_PRODVER is set to [$RTVAR_PLUGINS_PRODVER]! Setting TGT_VERSION to [$RTVAR_PLUGINS_PRODVER]!"
								local TGT_VERSION=$RTVAR_PLUGINS_PRODVER
							else
								local TGT_VERSION=$(getProdVersionThruProdGroup $TGT_PRODGRP)	
								echo "[$(date)] [${FUNCNAME[0]}] PLUGINS_PRODVER [$RTVAR_PLUGIN_PRODVER] is invalid or not supported product version! Setting PLUGIN_PROD_VER to default [$TGT_VERSION]!"
							fi
						else
							local TGT_VERSION=$(getProdVersionThruProdGroup $TGT_PRODGRP)	
						fi
	
						echo "[$(date)] [${FUNCNAME[0]}] Executing product plugin [$PLUGIN] on namespace [$NS] for product group [$TGT_PRODGRP] with product version [$TGT_VERSION]..."
						execPlugins "$PLUGIN" "$PLUGIN_ACTION" "$NS" "$TGT_PRODGRP" "$TGT_VERSION"
					done
				done		
			fi
		fi

		IFS=$'\n'

		if [ $MG_DEBUG == "true" ]
		then	
			local FUNC_END=$(getFuncEndTime)
			getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [PLUGIN=$PLG]"
		fi
	done
}

execPlugins()
{
	local PLUGIN=$1
	local ACTION=$2
	local NAMESPACE=$3
	local PRODGROUP=$4
	local PRODVER=$5

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] PLUGIN = [$PLUGIN] / ACTION = [$ACTION] / NAMESPACE = [$NAMESPACE] / PRODGROUP = [$PRODGROUP] / PRODVER = [$PRODVER]"
	fi

	if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
	then	
		local PLUGINS_PRODUCT_NSFILE=$PLUGINS_ROOT_OUTDIR/$PLUGIN/$NAMESPACE/$ACTION/product.ns.$$
	else
		local PLUGINS_PRODUCT_NSFILE=$PLUGINS_ROOT_OUTDIR/$PLUGIN/PRODGRP=$PRODGROUP/$NAMESPACE/$ACTION/product.ns.$$
	fi

	if [ ! -d $(dirname $PLUGINS_PRODUCT_NSFILE) ]
	then
		mkdir -p $(dirname $PLUGINS_PRODUCT_NSFILE)
	fi

	local PL_PRODGRP_REFFILE=${REFFILE_OUTDIR}/${PRODGROUP}.ns-ref

	if [ -s $PL_PRODGRP_REFFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Providing a copy of product group namespace reference file [$PL_PRODGRP_REFFILE] to PLUGINS custom script at location [$PLUGINS_PRODUCT_NSFILE]..."
		cp -p $PL_PRODGRP_REFFILE $PLUGINS_PRODUCT_NSFILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] PL_PRODGRP_REFFILE [$PL_PRODGRP_REFFILE] does not exist or is zero-sized! Setting to PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL]!"
		local PL_PRODGRP_REFFILE=$PROD_NAMESPACES_REFFILE_FINAL
	fi

	local PLUGINS_NAME=$PLUGIN
	local PLUGINS_PRODGRP=$PRODGROUP
	local PLUGINS_PRODVER=$PRODVER
	
	local DEF_ENV_ARR=("PLUGINS_NAME" "PLUGINS_PRODGRP" "PLUGINS_PRODVER" "PLUGINS_PRODUCT_NSFILE" "PLUGINS_ROOT_OUTDIR" "PLUGINS_ROOT_DEBUG_OUTDIR")
	local DEF_ENV=
	local LINE=
	local VARVALUE=

	local PLUGINS_USER_INPUT_ENV=$(compgen -A variable | grep -E '^RTVAR_PLUGINS_' | tr '\n' ' ')

	if [ ${#PLUGINS_USER_INPUT_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for USER_INPUT_ENV in $PLUGINS_USER_INPUT_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$USER_INPUT_ENV] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$USER_INPUT_ENV"
		done	
	fi

	local GMGFVAR_ENV=$(compgen -A variable | grep -E '^RTVAR_GMGFVAR_' | tr '\n' ' ')

	if [ ${#GMGFVAR_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for GMGFVAR in $GMGFVAR_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$GMGFVAR] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$GMGFVAR"
		done	
	fi

	IFS=$'\n'
	for DEF_ENV in ${DEF_ENV_ARR[@]}
	do
		if [[ $DEF_ENV =~ ^-f ]]
		then
			local PLUGINS_FUNCNAME=$(echo "$DEF_ENV" | $AWK '{ print $2 }')
				
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment function [$PLUGINS_FUNCNAME]..."
			fi

			export -f $PLUGINS_FUNCNAME
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$DEF_ENV = ${!DEF_ENV}]"
			fi

			export $DEF_ENV
		fi
	done

	local PROD_VER=$(echo "$PRODVER" | sed 's/\.//g')

	if [ $MG_DEBUG == "true" ] && [ ! -d $PLUGINS_ROOT_DEBUG_OUTDIR ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Making directory [$PLUGINS_ROOT_DEBUG_OUTDIR]..."
		mkdir -p $PLUGINS_ROOT_DEBUG_OUTDIR
	fi
	
	export PLUGINS_NAMESPACE=$NAMESPACE
	export PLUGINS_ACTION=$ACTION

	if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
	then
		export PLUGINS_OUTDIR=$PLUGINS_ROOT_OUTDIR/$PLUGIN/$NAMESPACE/$ACTION
		export PLUGINS_DEBUG_OUTDIR=$PLUGINS_ROOT_DEBUG_OUTDIR/$PLUGIN/$NAMESPACE/$ACTION
	else
		export PLUGINS_OUTDIR=$PLUGINS_ROOT_OUTDIR/$PLUGIN/PRODGRP=$PRODGROUP/$NAMESPACE/$ACTION
		export PLUGINS_DEBUG_OUTDIR=$PLUGINS_ROOT_DEBUG_OUTDIR/$PLUGIN/PRODGRP=$PRODGROUP/$NAMESPACE/$ACTION
	fi

	export PLUGINS_ANALYZE_OUTFILE=$ANALYZE_OUTFILE.$PLUGIN-$NAMESPACE-$ACTION
	export PLUGINS_PARAM_FILE="$MUSTGATHER_DIRNAME/config/plugins/$PLUGIN/$ACTION/plugin-$PLUGIN-$ACTION-${PROD_VER}.param"	
	export PLUGINS_SCRIPT="$MUSTGATHER_DIRNAME/config/plugins/$PLUGIN/$ACTION/plugin-$PLUGIN-$ACTION-${PROD_VER}.sh"	

	if [ -s $PLUGINS_SCRIPT ]
	then
		if [ ! -d $PLUGINS_OUTDIR ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Making directory [$PLUGINS_OUTDIR]..."
			mkdir -p $PLUGINS_OUTDIR
		fi

		if [ ${#TIMEOUT} -gt 0 ]
		then
			local TIMEOUT_CMD="$TIMEOUT $PLUGINS_TIMEOUT"
		else
			local TIMEOUT_CMD=""
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] TIMEOUT_CMD = [$TIMEOUT_CMD]"

			if [ ! -d $PLUGINS_DEBUG_OUTDIR ]
			then	
				echo "[$(date)] [${FUNCNAME[0]}] Making directory [$PLUGINS_DEBUG_OUTDIR]..."
				mkdir -p $PLUGINS_DEBUG_OUTDIR
			fi
		fi

		# Exporting user defined variables in PLUGINS_PARAM_FILE
		if [ -s $PLUGINS_PARAM_FILE ]
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Plugin [$PLUGIN] parameter file = [$PLUGINS_PARAM_FILE]"
			fi
	
			while read LINE
			do
				if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi	

				# Only process lines that are in format PARAM=VALUE
				local PLUGIN_PARAM_CHECK_RES=$(echo "$LINE" | $AWK '/^[^ ]+.*[^ ]+=[^ ]+/ { print }')

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] LINE = [$LINE]"
					echo "[$(date)] [${FUNCNAME[0]}] PLUGIN_PARAM_CHECK_RES = [$PLUGIN_PARAM_CHECK_RES][${#PLUGIN_PARAM_CHECK_RES}]"
				fi

				if [ ${#PLUGIN_PARAM_CHECK_RES} -eq 0 ]
				then
					continue
				fi

				local VAR=$(echo "$LINE" | $AWK -F= '{ print $1 }')
				# local VALUE=$(echo "$LINE" | $AWK -F= '{ print $2 }' | sed 's/^"//' | sed 's/"$//')
				local VALUE=$(echo "$LINE" | cut -f 2- -d = | sed 's/^"//' | sed 's/"$//')
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [PARAM-FILE] Exporting environment variable [$VAR = $VALUE]"
				fi
	
				export $VAR="$VALUE"
			done < $PLUGINS_PARAM_FILE
		fi

		# Exporting user provided environment variables
		local PLUGIN_ENVFILE=$PLUGINS_ROOT_OUTDIR/$PLUGIN.$ACTION.userenv

		if [ ${#PLUGINS_ENV} -gt 0 ] || [ -s $PLUGIN_ENVFILE ]
		then
			if [ -f $PLUGIN_ENVFILE ]
			then
				while read VARVALUE
				do
					local VAR=$(echo "$VARVALUE" | $AWK -F= '{ print $1 }')
					local VALUE=$(echo "$VARVALUE" | cut -f 2- -d = | sed 's/^"//' | sed 's/"$//' | sed "s/^'//" | sed "s/'$//")
		
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [USER-INPUT] Exporting environment variable [$VAR = $VALUE]"
					fi
		
					export $VAR="$VALUE"
				done < $PLUGIN_ENVFILE
			else
				echo "[$(date)] [${FUNCNAME[0]}] No user environment file [$PLUGIN_ENVFILE] is found for plugin [$PLUGIN]!"	
			fi
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Executing plugin [$PLUGIN] with script [$PLUGINS_SCRIPT]..."
		local MYCMD="$TIMEOUT_CMD bash $PLUGINS_SCRIPT"
		eval "$MYCMD" 2>&1

		if [ ${#TIMEOUT} -gt 0 ]
		then
			if [ $? -eq 124 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Plugin execution [$PLUGINS_SCRIPT] timeout after $PLUGINS_TIMEOUT!"
			fi
		fi

		# Merge PLUGINS_ANALYZE_OUTFILE into ANALYZE_OUTFILE
		if [ -s $PLUGINS_ANALYZE_OUTFILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Merging PLUGINS_ANALYZE_OUTFILE [$PLUGINS_ANALYZE_OUTFILE] into ANALYZE_OUTFILE [$ANALYZE_OUTFILE]..."
			cat $PLUGINS_ANALYZE_OUTFILE >> $ANALYZE_OUTFILE

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Backing up PLUGINS_ANALYZE_OUTFILE [$PLUGINS_ANALYZE_OUTFILE] to directory [$PLUGINS_DEBUG_OUTDIR]..."
				cp -p $PLUGINS_ANALYZE_OUTFILE $PLUGINS_DEBUG_OUTDIR
			fi

			echo "[$(date)] [${FUNCNAME[0]}] Removing PLUGINS_ANALYZE_OUTFILE [$PLUGINS_ANALYZE_OUTFILE]..."
			rm $PLUGINS_ANALYZE_OUTFILE
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up plugin [$PLUGIN] script file [$PLUGINS_SCRIPT] to directory [$PLUGINS_DEBUG_OUTDIR]..."
			cp -p $PLUGINS_SCRIPT $PLUGINS_DEBUG_OUTDIR

			if [ -f $PLUGINS_PARAM_FILE ] 
			then
				echo "[$(date)] [${FUNCNAME[0]}] Backing up plugin [$PLUGIN] parameter file [$PLUGINS_PARAM_FILE] to directory [$PLUGINS_DEBUG_OUTDIR]..."
				cp -p $PLUGINS_PARAM_FILE $PLUGINS_DEBUG_OUTDIR
			fi
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Plugin script file [$PLUGINS_SCRIPT] for plugin [$PLUGIN] does not exist or is zero-sized! Skipping..."
	fi
}

processCpFiles()
{
	if [ $MG_DEBUG == "true" ]
	then
		local FUNC_START=$(getFuncStartTime)
	fi

	local INPUT_CONFIG=$1
	local OUTPUT_FILE=$2	
	local CPFILES_PROD_GROUP=$3
	local CPFILES_PROD_VER=$4
	local CPFILES_PROD_VER_SHORT=$5
	local CPFILES_PROD_GROUP_NS_REFFILE=$6
	local CPFILES_CUSTOM_DATA=$7

	if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
	then
		local CPFILES_WORK_OUTDIR=$CPFILES_ROOT_OUTDIR
	else
		local CPFILES_WORK_OUTDIR=$CPFILES_ROOT_OUTDIR/PRODGRP=$CPFILES_PROD_GROUP
	fi

	local TAG=
	local CFGLINE=
	local PROD_NS=
	local NS=
	local POD=
	local CFGLINE_CTR=0

	local CFGFILE_MODE_COLUMNS=1
	local MANUAL_MODE_COLUMNS=5
	local CUSTOM_CFGFILE_MODE_COLUMNS=6

	if [ ! -d $(dirname $OUTPUT_FILE) ]
	then
		mkdir -p $(dirname $OUTPUT_FILE)
	fi

	if [ ! -d $CPFILES_WORK_OUTDIR ]
	then
		mkdir -p $CPFILES_WORK_OUTDIR
	fi

	local DEF_ENV_ARR=()

	local CPFILES_USER_INPUT_ENV=$(compgen -A variable | grep -E '^RTVAR_CPFILES_' | tr '\n' ' ')

	if [ ${#CPFILES_USER_INPUT_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for USER_INPUT_ENV in $CPFILES_USER_INPUT_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$USER_INPUT_ENV] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$USER_INPUT_ENV"
		done	
	fi

	local GMGFVAR_ENV=$(compgen -A variable | grep -E '^RTVAR_GMGFVAR_' | tr '\n' ' ')

	if [ ${#GMGFVAR_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for GMGFVAR in $GMGFVAR_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$GMGFVAR] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$GMGFVAR"
		done	
	fi

	IFS=$'\n'
	for DEF_ENV in ${DEF_ENV_ARR[@]}
	do
		if [[ $DEF_ENV =~ ^-f ]]
		then
			local CPFILES_FUNCNAME=$(echo "$DEF_ENV" | $AWK '{ print $2 }')

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment function [$CPFILES_FUNCNAME]..."
			fi

			export -f $CPFILES_FUNCNAME
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$DEF_ENV = ${!DEF_ENV}]"
			fi

			export $DEF_ENV
		fi
	done

	if [ ${#INPUT_CONFIG} -gt 0 ]
	then
		local NUM_COLUMN=$(echo "$INPUT_CONFIG" | $AWK -F${CPFILES_CFGFILE_DELIMITER} '{ print NF }')

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] INPUT_CONFIG=[$INPUT_CONFIG] / COLUMNS=[$NUM_COLUMN]"
		fi
		
		# Configuration file mode 
		if [ $NUM_COLUMN -eq $CFGFILE_MODE_COLUMNS ]
		then
			# local PROD_VER=$(echo "$PRODUCT_VERSION" | sed 's/\.//g')
			if [ ${#RTVAR_CPFILES_CFGFILE} -gt 0 ]
			then
				local CFGFILE="$RTVAR_CPFILES_CFGFILE"
			else
				if [ ${#CPFILES_CUSTOM_DATA} -gt 0 ]
				then
					local CFGFILE="$CPFILES_CUSTOM_DATA"
				else
					local CFGFILE="$MUSTGATHER_DIRNAME/config/cpfiles/$CPFILES_PROD_VER/config/cpfiles.cfg"
				fi
			fi
		
			if [ ! -s $CFGFILE ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Configuration file [$CFGFILE] does not exist or is zero-sized! Exiting..."
				return 1
			fi
		
			if [ ${#CPFILES_CUSTOM_DATA} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Backing up custom CPFILES configuration file [$CFGFILE] to directory [$CPFILES_WORK_OUTDIR]..."

				if [ $(echo "$CPFILES_DATA_SCRIPTDIR" | grep -E "$CPFILES_PROD_VER" | wc -l) -gt 0 ]
				then
					cp -p $CFGFILE $CPFILES_WORK_OUTDIR/$(basename $CFGFILE).1
				else
					cp -p $CFGFILE $CPFILES_WORK_OUTDIR/$(basename $CFGFILE).2
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] Backing up CPFILES configuration file [$CFGFILE] to directory [$CPFILES_WORK_OUTDIR]..."
				cp -p $CFGFILE $CPFILES_WORK_OUTDIR
			fi

			local TOTAL_INPUT_TAGS=$(echo "$INPUT_CONFIG" | $AWK -F@@ '{ print NF }')

			if [ $TOTAL_INPUT_TAGS -eq 1 ]
			then
				if [ "$INPUT_CONFIG" == "ALL" ]
				then
					local FILTER_CMD="grep -E -v '^[ ]*$CPFILES_CFGFILE_COMMENT' $CFGFILE"
				else
					local FILTER_CMD="grep -E "^\${TAG}${CPFILES_CFGFILE_DELIMITER}" $CFGFILE"
				fi
			else
				local FILTER_CMD="grep -E "^\${TAG}${CPFILES_CFGFILE_DELIMITER}" $CFGFILE"
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$INPUT_CONFIG] Total tags = [$TOTAL_INPUT_TAGS]"
				echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$INPUT_CONFIG] FILTER_CMD = [$FILTER_CMD]"
			fi

			IFS=$OLDIFS
			for TAG in $(echo "$INPUT_CONFIG" | sed 's/@@/ /g')
			do
				local MATCH_FOUND="false"
	
				echo "[$(date)] [${FUNCNAME[0]}] Entering configuration file mode [CFGFILE = $CFGFILE]..."

				IFS=$'\n'
				for CFGLINE in $(eval "$FILTER_CMD")
				do
					(( CFGLINE_CTR=CFGLINE_CTR+1 ))

					MATCH_FOUND="true"
	
					local TAGNAME=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $1 }')
					local NAMESPACE=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $2 }')
					local PODNAME=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $3 }')
					local CONTAINER=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $4 }')
					local REGEXSCRIPT=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $5 }')
					local FILES=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $6 }')
					local LIMITS=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $7 }')
		
					local NS_ARR=()
					local CPFILES_LINE_POD_CTR=0

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] CFGLINE = [$CFGLINE]"
						echo "[$(date)] [${FUNCNAME[0]}] TAGNAME = [$TAGNAME] / NAMESPACE = [$NAMESPACE] / PODNAME = [$PODNAME] / CONTAINER = [$CONTAINER] / REGEXSCRIPT = [$REGEXSCRIPT] / FILES = [$FILES] / LIMITS = [$LIMITS]"
					fi

					if [ ${#TAGNAME} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] TAGNAME is empty/null! Skipping..."
						continue
					fi

					if [ ${#NAMESPACE} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] NAMESPACE is empty/null! Skipping..."
						continue
					fi

					if [ ${#PODNAME} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] PODNAME is empty/null! Skipping..."
						continue
					fi

					if [ ${#FILES} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] FILES is empty/null! Skipping..."
						continue
					fi

		
					if [ $TAG == $TAGNAME ] || [ $TAG == "ALL" ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Config line [$CFGLINE] matches tag [$TAG]"
							echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Size of CPFILES_PROCESSED_TAGS = [${#CPFILES_PROCESSED_TAGS[@]}]"
						fi
				
						if [ ${#CPFILES_PROCESSED_TAGS[@]} -gt 0 ]
						then				
							local CPFILES_PROC_TO_PROCEED="true"

							for PROC_TAG in ${CPFILES_PROCESSED_TAGS[@]}
							do
								if [ "$PROC_TAG" == "$TAGNAME" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] WARNING: Tag [$TAGNAME] was proceesed earlier! Skipping config line [$CFGLINE]!"
									local CPFILES_PROC_TO_PROCEED="false"
									break
								fi
							done

							if [ $CPFILES_PROC_TO_PROCEED == "false" ]
							then
								continue
							fi
						fi

						if [[ "$NAMESPACE" =~ ^NS4PROD= ]]
						then
							local PROD_NAME=$(echo "$NAMESPACE" | $AWK -F= '{ print $2 }')
		
							echo "[$(date)] [${FUNCNAME[0]}] [CFG = $CFGLINE] Attempting to retrieve namespace for product [$PROD_NAME]..."

							if [ ${PROD_VERSIONS_SINGLE_PRODGROUP} == "true" ]
							then
								local PROD_NAMESPACES=$(getProdToNamespacesMapping $PROD_NAME)
							else
								local PROD_NAMESPACES=$(getProdToNamespacesMapping $PROD_NAME $CPFILES_PROD_GROUP_NS_REFFILE)
							fi

							echo "[$(date)] [${FUNCNAME[0]}] [CFG = $CFGLINE] Namespace retrieved for product [$PROD_NAME] = [$PROD_NAMESPACES]"
		
							if [ "$PROD_NAMESPACES" == $PROD_NAMESPACES_INVALID_STR ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [CFG = $CFGLINE] Unable to determine namespace! Skipping..."
								continue
							else
								IFS=$OLDIFS
								for PROD_NS in $PROD_NAMESPACES	
								do
									echo "[$(date)] [${FUNCNAME[0]}] [CFG = $CFGLINE] Adding product namespace [$PROD_NS]..."
									local NS_ARR[${#NS_ARR[@]}]=$PROD_NS
								done
								IFS=$'\n'
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
							if ! checkUserPriv get namespace $NAMESPACE
							then
								echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform verb [get] on resource [namespace]! Skipping..."
								continue	
							fi
	
							if ! $OC_CMD get ns $NAMESPACE > /dev/null
							then
								echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $CFGLINE] Namespace [$NAMESPACE] does not exist! Skipping..."
								continue
							else
								local NS_ARR[${#NS_ARR[@]}]=$NAMESPACE
							fi
						fi
	
						IFS=$OLDIFS
						for NS in ${NS_ARR[@]}
						do
							if toExcludeProdNamespace $NS
							then
								echo "[$(date)] [${FUNCNAME[0]}] [CFGLINE = $CFGLINE] To exclude namespace [$NS]. Skipping..."
								continue
							fi	

							echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 
	
							if ! checkUserPriv get pod $NS
							then
								echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform verb [get] on resource [pod] in namespace [$NS]! Skipping..."
								continue	
							fi
	
							if ! checkUserPriv create pods/exec $NS
							then
								echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform verb [exec] on resource 'pod' in namespace [$NS]! Skipping..."
								continue
							fi

							if [ "$PODNAME" == "OBJNAME" ]
							then
								if [ ${#REGEXSCRIPT} -eq 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] PODNAME is set to [OBJNAME], but REGEXSCRIPT is empty/null! Skipping..."
									continue
								else
									if [[ ! $REGEXSCRIPT =~ ^/ ]]
									then
										if [ ${#CPFILES_DATA_SCRIPTDIR} -gt 0 ]
										then
											local REGEXSCRIPT=$CPFILES_DATA_SCRIPTDIR/$REGEXSCRIPT
										else
											local REGEXSCRIPT=$MUSTGATHER_DIRNAME/config/cpfiles/$CPFILES_PROD_VER/scripts/$REGEXSCRIPT
										fi
									fi
		
									local REGEXSCRIPT_LOC=$(echo "$REGEXSCRIPT" | $AWK '{ print $1 }')
			
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] REGEXSCRIPT_LOC = [$REGEXSCRIPT_LOC]"
									fi
		
									if [ ! -s $REGEXSCRIPT_LOC ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] REGEXSCRIPT [$REGEXSCRIPT_LOC] does not exist or is zero-sized! Skipping..."
										continue
									else
										if [ ${#TIMEOUT} -gt 0 ]
										then
											local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $REGEXSCRIPT $NS"	
											echo "[$(date)] [${FUNCNAME[0]}] Executing regex script [$CMD]..."
											PODNAME=$(eval "$CMD")
											C_EXITSTATUS=$?
						
											if [ $C_EXITSTATUS -eq 124 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Regex script [$REGEXSCRIPT] timeout after $DEFAULT_TIMEOUT! Skipping..."
												continue
											else	
												if [ $MG_DEBUG == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT] exits with status [$C_EXITSTATUS]"
												fi
											fi
										else
											local CMD="/bin/bash $REGEXSCRIPT $NS"	
											echo "[$(date)] [${FUNCNAME[0]}] Executing regex script [$CMD]..."
											PODNAME=$(eval "$CMD")
											C_EXITSTATUS=$?
		
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Regex script file [$REGEXSCRIPT] exits with status [$C_EXITSTATUS]"
											fi
										fi
		
										echo "[$(date)] [${FUNCNAME[0]}] Expanded PODNAME regex = [$PODNAME]"
		
										if [ ${#PODNAME} -eq 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Expanded PODNAME is empty/null! Skipping..."
											continue
										fi
									fi
								fi
							fi

							if [[ ${FILES} =~ ^bash[[:space:]] ]]
							then
								local FILES_SCRIPT_NAME=$(echo "$FILES" | $AWK '{ print $2 }')
								local FILES_SCRIPT_ARGS=$(echo "$FILES" | $AWK '{ $1="";$2="" } END { print }' | sed 's/^[ ]*//')

								if [[ ! $FILES_SCRIPT_NAME =~ ^/ ]]
								then
									if [ ${#CPFILES_DATA_SCRIPTDIR} -gt 0 ]
									then
										local FILES_SCRIPT_NAME=$CPFILES_DATA_SCRIPTDIR/$FILES_SCRIPT_NAME
									else
										local FILES_SCRIPT_NAME=$MUSTGATHER_DIRNAME/config/cpfiles/$CPFILES_PROD_VER/scripts/$FILES_SCRIPT_NAME
									fi	
								fi
		
								local FILES_SCRIPT_LOC=$(echo "$FILES_SCRIPT_NAME" | $AWK '{ print $1 }')
			
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] FILES_SCRIPT_NAME = [$FILES_SCRIPT_NAME]"
									echo "[$(date)] [${FUNCNAME[0]}] FILES_SCRIPT_ARGS = [$FILES_SCRIPT_ARGS]"
								fi

								if [ ! -s $FILES_SCRIPT_NAME ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] FILES script [$FILES_SCRIPT_NAME] does not exist or is zero-sized! Skipping..."
									continue
								else
									if [ ${#TIMEOUT} -gt 0 ]
									then
										local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $FILES_SCRIPT_NAME $FILES_SCRIPT_ARGS $NS"	
										echo "[$(date)] [${FUNCNAME[0]}] Executing regex script [$CMD]..."
										FILES=$(eval "$CMD")
										C_EXITSTATUS=$?
					
										if [ $C_EXITSTATUS -eq 124 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] FILES script [$FILES_SCRIPT_NAME] timeout after $DEFAULT_TIMEOUT! Skipping..."
											continue
										else	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] FILES script file [$FILES_SCRIPT_NAME] exits with status [$C_EXITSTATUS]"
											fi
										fi
									else
										local CMD="/bin/bash $FILES_SCRIPT_NAME $FILES_SCRIPT_ARGS $NS"	
										echo "[$(date)] [${FUNCNAME[0]}] Executing regex script [$CMD]..."
										FILES=$(eval "$CMD")
										C_EXITSTATUS=$?
	
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] FILES script file [$FILES_SCRIPT_NAME] exits with status [$C_EXITSTATUS]"
										fi
									fi
	
									if [ ${#FILES} -eq 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Expanded FILES is empty/null! Skipping..."
										continue
									else
										local FILES_SCRIPT_OUTPUT_COUNT=$(echo "$FILES" | wc -l)	
			
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] FILES_SCRIPT_OUTPUT_COUNT = [$FILES_SCRIPT_OUTPUT_COUNT]"
										fi
										
										if [ ${FILES_SCRIPT_OUTPUT_COUNT} -eq 1 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Expanded FILES = [$FILES]"
										else
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] FILES script output = [$FILES]"
											fi
	
											# For multiple lines script output, first line is treated as FILES and second line as LIMITS
											local NEW_LIMITS=$(echo "$FILES" | sed -n "2p")
											FILES=$(echo "$FILES" | head -1) 
	
											if [ ${#FILES} -eq 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Expanded FILES is empty/null! Skipping..."
												continue
											else
												echo "[$(date)] [${FUNCNAME[0]}] Expanded FILES = [$FILES]"
											fi
						
											if [ ${#LIMITS} -gt 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] Replacing current LIMITS [$LIMITS] with new LIMITS [$NEW_LIMITS]..."
											else
												echo "[$(date)] [${FUNCNAME[0]}] Setting LIMITS to [$NEW_LIMITS]..."
											fi
	
											LIMITS="$NEW_LIMITS"
										fi
									fi
								fi
							fi

							IFS=$OLDIFS
							local CPFILES_POD_CTR=0
	
							for POD in $($OC_CMD get pod --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}' -n $NS | $AWK '/'$PODNAME'/ { print }' | tr '\n' ' ' | sed 's/[ ]$//')
							do
								local POD_STATUS=$($OC_CMD get pod -n $NS --no-headers $POD | $AWK '{ print $3 }')
	
								if [ ${#POD_STATUS} -eq 0 ] || [ ! $POD_STATUS == "Running" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [namespace=$NS # pod=$POD # status=$POD_STATUS] Pod is not in RUNNING state! Skipping..."
									continue
								else
									if [ ${#INPUT_FILE_LIST[@]} -gt 0 ]
									then
										unset INPUT_FILE_LIST
									fi

									if [ ${#INPUT_FILE_LIMIT[@]} -gt 0 ]
									then
										unset INPUT_FILE_LIMIT
									fi

									if [ ${#LIMITS} -eq 0 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$FILES] to final config file [$OUTPUT_FILE]..."
										echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$FILES" >> $OUTPUT_FILE
									else
										# To test whether target pod comes with bash shell 
										if [ ${#CONTAINER} -gt 0 ]
										then
											local POD_BASH_TEST=$($OC_CMD exec -n $NS -c $CONTAINER $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- bash -c 'date')
										else
											local POD_BASH_TEST=$($OC_CMD exec -n $NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- bash -c 'date')
										fi
							
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] POD_BASH_TEST = [$POD_BASH_TEST]"
										fi
							
										if [ ${#POD_BASH_TEST} -gt 0 ]
										then
											local POD_SHELL="bash"
										else
											local POD_SHELL="sh"
										fi
						
										echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] Setting POD_SHELL for target pod [$POD] to [$POD_SHELL]!"
	
										if [[ ${FILES} =~ : ]]
										then
											# Configuration of multiple files/directories
											local INPUT_FILE_LIST_ITEM_COUNT=$(echo "$FILES" | $AWK -F: '{ print NF }')
											local INPUT_FILE_LIMIT_ITEM_COUNT=$(echo "$LIMITS" | $AWK -F: '{ print NF }')

											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$POD] INPUT_FILE_LIST_ITEM_COUNT = [$INPUT_FILE_LIST_ITEM_COUNT] / INPUT_FILE_LIMIT_ITEM_COUNT = [$INPUT_FILE_LIMIT_ITEM_COUNT]"
											fi

											if [ ${INPUT_FILE_LIST_ITEM_COUNT} -ne ${INPUT_FILE_LIMIT_ITEM_COUNT} ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$POD] INPUT_FILE_LIST_ITEM_COUNT [$INPUT_FILE_LIST_ITEM_COUNT] does not equal to INPUT_FILE_LIMIT_ITEM_COUNT [$INPUT_FILE_LIMIT_ITEM_COUNT]! Skipping..."
												continue
											fi							

											local CFG_FILE_LINE_CTR=0
											set -f
	
											for CFG_FILE_LINE in $(echo "$FILES" | sed 's/:/ /g')
											do
												(( CFG_FILE_LINE_CTR=CFG_FILE_LINE_CTR+1 ))

												if [ $MG_DEBUG == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] [$POD] [$CFG_FILE_LINE_CTR] CFG_FILE_LINE = [$CFG_FILE_LINE]"
												fi

												local INPUT_FILE_CUR_LIMIT=$(echo "$LIMITS" | $AWK -F: '{ print $'$CFG_FILE_LINE_CTR' }')

												if [ ${#INPUT_FILE_CUR_LIMIT} -gt 0 ]
												then
													if [[ ! "$INPUT_FILE_CUR_LIMIT" =~ ^head[[:space:]]*-[0-9]*$ ]] && [[ ! "$INPUT_FILE_CUR_LIMIT" =~ ^tail[[:space:]]*-[0-9]*$ ]]
													then
														echo "[$(date)] [${FUNCNAME[0]}] [$POD] [$CFG_FILE_LINE_CTR] INPUT_FILE_CUR_LIMIT [$INPUT_FILE_CUR_LIMIT] is invalid! Skipping..."
														continue
													fi
												fi

												local INPUT_FILE_LIST[${#INPUT_FILE_LIST[@]}]="$CFG_FILE_LINE"
												local INPUT_FILE_LIMIT[${#INPUT_FILE_LIMIT[@]}]="$INPUT_FILE_CUR_LIMIT"

												if [ $MG_DEBUG == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] [$POD] [$CFG_FILE_LINE_CTR] INPUT_FILE_LIST = [${INPUT_FILE_LIST[@]}] [LEN=${#INPUT_FILE_LIST[@]}]"
													echo "[$(date)] [${FUNCNAME[0]}] [$POD] [$CFG_FILE_LINE_CTR] INPUT_FILE_LIMIT = [${INPUT_FILE_LIMIT[@]}] [LEN=${#INPUT_FILE_LIMIT[@]}]"
												fi
											done

											set +f
										else
											if [[ ! "$LIMITS" =~ ^head[[:space:]]*-[0-9]*$ ]] && [[ ! "$LIMITS" =~ ^tail[[:space:]]*-[0-9]*$ ]]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$POD] LIMIT [$LIMIT] is invalid! Skipping..."
												continue
											fi

											local INPUT_FILE_LIST=("$FILES")
											local INPUT_FILE_LIMIT=("$LIMITS")
										fi

										if [ ${#INPUT_FILE_LIST[@]} -ne ${#INPUT_FILE_LIMIT[@]} ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$POD] Total item in INPUT_FILE_LIST [${#INPUT_FILE_LIST[@]}] does not equal total item in INPUT_FILE_LIMIT [${#INPUT_FILE_LIMIT[@]}]! Skipping..."
											continue
										else
											echo "[$(date)] [${FUNCNAME[0]}] [$POD] Final length: INPUT_FILE_LIST = [${#INPUT_FILE_LIST[@]}] / INPUT_FILE_LIMIT = [${#INPUT_FILE_LIMIT[@]}]"
										fi

										local INPUT_FILE_CTR=0
										set -f

										for INPUT_FILE in ${INPUT_FILE_LIST[@]}
										do
											local INPUT_FILE_REGEX="false"
											local INPUT_LIMIT=${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}

											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$POD] INPUT_FILE_CTR = [$INPUT_FILE_CTR] / INPUT_FILE = [$INPUT_FILE] / INPUT_LIMIT = [$INPUT_LIMIT]"
											fi	

											if [ ${#CONTAINER} -gt 0 ]
											then
												if echo x"$INPUT_FILE" | grep -E '\*|\[|\?|{.*}' > /dev/null 
												then
													if [ ${#INPUT_LIMIT} -gt 0 ]
													then
														local INPUT_FILE_REGEX="true"
														local TGT_FILE_LIST_CMD="$OC_CMD exec -n $NS -c $CONTAINER $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -dt $INPUT_FILE | ${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}'"
													else
														echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE] to final config file [$OUTPUT_FILE]..."
														echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE" >> $OUTPUT_FILE
														(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
														continue
													fi
												else
													if [ ${#INPUT_LIMIT} -gt 0 ]
													then
														local TGT_FILE_LIST_CMD="$OC_CMD exec -n $NS -c $CONTAINER $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -t $INPUT_FILE | ${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}'"
													else
														echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE] to final config file [$OUTPUT_FILE]..."
														echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE" >> $OUTPUT_FILE
														(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
														continue
													fi
												fi
											else
												if echo x"$INPUT_FILE" | grep -E '\*|\[|\?|{.*}' > /dev/null 
												then
													if [ ${#INPUT_LIMIT} -gt 0 ]
													then
														local INPUT_FILE_REGEX="true"
														local TGT_FILE_LIST_CMD="$OC_CMD exec -n $NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -dt $INPUT_FILE | ${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}'"
													else
														echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE] to final config file [$OUTPUT_FILE]..."
														echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE" >> $OUTPUT_FILE
														(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
														continue
													fi
												else
													if [ ${#INPUT_LIMIT} -gt 0 ]
													then
														local TGT_FILE_LIST_CMD="$OC_CMD exec -n $NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -t $INPUT_FILE | ${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}'"
													else
														echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE] to final config file [$OUTPUT_FILE]..."
														echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE" >> $OUTPUT_FILE
														(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
														continue
													fi
												fi
											fi
								
											local TGT_FILE_LIST=$(eval "$TGT_FILE_LIST_CMD")
			
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] INPUT_FILE_REGEX = [$INPUT_FILE_REGEX]"
												echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] TGT_FILE_LIST_CMD = [$TGT_FILE_LIST_CMD]"
												echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] TGT_FILE_LIST = [$TGT_FILE_LIST]"
											fi	
			
											if [ ${#TGT_FILE_LIST} -gt 0 ]
											then
												for TGT_FILE in $TGT_FILE_LIST
												do
													if [ $INPUT_FILE_REGEX == "true" ]
													then
														echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$TGT_FILE] to final config file [$OUTPUT_FILE]..."
														echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$TGT_FILE" >> $OUTPUT_FILE
													else
														echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE/$TGT_FILE] to final config file [$OUTPUT_FILE]..."
														echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE/$TGT_FILE" >> $OUTPUT_FILE
													fi
												done
											else
												echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] TGT_FILE_LIST is empty/null!"
											fi
		
											(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
										done

										set +f
									fi
								fi								
		
								(( CPFILES_POD_CTR=CPFILES_POD_CTR+1 ))
							done

							echo "[$(date)] [${FUNCNAME[0]}] [CFG = $CFGLINE] [NS=$NS] Total pods involved = [$CPFILES_POD_CTR]"
						done
						IFS=$'\n'

						echo "[$(date)] [${FUNCNAME[0]}] [$CFGLINE_CTR] Adding tag [$TAGNAME] into CPFILES_PROCESSED_TAGS array..."
						CPFILES_PROCESSED_TAGS[${#CPFILES_PROCESSED_TAGS[@]}]="$TAGNAME"
					else
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Config line [$CFGLINE] does NOT match tag [$TAG]. Skipping..."
						fi
					fi
				done
				IFS=$OLDIFS
	
				if [ $MATCH_FOUND == "false" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] No config line in file [$CFGFILE] matches tag [$TAG]!"
				fi
			done
		else
			# Manual (dynamic) mode
			if [ $NUM_COLUMN -eq ${MANUAL_MODE_COLUMNS} ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Entering manual/dynamic mode..."
	
				local NAMESPACE=$(echo "$INPUT_CONFIG" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $1 }')
				local PODNAME=$(echo "$INPUT_CONFIG" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $2 }')
				local CONTAINER=$(echo "$INPUT_CONFIG" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $3 }')
				local FILES=$(echo "$INPUT_CONFIG" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $4 }')
				local LIMITS=$(echo "$INPUT_CONFIG" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $5 }')
	
				if [ ${#NAMESPACE} -eq 0 ] || [ ${#PODNAME} -eq 0 ] || [ ${#FILES} -eq 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Key columns [NAMESPACE and PODNAME and FILES] cannot be empty! Exiting..."
					return 1
				fi
	
				local NS_ARR=()
				local CPFILES_LINE_POD_CTR=0
	
				if [[ "$NAMESPACE" =~ ^NS4PROD= ]]
				then
					local PROD_NAME=$(echo "$NAMESPACE" | $AWK -F= '{ print $2 }')
	
					echo "[$(date)] [${FUNCNAME[0]}] [CFG = $INPUT_CONFIG] Attempting to retrieve namespace for product [$PROD_NAME]..."
	
					if [ ${PROD_VERSIONS_SINGLE_PRODGROUP} == "true" ]
					then
						local PROD_NAMESPACES=$(getProdToNamespacesMapping $PROD_NAME)
					else
						local PROD_NAMESPACES=$(getProdToNamespacesMapping $PROD_NAME $CPFILES_PROD_GROUP_NS_REFFILE)
					fi

					echo "[$(date)] [${FUNCNAME[0]}] [CFG = $INPUT_CONFIG] Namespace retrieved for product [$PROD_NAME] = [$PROD_NAMESPACES]"
	
					if [ "$PROD_NAMESPACES" == $PROD_NAMESPACES_INVALID_STR ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFG = $INPUT_CONFIG] Unable to determine namespace! Skipping..."
						continue
					else
						for PROD_NS in $PROD_NAMESPACES	
						do
							echo "[$(date)] [${FUNCNAME[0]}] [CFG = $INPUT_CONFIG] Adding product namespace [$PROD_NS]..."
							local NS_ARR[${#NS_ARR[@]}]=$PROD_NS
						done
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Checking user privileges..." 

					if ! checkUserPriv get namespace $NAMESPACE
					then
						echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform verb [get] on resource [namespace]! Skipping..."
						continue	
					fi

					if ! $OC_CMD get ns $NAMESPACE > /dev/null
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFG = $INPUT_CONFIG] Namespace [$NAMESPACE] does not exist! Skipping..."
						continue
					else
						echo "[$(date)] [${FUNCNAME[0]}] [CFG = $INPUT_CONFIG] Adding valid namespace [$NAMESPACE] into array NS_ARR..."
						local NS_ARR[${#NS_ARR[@]}]=$NAMESPACE
					fi
				fi
	
				for NS in ${NS_ARR[@]}
				do
					if toExcludeProdNamespace $NS
					then
						echo "[$(date)] [${FUNCNAME[0]}] [CFG = $INPUT_CONFIG] To exclude namespace [$NS]. Skipping..."
						continue
					fi	

					if ! checkUserPriv create pods/exec $NS
					then
						echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform verb [exec] on resource 'pod' in namespace [$NS]! Skipping..."
						continue
					fi

					if [[ ${FILES} =~ ^bash[[:space:]] ]]
					then
						local FILES_SCRIPT_NAME=$(echo "$FILES" | $AWK '{ print $2 }')
						local FILES_SCRIPT_ARGS=$(echo "$FILES" | $AWK '{ $1="";$2="" } END { print }' | sed 's/^[ ]*//')

						if [[ ! $FILES_SCRIPT_NAME =~ ^/ ]]
						then
							if [ ${#CPFILES_DATA_SCRIPTDIR} -gt 0 ]
							then
								local FILES_SCRIPT_NAME=$CPFILES_DATA_SCRIPTDIR/$FILES_SCRIPT_NAME
							else
								local FILES_SCRIPT_NAME=$MUSTGATHER_DIRNAME/config/cpfiles/$CPFILES_PROD_VER/scripts/$FILES_SCRIPT_NAME
							fi
						fi

						local FILES_SCRIPT_LOC=$(echo "$FILES_SCRIPT_NAME" | $AWK '{ print $1 }')
	
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] FILES_SCRIPT_NAME = [$FILES_SCRIPT_NAME]"
							echo "[$(date)] [${FUNCNAME[0]}] FILES_SCRIPT_ARGS = [$FILES_SCRIPT_ARGS]"
						fi

						if [ ! -s $FILES_SCRIPT_NAME ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] FILES script [$FILES_SCRIPT_NAME] does not exist or is zero-sized! Skipping..."
							continue
						else
							if [ ${#TIMEOUT} -gt 0 ]
							then
								local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $FILES_SCRIPT_NAME $FILES_SCRIPT_ARGS $NS"	
								echo "[$(date)] [${FUNCNAME[0]}] Executing regex script [$CMD]..."
								FILES=$(eval "$CMD")
								C_EXITSTATUS=$?
			
								if [ $C_EXITSTATUS -eq 124 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] FILES script [$FILES_SCRIPT_NAME] timeout after $DEFAULT_TIMEOUT! Skipping..."
									continue
								else	
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] FILES script file [$FILES_SCRIPT_NAME] exits with status [$C_EXITSTATUS]"
									fi
								fi
							else
								local CMD="/bin/bash $FILES_SCRIPT_NAME $FILES_SCRIPT_ARGS $NS"	
								echo "[$(date)] [${FUNCNAME[0]}] Executing regex script [$CMD]..."
								FILES=$(eval "$CMD")
								C_EXITSTATUS=$?
	
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] FILES script file [$FILES_SCRIPT_NAME] exits with status [$C_EXITSTATUS]"
								fi
							fi
							
							if [ ${#FILES} -eq 0 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Expanded FILES is empty/null! Skipping..."
								continue
							else
								local FILES_SCRIPT_OUTPUT_COUNT=$(echo "$FILES" | wc -l)	
	
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] FILES_SCRIPT_OUTPUT_COUNT = [$FILES_SCRIPT_OUTPUT_COUNT]"
								fi
								
								if [ ${#FILES_SCRIPT_OUTPUT_COUNT} -gt 0 ]
								then
									if [ $(echo "$FILES" | wc -l) -eq 1 ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Expanded FILES = [$FILES]"
									else
										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] FILES script output = [$FILES]"
										fi
	
										# For multiple lines script output, first line is treated as FILES and second line as LIMITS
										local NEW_LIMITS=$(echo "$FILES" | sed -n "2p")
										FILES=$(echo "$FILES" | head -1) 
						
										if [ ${#FILES} -eq 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Expanded FILES is empty/null! Skipping..."
											continue
										else
											echo "[$(date)] [${FUNCNAME[0]}] Expanded FILES = [$FILES]"
										fi
	
										if [ ${#LIMITS} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] Replacing current LIMITS [$LIMITS] with new LIMITS [$NEW_LIMITS]..."
										else
											echo "[$(date)] [${FUNCNAME[0]}] Setting LIMITS to [$NEW_LIMITS]..."
										fi
		
										LIMITS="$NEW_LIMITS"
									fi
								fi
							fi
						fi
					fi

					IFS=$OLDIFS
					local CPFILES_POD_CTR=0

					for POD in $($OC_CMD get pod --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}' -n $NS | $AWK '/'$PODNAME'/ { print }' | tr '\n' ' ' | sed 's/[ ]$//')
					do
						local POD_STATUS=$($OC_CMD get pod -n $NS --no-headers $POD | $AWK '{ print $3 }')
	
						if [ ${#POD_STATUS} -eq 0 ] || [ ! $POD_STATUS == "Running" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [namespace=$NS / pod=$POD / status=$POD_STATUS] Pod is not in RUNNING state! Skipping..."
							continue
						else
							# To test whether target pod comes with bash shell 
							if [ ${#CONTAINER} -gt 0 ]
							then
								local POD_BASH_TEST=$($OC_CMD exec -n $NS -c $CONTAINER $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- bash -c 'date')
							else
								local POD_BASH_TEST=$($OC_CMD exec -n $NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- bash -c 'date')
							fi
				
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] POD_BASH_TEST = [$POD_BASH_TEST]"
							fi
				
							if [ ${#POD_BASH_TEST} -gt 0 ]
							then
								local POD_SHELL="bash"
							else
								local POD_SHELL="sh"
							fi
	
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] Setting POD_SHELL for target pod [$POD] to [$POD_SHELL]!"
	
							if [ ${#LIMITS} -eq 0 ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$FILES] to final config file [$OUTPUT_FILE]..."
								echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$FILES" >> $OUTPUT_FILE
							else
								if [[ ${FILES} =~ : ]]
								then
									# Configuration of multiple files/directories
									local INPUT_FILE_LIST_ITEM_COUNT=$(echo "$FILES" | $AWK -F: '{ print NF }')
									local INPUT_FILE_LIMIT_ITEM_COUNT=$(echo "$LIMITS" | $AWK -F: '{ print NF }')

									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$POD] INPUT_FILE_LIST_ITEM_COUNT = [$INPUT_FILE_LIST_ITEM_COUNT] / INPUT_FILE_LIMIT_ITEM_COUNT = [$INPUT_FILE_LIMIT_ITEM_COUNT]"
									fi

									if [ ${INPUT_FILE_LIST_ITEM_COUNT} -ne ${INPUT_FILE_LIMIT_ITEM_COUNT} ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$POD] INPUT_FILE_LIST_ITEM_COUNT [$INPUT_FILE_LIST_ITEM_COUNT] does not equal to INPUT_FILE_LIMIT_ITEM_COUNT [$INPUT_FILE_LIMIT_ITEM_COUNT]! Skipping..."
										continue
									fi							

									local CFG_FILE_LINE_CTR=0
									set -f
		
									for CFG_FILE_LINE in $(echo "$FILES" | sed 's/:/ /g')
									do
										(( CFG_FILE_LINE_CTR=CFG_FILE_LINE_CTR+1 ))

										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$POD] [$CFG_FILE_LINE_CTR] CFG_FILE_LINE = [$CFG_FILE_LINE]"
										fi

										local INPUT_FILE_CUR_LIMIT=$(echo "$LIMITS" | $AWK -F: '{ print $'$CFG_FILE_LINE_CTR' }')

										if [ ${#INPUT_FILE_CUR_LIMIT} -gt 0 ]
										then
											if [[ ! "$INPUT_FILE_CUR_LIMIT" =~ ^head[[:space:]]*-[0-9]*$ ]] && [[ ! "$INPUT_FILE_CUR_LIMIT" =~ ^tail[[:space:]]*-[0-9]*$ ]]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$POD] [$CFG_FILE_LINE_CTR] INPUT_FILE_CUR_LIMIT [$INPUT_FILE_CUR_LIMIT] is invalid! Skipping..."
												continue
											fi
										fi

										local INPUT_FILE_LIST[${#INPUT_FILE_LIST[@]}]="$CFG_FILE_LINE"
										local INPUT_FILE_LIMIT[${#INPUT_FILE_LIMIT[@]}]="$INPUT_FILE_CUR_LIMIT"

										if [ $MG_DEBUG == "true" ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] [$POD] [$CFG_FILE_LINE_CTR] INPUT_FILE_LIST = [${INPUT_FILE_LIST[@]}] [LEN=${#INPUT_FILE_LIST[@]}]"
											echo "[$(date)] [${FUNCNAME[0]}] [$POD] [$CFG_FILE_LINE_CTR] INPUT_FILE_LIMIT = [${INPUT_FILE_LIMIT[@]}] [LEN=${#INPUT_FILE_LIMIT[@]}]"
										fi
									done

									set +f
								else
									if [[ ! "$LIMITS" =~ ^head[[:space:]]*-[0-9]*$ ]] && [[ ! "$LIMITS" =~ ^tail[[:space:]]*-[0-9]*$ ]]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$POD] LIMIT [$LIMIT] is invalid! Skipping..."
										continue
									fi

									local INPUT_FILE_LIST=("$FILES")
									local INPUT_FILE_LIMIT=("$LIMITS")
								fi

								if [ ${#INPUT_FILE_LIST[@]} -ne ${#INPUT_FILE_LIMIT[@]} ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$POD] Total item in INPUT_FILE_LIST [${#INPUT_FILE_LIST[@]}] does not equal total item in INPUT_FILE_LIMIT [${#INPUT_FILE_LIMIT[@]}]! Skipping..."
									continue
								else
									echo "[$(date)] [${FUNCNAME[0]}] [$POD] Final length: INPUT_FILE_LIST = [${#INPUT_FILE_LIST[@]}] / INPUT_FILE_LIMIT = [${#INPUT_FILE_LIMIT[@]}]"
								fi

								local INPUT_FILE_CTR=0
								set -f

								for INPUT_FILE in ${INPUT_FILE_LIST[@]}
								do
									local INPUT_FILE_REGEX="false"
									local INPUT_LIMIT=${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}

									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$POD] INPUT_FILE_CTR = [$INPUT_FILE_CTR] / INPUT_FILE = [$INPUT_FILE] / INPUT_LIMIT = [$INPUT_LIMIT]"
									fi	

									if [ ${#CONTAINER} -gt 0 ]
									then
										if echo x"$INPUT_FILE" | grep -E '\*|\[|\?|{.*}' > /dev/null 
										then
											if [ ${#INPUT_LIMIT} -gt 0 ]
											then
												local INPUT_FILE_REGEX="true"
												local TGT_FILE_LIST_CMD="$OC_CMD exec -n $NS -c $CONTAINER $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -dt $INPUT_FILE | ${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}'"
											else
												echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE] to final config file [$OUTPUT_FILE]..."
												echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE" >> $OUTPUT_FILE
												(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
												continue
											fi
										else
											if [ ${#INPUT_LIMIT} -gt 0 ]
											then
												local TGT_FILE_LIST_CMD="$OC_CMD exec -n $NS -c $CONTAINER $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -t $INPUT_FILE | ${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}'"
											else
												echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE] to final config file [$OUTPUT_FILE]..."
												echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE" >> $OUTPUT_FILE
												(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
												continue
											fi
										fi
									else
										if echo x"$INPUT_FILE" | grep -E '\*|\[|\?|{.*}' > /dev/null 
										then
											if [ ${#INPUT_LIMIT} -gt 0 ]
											then
												local INPUT_FILE_REGEX="true"
												local TGT_FILE_LIST_CMD="$OC_CMD exec -n $NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -dt $INPUT_FILE | ${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}'"
											else
												echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE] to final config file [$OUTPUT_FILE]..."
												echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE" >> $OUTPUT_FILE
												(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
												continue
											fi
										else
											if [ ${#INPUT_LIMIT} -gt 0 ]
											then
												local TGT_FILE_LIST_CMD="$OC_CMD exec -n $NS $POD --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -t $INPUT_FILE | ${INPUT_FILE_LIMIT[$INPUT_FILE_CTR]}'"
											else
												echo "[$(date)] [${FUNCNAME[0]}] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE] to final config file [$OUTPUT_FILE]..."
												echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE" >> $OUTPUT_FILE
												(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
												continue
											fi
										fi
									fi
						
									local TGT_FILE_LIST=$(eval "$TGT_FILE_LIST_CMD")
	
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] INPUT_FILE_REGEX = [$INPUT_FILE_REGEX]"
										echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] TGT_FILE_LIST_CMD = [$TGT_FILE_LIST_CMD]"
										echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] TGT_FILE_LIST = [$TGT_FILE_LIST]"
									fi	
	
									if [ ${#TGT_FILE_LIST} -gt 0 ]
									then
										for TGT_FILE in $TGT_FILE_LIST
										do
											if [ $INPUT_FILE_REGEX == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$TGT_FILE] to final config file [$OUTPUT_FILE]..."
												echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$TGT_FILE" >> $OUTPUT_FILE
											else
												echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] Writing processed config line [$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE/$TGT_FILE] to final config file [$OUTPUT_FILE]..."
												echo "$NS$CPFILES_CFGFILE_DELIMITER$POD$CPFILES_CFGFILE_DELIMITER$CONTAINER$CPFILES_CFGFILE_DELIMITER$INPUT_FILE/$TGT_FILE" >> $OUTPUT_FILE
											fi
										done
									else
										echo "[$(date)] [${FUNCNAME[0]}] [$INPUT_FILE_CTR] TGT_FILE_LIST is empty/null!"
									fi

									(( INPUT_FILE_CTR=INPUT_FILE_CTR+1 ))
								done

								set +f
							fi
						fi								

						(( CPFILES_POD_CTR=CPFILES_POD_CTR+1 ))
					done

					echo "[$(date)] [${FUNCNAME[0]}] [CFG = $INPUT_CONFIG] [NS=$NS] Total pods involved = [$CPFILES_POD_CTR]"
				done
			fi
		fi
	fi

	IFS=$'\n'

	if [ $MG_DEBUG == "true" ]
	then	
		local FUNC_END=$(getFuncEndTime)
		getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [PRODGRP=$CPFILES_PROD_GROUP / PRODVER=$CPFILES_PROD_VER]"
	fi
}

doCpFiles()
{
	if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
	then
		while read PROD_VER_LINE
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_VER_LINE = [$PROD_VER_LINE]"
			fi

			local CPFILES_PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')

			if [ ${#RTVAR_CPFILES_PRODVER} -gt 0 ]
			then
				local CPFILES_PRODVER_VALID="false"
	
				for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
				do
					if [ $RTVAR_CPFILES_PRODVER == $VALID_PROD_VERSION ]
					then
						local CPFILES_PRODVER_VALID="true"
						break
					fi
				done	
	
				if [ $CPFILES_PRODVER_VALID == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] CPFILES_PRODVER is set to [$RTVAR_CPFILES_PRODVER]! Setting CPFILES_PROD_VER to [$RTVAR_CPFILES_PRODVER]!"
					local CPFILES_PROD_VER=$RTVAR_CPFILES_PRODVER
				else
					local CPFILES_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
					echo "[$(date)] [${FUNCNAME[0]}] CPFILES_PRODVER [$RTVAR_CPFILES_PRODVER] is invalid or not supported product version! Setting CPFILES_PROD_VER to default [$CPFILES_PROD_VER]!"
				fi
			else
				local CPFILES_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
			fi

			local CPFILES_PROD_VER_SHORT=$(echo "$CPFILES_PROD_VER" | sed 's/\.//g')
			local CPFILES_PROD_GROUP_NS_REFFILE=${REFFILE_OUTDIR}/${CPFILES_PROD_GROUP}.ns-ref
	
			if [ -f ${CPFILES_PROD_GROUP_NS_REFFILE} ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Calling function getCpFiles() - [CPFILES_PROD_GROUP=$CPFILES_PROD_GROUP ## CPFILES_PROD_VER=$CPFILES_PROD_VER ## CPFILES_PROD_VER_SHORT=$CPFILES_PROD_VER_SHORT ## CPFILES_PROD_GROUP_NS_REFFILE=$CPFILES_PROD_GROUP_NS_REFFILE ]"
				execCpFiles "$CPFILES_PROD_GROUP" "$CPFILES_PROD_VER" "$CPFILES_PROD_VER_SHORT" "$CPFILES_PROD_GROUP_NS_REFFILE"
			else
				echo "[$(date)] [${FUNCNAME[0]}] Product group namespace reference file [${REFFILE_OUTDIR}/${MISSINGOBJ_PROD_GROUP}.ns-ref] does not exist or is zero-sized! Skipping..."
				continue
			fi
		done < $PROD_VERSIONS_REFFILE_FINAL
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product group namespace reference file [$PROD_VERSIONS_REFFILE_FINAL] does not exist or is zero-sized!"
		echo "[$(date)] [${FUNCNAME[0]}] Falling back to default 'non-product-group' execution..."

		local CPFILES_PROD_GROUP="default"
		local CPFILES_PROD_VER=$PRODUCT_VERSION
		local CPFILES_PROD_VER_SHORT=$(echo "$CPFILES_PROD_VER" | sed 's/\.//g')
		local CPFILES_PROD_GROUP_NS_REFFILE=$PROD_NAMESPACES_REFFILE
	
		echo "[$(date)] [${FUNCNAME[0]}] Calling function getCpFiles() - [ CPFILES_PROD_GROUP=$CPFILES_PROD_GROUP ## CPFILES_PROD_VER=$CPFILES_PROD_VER ## CPFILES_PROD_VER_SHORT=$CPFILES_PROD_VER_SHORT ## CPFILES_PROD_GROUP_NS_REFFILE=$CPFILES_PROD_GROUP_NS_REFFILE ]"
		execCpFiles "$CPFILES_PROD_GROUP" "$CPFILES_PROD_VER" "$CPFILES_PROD_VER_SHORT" "$CPFILES_PROD_GROUP_NS_REFFILE"
	fi
}

execCpFiles()
{
	local CPFILES_PROD_GROUP=$1
	local CPFILES_PROD_VER=$2
	local CPFILES_PROD_VER_SHORT=$3
	local CPFILES_PROD_GROUP_NS_REFFILE=$4

	local CPFILES_RAW_CTR=0
 	local CPFILES_LINE_CTR=0
	local CPFILES_ATMP_CTR=0
 	local CPFILES_SUCC_CTR=0
 	local CPFILES_FAIL_CTR=0

	local FILE=
	local EXT_FILE=
	local CPFILES_RESULT_DIR=
	local CMDEXEC_EXTRA_LINE=
	local CFGLINE=

	if [ $PROD_VERSIONS_SINGLE_PRODGROUP == "true" ]
	then
		local CPFILES_PRODGROUP_OUTDIR=$CPFILES_ROOT_OUTDIR
		local CPFILES_PRODGROUP_DEBUG_DIR=$CPFILES_DEBUG_OUTDIR
	else
		local CPFILES_PRODGROUP_OUTDIR=$CPFILES_ROOT_OUTDIR/PRODGRP=$CPFILES_PROD_GROUP
		local CPFILES_PRODGROUP_DEBUG_DIR=$CPFILES_DEBUG_OUTDIR/PRODGRP=$CPFILES_PROD_GROUP
	fi

	if [ "$CPFILES_FILES" == ".listcpfiles" ] || [ "$CPFILES_FILES" == ".listcpfiles_custom" ]
	then
		if [ "$CPFILES_FILES" == ".listcpfiles" ]
		then
			CPFILES_CFGFILE=$MUSTGATHER_DIRNAME/config/cpfiles/$CPFILES_PROD_VER/config/cpfiles.cfg
			CPFILES_SCRIPTDIR=$MUSTGATHER_DIRNAME/config/cpfiles/$CPFILES_PROD_VER/scripts
		else
			CPFILES_CFGFILE=$MUSTGATHER_DIRNAME/data/cpfiles/$CPFILES_PROD_VER/config/cpfiles_custom.cfg
			CPFILES_SCRIPTDIR=$MUSTGATHER_DIRNAME/data/cpfiles/$CPFILES_PROD_VER/scripts

			if [ ! -s $CPFILES_CFGFILE ]
			then
				CPFILES_CFGFILE=$MUSTGATHER_DIRNAME/data/cpfiles/config/cpfiles_custom.cfg
				CPFILES_SCRIPTDIR=$MUSTGATHER_DIRNAME/data/cpfiles/scripts

				if [ ! -s $CPFILES_CFGFILE ]
				then
					CPFILES_CFGFILE=
					CPFILES_SCRIPTDIR=	
				fi
			fi	
		fi

		if [ ${#CPFILES_CFGFILE} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Unable to locate CPFILES configuration file! Returning..."
			return 1
		else
			if [ ${REPORT_ON_SCREEN} != "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Setting REPORT_ON_SCREEN to [true]..."
				REPORT_ON_SCREEN="true"
				REPORT_ON_SCREEN_SUMMARY_FILE=$ROOT_OUTDIR/${ANALYZE_OUTFILE##*/}.$$
			fi	

			echo "[PROD_GRP = $CPFILES_PROD_GROUP / PROV_VER = $CPFILES_PROD_VER]" >> $ANALYZE_OUTFILE
			echo "====================================================================================================================================================================================" >> $ANALYZE_OUTFILE
			printf "%-20s %-30s %-50s %-80s \n" "TAG" "NAMESPACE" "TARGET POD (REGEX)" "TARGET FILES/DIRECTORIES" >> $ANALYZE_OUTFILE
			echo "====================================================================================================================================================================================" >> $ANALYZE_OUTFILE

			while read LINE
			do
				# Skip all lines that start with @ and blank lines
				if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "$CPFILES_CFGFILE_COMMENT"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi
		
				local CPFILES_HELP_TAG=$(echo "$LINE" | $AWK -F"$CPFILES_CFGFILE_DELIMITER" '{ print $1 }')
				local CPFILES_HELP_NS=$(echo "$LINE" | $AWK -F"$CPFILES_CFGFILE_DELIMITER" '{ print $2 }')

				if [[ $CPFILES_HELP_NS =~ ^NS4PROD= ]]
				then
					local CPFILES_HELP_NS=$(getProdToNamespacesMapping "$(echo $CPFILES_HELP_NS | $AWK -F= '{ print $2 }')")	
				fi

				local CPFILES_HELP_POD=$(echo "$LINE" | $AWK -F"$CPFILES_CFGFILE_DELIMITER" '{ print $3 }')
				local CPFILES_HELP_REGEX=$(echo "$LINE" | $AWK -F"$CPFILES_CFGFILE_DELIMITER" '{ print $5 }')
			
				if [ ${CPFILES_HELP_POD} == "OBJNAME" ] && [ ${#CPFILES_HELP_REGEX} -gt 0 ]
				then
					local CPFILES_HELP_REGEX_SCRIPT=$(echo "$CPFILES_HELP_REGEX" | $AWK '{ print $1 }')

					if [ -s $CPFILES_SCRIPTDIR/$CPFILES_HELP_REGEX_SCRIPT ]
					then
						if [ ${#TIMEOUT} -gt 0 ]
						then
							local CMD="$TIMEOUT $DEFAULT_TIMEOUT /bin/bash $CPFILES_SCRIPTDIR/$CPFILES_HELP_REGEX $CPFILES_HELP_NS"	
							echo "[$(date)] [${FUNCNAME[0]}] Executing regex script [$CMD]..."
							local CPFILES_HELP_POD=$(eval "$CMD")
						else
							local CMD="/bin/bash $CPFILES_SCRIPTDIR/$CPFILES_HELP_REGEX $CPFILES_HELP_NS"	
							echo "[$(date)] [${FUNCNAME[0]}] Executing regex script [$CMD]..."
							local CPFILES_HELP_POD=$(eval "$CMD")
						fi
					else
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] CPFILES script [$CPFILES_SCRIPTDIR/$CPFILES_HELP_REGEX_SCRIPT] does not exist or is zero-sized!"
						fi
					fi
				fi

				local CPFILES_HELP_FILEDIR=$(echo "$LINE" | $AWK -F"$CPFILES_CFGFILE_DELIMITER" '{ print $6 }')
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] CPFILES_HELP_TAG = [$CPFILES_HELP_TAG] / CPFILES_HELP_POD = [$CPFILES_HELP_POD] / CPFILES_HELP_FILEDIR = [$CPFILES_HELP_FILEDIR]"
				fi

				printf "%-20s %-30s %-50s %-80s \n" "$CPFILES_HELP_TAG" "$CPFILES_HELP_NS" "$CPFILES_HELP_POD" "$CPFILES_HELP_FILEDIR" >> $ANALYZE_OUTFILE
			done < <(sort $CPFILES_CFGFILE)

			echo >> $ANALYZE_OUTFILE
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Processing CPFILES input..."
	
		CPFILES_FILES_PROC=$CPFILES_PRODGROUP_OUTDIR/FINAL-CPFILES-CFG.proc
		echo "[$(date)] [${FUNCNAME[0]}] Setting CPFILES_FILES_PROC to [$CPFILES_FILES_PROC]..."
		CPFILES_FILES_FINAL=$CPFILES_PRODGROUP_OUTDIR/FINAL-CPFILES-CFG.cfg
		echo "[$(date)] [${FUNCNAME[0]}] Setting CPFILES_FILES_FINAL to [$CPFILES_FILES_FINAL]..."
	
		if [ ${#CPFILES_FILES} -gt 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Processing user input CPFILES_FILES [$CPFILES_FILES]..."
	
			if [ $(echo "$CPFILES_FILES" | $AWK -F${CPFILES_CFGFILE_DELIMITER} '{ print NF }') -eq 1 ]
			then
				if [ ${#RTVAR_CPFILES_CFGFILE} -gt 0 ]
				then
					local COUNT_CFGFILE="$RTVAR_CPFILES_CFGFILE"
				else
					local COUNT_CFGFILE="$MUSTGATHER_DIRNAME/config/cpfiles/$CPFILES_PROD_VER/config/cpfiles.cfg"
				fi
	
				while read CPFILES_INPUT_LINE
				do
					# Skip all lines that start with @ and blank lines
					if [[ $(echo "$CPFILES_INPUT_LINE" | $AWK '{$1=$1};1') == "$CPFILES_CFGFILE_COMMENT"* ]] || [[ $(echo "$CPFILES_INPUT_LINE" | $AWK '{ print NF }') -eq 0 ]]
					then
						continue
					fi
				
					(( CPFILES_RAW_CTR=CPFILES_RAW_CTR+1 ))
				done < $COUNT_CFGFILE
			else
				(( CPFILES_RAW_CTR=CPFILES_RAW_CTR+1 ))
			fi
	
			processCpFiles "$CPFILES_FILES" "$CPFILES_FILES_PROC" "$CPFILES_PROD_GROUP" "$CPFILES_PROD_VER" "$CPFILES_PROD_VER_SHORT" "$CPFILES_PROD_GROUP_NS_REFFILE" 
		fi
	
		if [ ${#CMD_EXEC_RESULT_CPFILES_FILE} -gt 0 ] && [ -s $CMD_EXEC_RESULT_CPFILES_FILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Processing CMD_EXEC_RESULT_CPFILES_FILE [$CMD_EXEC_RESULT_CPFILES_FILE]..."
	
			while read CMDEXEC_EXTRA_LINE
			do
				# Skip all lines that start with @ and blank lines
				if [[ $(echo "$CMDEXEC_EXTRA_LINE" | $AWK '{$1=$1};1') == "$CPFILES_CFGFILE_COMMENT"* ]] || [[ $(echo "$CMDEXEC_EXTRA_LINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi
				
				echo "[$(date)] [${FUNCNAME[0]}] Processing config line [$CMDEXEC_EXTRA_LINE]..."
	
				if ! checkCpFilesFormat $CMDEXEC_EXTRA_LINE
				then
					echo "[$(date)] [${FUNCNAME[0]}] User input [$CMDEXEC_EXTRA_LINE] for "cpfiles" collection mode is invalid!"
					continue
				fi
	
				(( CPFILES_RAW_CTR=CPFILES_RAW_CTR+1 ))
				processCpFiles $CMDEXEC_EXTRA_LINE $CPFILES_FILES_PROC				
			done < $CMD_EXEC_RESULT_CPFILES_FILE
		fi
	
		# Custom configuration file in 'data' directory
		if [ -s $MUSTGATHER_DIRNAME/data/cpfiles/$CPFILES_PROD_VER/config/cpfiles_custom.cfg ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Processing custom configuration file [$MUSTGATHER_DIRNAME/data/cpfiles/$CPFILES_PROD_VER/config/cpfiles_custom.cfg]..."
			echo "[$(date)] [${FUNCNAME[0]}] Setting CPFILES_DATA_SCRIPTDIR to [$MUSTGATHER_DIRNAME/data/cpfiles/$CPFILES_PROD_VER/scripts]..."
	
			CPFILES_DATA_SCRIPTDIR=$MUSTGATHER_DIRNAME/data/cpfiles/$CPFILES_PROD_VER/scripts
	
			while read CPFILES_INPUT_LINE
			do
				# Skip all lines that start with @ and blank lines
				if [[ $(echo "$CPFILES_INPUT_LINE" | $AWK '{$1=$1};1') == "$CPFILES_CFGFILE_COMMENT"* ]] || [[ $(echo "$CPFILES_INPUT_LINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi
				
				(( CPFILES_RAW_CTR=CPFILES_RAW_CTR+1 ))
			done < $MUSTGATHER_DIRNAME/data/cpfiles/$CPFILES_PROD_VER/config/cpfiles_custom.cfg
	
			processCpFiles "$CPFILES_FILES" "$CPFILES_FILES_PROC" "$CPFILES_PROD_GROUP" "$CPFILES_PROD_VER" "$CPFILES_PROD_VER_SHORT" "$CPFILES_PROD_GROUP_NS_REFFILE" "$MUSTGATHER_DIRNAME/data/cpfiles/$CPFILES_PROD_VER/config/cpfiles_custom.cfg"
	
			# Re-initialize for the next processing round
			CPFILES_DATA_SCRIPTDIR=
		else	
			if [ -s $MUSTGATHER_DIRNAME/data/cpfiles/config/cpfiles_custom.cfg ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Processing custom configuration file [$MUSTGATHER_DIRNAME/data/cpfiles/config/cpfiles_custom.cfg]..."
				echo "[$(date)] [${FUNCNAME[0]}] Setting CPFILES_DATA_SCRIPTDIR to [$MUSTGATHER_DIRNAME/data/cpfiles/scripts]..."
		
				CPFILES_DATA_SCRIPTDIR=$MUSTGATHER_DIRNAME/data/cpfiles/scripts
		
				while read CPFILES_INPUT_LINE
				do
					# Skip all lines that start with @ and blank lines
					if [[ $(echo "$CPFILES_INPUT_LINE" | $AWK '{$1=$1};1') == "$CPFILES_CFGFILE_COMMENT"* ]] || [[ $(echo "$CPFILES_INPUT_LINE" | $AWK '{ print NF }') -eq 0 ]]
					then
						continue
					fi
					
					(( CPFILES_RAW_CTR=CPFILES_RAW_CTR+1 ))
				done < $MUSTGATHER_DIRNAME/data/cpfiles/config/cpfiles_custom.cfg
		
				processCpFiles "$CPFILES_FILES" "$CPFILES_FILES_PROC" "$CPFILES_PROD_GROUP" "$CPFILES_PROD_VER" "$CPFILES_PROD_VER_SHORT" "$CPFILES_PROD_GROUP_NS_REFFILE" "$MUSTGATHER_DIRNAME/data/cpfiles/config/cpfiles_custom.cfg"
		
				# Re-initialize for the next processing round
				CPFILES_DATA_SCRIPTDIR=
			fi
		fi
	
		# Scanning CPFILES_FILES_PROC for duplicated config lines
		if [ -s $CPFILES_FILES_PROC ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Scanning CPFILES_FILES_PROC [$CPFILES_FILES_PROC] for duplicated config lines..."
	
			for UNIQ_CPFILES_LINE in $(sort $CPFILES_FILES_PROC | uniq -c | sed 's/^\s*//')
			do
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] UNIQ_CPFILES_LINE = [$UNIQ_CPFILES_LINE]"
				fi
	
				local UNIQ_CPFILES_LINE_COUNT=$(echo "$UNIQ_CPFILES_LINE" | $AWK '{ print $1 }')
				local UNIQ_CPFILES_LINE_CFGLINE=$(echo "$UNIQ_CPFILES_LINE" | cut -c2- | sed 's/^\s*//')
	
				if [ ${#UNIQ_CPFILES_LINE_COUNT} -gt 0 ] && [ ${UNIQ_CPFILES_LINE_COUNT} -gt 1 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Removing duplicated configuration line = [$UNIQ_CPFILES_LINE_CFGLINE]"
				fi
	
				echo "$UNIQ_CPFILES_LINE_CFGLINE" >> ${CPFILES_FILES_FINAL}
			done
		else
			touch $CPFILES_FILES_FINAL
		fi
	
		if [ $MG_DEBUG == "true" ]
		then
			local FUNC_START=$(getFuncStartTime)
		fi
	
		if [ -s $CPFILES_FILES_FINAL ]
		then
			if [ $MG_DEBUG == "true" ] && [ ! -d $CPFILES_DEBUG_OUTDIR ]
			then
				mkdir -p $CPFILES_DEBUG_OUTDIR
			fi
	
			while read CFGLINE
			do
				local NAMESPACE=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $1 }')
				local PODNAME=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $2 }')
				local CONTAINER=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $3 }')
				local FILES=$(echo "$CFGLINE" | $AWK -F$CPFILES_CFGFILE_DELIMITER '{ print $4 }')
	
				local F_OUTDIR=$CPFILES_PRODGROUP_OUTDIR/$NAMESPACE/$PODNAME
	
				(( CPFILES_LINE_CTR=CPFILES_LINE_CTR+1 ))
				
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] CFGLINE = [$CFGLINE]"
				fi
	
				if [ ! -d $F_OUTDIR ]
				then
					mkdir -p $F_OUTDIR
				fi
	
				# To test whether target pod comes with bash shell 
				if [ ${#CONTAINER} -gt 0 ]
				then
					local POD_BASH_TEST=$($OC_CMD exec -n $NAMESPACE -c $CONTAINER $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- bash -c 'date')
				else
					local POD_BASH_TEST=$($OC_CMD exec -n $NAMESPACE $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- bash -c 'date')
				fi
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] POD_BASH_TEST = [$POD_BASH_TEST]"
				fi
	
				if [ ${#POD_BASH_TEST} -gt 0 ]
				then
					local POD_SHELL="bash"
				else
					local POD_SHELL="sh"
				fi
		
				echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] Setting POD_SHELL for target pod [$PODNAME] to [$POD_SHELL]!"
		
				IFS=$OLDIFS
	
				set -f
				for FILE in $(echo "$FILES" | sed 's/:/ /g')
				do
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [FILES = $FILES] FILE = [$FILE]"
					fi
	
					local CPFILES_RESULT_DIR_ARRAY=()
					
					if [ ${#CONTAINER} -gt 0 ]
					then
						local CPFILES_LS_DEBUG="$OC_CMD exec -n $NAMESPACE -c $CONTAINER $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -l $FILE'"
						local CPFILES_EXT_CMD="$OC_CMD exec -n $NAMESPACE -c $CONTAINER $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls $FILE'"
					else
						local CPFILES_LS_DEBUG="$OC_CMD exec -n $NAMESPACE $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -l $FILE'"
						local CPFILES_EXT_CMD="$OC_CMD exec -n $NAMESPACE $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls $FILE'"
					fi
	
					if echo x"$FILE" | grep -E '\*|\[|\?|{.*}' > /dev/null 
					then
						echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Expanding filename wildcard [$FILE]..."
	
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Executing command '${CPFILES_EXT_CMD}'..."
						fi
	
						local CPFILES_REMOTE_BASEDIR=
	
						for EXT_FILE in $(eval "$CPFILES_EXT_CMD" | grep -v '^$')
						do
							(( CPFILES_ATMP_CTR=CPFILES_ATMP_CTR+1 ))
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] EXT_FILE = [$EXT_FILE]"
							fi
	
							if [ ${#CONTAINER} -gt 0 ]
							then
								# FILE is a directory 
								if [[ ! "$EXT_FILE" =~ ^/ ]]
								then
									if [ ${#CPFILES_REMOTE_BASEDIR} -eq 0 ]
									then
										local CPFILES_REMOTE_BASEDIR_CMD="$OC_CMD exec -n $NAMESPACE -c $CONTAINER $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -d $FILE'"
	
										echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Executing command '${CPFILES_REMOTE_BASEDIR_CMD}'..."
										local CPFILES_REMOTE_BASEDIR=$(eval "$CPFILES_REMOTE_BASEDIR_CMD")
									fi
	
									if [ ${#CPFILES_REMOTE_BASEDIR} -gt 0 ]
									then
										local EXT_FILE="$CPFILES_REMOTE_BASEDIR/$EXT_FILE"	
										echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Setting EXT_FILE to [$EXT_FILE]..."
									else
										echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Unable to determine remote directory name! Skipping..."
										continue
									fi
								else
									if [[ "$EXT_FILE" =~ :$ ]]
									then
										(( CPFILES_ATMP_CTR=CPFILES_ATMP_CTR-1 ))
	
										local CPFILES_REMOTE_BASEDIR=$(echo "$EXT_FILE" | sed 's/:$//')
										echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Setting CPFILES_REMOTE_BASEDIR to [${CPFILES_REMOTE_BASEDIR}]..."
										continue
									fi
	
								fi
	
								local EXT_BASENAME=$(dirname "$EXT_FILE" | sed 's#/#^#g')
	
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Adding EXT_BASENAME [$F_OUTDIR/$EXT_BASENAME] into CPFILES_RESULT_DIR_ARRAY..."
								CPFILES_RESULT_DIR_ARRAY[${#CPFILES_RESULT_DIR_ARRAY[@]}]=$F_OUTDIR/$EXT_BASENAME
					
								local CPFILES_CP_CMD="$OC_CMD cp --retries=$CPFILES_RETRIES -c $CONTAINER $NAMESPACE/$PODNAME:$EXT_FILE $F_OUTDIR/$EXT_BASENAME/$(basename $EXT_FILE)"
								local CPFILES_CAT_CMD="$OC_CMD exec -n $NAMESPACE -c $CONTAINER $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- cat $EXT_FILE"
								local CPFILES_ECHO_SUFFIX="[namespace=$NAMESPACE # pod=$PODNAME # container=$CONTAINER # file=$FILE # ext_file=$EXT_FILE]"
							else
								# FILE is a directory 
								if [[ ! "$EXT_FILE" =~ ^/ ]]
								then
									if [ ${#CPFILES_REMOTE_BASEDIR} -eq 0 ]
									then
										local CPFILES_REMOTE_BASEDIR_CMD="$OC_CMD exec -n $NAMESPACE $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- $POD_SHELL -c 'ls -d $FILE'"
	
										echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Executing command '${CPFILES_REMOTE_BASEDIR_CMD}'..."
										local CPFILES_REMOTE_BASEDIR=$(eval "$CPFILES_REMOTE_BASEDIR_CMD")
									fi
	
									if [ ${#CPFILES_REMOTE_BASEDIR} -gt 0 ]
									then
										local EXT_FILE="$CPFILES_REMOTE_BASEDIR/$EXT_FILE"	
										echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Setting EXT_FILE to [$EXT_FILE]..."
									else
										echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Unable to determine remote directory name! Skipping..."
										continue
									fi
								else
									if [[ "$EXT_FILE" =~ :$ ]]
									then
										(( CPFILES_ATMP_CTR=CPFILES_ATMP_CTR-1 ))
	
										local CPFILES_REMOTE_BASEDIR=$(echo "$EXT_FILE" | sed 's/:$//')
										echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Setting CPFILES_REMOTE_BASEDIR to [${CPFILES_REMOTE_BASEDIR}]..."
										continue
									fi
								fi
	
								local EXT_BASENAME=$(dirname "$EXT_FILE" | sed 's#/#^#g')
	
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] [namespace=$NAMESPACE # pod=$PODNAME # file=$FILE] Adding EXT_BASENAME [$F_OUTDIR/$EXT_BASENAME] into CPFILES_RESULT_DIR_ARRAY..."
								CPFILES_RESULT_DIR_ARRAY[${#CPFILES_RESULT_DIR_ARRAY[@]}]=$F_OUTDIR/$EXT_BASENAME
					
								local CPFILES_CP_CMD="$OC_CMD cp --retries=$CPFILES_RETRIES $NAMESPACE/$PODNAME:$EXT_FILE $F_OUTDIR/$EXT_BASENAME/$(basename $EXT_FILE)"
								local CPFILES_CAT_CMD="$OC_CMD exec -n $NAMESPACE $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- cat $EXT_FILE"
								local CPFILES_ECHO_SUFFIX="[namespace=$NAMESPACE # pod=$PODNAME # file=$FILE # ext_file=$EXT_FILE]"
							fi
	
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Executing command '${CPFILES_CP_CMD}'"
							eval "$CPFILES_CP_CMD"
	
							local CPFILES_EXIT_STATUS=$?	
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Exit status = [$CPFILES_EXIT_STATUS]"
	
							if [ $CPFILES_EXIT_STATUS -ne 0 ]	
							then
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Executing command '${CPFILES_CAT_CMD}' => $F_OUTDIR/$EXT_BASENAME/$(basename $EXT_FILE)"
	
								if [ ! -d $F_OUTDIR/$EXT_BASENAME ]
								then
									mkdir -p $F_OUTDIR/$EXT_BASENAME
								fi
	
								eval "$CPFILES_CAT_CMD" > $F_OUTDIR/$EXT_BASENAME/$(basename $EXT_FILE) 2>&1
								local CPFILES_EXIT_STATUS=$?
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Exit status = [$CPFILES_EXIT_STATUS]"
							fi
	
							if [ $CPFILES_EXIT_STATUS -eq 0 ]
							then
								if [ -f $F_OUTDIR/$EXT_BASENAME/$(basename $EXT_FILE) ] || [ -d $F_OUTDIR/$EXT_BASENAME/$(basename $EXT_FILE) ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} File copy successful? [Y]"
									(( CPFILES_SUCC_CTR=CPFILES_SUCC_CTR+1 ))
								else
									echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} File copy successful? [N]"
									(( CPFILES_FAIL_CTR=CPFILES_FAIL_CTR+1 ))
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} File copy successful? [N]"
								(( CPFILES_FAIL_CTR=CPFILES_FAIL_CTR+1 ))
							fi
						done
					else
						(( CPFILES_ATMP_CTR=CPFILES_ATMP_CTR+1 ))
	
						local BASENAME=$(echo "$FILE" | sed 's#/#^#g')
						CPFILES_RESULT_DIR_ARRAY[${#CPFILES_RESULT_DIR_ARRAY[@]}]=$F_OUTDIR/$BASENAME
	
						if [ ${#CONTAINER} -gt 0 ]
						then
							local CPFILES_CP_CMD="$OC_CMD cp --retries=$CPFILES_RETRIES -c $CONTAINER $NAMESPACE/$PODNAME:$FILE $F_OUTDIR/$BASENAME"
							local CPFILES_CAT_CMD="$OC_CMD exec -n $NAMESPACE -c $CONTAINER $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- cat $FILE"
							local CPFILES_ECHO_SUFFIX="[namespace=$NAMESPACE # pod=$PODNAME # container=$CONTAINER # file=$FILE]"
						else
							local CPFILES_CP_CMD="$OC_CMD cp --retries=$CPFILES_RETRIES $NAMESPACE/$PODNAME:$FILE $F_OUTDIR/$BASENAME"
							local CPFILES_CAT_CMD="$OC_CMD exec -n $NAMESPACE $PODNAME --request-timeout="$DEFAULT_OC_EXEC_TIMEOUT" -- cat $FILE"
							local CPFILES_ECHO_SUFFIX="[namespace=$NAMESPACE # pod=$PODNAME # file=$FILE]"
						fi
	
						echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Executing command '${CPFILES_CP_CMD}'"
						eval "$CPFILES_CP_CMD"
	
						local CPFILES_EXIT_STATUS=$?	
						echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Exit status = [$CPFILES_EXIT_STATUS]"
	
						if [ $CPFILES_EXIT_STATUS -ne 0 ]	
						then
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Executing command '${CPFILES_CAT_CMD}' => $F_OUTDIR/$BASENAME"
							eval "$CPFILES_CAT_CMD" > $F_OUTDIR/$BASENAME 2>&1
							local CPFILES_EXIT_STATUS=$?
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Exit status = [$CPFILES_EXIT_STATUS]"
						fi
	
						if [ $CPFILES_EXIT_STATUS -eq 0 ]
						then
							if [ -f $F_OUTDIR/$BASENAME ] || [ -d $F_OUTDIR/$BASENAME ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} File copy successful? [Y]"
								(( CPFILES_SUCC_CTR=CPFILES_SUCC_CTR+1 ))
							else
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} File copy successful? [N]"
								(( CPFILES_FAIL_CTR=CPFILES_FAIL_CTR+1 ))
							fi
						else
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} File copy successful? [N]"
							(( CPFILES_FAIL_CTR=CPFILES_FAIL_CTR+1 ))
						fi
					fi
			
					if [ $MG_DEBUG == "true" ]
					then
						if [ ! -d $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME ]
						then	
							mkdir -p $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME/
						fi
	
						echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] Size of CPFILES_RESULT_DIR_ARRAY = [${#CPFILES_RESULT_DIR_ARRAY[@]}]"
		
						for CPFILES_RESULT_DIR in $(echo ${CPFILES_RESULT_DIR_ARRAY[@]} | tr ' ' '\n' | sort -u | tr '\n' ' ')
						do	
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] Checking for CPFILES_RESULT_DIR [$CPFILES_RESULT_DIR]..."
	
							local CPFILES_LS_CMD="ls -l $CPFILES_RESULT_DIR"
							local CPFILES_FILECOUNT=$(ls $CPFILES_RESULT_DIR | wc -l | $AWK '{ print $1 }')
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] CPFILES result [$(basename $CPFILES_RESULT_DIR)] [FILECOUNT=$CPFILES_FILECOUNT] = [$(eval $CPFILES_LS_CMD)]"
	
							local REMOTE_BASENAME=$(basename ${CPFILES_RESULT_DIR})
	
							if echo x"$FILE" | grep -E '\*|\[|\?' > /dev/null
							then
								local FINAL_REMOTE_LS="true"
							else
								local FINAL_REMOTE_LS="false"
	
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Executing command '$CPFILES_LS_DEBUG' => $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME/$REMOTE_BASENAME.ls"
								eval "$CPFILES_LS_DEBUG" > $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME/$REMOTE_BASENAME.ls
	
								if [ -s $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME/$REMOTE_BASENAME.ls ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] REMOTE_LS_RESULT [$FILE] = [$(cat $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME/$REMOTE_BASENAME.ls)]"
								fi
							fi
						done
	
						if [ ${#FINAL_REMOTE_LS} -gt 0 ] && [ $FINAL_REMOTE_LS == "true" ]
						then		
							local REMOTE_BASENAME=$(echo "$FILE" | sed 's#/#^#g')
	
							echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] ${CPFILES_ECHO_SUFFIX} Executing command '$CPFILES_LS_DEBUG' => $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME/$REMOTE_BASENAME.ls"
							eval "$CPFILES_LS_DEBUG" > $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME/$REMOTE_BASENAME.ls
	
							if [ -s $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME/$REMOTE_BASENAME.ls ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [#$CPFILES_LINE_CTR] REMOTE_LS_RESULT [$FILE] = [$(cat $CPFILES_PRODGROUP_DEBUG_DIR/$NAMESPACE/$PODNAME/$REMOTE_BASENAME.ls)]"
							fi
						fi
					fi
				done
	
				set +f
				IFS=$'\n'
			done < $CPFILES_FILES_FINAL
		else
			echo "[$(date)] [${FUNCNAME[0]}] CPFILES_FILES_FINAL [$CPFILES_FILES_FINAL] does not exist or is zero-sized! Exiting..."
			return 1
		fi
	
		echo "[$(date)] [${FUNCNAME[0]}] Total raw config lines = [$CPFILES_RAW_CTR]"
		echo "[$(date)] [${FUNCNAME[0]}] Total processed config lines = [$(wc -l $CPFILES_FILES_FINAL | $AWK '{ print $1 }')]"
		echo "[$(date)] [${FUNCNAME[0]}] Total read config lines = [$CPFILES_LINE_CTR]"
		echo "[$(date)] [${FUNCNAME[0]}] Total files involved = [$CPFILES_ATMP_CTR]"
		echo "[$(date)] [${FUNCNAME[0]}] Total successful copy = [$CPFILES_SUCC_CTR]"
		echo "[$(date)] [${FUNCNAME[0]}] Total failed copy = [$CPFILES_FAIL_CTR]"
	
		if [ $MG_DEBUG == "true" ]
		then	
			local FUNC_END=$(getFuncEndTime)
			getFuncElapsedTime "${FUNCNAME[0]}" "$FUNC_START" "$FUNC_END" "for [PRODGRP=$CPFILES_PROD_GROUP / PRODVER=$CPFILES_PROD_VER]"
		fi
	fi
}

checkMustGatherOpt()
{
	if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 1 ]
	then
		echo "[$(date)] Multiple primary data collection modes [${PRIMARY_MODE_ARRAY[@]}] are selected. Please choose only one option. Operation is not supported. Exiting..."
		echo
		echoUsage
		cleanUpDataDir 
		exit 1
	else
		if [ ${#PRIMARY_MODE_ARRAY[@]} -eq 0 ]
		then
			# No primary data collection mode is selected 
			if [ ${#SECONDARY_MODE_ARRAY[@]} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] No primary (-a, -c, -b, -l, -k, -z) nor secondary (-d, -C, -m, -e, -x, -A, -P, -F, -K) data collection mode is selected. Exiting..."
				echo
				if [ $CHECK_FOR_UPDATE == "false" ]
				then
					echoUsage
				fi

				cleanUpDataDir
				exit 1
			else
				# Primary modes = all, comprehensive, basic, limited
				# Secondary modes precedence = clusternodes -> cmdexec -> manualcollect -> extra -> missingobj
	
				if [ $GET_NODES_DATA == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] INFO: Gather cluster nodes data (-d) mode is selected."
					MUSTGATHER_OPT="clusternodes"
					OPTSET=1
				else		
					if [ ${#CMD_EXEC_FILE} -gt 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] INFO: Manual command execution (-C) mode is selected."
						MUSTGATHER_OPT="cmdexec"
						OPTSET=1	
					else
						if [ $MANUAL_COLL -eq 1 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] INFO: Full manual data collection mode is selected."
							MUSTGATHER_OPT="manualcollect"
							OPTSET=1	
						else
							if [ ${EXTRA_NAMESPACES}x != "x" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] INFO: Targeted namespace data collection (-e) mode is selected." 
								MUSTGATHER_OPT="extra"
								OPTSET=1	
							else
								if [ $GET_MISS_OBJ == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] INFO: Scan missing objects (-x) mode is selected." 
									MUSTGATHER_OPT="missingobj"
									OPTSET=1
								else
									if [ $GET_COMPLIANCE == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] INFO: Compliance check (-A) mode is selected." 
										MUSTGATHER_OPT="compliance"
										OPTSET=1
									else
										if [ ${#PLUGINS} -gt 0 ]
										then
											echo "[$(date)] [${FUNCNAME[0]}] INFO: Product plugin (-P) mode is selected."
											MUSTGATHER_OPT="plugins"
											OPTSET=1
										else
											if [ ${CPFILES_ENABLED} == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] INFO: File copy (-F) mode is selected."
												MUSTGATHER_OPT="cpfiles"
												OPTSET=1
											else
												if [ $DIFF_SNAPSHOTS == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] INFO: Snapshots (-K) mode is selected."
													MUSTGATHER_OPT="snapshots"
													OPTSET=1
												fi
											fi
										fi
									fi
								fi
							fi
						fi
					fi
				fi
			fi
		fi
	fi
}

checkProdNamespace()
{
	echo "[$(date)] [${FUNCNAME[0]}] Checking product namespaces..." 

	local ASSUME_VALID="false"
	local NS=
	local VALID_NS=
	local LINE=

	if ! checkUserPriv get namespace all
	then
		echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to perform verb [get] on resource 'namespace'. Assuming all detected namespaces are valid!"
		local ASSUME_VALID="true"
	fi

	if [ ${#PROD_NAMESPACES_UNIQUE[@]} -gt 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Product namespaces array [PROD_NAMESPACES_UNIQUE] is not empty! Resetting..."
		unset PROD_NAMESPACES_UNIQUE
	fi

	if [ -f $PROD_NAMESPACES_REFFILE_FINAL ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Product namespaces reference file [$PROD_NAMESPACES_REFFILE_FINAL] exists! Removing..."
		rm $PROD_NAMESPACES_REFFILE_FINAL
	fi

	local TMP_WORKFILE=$RUNTIME_OUTDIR/checkProdNamespaceArray.tmp

	if [ -s $PROD_NAMESPACES_REFFILE ]
	then
		PROD_NAMESPACES_KEYVAL_ARR_FINALIZED="false"

		while read LINE
		do
			if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi	
	
			local PROD_NAME=$(echo "$LINE" | $AWK -F= '{ print $1 }')
			local PROD_NS=$(echo "$LINE" | $AWK -F= '{ print $2 }')
			local PROD_NS_REFLINE_PRODNAME="${PROD_NAME}="

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] LINE = [$LINE] / PROD_NAME = [$PROD_NAME] / PROD_NS = [$PROD_NS]"
			fi

			if [ ${#PROD_NS} -gt 0 ]
			then
				local PROD_NS_REFLINE_PRODNS=

				IFS=$OLDIFS

				for NS in $(echo "$PROD_NS" | sed 's/,/ /g')
				do
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [LINE = $LINE] [PROD_NAME = $PROD_NAME / PROD_NS = $PROD_NS] NS = [$NS]"
					fi

					local IS_VALID_NS="false"

					if [ $ASSUME_VALID == "false" ]
					then
						if $OC_CMD get ns $NS > /dev/null
						then
							echo "[$(date)] [${FUNCNAME[0]}] [LINE = $LINE] [PROD_NAME = $PROD_NAME / PROD_NS = $PROD_NS] Namespace [$NS] is valid!"
							# echo "$NS" >> $TMP_WORKFILE
							local IS_VALID_NS="true"
						else
							echo "[$(date)] [${FUNCNAME[0]}] [LINE = $LINE] [PROD_NAME = $PROD_NAME / PROD_NS = $PROD_NS] Namespace [$NS] is invalid!" 
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] [LINE = $LINE] [PROD_NAME = $PROD_NAME / PROD_NS = $PROD_NS] Namespace [$NS] is assumed valid!" 
						# echo "$NS" >> $TMP_WORKFILE
						local IS_VALID_NS="true"
					fi

					# To create PROD_NAMESPACES_REFFILE_FINAL
					if [ $IS_VALID_NS == "true" ]
					then
						if toExcludeProdNamespace $NS 
						then
							echo "[$(date)] [${FUNCNAME[0]}] To exclude namespace [$NS]. Skipping..."
						else
							# Namespace is valid and not excluded by user
							if [ ${#PROD_NS_REFLINE_PRODNS} -eq 0 ]
							then
								local PROD_NS_REFLINE_PRODNS="$NS"
							else
								local PROD_NS_REFLINE_PRODNS="$PROD_NS_REFLINE_PRODNS,$NS"
							fi	

							# Temp workfile for PROD_NAMESPACES_UNIQUE
							echo "$NS" >> $TMP_WORKFILE

							if [ $BASH_V4 == "true" ]
							then
								if [ ${PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAME]+_} ]
								then
									local UPDATED_VAL="${PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAME]},$NS"
									echo "[$(date)] [${FUNCNAME[0]}] [LINE = $LINE] [PROD_NAME = $PROD_NAME / PROD_NS = $PROD_NS] Updating KEY [$PROD_NAME] / VALUE [$UPDATED_VAL] into array PROD_NAMESPACES_KEYVAL_ARR!"
									PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAME]=$UPDATED_VAL
								else
									echo "[$(date)] [${FUNCNAME[0]}] [LINE = $LINE] [PROD_NAME = $PROD_NAME / PROD_NS = $PROD_NS] Adding KEY [$PROD_NAME] / VALUE [$NS] into array PROD_NAMESPACES_KEYVAL_ARR!"
									PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAME]=$NS
								fi
							fi
						fi
					fi
				done

				echo "[$(date)] [${FUNCNAME[0]}] [LINE = $LINE] Writing new line [${PROD_NS_REFLINE_PRODNAME}${PROD_NS_REFLINE_PRODNS}] to product namespace final reference file [${PROD_NAMESPACES_REFFILE_FINAL}]..."
				echo "${PROD_NS_REFLINE_PRODNAME}${PROD_NS_REFLINE_PRODNS}" >> ${PROD_NAMESPACES_REFFILE_FINAL}

				IFS=$'\n'
			else
				echo "[$(date)] [${FUNCNAME[0]}] [LINE = $LINE] [PROD_NAME = $PROD_NAME / PROD_NS = $PROD_NS] PROD_NS is empty and invalid!" 
				return 1
			fi
		done < $PROD_NAMESPACES_REFFILE

		if [ -s $PROD_NAMESPACES_REFFILE_FINAL ]
		then
			sort -o $PROD_NAMESPACES_REFFILE_FINAL $PROD_NAMESPACES_REFFILE_FINAL	
			PROD_NAMESPACES_KEYVAL_ARR_FINALIZED="true"
		else
			echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL] does not exist or is zero-sized!"
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_KEYVAL_ARR =>"
			for ARR_KEY in ${!PROD_NAMESPACES_KEYVAL_ARR[@]}
			do
				echo "KEY[$ARR_KEY] = [${PROD_NAMESPACES_KEYVAL_ARR[$ARR_KEY]}]"
			done
		fi

		if [ -s $TMP_WORKFILE ]
		then
			# To create PROD_NAMESPACES_UNIQUE array

			for VALID_NS in $(sort $TMP_WORKFILE | uniq)
			do
				echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$VALID_NS] into PROD_NAMESPACES_UNIQUE array!"
				PROD_NAMESPACES_UNIQUE[${#PROD_NAMESPACES_UNIQUE[@]}]=$VALID_NS
				echo "$VALID_NS" >> $PROD_NAMESPACES_UNIQUE_REFFILE
			done

			if [ ${#PROD_NAMESPACES_UNIQUE[@]} -gt 0 ]
			then
				PROD_NAMESPACES_UNIQUE_STR="${PROD_NAMESPACES_UNIQUE[@]}"
			fi

			rm $TMP_WORKFILE
		fi

		return 0
	else
		return 1
	fi
}

createProdNamespaceDir()
{
	local PROD_NS=

	echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_UNIQUE = ${PROD_NAMESPACES_UNIQUE[@]}" | tee -a $RUNTIME_LOGFILE

	for PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
	do
		local NS_OUTDIR=$PRODUCT_DATA_OUTDIR/$PROD_NS

		echo "[$(date)] [${FUNCNAME[0]}] Creating product namespace directory [$NS_OUTDIR]..." | tee -a $RUNTIME_LOGFILE
		mkdir -p $NS_OUTDIR

		IFS=$OLDIFS
		
		local PRODUCTS=$(getNamespaceToProdMapping $PROD_NS | sed 's/ /,/g')
		
		if [ ${#PRODUCTS} -gt 0 ]
		then
			if [ "$PRODUCTS" == $PROD_NAMESPACES_INVALID_STR ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [$PROD_NS] [PRODUCTS=$PRODUCTS] Unable to create product namespace pointer file!" | tee -a $RUNTIME_LOGFILE
			else
				local NS_POINTER_FILE="$PRODUCT_DATA_OUTDIR/${PROD_NS}@PROD=${PRODUCTS}"
				echo "[$(date)] [${FUNCNAME[0]}] [$PROD_NS] Creating product namespace pointer file [$NS_POINTER_FILE]!" | tee -a $RUNTIME_LOGFILE
				touch $NS_POINTER_FILE
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] [$PROD_NS] [PRODUCTS=$PRODUCTS] Unable to create product namespace pointer file!" | tee -a $RUNTIME_LOGFILE
		fi
	done
}

isPodOk()
{
	local IN_POD_NAMESPACE=$1
	local IN_POD_NAME=$2

	if [ ${#IN_POD_NAMESPACE} -lt 0 ] || [ ${#IN_POD_NAME} -lt 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Invalid input! Either pod namespace [$IN_POD_NAMESPACE] or pod name [$IN_POD_NAME] is empty!"
		return 1
	else
		if ! checkUserPriv get pod $IN_POD_NAMESPACE
		then
			echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to execute '$OC_CMD get' on resource [pod] in namespace [$IN_POD_NAMESPACE]..."	
			return 1
		else
			local CMD="$OC_CMD get pod --no-headers -n $IN_POD_NAMESPACE | $AWK '\$1 ~ /$IN_POD_NAME/ { print \$0 }'"
			echo "[$(date)] [${FUNCNAME[0]}] Executing command [$CMD]..."
			local IN_POD_LINE=$(eval $CMD)

			if [ ${#IN_POD_LINE} -gt 0 ]
			then
				local IN_POD_COUNT=$(echo "$IN_POD_LINE" | wc -l | $AWK '{ print $1 }')

				if [ "$IN_POD_COUNT" -eq 1 ]
				then
					local P_READY_COUNT=$(echo "$IN_POD_LINE" | $AWK '{ print $2 }')
					local P_STATUS=$(echo "$IN_POD_LINE" | $AWK '{ print $3 }')
					local P_CHECK_RES=$(echo "$P_READY_COUNT" | $AWK -F '/' '{ if ( $1 == $2 ) { print "OK" } else { print "NOK" } }')

					if [ $P_STATUS == "Running" ] && [ ${P_CHECK_RES} == "OK" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Pod [$IN_POD_NAME] is in state [$P_STATUS] with count [$P_READY_COUNT]!"
						return 0
					else
						echo "[$(date)] [${FUNCNAME[0]}] Pod [$IN_POD_NAME] is in state [$P_STATUS] with count [$P_READY_COUNT]!"
						return 1
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] More than one pods [$IN_POD_COUNT] with regex [$IN_POD_NAME] are detected! Failing..."
					return 1
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] Command [$CMD] failed! Command output is empty!"
				return 1
			fi
		fi
	fi
}

isPodLineOk()
{
	# If pod is RUNNING and ALL containers are up, returns 0. Otherwise, returns 1.

	local IN_POD_LINE=$1

	if [ ${#IN_POD_LINE} -gt 0 ]
	then
		if [ $(echo "$IN_POD_LINE" | $AWK '{ print NF }') -ge 3 ]
		then
			local POD=$(echo "$IN_POD_LINE" | $AWK '{ print $1 }')

			if [ $(echo "$POD" | $AWK -F'/' '{ print NF }') -gt 1 ]
			then
				local POD_NAME=$(echo "$POD" | $AWK -F'/' '{ print $2 }')
			else
				local POD_NAME=$(echo "$POD" | $AWK -F'/' '{ print $1 }')
			fi

			local P_READY_COUNT=$(echo "$IN_POD_LINE" | $AWK '{ print $2 }')
			local P_STATUS=$(echo "$IN_POD_LINE" | $AWK '{ print $3 }')
			local P_CHECK_RES=$(echo "$P_READY_COUNT" | $AWK -F '/' '{ if ( $1 == $2 ) { print "OK" } else { print "NOK" } }')

			if [ $P_STATUS == "Running" ] && [ ${P_CHECK_RES} == "OK" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Pod [$POD_NAME] is in state [$P_STATUS] with count [$P_READY_COUNT]!"
				return 0
			else
				echo "[$(date)] [${FUNCNAME[0]}] Pod [$POD_NAME] is in state [$P_STATUS] with count [$P_READY_COUNT]!"
				return 1
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] Invalid pod line [$POD_LINE]! Skipping..."
			return 1
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Empty pod line [$POD_LINE]! Skipping..."
		return 1
	fi 
}

toContinue()
{
	local ASK_USER_AGREEMENT=1

	while [ $ASK_USER_AGREEMENT -eq 1 ]
	do
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Are you sure you want to proceed with general data collection (y/n)? ${NORMAL}${NEWLINE}"
		echo -n "[$(date)] [${FUNCNAME[0]}] Are you sure you want to proceed with general data collection (y/n)? " >> $RUNTIME_LOGFILE

		if [ $AUTO_YES == "true" ]
		then
			NON_PROD_COLLECT_AGREEMENT="y"
			echo "$NON_PROD_COLLECT_AGREEMENT" | tee -a $RUNTIME_LOGFILE
			echo "[$(date)] [${FUNCNAME[0]}] Option [-Y] is set! Auto answering [y]..." | tee -a $RUNTIME_LOGFILE
		else
			if [ $MG_TTY == "false" ]
			then
				NON_PROD_COLLECT_AGREEMENT="n"
				echo "$NON_PROD_COLLECT_AGREEMENT" | tee -a $RUNTIME_LOGFILE
				echo "[$(date)] [${FUNCNAME[0]}] In non-TTY mode, auto answering [n]..." | tee -a $RUNTIME_LOGFILE
			else
				read -t $DEFAULT_USERINPUT_TIMEOUT NON_PROD_COLLECT_AGREEMENT
				local EXIT_STATUS=$?
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] EXIT_STATUS = [$EXIT_STATUS]" | tee -a $RUNTIME_LOGFILE
				fi
	
				if [ $EXIT_STATUS -gt 128 ]
				then
					echo | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [${FUNCNAME[0]}] Timeout waiting for user input. Auto answer [N]..." | tee -a $RUNTIME_LOGFILE
					NON_PROD_COLLECT_AGREEMENT="N"
				else
					echo "$NON_PROD_COLLECT_AGREEMENT" >> $RUNTIME_LOGFILE

					if [ ${#NON_PROD_COLLECT_AGREEMENT} -eq 0 ]
					then
						NON_PROD_COLLECT_AGREEMENT="N"
					fi
				fi
			fi
		fi

		if [ ${#NON_PROD_COLLECT_AGREEMENT} -gt 0 ]
		then
			if [ ${NON_PROD_COLLECT_AGREEMENT} == "n" ] || [ ${NON_PROD_COLLECT_AGREEMENT} == "N" ]
			then
				echo "User input [$NON_PROD_COLLECT_AGREEMENT]. To exit data collection..."  | tee -a $RUNTIME_LOGFILE
				return 1	
			else
				if [ ${NON_PROD_COLLECT_AGREEMENT} == "y" ] || [ ${NON_PROD_COLLECT_AGREEMENT} == "Y" ]
				then
					echo "User input [$NON_PROD_COLLECT_AGREEMENT]. To proceed..." | tee -a $RUNTIME_LOGFILE
					return 0
				else
					echo "Invalid user input [$NON_PROD_COLLECT_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
				fi
			fi
		else
			echo "Invalid user input [$NON_PROD_COLLECT_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
		fi
	done
}

getProdToNamespacesMapping()
{
	local INPUT_PROD_NAME=$1	
	local INPUT_REFFILE=$2

	local LINE=

	if [ ${#INPUT_PROD_NAME} -eq 0 ]
	then	
		echo "$PROD_NAMESPACES_INVALID_STR"
		return 1
	fi

	if [ ${#INPUT_REFFILE} -gt 0 ] 
	then
		if [ ! -s $INPUT_REFFILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] INPUT_REFFILE [$INPUT_REFFILE] does not exist or is zero-sized! Setting input file to PROD_NAMESPACES_REFFILE [$PROD_NAMESPACES_REFFILE]..." >&2
			local INPUT_REFFILE=$PROD_NAMESPACES_REFFILE	
		fi
	else
		if [ $BASH_V4 == "true" ] && [ ${#PROD_NAMESPACES_KEYVAL_ARR[@]} -gt 0 ] && [ $PROD_NAMESPACES_KEYVAL_ARR_FINALIZED == "true" ]
		then
			local RETVAL=${PROD_NAMESPACES_KEYVAL_ARR[$INPUT_PROD_NAME]}
	
			if [ ${#RETVAL} -gt 0 ]
			then
				local FINAL_RETVAL=$(echo "$RETVAL" | sed 's/,/ /g')

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [PROD=$INPUT_PROD_NAME] Namespace(s) retrieved from PROD_NAMESPACES_KEYVAL_ARR cache = [$FINAL_RETVAL]" >&2
				fi
				
				echo "$FINAL_RETVAL"
				return 0
			else
				if [ -s $PROD_NAMESPACES_REFFILE_FINAL ] && [ $PROD_NAMESPACES_KEYVAL_ARR_FINALIZED == "true" ]
				then
					local INPUT_REFFILE=$PROD_NAMESPACES_REFFILE_FINAL
				else
					local INPUT_REFFILE=$PROD_NAMESPACES_REFFILE
				fi
			fi
		else
			if [ -s $PROD_NAMESPACES_REFFILE_FINAL ] && [ $PROD_NAMESPACES_KEYVAL_ARR_FINALIZED == "true" ]
			then
				local INPUT_REFFILE=$PROD_NAMESPACES_REFFILE_FINAL
			else
				local INPUT_REFFILE=$PROD_NAMESPACES_REFFILE
			fi
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] [PROD=$INPUT_PROD_NAME] BASH_V4 = [$BASH_V4] / PROD_NAMESPACES_KEYVAL_ARR = [${#PROD_NAMESPACES_KEYVAL_ARR[@]}] / PROD_NAMESPACES_KEYVAL_ARR_FINALIZED = [$PROD_NAMESPACES_KEYVAL_ARR_FINALIZED] / INPUT_REFFILE = [$INPUT_REFFILE]" >&2
	fi

	if [ -s $INPUT_REFFILE ]
	then
		local RESOLVED_NS=$($AWK -F= '$1 ~ /^'$INPUT_PROD_NAME'$/ { print $2 }' $INPUT_REFFILE | sed 's/,/ /g')

		if [ ${#RESOLVED_NS} -gt 0 ]
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [PROD=$INPUT_PROD_NAME] Namespace(s) retrieved from reference file [$INPUT_REFFILE] = [$RESOLVED_NS]" >&2
			fi

			echo "$RESOLVED_NS"
			return 0
		else
			echo "$PROD_NAMESPACES_INVALID_STR"
			return 1	
		fi			
	else
		echo "$PROD_NAMESPACES_INVALID_STR"
		return 1
	fi
}

getNamespaceToProdMapping()
{
	local INPUT_NS=$1
	local INPUT_REFFILE=$2
	
	local NS=
	local LINE=

	if [ ${#INPUT_NS} -eq 0 ]
	then
		echo "$PROD_NAMESPACES_INVALID_STR"
		return 1
	fi

	if [ ${#INPUT_REFFILE} -gt 0 ] 
	then
		if [ ! -s $INPUT_REFFILE ]
		then
			local INPUT_REFFILE=$PROD_NAMESPACES_REFFILE	
		fi
	else
		local INPUT_REFFILE=$PROD_NAMESPACES_REFFILE
	fi

	RESULT=

	if [ -s $INPUT_REFFILE ]
	then
		while read LINE
		do
			if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi
	
			local PROD_NAME=$(echo "$LINE" | $AWK -F= '{ print $1 }')
			local PROD_NS=$(echo "$LINE" | $AWK -F= '{ print $2 }')

			IFS=$OLDIFS

			for NS in $(echo "$PROD_NS" | sed 's/,/ /g')
			do
				if [ $INPUT_NS == $NS ]
				then
					if [ ${#RESULT} -eq 0 ]
					then
						local RESULT=$PROD_NAME
					else
						local RESULT="$RESULT $PROD_NAME"
					fi
				fi
			done

			IFS=$'\n'
		done < $INPUT_REFFILE	

		if [ ${#RESULT} -gt 0 ]
		then
			echo "$RESULT"
			return 0
		else
			echo "$PROD_NAMESPACES_INVALID_STR"
			return 1
		fi
	else
		echo "$PROD_NAMESPACES_INVALID_STR"
		return 1
	fi
}

getUniqueProdNamespaces()
{
	local NS_INFILE=$1
	local UNIQ_NS=""

	local NS=

	if [ ${#NS_INFILE} -gt 0 ] && [ -s ${NS_INFILE} ]
	then
		while read NS
		do
			if [ ${#UNIQ_NS} -eq 0 ]
			then
				local UNIQ_NS=$NS
			else
				local UNIQ_NS="$UNIQ_NS $NS"
			fi
		done < ${NS_INFILE}
	else
		for NS in ${PROD_NAMESPACES_UNIQUE}
		do
			if [ ${#UNIQ_NS} -eq 0 ]
			then
				local UNIQ_NS=$NS
			else
				local UNIQ_NS="$UNIQ_NS $NS"
			fi
		done
	fi

	echo "$UNIQ_NS"
}

getUniqueProdVersions()
{
	local VER_INFILE=$1
	local UNIQ_VER=""
	
	local VER=

	if [ ${#VER_INFILE} -gt 0 ] && [ -s ${VER_INFILE} ]
	then
		while read VER
		do
			if [ ${#UNIQ_VER} -eq 0 ]
			then
				local UNIQ_VER=$VER
			else
				local UNIQ_VER="$UNIQ_VER $VER"
			fi
		done < ${VER_INFILE}
	else
		for VER in ${PROD_VERSIONS_UNIQUE}
		do
			if [ ${#UNIQ_VER} -eq 0 ]
			then
				local UNIQ_VER=$VER
			else
				local UNIQ_VER="$UNIQ_VER $VER"
			fi
		done
	fi

	echo "$UNIQ_VER"
}

createApiList()
{
	if [ ${#CREATE_API_LIST} -gt 0 ] && [ ${CREATE_API_LIST} == "true" ]
	then
		if [ ! -d $RES_LIST_OUTDIR ]
		then
			mkdir -p $RES_LIST_OUTDIR
		fi
	
		if [ $FAST_OC == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Creating full API groups list [$RES_GROUP_LIST_OUTFILE]..."
			$CURL -s -k -m $CURL_TIMEOUT $OC_APISVR	> $RES_GROUP_LIST_OUTFILE
	
			if [ -s $RES_GROUP_LIST_OUTFILE ]
			then
				for APIGROUP in $(grep '"/api' $RES_GROUP_LIST_OUTFILE | grep '"/api' | sed 's/^[ ]*"//' | sed 's/",[ ]*//')
				do
					echo "[$(date)] [${FUNCNAME[0]}] Creating api list for group [$APIGROUP]..."
					local CMD="$CURL -s -k -m $CURL_TIMEOUT ${OC_APISVR}${APIGROUP}"
					eval "$CMD" > $RES_LIST_OUTDIR/$(echo "$APIGROUP" | sed 's#/#_#g').out
				done < $RES_GROUP_LIST_OUTFILE 
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] API groups list [$RES_GROUP_LIST_OUTFILE] does not exist or is zero-sized!"
				fi
			fi
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] FAST_OC = [$FAST_OC] / Not creating API groups list [$RES_GROUP_LIST_OUTFILE]..."
			fi
		fi	
	else
		echo "[$(date)] [${FUNCNAME[0]}] CREATE_API_LIST is not set or is disabled! Skipping..."
	fi
}

createResourceList()
{
	if [ ! -d $RES_LIST_OUTDIR ]
	then
		mkdir -p $RES_LIST_OUTDIR
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Creating full API resource list [$RES_LIST_OUTFILE]..."
	$OC_CMD api-resources > $RES_LIST_OUTFILE

	if [ -s $RES_LIST_OUTFILE ]
	then
		local TMP_FIELDWIDTHS=$(echo "$(head -1 $RES_LIST_OUTFILE)" | grep -E -o '[A-Z]+\s*' | $AWK '{printf "%d ", length($0)}' | sed 's/^[ ]*//;s/[ ]*$//')

		# Total length minus last column (not accurate using HEADERS)
		local TMP_FIELDWIDTHS_LEN=$(echo "$TMP_FIELDWIDTHS" | $AWK 'BEGIN { SUM=0 } { for (i=1; i<NF; i++) { SUM+=$i } } END { print SUM}')

		# Get longest line
		local LONGEST_LINE_LEN=$(cat $RES_LIST_OUTFILE | $AWK 'length > max_length { max_length = length; longest_line = $0 } END { print length(longest_line) }')

		# Calculate width of last column
		local LAST_COL_WIDTH=$((LONGEST_LINE_LEN-TMP_FIELDWIDTHS_LEN))

		local FINAL_FIELDWIDTHS="$(echo "$TMP_FIELDWIDTHS" | $AWK '{ for (i=1; i<NF; i++) { print $i } }') ${LAST_COL_WIDTH}"

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] TMP_FIELDWIDTHS=[$TMP_FIELDWIDTHS] / TMP_FIELDWIDTHS_LEN=[$TMP_FIELDWIDTHS_LEN] / LONGEST_LINE_LEN=[$LONGEST_LINE_LEN] / LAST_COL_WIDTH=[$LAST_COL_WIDTH] / FINAL_FIELDWIDTHS=[$( echo $FINAL_FIELDWIDTHS | tr '\n' ' ' | sed 's/[ ]*$//')]"
		fi

		local PRINTF_COL_ARR=()
		local COL_POSITION=0
		local PREV_COL=0

		local COL=

		IFS=$OLDIFS
		for COL in $FINAL_FIELDWIDTHS
		do
			local CUR_COL=$((PREV_COL+1))

			case "$COL_POSITION" in
				0) PRINTF_COL_ARR[$COL_POSITION]="1,$COL" 
				   PREV_COL=$COL
					;;
				1) NEW_COL_POS=$((CUR_COL+COL-1))
				   PRINTF_COL_ARR[$COL_POSITION]="$CUR_COL,$COL"
				   PREV_COL=$NEW_COL_POS
					;;	
				2) NEW_COL_POS=$((CUR_COL+COL-1))
				   PRINTF_COL_ARR[$COL_POSITION]="$CUR_COL,$COL"
				   PREV_COL=$NEW_COL_POS
					;;	
				3) NEW_COL_POS=$((CUR_COL+COL-1))
				   PRINTF_COL_ARR[$COL_POSITION]="$CUR_COL,$COL"
				   PREV_COL=$NEW_COL_POS
					;;	
				4) NEW_COL_POS=$((CUR_COL+COL-1))
				   PRINTF_COL_ARR[$COL_POSITION]="$CUR_COL,$COL"
				   PREV_COL=$NEW_COL_POS
				   break
					;;	
			esac	
			
			(( COL_POSITION=COL_POSITION+1 ))
		done
		IFS=$'\n'

		if [ ${#PRINTF_COL_ARR[@]} -ne 5 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Failed to determine column widths. Returning..."
			return 1
		fi

		local RES_LIST_TMPFILE="$RES_LIST_OUTFILE.tmp"
		# tail -n +2 $RES_LIST_OUTFILE | sort > $RES_LIST_TMPFILE
		sed '1d' $RES_LIST_OUTFILE | sort > $RES_LIST_TMPFILE

		if [ -s $RES_LIST_TMPFILE ]
		then
			# Output file format
			# API_NAME|API_LONGNAME|API_SHORTNAME|tolower(API_KIND)|API_KIND_ORIG|API_NAMESPACED|API_VERSION
			if [[ $AWK =~ gawk$ ]]
			then
				local PROC_CMD="$AWK '{ API_NAME=gensub(/[ ]*$/,\"\",1,substr(\$0,"${PRINTF_COL_ARR[0]}")); API_SHORTNAME=gensub(/[ ]*$/,\"\",1,substr(\$0,"${PRINTF_COL_ARR[1]}")); API_VERSION=gensub(/[ ]*$/,\"\",1,substr(\$0,"${PRINTF_COL_ARR[2]}")); API_GROUPNAME=gensub(/\/v[0-9]+.*$/,\"\",1,gensub(/^v[0-9]+$/,\"\",1,gensub(/[ ]*$/,\"\",1,substr(\$0,"${PRINTF_COL_ARR[2]}")))); API_NAMESPACED=gensub(/[ ]*$/,\"\",1,substr(\$0,"${PRINTF_COL_ARR[3]}")); API_KIND=tolower(gensub(/[ ]*$/,\"\",1,substr(\$0,"${PRINTF_COL_ARR[4]}")));  API_KIND_ORIG=gensub(/[ ]*$/,\"\",1,substr(\$0,"${PRINTF_COL_ARR[4]}")); if ( length(API_GROUPNAME) > 0 ) { API_LONGNAME=API_KIND \".\" API_GROUPNAME \",\" API_NAME \".\" API_GROUPNAME; if ( length(API_SHORTNAME) > 0 ) { SNARRLEN=split(API_SHORTNAME, SNARR, \",\"); for (i=1; i<=SNARRLEN; i++) { API_LONGNAME=API_LONGNAME \",\" SNARR[i] \".\" API_GROUPNAME } } } else { API_LONGNAME=API_KIND }; print API_NAME \"|\" API_LONGNAME \"|\" API_SHORTNAME \"|\" API_KIND \"|\" API_KIND_ORIG \"|\" API_NAMESPACED \"|\" API_VERSION }' $RES_LIST_TMPFILE"
			else
				local PROC_CMD="$AWK '{ API_NAME=substr(\$0,"${PRINTF_COL_ARR[0]}"); gsub(/[ ]*$/,\"\",API_NAME); API_SHORTNAME=substr(\$0,"${PRINTF_COL_ARR[1]}"); gsub(/[ ]*$/,\"\",API_SHORTNAME); API_VERSION=substr(\$0,"${PRINTF_COL_ARR[2]}"); gsub(/[ ]*$/,\"\",API_VERSION); API_GROUPNAME=substr(\$0,"${PRINTF_COL_ARR[2]}"); gsub(/[ ]*$/,\"\",API_GROUPNAME); gsub(/^v[0-9]+$/,\"\",API_GROUPNAME); gsub(/\/v[0-9]+.*$/,\"\",API_GROUPNAME); API_NAMESPACED=substr(\$0,"${PRINTF_COL_ARR[3]}"); gsub(/[ ]*$/,\"\",API_NAMESPACED); API_KIND_ORIG=substr(\$0,"${PRINTF_COL_ARR[4]}"); gsub(/[ ]*$/,\"\",API_KIND_ORIG); API_KIND=tolower(API_KIND_ORIG); if ( length(API_GROUPNAME ) > 0 ) { API_LONGNAME=API_KIND \".\" API_GROUPNAME \",\" API_NAME \".\" API_GROUPNAME ; if ( length(API_SHORTNAME) > 0 ) { SNARRLEN=split(API_SHORTNAME, SNARR, \",\"); for (i=1; i<=SNARRLEN; i++) { API_LONGNAME=API_LONGNAME \",\" SNARR[i] \".\" API_GROUPNAME } } } else { API_LONGNAME=API_KIND }; print API_NAME \"|\" API_LONGNAME \"|\" API_SHORTNAME \"|\" API_KIND \"|\" API_KIND_ORIG \"|\" API_NAMESPACED \"|\" API_VERSION }' $RES_LIST_TMPFILE"  
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD = [$PROC_CMD]"
			fi

			# Add a 7th column - higher priority(0) is given to resource of type "v1" (to prevent any resource with the same name from getting chosen during search)
			eval "$PROC_CMD" | $AWK -F'|' '{ if ( $7 ~ /^v[0-9]+$|^$/ ) { print $0 "|0" } else { print $0 "|8" } }' | sort -n -t'|' -k8 > $RES_LIST_PROCFILE

			rm $RES_LIST_TMPFILE
		else
			echo "[$(date)] [${FUNCNAME[0]}] RES_LIST_TMPFILE [$RES_LIST_TMPFILE] does not exist or is zero-sized!"
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] RES_LIST_OUTFILE [$RES_LIST_OUTFILE] does not exist or is zero-sized!"
	fi
}

getAllValidApiNames()
{
	# Return value:
	# 0 = function call is successful 
	# 1 = function call failed
	# 2 = RES_LIST_PROCFILE does not exists or is zero-sized

	local IN_API_NAME=$(echo "$1" | $AWK '{ print tolower($0) }')

	if [ -s $RES_LIST_PROCFILE ]
	then
		local PROC_CMD="$AWK -F'|' 'BEGIN { MATCH_FOUND=\"false\" } { API_NAME=\$1; API_LONGNAMES=\$2; API_SHORTNAMES=\$3; API_KIND=\$4; API_KIND_ORIG=\$5; API_NAMESPACED=\$6; if ( API_NAME ~ /^"$IN_API_NAME"$/ ) { MATCH_FOUND=\"true\"; print API_NAME \"##\" API_LONGNAMES \"##\" API_SHORTNAMES \"##\" API_KIND; exit 0 } else { if ( API_KIND ~ /^"$IN_API_NAME"$/ ) { MATCH_FOUND=\"true\"; print API_NAME \"##\" API_LONGNAMES \"##\" API_SHORTNAMES \"##\" API_KIND; exit 0 } else { split(API_SHORTNAMES, SN, \",\"); for (i in SN) { if ( SN[i] ~ /^"$IN_API_NAME"$/ ) { MATCH_FOUND=\"true\"; print API_NAME \"##\" API_LONGNAMES \"##\" API_SHORTNAMES \"##\" API_KIND; exit 0 } } if ( MATCH_FOUND == \"false\" ) { split(API_LONGNAMES, LN, \",\"); for (i in LN) { if ( LN[i] ~ /^"$IN_API_NAME"$/ ) { MATCH_FOUND=\"true\"; print API_NAME \"##\" API_LONGNAMES \"##\" API_SHORTNAMES \"##\" API_KIND; exit 0 } } } } } } END { if ( MATCH_FOUND == \"false\" ) { print \"\"; exit 1 } } ' $RES_LIST_PROCFILE"

 		if [ $MG_DEBUG == "true" ]
 		then
 			echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD = [$PROC_CMD]" >&2
 		fi

		GET_ALL_VALID_API_NAMES_TMP_RESULT=$(eval "$PROC_CMD")
		local PROC_CMD_EXIT_STATUS=$?

		if [ ${#PROC_CMD_EXIT_STATUS} -gt 0 ] 
		then
			echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD_EXIT_STATUS = [$PROC_CMD_EXIT_STATUS]" >&2

			if [ $PROC_CMD_EXIT_STATUS -eq 0 ]
			then
				local RES_API_NAME=$(echo "$GET_ALL_VALID_API_NAMES_TMP_RESULT" | $AWK -F## '{ print $1 }')
				local RES_API_LONGNAMES=$(echo "$GET_ALL_VALID_API_NAMES_TMP_RESULT" | $AWK -F## '{ print $2 }')
				local RES_API_SHORTNAMES=$(echo "$GET_ALL_VALID_API_NAMES_TMP_RESULT" | $AWK -F## '{ print $3 }')
				local RES_API_KIND=$(echo "$GET_ALL_VALID_API_NAMES_TMP_RESULT" | $AWK -F## '{ print $4 }')
		
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] RES_API_NAME = [$RES_API_NAME]" >&2
					echo "[$(date)] [${FUNCNAME[0]}] RES_API_LONGNAMES = [$RES_API_LONGNAMES]" >&2
					echo "[$(date)] [${FUNCNAME[0]}] RES_API_SHORTNAMES = [$RES_API_SHORTNAMES]" >&2
					echo "[$(date)] [${FUNCNAME[0]}] RES_API_KIND = [$RES_API_KIND]" >&2
				fi
		
				# Check whether API_NAME is first choice
				local RES_API_NAME_CNT=$($AWK -F'|' '$1 ~ /^'$RES_API_NAME'$/ { CTR++ } END { print CTR }' $RES_LIST_PROCFILE)
		
				if [ ${#RES_API_NAME_CNT} -gt 0 ] 
				then
 					if [ $MG_DEBUG == "true" ]
 					then
						echo "[$(date)] [${FUNCNAME[0]}] RES_API_NAME_CNT = [$RES_API_NAME_CNT]" >&2
					fi

					if [ ${RES_API_NAME_CNT} -gt 1 ]
					then
						local IS_API_NAME_FIRST_CHOICE=$($AWK -F'|' '$1 ~ /^'$RES_API_NAME'$/' $RES_LIST_PROCFILE | $AWK -F'|' '$2 ~ /^'$RES_API_LONGNAMES'$/ { if ( NR == 1 ) { print "true" } else { print "false" } }')

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] IS_API_NAME_FIRST_CHOICE = [$IS_API_NAME_FIRST_CHOICE]" >&2
						fi

						if [ ${IS_API_NAME_FIRST_CHOICE} == "true" ]
						then
 							if [ $MG_DEBUG == "true" ]
 							then
								echo "[$(date)] [${FUNCNAME[0]}] API_NAME [$RES_API_NAME] is first choice! Setting FINAL_API_NAME to [$RES_API_NAME]..." >&2
							fi

							local FINAL_API_NAME=$RES_API_NAME	
						else
 							if [ $MG_DEBUG == "true" ]
 							then
								echo "[$(date)] [${FUNCNAME[0]}] API_NAME [$RES_API_NAME] is NOT first choice! Setting FINAL_API_NAME to blank..." >&2
							fi

							local FINAL_API_NAME=""
						fi
					else
 						if [ $MG_DEBUG == "true" ]
 						then
							echo "[$(date)] [${FUNCNAME[0]}] API_NAME [$RES_API_NAME] is unique! Setting FINAL_API_NAME to [$RES_API_NAME]..." >&2
						fi

						local FINAL_API_NAME=$RES_API_NAME
					fi
				else
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] RES_API_NAME_CNT is empty/null! Setting FINAL_API_NAME to blank..." >&2
					fi

					local FINAL_API_NAME=""
				fi
		
				# Check whether API_KIND is first choice
				local RES_API_KIND_CNT=$($AWK -F'|' '$4 ~ /^'$RES_API_KIND'$/ { CTR++ } END { print CTR }' $RES_LIST_PROCFILE)
		
				if [ ${#RES_API_KIND_CNT} -gt 0 ] 
				then
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] RES_API_KIND_CNT = [$RES_API_KIND_CNT]" >&2
					fi

					if [ ${RES_API_KIND_CNT} -gt 1 ]
					then
						local IS_API_KIND_FIRST_CHOICE=$($AWK -F'|' '$4 ~ /^'$RES_API_KIND'$/' $RES_LIST_PROCFILE | $AWK -F'|' '$2 ~ /^'$RES_API_LONGNAMES'$/ { if ( NR == 1 ) { print "true" } else { print "false" } }')

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] IS_API_KIND_FIRST_CHOICE = [$IS_API_KIND_FIRST_CHOICE]" >&2
						fi

						if [ ${IS_API_KIND_FIRST_CHOICE} == "true" ]
						then
 							if [ $MG_DEBUG == "true" ]
 							then
								echo "[$(date)] [${FUNCNAME[0]}] API_KIND [$RES_API_KIND] is first choice! Setting FINAL_API_KIND to [$RES_API_KIND]..." >&2
							fi

							local FINAL_API_KIND=$RES_API_KIND
						else
 							if [ $MG_DEBUG == "true" ]
 							then
								echo "[$(date)] [${FUNCNAME[0]}] API_KIND [$RES_API_KIND] is NOT first choice! Setting FINAL_API_KIND to blank..." >&2
							fi

							local FINAL_API_KIND=""
						fi
					else
 						if [ $MG_DEBUG == "true" ]
 						then
							echo "[$(date)] [${FUNCNAME[0]}] API_KIND [$RES_API_KIND] is unique! Setting FINAL_API_KIND to [$RES_API_KIND]..." >&2
						fi

						local FINAL_API_KIND=$RES_API_KIND
					fi
				else
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] RES_API_KIND_CNT is empty/null! Setting FINAL_API_KIND to blank..." >&2
					fi

					local FINAL_API_KIND=""
				fi

				# Check whether API_SHORTNAMES is first choice
				local RES_API_SHORTNAMES_LEN=$(echo "$RES_API_SHORTNAMES" | $AWK -F',' '{ print NF }')

				if [ ${#RES_API_SHORTNAMES_LEN} -gt 0 ]
				then
					if [ ${RES_API_SHORTNAMES_LEN} -eq 0 ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] RES_API_SHORTNAMES_LEN is zero! Setting FINAL_API_SHORTNAMES to blank..." >&2	
						fi

						local FINAL_API_SHORTNAMES=""
					else
						local FINAL_API_SHORTNAMES=
						local TMP_API_SHORTNAMES_MATCHED=$($AWK -F'|' '$3 ~ /'$(echo "$RES_API_SHORTNAMES" | sed 's/,/|/g')'/' $RES_LIST_PROCFILE)
						
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] Loose filtering of matching APIs based on API_SHORTNAMES [$(echo "$RES_API_SHORTNAMES" | sed 's/,/|/g')]..." >&2
							echo "[$(date)] [${FUNCNAME[0]}] TMP_API_SHORTNAMES_MATCHED => [" >&2
							echo "$TMP_API_SHORTNAMES_MATCHED" >&2
							echo "]" >&2
						fi	

						IFS=$OLDIFS
						for RES_API_SHORTNAME in $(echo "$RES_API_SHORTNAMES" | sed 's/,/ /g')
						do
							local LINE_CTR=0

 							if [ $MG_DEBUG == "true" ]
 							then
								echo "[$(date)] [${FUNCNAME[0]}] Starting comparison of RES_API_SHORTNAME [$RES_API_SHORTNAME] against TMP_API_SHORTNAMES_MATCHED lines..." >&2
								echo "[$(date)] [${FUNCNAME[0]}] Unsetting RES_API_SHORTNAME_FOUND_ARR..." >&2
							fi

							unset RES_API_SHORTNAME_FOUND_ARR

							IFS=$'\n'
							for TMP_API_SHORTNAMES_MATCHED_LINE in $TMP_API_SHORTNAMES_MATCHED
							do
								(( LINE_CTR=LINE_CTR+1 ))
	
								local TMP_API_SHORTNAMES=$(echo "$TMP_API_SHORTNAMES_MATCHED_LINE" | $AWK -F'|' '{ print $3 }')	
								local TMP_API_LONGNAMES=$(echo "$TMP_API_SHORTNAMES_MATCHED_LINE" | $AWK -F'|' '{ print $2 }')
	
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] TMP_API_SHORTNAMES = [$TMP_API_SHORTNAMES]" >&2
									echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] TMP_API_LONGNAMES = [$TMP_API_LONGNAMES]" >&2
								fi

								IFS=$OLDIFS
								for TMP_API_SHORTNAME in $(echo "$TMP_API_SHORTNAMES" | sed 's/,/ /g')
								do
 									if [ $MG_DEBUG == "true" ]
 									then
										echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] Comparing RES_API_SHORTNAME [$RES_API_SHORTNAME] to TMP_API_SHORTNAME [$TMP_API_SHORTNAME]..." >&2	
									fi

									if [ "$TMP_API_SHORTNAME" == "$RES_API_SHORTNAME" ]
									then
										if [ "$TMP_API_LONGNAMES" == "$RES_API_LONGNAMES" ]
										then
 											if [ $MG_DEBUG == "true" ]
 											then
												echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] TMP_API_LONGNAMES [$TMP_API_LONGNAMES] matches RES_API_LONGNAMES [$RES_API_LONGNAMES]" >&2
											fi

											if [ $LINE_CTR -eq 1 ]
											then
 												if [ $MG_DEBUG == "true" ]
 												then
													echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] RES_API_SHORTNAME [$RES_API_SHORTNAME] is first choice! Adding [$RES_API_SHORTNAME] to FINAL_API_SHORTNAMES [$FINAL_API_SHORTNAMES]..." >&2
												fi
			
												if [ ${#FINAL_API_SHORTNAMES} -eq 0 ]
												then
													local FINAL_API_SHORTNAMES=$RES_API_SHORTNAME
												else	
													local FINAL_API_SHORTNAMES="$FINAL_API_SHORTNAMES $RES_API_SHORTNAME"
												fi
											else
												if [ ${#RES_API_SHORTNAME_FOUND_ARR[@]} -gt 0 ]
												then
													local TO_ADD_TO_FINAL_API_SHORTNAMES="true"

													for RES_API_SHORTNAME_FOUND_ARR_ITEM in ${RES_API_SHORTNAME_FOUND_ARR[@]}
													do
 														if [ $MG_DEBUG == "true" ]
 														then
															echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] Comparing RES_API_SHORTNAME [$RES_API_SHORTNAME] against RES_API_SHORTNAME_FOUND_ARR_ITEM [$RES_API_SHORTNAME_FOUND_ARR_ITEM]..." >&2
														fi

														if [ "$RES_API_SHORTNAME_FOUND_ARR_ITEM" == "$RES_API_SHORTNAME" ]
														then
 															if [ $MG_DEBUG == "true" ]
 															then
																echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] RES_API_SHORTNAME [$RES_API_SHORTNAME] is NOT first choice! Not adding to FINAL_API_SHORTNAMES..." >&2 
															fi

															local TO_ADD_TO_FINAL_API_SHORTNAMES="false"
															break
														fi
													done

													if [ $TO_ADD_TO_FINAL_API_SHORTNAMES == "true" ]
													then
 														if [ $MG_DEBUG == "true" ]
 														then
															echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] RES_API_SHORTNAME [$RES_API_SHORTNAME] is first choice! Adding [$RES_API_SHORTNAME] to FINAL_API_SHORTNAMES [$FINAL_API_SHORTNAMES]..." >&2
														fi
				
														if [ ${#FINAL_API_SHORTNAMES} -eq 0 ]
														then
															local FINAL_API_SHORTNAMES=$RES_API_SHORTNAME
														else	
															local FINAL_API_SHORTNAMES="$FINAL_API_SHORTNAMES $RES_API_SHORTNAME"
														fi
													fi
												else
 													if [ $MG_DEBUG == "true" ]
 													then
														echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] RES_API_SHORTNAME [$RES_API_SHORTNAME] is first choice! Adding [$RES_API_SHORTNAME] to FINAL_API_SHORTNAMES [$FINAL_API_SHORTNAMES]..." >&2
													fi
			
													if [ ${#FINAL_API_SHORTNAMES} -eq 0 ]
													then
														local FINAL_API_SHORTNAMES=$RES_API_SHORTNAME
													else	
														local FINAL_API_SHORTNAMES="$FINAL_API_SHORTNAMES $RES_API_SHORTNAME"
													fi
												fi
											fi	
										else
 											if [ $MG_DEBUG == "true" ]
 											then
												echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] TMP_API_LONGNAMES [$TMP_API_LONGNAMES] does NOT match RES_API_LONGNAMES [$RES_API_LONGNAMES]" >&2
												echo "[$(date)] [${FUNCNAME[0]}] [$LINE_CTR] Adding RES_API_SHORTNAME [$RES_API_SHORTNAME] into array RES_API_SHORTNAME_FOUND_ARR [${RES_API_SHORTNAME_FOUND_ARR[@]}]..." >&2
											fi

											local RES_API_SHORTNAME_FOUND_ARR[${#RES_API_SHORTNAME_FOUND_ARR[@]}]="$RES_API_SHORTNAME"
										fi
									fi	
								done
							done
						done
					fi	
				else
					echo "[$(date)] [${FUNCNAME[0]}] RES_API_SHORTNAMES_LEN is empty/null! Setting FINAL_API_SHORTNAMES to blank..." >&2	
					local FINAL_API_SHORTNAMES=""
				fi	

				# API_LONGNAMES are always unique
				local FINAL_API_LONGNAMES=$(echo "$RES_API_LONGNAMES" | sed 's/,/ /g')
				local FINAL_ALL_VALID_API_NAMES="$FINAL_API_NAME $FINAL_API_LONGNAMES $FINAL_API_SHORTNAMES $FINAL_API_KIND"

 				if [ $MG_DEBUG == "true" ]
 				then
					echo "[$(date)] [${FUNCNAME[0]}] FINAL_ALL_VALID_API_NAMES = [$FINAL_ALL_VALID_API_NAMES]" >&2
				fi

				echo "$FINAL_ALL_VALID_API_NAMES"
			else
				echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD_EXIT_STATUS [$PROC_CMD_EXIT_STATUS] is not zero/successful! Returning..." >&2
			fi

			return $PROC_CMD_EXIT_STATUS
		else
			echo "[$(date)] [${FUNCNAME[0]}] PROC_CMD_EXIT_STATUS is empty/null! Returning..." >&2
			return 1
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] RES_LIST_PROCFILE [$RES_LIST_PROCFILE] does not exist or is zero-sized! Returning..." >&2
		return 2
	fi
}

createSensitiveDataArr()
{
	local TMP_INPUT_FILE=$RUNTIME_OUTDIR/sensitive-data.tmp
	local SYSTEM_SENSITIVE_DATA_DEF="false"
	local PRODUCT_SENSITIVE_DATA_DEF="false"

	if [ -s $MUSTGATHER_DIRNAME/sensitive-data.lst ]
	then
		local SYSTEM_SENSITIVE_DATA_DEF="true"
	else
		echo "[$(date)] [${FUNCNAME[0]}] Default sensitive data file [$MUSTGATHER_DIRNAME/sensitive-data.lst] does not exist or is zero-sized!"
	fi

	if [ -s $MUSTGATHER_DIRNAME/config/sensitive-data.lst ] 
	then
		if [ $(grep -E -v '^[[:space:]]*#' $MUSTGATHER_DIRNAME/config/sensitive-data.lst | wc -l) -gt 0 ]
		then
			local PRODUCT_SENSITIVE_DATA_DEF="true"
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Product sensitive data file [$MUSTGATHER_DIRNAME/config/sensitive-data.lst] exists, but does not contain any valid configuration!"
			fi
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product sensitive data file [$MUSTGATHER_DIRNAME/config/sensitive-data.lst] does not exist or is zero-sized!"
	fi

	if [ $SYSTEM_SENSITIVE_DATA_DEF == "false" ] && [ $PRODUCT_SENSITIVE_DATA_DEF == "false" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Both system and product sensitive data file do not exist or are zero-sized! Returning..."	
		return 0
	else
		if [ $SYSTEM_SENSITIVE_DATA_DEF == "true" ] && [ $PRODUCT_SENSITIVE_DATA_DEF == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Creating sensitive data array based on [$MUSTGATHER_DIRNAME/sensitive-data.lst] and [$MUSTGATHER_DIRNAME/config/sensitive-data.lst]..."				
		else
			if [ $SYSTEM_SENSITIVE_DATA_DEF == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Creating sensitive data array based on [$MUSTGATHER_DIRNAME/sensitive-data.lst]..."				
			else
				echo "[$(date)] [${FUNCNAME[0]}] Creating sensitive data array based on [$MUSTGATHER_DIRNAME/config/sensitive-data.lst]..."				
			fi
		fi
	fi

	if [ $SYSTEM_SENSITIVE_DATA_DEF == "true" ]
	then
		while read RESTYPE_LINE
		do
			# Skip all lines that start with # and blank lines
			if [[ $(echo "$RESTYPE_LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$RESTYPE_LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi

			local RESTYPE_LINE=$(echo "$RESTYPE_LINE" | sed 's/^\s*//')

			echo "[$(date)] [${FUNCNAME[0]}] Getting all valid API names for [$RESTYPE_LINE]..."
			local ALL_VALID_API_NAMES=$(getAllValidApiNames "$RESTYPE_LINE")		

			if [ ${#ALL_VALID_API_NAMES} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] All valid API names for [$RESTYPE_LINE] = [$ALL_VALID_API_NAMES]"
				echo "$ALL_VALID_API_NAMES" | sed 's/ /\n/g' | grep -v '^$' >> $TMP_INPUT_FILE	
			else
				echo "[$(date)] [${FUNCNAME[0]}] Failed to obtain valid API names for [$RESTYPE_LINE]..."					
			fi
		done < $MUSTGATHER_DIRNAME/sensitive-data.lst
	fi

	if [ $PRODUCT_SENSITIVE_DATA_DEF == "true" ]
	then
		while read RESTYPE_LINE
		do
			# Skip all lines that start with # and blank lines
			if [[ $(echo "$RESTYPE_LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$RESTYPE_LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi

			local RESTYPE_LINE=$(echo "$RESTYPE_LINE" | sed 's/^\s*//')

			echo "[$(date)] [${FUNCNAME[0]}] Getting all valid API names for [$RESTYPE_LINE]..."
			local ALL_VALID_API_NAMES=$(getAllValidApiNames "$RESTYPE_LINE")		

			if [ ${#ALL_VALID_API_NAMES} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] All valid API names for [$RESTYPE_LINE] = [$ALL_VALID_API_NAMES]"
				echo "$ALL_VALID_API_NAMES" | sed 's/ /\n/g' | grep -v '^$' >> $TMP_INPUT_FILE	
			else
				echo "[$(date)] [${FUNCNAME[0]}] Failed to obtain valid API names for [$RESTYPE_LINE]..."					
			fi
		done < $MUSTGATHER_DIRNAME/config/sensitive-data.lst

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up [$MUSTGATHER_DIRNAME/config/sensitive-data.lst] to directory [$MAIN_ROOT_DEBUG_OUTDIR]..."
			cp -p $MUSTGATHER_DIRNAME/config/sensitive-data.lst $MAIN_ROOT_DEBUG_OUTDIR
		fi
	fi

	if [ -s $TMP_INPUT_FILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Sorting and producting unique values from TMP_INPUT_FILE [$TMP_INPUT_FILE] to SENSITIVE_DATA_REFFILE [$SENSITIVE_DATA_REFFILE]..."
		sort $TMP_INPUT_FILE | uniq > $SENSITIVE_DATA_REFFILE	
		rm $TMP_INPUT_FILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] TMP_INPUT_FILE [$TMP_INPUT_FILE] does not exist or is zero-sized! Returning..."
		return 1
	fi

	if [ $BASH_V4 == "true" ]
	then
		mapfile -t SENSITIVE_DATA_ARR < $SENSITIVE_DATA_REFFILE
	else
		SENSITIVE_DATA_ARR=( $(cat $SENSITIVE_DATA_REFFILE) )
	fi

	if [ ${#SENSITIVE_DATA_ARR[@]} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Creation of sensitive data array failed! Returning..."
		return 1
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Content of SENSITIVE_DATA_ARR => ["
			printf "%s\n" "${SENSITIVE_DATA_ARR[@]}"
			echo "]"
		fi
	fi
}

isSensitiveData()
{
	# Return 0 = Resource type is sensitive
	# Return 1 = Resource type is NOT sensitive

	local IN_RES_TYPE=$1

	if [ ${#IN_RES_TYPE} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is empty! Returning..." >&2
		return 1
	else
		# To cater for scripts executed in subshell
		if [ $GMGF_PID != $$ ]
		then
			local CMD="$AWK '/^$IN_RES_TYPE\$/' $SENSITIVE_DATA_REFFILE"
			local RES=$(eval "$CMD")

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CMD = [$CMD]" >&2
			fi

			if [ ${#RES} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is sensitive resource type!" >&2
				return 0
			else
				echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is NOT sensitive resource type!" >&2
				return 1
			fi	
		fi

		if [ ${#SENSITIVE_DATA_ARR[@]} -eq 0 ]
		then	
			echo "[$(date)] [${FUNCNAME[0]}] SENSITIVE_DATA_ARR is empty! Returning..." >&2
			return 1
		else
			for SENSITIVE_RES_TYPE in ${SENSITIVE_DATA_ARR[@]}
			do
				if [ "$IN_RES_TYPE" == "$SENSITIVE_RES_TYPE" ]
				then
					if  [ $GMGF_PID != $$ ] 
					then
						echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is sensitive resource type!" >&2
					else
						echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is sensitive resource type!" 
					fi

					return 0
				fi
			done

			if [ $MG_DEBUG == "true" ]
			then
				if [ $GMGF_PID != $$ ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is NOT sensitive resource type!" >&2
				else
					echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is NOT sensitive resource type!" 
				fi
			fi

			return 1
		fi
	fi
}

createRestrictedDataArr()
{
	local TMP_INPUT_FILE=$RUNTIME_OUTDIR/restricted-data.tmp
	local SYSTEM_RESTRICTED_DATA_DEF="false"
	local PRODUCT_RESTRICTED_DATA_DEF="false"

	if [ -s $MUSTGATHER_DIRNAME/restricted-data.lst ]
	then
		local SYSTEM_RESTRICTED_DATA_DEF="true"
	else
		echo "[$(date)] [${FUNCNAME[0]}] Default restricted data file [$MUSTGATHER_DIRNAME/restricted-data.lst] does not exist or is zero-sized!"
	fi

	if [ -s $MUSTGATHER_DIRNAME/config/restricted-data.lst ] 
	then
		if [ $(grep -E -v '^[[:space:]]*#' $MUSTGATHER_DIRNAME/config/restricted-data.lst | wc -l) -gt 0 ]
		then
			local PRODUCT_RESTRICTED_DATA_DEF="true"
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Product restricted data file [$MUSTGATHER_DIRNAME/config/restricted-data.lst] exists, but does not contain any valid configuration!"
			fi
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product restricted data file [$MUSTGATHER_DIRNAME/config/restricted-data.lst] does not exist or is zero-sized!"
	fi

	if [ $SYSTEM_RESTRICTED_DATA_DEF == "false" ] && [ $PRODUCT_RESTRICTED_DATA_DEF == "false" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Both system and product restricted data file do not exist or are zero-sized! Returning..."	
		return 0
	else
		if [ $SYSTEM_RESTRICTED_DATA_DEF == "true" ] && [ $PRODUCT_RESTRICTED_DATA_DEF == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Creating restricted data array based on [$MUSTGATHER_DIRNAME/restricted-data.lst] and [$MUSTGATHER_DIRNAME/config/restricted-data.lst]..."				
		else
			if [ $SYSTEM_RESTRICTED_DATA_DEF == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Creating restricted data array based on [$MUSTGATHER_DIRNAME/restricted-data.lst]..."				
			else
				echo "[$(date)] [${FUNCNAME[0]}] Creating restricted data array based on [$MUSTGATHER_DIRNAME/config/restricted-data.lst]..."				
			fi
		fi
	fi

	if [ $SYSTEM_RESTRICTED_DATA_DEF == "true" ]
	then
		while read RESTYPE_LINE
		do
			# Skip all lines that start with # and blank lines
			if [[ $(echo "$RESTYPE_LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$RESTYPE_LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi

			local RESTYPE_LINE=$(echo "$RESTYPE_LINE" | sed 's/^\s*//')

			echo "[$(date)] [${FUNCNAME[0]}] Getting all valid API names for [$RESTYPE_LINE]..."
			local ALL_VALID_API_NAMES=$(getAllValidApiNames "$RESTYPE_LINE")		

			if [ ${#ALL_VALID_API_NAMES} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] All valid API names for [$RESTYPE_LINE] = [$ALL_VALID_API_NAMES]"
				echo "$ALL_VALID_API_NAMES" | sed 's/ /\n/g' | grep -v '^$' >> $TMP_INPUT_FILE	
			else
				echo "[$(date)] [${FUNCNAME[0]}] Failed to obtain valid API names for [$RESTYPE_LINE]..."					
			fi
		done < $MUSTGATHER_DIRNAME/restricted-data.lst
	fi

	if [ $PRODUCT_RESTRICTED_DATA_DEF == "true" ]
	then
		while read RESTYPE_LINE
		do
			# Skip all lines that start with # and blank lines
			if [[ $(echo "$RESTYPE_LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$RESTYPE_LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi

			local RESTYPE_LINE=$(echo "$RESTYPE_LINE" | sed 's/^\s*//')

			echo "[$(date)] [${FUNCNAME[0]}] Getting all valid API names for [$RESTYPE_LINE]..."
			local ALL_VALID_API_NAMES=$(getAllValidApiNames "$RESTYPE_LINE")		

			if [ ${#ALL_VALID_API_NAMES} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] All valid API names for [$RESTYPE_LINE] = [$ALL_VALID_API_NAMES]"
				echo "$ALL_VALID_API_NAMES" | sed 's/ /\n/g' | grep -v '^$' >> $TMP_INPUT_FILE	
			else
				echo "[$(date)] [${FUNCNAME[0]}] Failed to obtain valid API names for [$RESTYPE_LINE]..."					
			fi
		done < $MUSTGATHER_DIRNAME/config/restricted-data.lst

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up [$MUSTGATHER_DIRNAME/config/restricted-data.lst] to directory [$MAIN_ROOT_DEBUG_OUTDIR]..."
			cp -p $MUSTGATHER_DIRNAME/config/restricted-data.lst $MAIN_ROOT_DEBUG_OUTDIR
		fi
	fi

	if [ -s $TMP_INPUT_FILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Sorting and producting unique values from TMP_INPUT_FILE [$TMP_INPUT_FILE] to RESTRICTED_DATA_REFFILE [$RESTRICTED_DATA_REFFILE]..."
		sort $TMP_INPUT_FILE | uniq > $RESTRICTED_DATA_REFFILE	
		rm $TMP_INPUT_FILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] TMP_INPUT_FILE [$TMP_INPUT_FILE] does not exist or is zero-sized! Returning..."
		return 1
	fi

	if [ $BASH_V4 == "true" ]
	then
		mapfile -t RESTRICTED_DATA_ARR < $RESTRICTED_DATA_REFFILE
	else
		RESTRICTED_DATA_ARR=( $(cat $RESTRICTED_DATA_REFFILE) )
	fi

	if [ ${#RESTRICTED_DATA_ARR[@]} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Creation of restricted data array failed! Returning..."
		return 1
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Content of RESTRICTED_DATA_ARR => ["
			printf "%s\n" "${RESTRICTED_DATA_ARR[@]}"
			echo "]"
		fi
	fi
}

isRestrictedData()
{
	# Return 0 = Resource type is restricted
	# Return 1 = Resource type is NOT restricted

	local IN_RES_TYPE=$1

	if [ ${#IN_RES_TYPE} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is empty! Returning..." >&2
		return 1
	else
		# To cater for scripts executed in subshell
		if [ $GMGF_PID != $$ ]
		then
			local CMD="$AWK '/^$IN_RES_TYPE\$/' $RESTRICTED_DATA_REFFILE"
			local RES=$(eval "$CMD")

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] CMD = [$CMD]" >&2
			fi

			if [ ${#RES} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is restricted resource type!" >&2
				return 0
			else
				echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is NOT restricted resource type!" >&2
				return 1
			fi	
		fi

		if [ ${#RESTRICTED_DATA_ARR[@]} -eq 0 ]
		then	
			echo "[$(date)] [${FUNCNAME[0]}] RESTRICTED_DATA_ARR is empty! Returning..." >&2
			return 1
		else
			for RESTRICTED_RES_TYPE in ${RESTRICTED_DATA_ARR[@]}
			do
				if [ "$IN_RES_TYPE" == "$RESTRICTED_RES_TYPE" ]
				then
					if  [ $GMGF_PID != $$ ] 
					then
						echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is restricted resource type!" >&2
					else
						echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is restricted resource type!" 
					fi

					return 0
				fi
			done

			if [ $MG_DEBUG == "true" ]
			then
				if [ $GMGF_PID != $$ ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is NOT restricted resource type!" >&2
				else
					echo "[$(date)] [${FUNCNAME[0]}] IN_RES_TYPE [$IN_RES_TYPE] is NOT restricted resource type!" 
				fi
			fi

			return 1
		fi
	fi
}

grepPattern()
{
	if [ $GET_POD_LOGS == "false" ] && [ $OC_DESC_ON == "false" ] && [ $GET_NODES_DATA == "false" ] && [ ${CPFILES_ENABLED} == "false" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] GET_POD_LOGS, OC_DESC_ON, GET_NODES_DATA are set to [false] and CPFILES_FILES is null. No pod logs, event logs, nodes data or files copied from pod  to work on. Skipping..."
		return 1
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Executing 'grepPattern' function for patterns [$GREP_PATTERN]"

	local KEYVALUE_CTR=0
	local OVERALL_PODLOG_CTR=0
	local OVERALL_EVENT_CTR=0
	local OVERALL_NODEFILE_CTR=0
	local OVERALL_CPFILES_CTR=0
	local PRINT_PODLOG_HEADER="true"
	local PRINT_EVENT_HEADER="true"
	local PRINT_NODEFILE_HEADER="true"
	local PRINT_CPFILES_HEADER="true"
	local PATTERN_HIT_ARR=()
	
	local KV=
	local KEYVALUE=
	local V=
	local PATTERN=
	local NS=
	local POD_LOG=
	local DIR=
	local EVENT_LOG=
	local WDIR=
	local DESC_FILE=
	local LOG_FILE=
	local NODE_FILE=
	local CP_FILE=
	local PODLOGS_HIT_FILE=
	local PODLOGS_MISS_FILE=
	local EVENTS_HIT_FILE=
	local EVENTS_MISS_FILE=
	local NODEFILE_HIT_FILE=
	local NODEFILE_MISS_FILE=
	local CPFILES_HIT_FILE=
	local CPFILES_MISS_FILE=
	
	IFS=$'\n'

	for KV in $(echo "$GREP_PATTERN" | $AWK 'BEGIN{RS="##"} {$1=$1}1')
	do
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Adding keyvalue [$KV] into array!"
		fi

		local KEYVALUE_ARR[${#KEYVALUE_ARR[@]}]=$KV
	done

	echo "===================================================" >> $ANALYZE_OUTFILE
	echo "SUMMARY REPORT OF ON-SITE GREP" >> $ANALYZE_OUTFILE
	echo "===================================================" >> $ANALYZE_OUTFILE

	if [ $MG_DEBUG == "true" ]
	then
		local GREPPATTERN_DEBUG_OUTDIR=$DEBUG_OUTDIR/grepPattern
		echo "[$(date)] [${FUNCNAME[0]}] Making directory [$GREPPATTERN_DEBUG_OUTDIR]..."
		mkdir -p $GREPPATTERN_DEBUG_OUTDIR
	fi

	for KEYVALUE in "${KEYVALUE_ARR[@]}"
	do
		local PATTERN_CTR=0	
		local PATTERN_ARR=()

		local KEY=$(echo "$KEYVALUE" | $AWK -F: '{ print $1 }')
		local VALUE=$(echo "$KEYVALUE" | $AWK -F: '{ for (i=2; i<=NF; i++) { if (i==2) {VAL=$i} else {VAL=VAL ":" $i} }} END { print VAL }')

		if [ ${#KEY} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [KV=$KEYVALUE_CTR] [KV=$KEYVALUE] KEY is null! Skipping..."
			(( KEYVALUE_CTR=KEYVALUE_CTR+1 ))
			continue
		fi

		if [ ${#VALUE} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [KV=$KEYVALUE_CTR] [KV=$KEYVALUE] VALUE is null! Skipping..."
			(( KEYVALUE_CTR=KEYVALUE_CTR+1 ))
			continue
		fi

		echo "[$(date)] [${FUNCNAME[0]}] [KV=$KEYVALUE_CTR] KEYVALUE = $KEYVALUE"
		echo "[$(date)] [${FUNCNAME[0]}] [KV=$KEYVALUE_CTR] KEY = $KEY"
		echo "[$(date)] [${FUNCNAME[0]}] [KV=$KEYVALUE_CTR] VALUE = $VALUE"

		for V in $(echo "$VALUE" | $AWK 'BEGIN{RS="@@"} {$1=$1}1')
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [KV=$KEYVALUE_CTR] Adding pattern [$V] into array!"
			fi
			
			local PATTERN_ARR[${#PATTERN_ARR[@]}]=$V
		done

		for PATTERN in "${PATTERN_ARR[@]}"
		do
			echo "[$(date)] [${FUNCNAME[0]}] [KV=$KEYVALUE_CTR] KEY[$KEY] / PATTERN[$PATTERN_CTR] = $PATTERN"

			# Primary data collection mode
			if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ]
			then
				# Product namespaces
				for NS in ${PROD_NAMESPACES_UNIQUE[@]}
				do
					if [ $GET_POD_LOGS == "true" ]
					then
		         			local NS_POD_OUTDIR="$PRODUCT_DATA_OUTDIR/$NS/pod"
	
						if [ ! -d $NS_POD_OUTDIR ]
						then
							local NS_POD_OUTDIR="$PRODUCT_DATA_OUTDIR/$NS/pods"

							if [ ! -d $NS_POD_OUTDIR ]
							then
								local NS_POD_OUTDIR="$PRODUCT_DATA_OUTDIR/$NS/po"
					
								if [ ! -d $NS_POD_OUTDIR ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Target directory [$NS_POD_OUTDIR] does not exist! Skipping..."
									continue
								fi
							fi
						fi
					
						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Scanning directory [$NS_POD_OUTDIR]..."
	
						if [ $KEY == "ALL" ]
						then
							local GREP_COND="ls $NS_POD_OUTDIR"
						else
							local GREP_COND="ls $NS_POD_OUTDIR | grep -E '$KEY'" 
						fi

						local FILE_MATCHED=0
	
						for POD_LOG in $(eval "$GREP_COND" | grep -E 'log$|log.prev$')
						do
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$NS_POD_OUTDIR/$POD_LOG]..."
							fi

							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							local HIT_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							local MISS_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss

							grepTextFile $NS_POD_OUTDIR $POD_LOG $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_PODLOG_CTR $PRINT_PODLOG_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_POD_LOGS_OUTFILE" "$GREP_POD_LOGS_TYPE"
							local PRINT_PODLOG_HEADER="false"
							(( OVERALL_PODLOG_CTR=OVERALL_PODLOG_CTR+1 ))
							(( FILE_MATCHED=FILE_MATCHED+1 ))
						done	

						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Total file matched in directory [$NS_POD_OUTDIR] = $FILE_MATCHED"

						if [ $FILE_MATCHED -eq 0 ]
						then
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss
						fi
					fi

					if [ $OC_DESC_ON == "true" ]
					then
						for DIR in $(find $PRODUCT_DATA_OUTDIR/$NS -type d)
						do
							local NS_OUTDIR=$DIR
	
							if [ ! -d $NS_OUTDIR ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Target directory [$NS_OUTDIR] does not exist! Skipping..."
								continue
							fi
					
							echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Scanning directory [$NS_OUTDIR]..."
	
							if [ $KEY == "ALL" ]
							then
								local GREP_COND="ls $NS_OUTDIR"
							else
								local GREP_COND="ls $NS_OUTDIR | grep -E '$KEY'" 
							fi
							
							local FILE_MATCHED=0
	
							for EVENT_LOG in $(eval "$GREP_COND" | grep -E 'desc$')
							do
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$NS_OUTDIR/$EVENT_LOG]..."
								fi

								local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
								local HIT_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.hit
								local MISS_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.miss

								grepTextFile $NS_OUTDIR $EVENT_LOG $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_EVENT_CTR $PRINT_EVENT_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_EVENTS_OUTFILE" "$GREP_EVENTS_TYPE"
								local PRINT_EVENT_HEADER="false"
								(( OVERALL_EVENT_CTR=OVERALL_EVENT_CTR+1 ))
								(( FILE_MATCHED=FILE_MATCHED+1 ))
							done

							echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Total file matched in directory [$NS_OUTDIR] = $FILE_MATCHED"

							if [ $FILE_MATCHED -eq 0 ]
							then
								local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
								touch $OUTDIR/grep_EVENTS-$KEY:$PAT.hit
								touch $OUTDIR/grep_EVENTS-$KEY:$PAT.miss
							fi
						done
					fi
				done

				# Cluster data 
				if [ -d $CLUSTER_DATA_OUTDIR ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] Scanning directory [$CLUSTER_DATA_OUTDIR]..."

					if [ $OC_DESC_ON == "true" ]
					then
						local GREP_COND="find $CLUSTER_DATA_OUTDIR -type f -name '*.desc' 2> /dev/null | sort "
						local FILE_MATCHED=0
	
						for DESC_FILE in $(eval "$GREP_COND")
						do
							local DESC_DIRNAME=$(dirname $DESC_FILE)
							local DESC_FILENAME=$(basename $DESC_FILE)
	
							if [ $KEY != "ALL" ]
							then
								if [[ ! $DESC_FILENAME =~ $KEY ]]
								then	
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] File [$DESC_FILE] does not match KEY [$KEY]. Skipping..."
									fi
	
									continue
								fi
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$DESC_FILE]..."
							fi
	
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							local HIT_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.hit
							local MISS_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.miss
	
							grepTextFile $DESC_DIRNAME $DESC_FILENAME $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_EVENT_CTR $PRINT_EVENT_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_EVENTS_OUTFILE" "$GREP_EVENTS_TYPE"
							local PRINT_EVENT_HEADER="false"
							(( OVERALL_EVENT_CTR=OVERALL_EVENT_CTR+1 ))
							(( FILE_MATCHED=FILE_MATCHED+1 ))
						done
	
						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Total file matched in directory [$CLUSTER_DATA_OUTDIR] = $FILE_MATCHED"
	
						if [ $FILE_MATCHED -eq 0 ]
						then
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							touch $OUTDIR/grep_EVENTS-$KEY:$PAT.hit
							touch $OUTDIR/grep_EVENTS-$KEY:$PAT.miss
						fi
					fi

					if [ $GET_POD_LOGS == "true" ]
					then
						local GREP_COND="find $CLUSTER_DATA_OUTDIR -type f 2> /dev/null | grep -E '.log$|.log.prev$' | sort "
						local FILE_MATCHED=0
	
						for LOG_FILE in $(eval "$GREP_COND")
						do
							local LOG_DIRNAME=$(dirname $LOG_FILE)
							local LOG_FILENAME=$(basename $LOG_FILE)
	
							if [ $KEY != "ALL" ]
							then
								if [[ ! $LOG_FILENAME =~ $KEY ]]
								then	
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] File [$LOG_FILE] does not match KEY [$KEY]. Skipping..."
									fi
	
									continue
								fi
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$LOG_FILE]..."
							fi
	
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							local HIT_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							local MISS_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss
	
							grepTextFile $LOG_DIRNAME $LOG_FILENAME $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_PODLOG_CTR $PRINT_PODLOG_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_POD_LOGS_OUTFILE" "$GREP_POD_LOGS_TYPE"
							local PRINT_PODLOG_HEADER="false"
							(( OVERALL_PODLOG_CTR=OVERALL_PODLOG_CTR+1 ))
							(( FILE_MATCHED=FILE_MATCHED+1 ))
						done
	
						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Total file matched in directory [$CLUSTER_DATA_OUTDIR] = $FILE_MATCHED"
	
						if [ $FILE_MATCHED -eq 0 ]
						then
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss
						fi
					fi
				fi

				# Custom data
				if [ -d $CUSTOM_DATA_OUTDIR ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] Scanning directory [$CUSTOM_DATA_OUTDIR]..."

					if [ $OC_DESC_ON == "true" ]
					then
						local GREP_COND="find $CUSTOM_DATA_OUTDIR -type f -name '*.desc' 2> /dev/null | sort "
						local FILE_MATCHED=0
	
						for DESC_FILE in $(eval "$GREP_COND")
						do
							local DESC_DIRNAME=$(dirname $DESC_FILE)
							local DESC_FILENAME=$(basename $DESC_FILE)
	
							if [ $KEY != "ALL" ]
							then
								if [[ ! $DESC_FILENAME =~ $KEY ]]
								then	
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] File [$DESC_FILE] does not match KEY [$KEY]. Skipping..."
									fi
	
									continue
								fi
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$DESC_FILE]..."
							fi
	
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							local HIT_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.hit
							local MISS_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.miss
	
							grepTextFile $DESC_DIRNAME $DESC_FILENAME $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_EVENT_CTR $PRINT_EVENT_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_EVENTS_OUTFILE" "$GREP_EVENTS_TYPE"
							local PRINT_EVENT_HEADER="false"
							(( OVERALL_EVENT_CTR=OVERALL_EVENT_CTR+1 ))
							(( FILE_MATCHED=FILE_MATCHED+1 ))
						done
	
						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Total file matched in directory [$CUSTOM_DATA_OUTDIR] = $FILE_MATCHED"
	
						if [ $FILE_MATCHED -eq 0 ]
						then
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							touch $OUTDIR/grep_EVENTS-$KEY:$PAT.hit
							touch $OUTDIR/grep_EVENTS-$KEY:$PAT.miss
						fi
					fi

					if [ $GET_POD_LOGS == "true" ]
					then
						local GREP_COND="find $CUSTOM_DATA_OUTDIR -type f 2> /dev/null | grep -E '.log$|.log.prev$' | sort "
						local FILE_MATCHED=0
	
						for LOG_FILE in $(eval "$GREP_COND")
						do
							local LOG_DIRNAME=$(dirname $LOG_FILE)
							local LOG_FILENAME=$(basename $LOG_FILE)
	
							if [ $KEY != "ALL" ]
							then
								if [[ ! $LOG_FILENAME =~ $KEY ]]
								then	
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] File [$LOG_FILE] does not match KEY [$KEY]. Skipping..."
									fi
	
									continue
								fi
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$LOG_FILE]..."
							fi
	
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							local HIT_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							local MISS_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss
	
							grepTextFile $LOG_DIRNAME $LOG_FILENAME $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_PODLOG_CTR $PRINT_PODLOG_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_POD_LOGS_OUTFILE" "$GREP_POD_LOGS_TYPE"
							local PRINT_PODLOG_HEADER="false"
							(( OVERALL_PODLOG_CTR=OVERALL_PODLOG_CTR+1 ))
							(( FILE_MATCHED=FILE_MATCHED+1 ))
						done
	
						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Total file matched in directory [$CUSTOM_DATA_OUTDIR] = $FILE_MATCHED"
	
						if [ $FILE_MATCHED -eq 0 ]
						then
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss
						fi
					fi
				fi

				# OTHER_NAMESPACES directory scan
				if [ -d $OTHER_NS_DATA_OUTDIR ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Scanning directory [$OTHER_NS_DATA_OUTDIR]..."

					if [ $OC_DESC_ON == "true" ]
					then
						local GREP_COND="find $OTHER_NS_DATA_OUTDIR -type f -name '*.desc' 2> /dev/null | sort "
						local FILE_MATCHED=0
	
						for DESC_FILE in $(eval "$GREP_COND")
						do
							local DESC_DIRNAME=$(dirname $DESC_FILE)
							local DESC_FILENAME=$(basename $DESC_FILE)
	
							if [ $KEY != "ALL" ]
							then
								if [[ ! $DESC_FILENAME =~ $KEY ]]
								then	
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] File [$DESC_FILE] does not match KEY [$KEY]. Skipping..."
									fi
	
									continue
								fi
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$DESC_FILE]..."
							fi
	
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							local HIT_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.hit
							local MISS_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.miss
	
							grepTextFile $DESC_DIRNAME $DESC_FILENAME $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_EVENT_CTR $PRINT_EVENT_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_EVENTS_OUTFILE" "$GREP_EVENTS_TYPE"
							local PRINT_EVENT_HEADER="false"
							(( OVERALL_EVENT_CTR=OVERALL_EVENT_CTR+1 ))
							(( FILE_MATCHED=FILE_MATCHED+1 ))
						done
	
						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Total file matched in directory [$OTHER_NS_DATA_OUTDIR] = $FILE_MATCHED"
	
						if [ $FILE_MATCHED -eq 0 ]
						then
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							touch $OUTDIR/grep_EVENTS-$KEY:$PAT.hit
							touch $OUTDIR/grep_EVENTS-$KEY:$PAT.miss
						fi
					fi

					if [ $GET_POD_LOGS == "true" ]
					then
						local GREP_COND="find $OTHER_NS_DATA_OUTDIR -type f 2> /dev/null | grep -E '.log$|.log.prev$' | sort "
						local FILE_MATCHED=0
	
						for LOG_FILE in $(eval "$GREP_COND")
						do
							local LOG_DIRNAME=$(dirname $LOG_FILE)
							local LOG_FILENAME=$(basename $LOG_FILE)
	
							if [ $KEY != "ALL" ]
							then
								if [[ ! $LOG_FILENAME =~ $KEY ]]
								then	
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] File [$LOG_FILE] does not match KEY [$KEY]. Skipping..."
									fi
	
									continue
								fi
							fi
	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$LOG_FILE]..."
							fi
	
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							local HIT_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							local MISS_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss
	
							grepTextFile $LOG_DIRNAME $LOG_FILENAME $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_PODLOG_CTR $PRINT_PODLOG_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_POD_LOGS_OUTFILE" "$GREP_POD_LOGS_TYPE"
							local PRINT_PODLOG_HEADER="false"
							(( OVERALL_PODLOG_CTR=OVERALL_PODLOG_CTR+1 ))
							(( FILE_MATCHED=FILE_MATCHED+1 ))
						done
	
						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Total file matched in directory [$OTHER_NS_DATA_OUTDIR] = $FILE_MATCHED"
	
						if [ $FILE_MATCHED -eq 0 ]
						then
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss
						fi
					fi
				fi
			fi

			# Secondary data collection mode (only manualcollect and extra-namespaces modes could have pod logs)
			if [ ${MANUAL_COLL} -eq 1 ] 
			then
				for NS in $(ls -l $MANUAL_COLL_OUTDIR 2> /dev/null | grep -E ^d | $AWK '{ print $NF }')
				do
					for DIR in $(ls -l $MANUAL_COLL_OUTDIR/$NS 2> /dev/null | grep -E ^d | $AWK '{ print $NF }')
					do
						if [ $GET_POD_LOGS == "true" ]
						then
							if [ $DIR == "po" ] || [ $DIR == "pod" ] || [ $DIR == "pods" ]
							then
								local NS_POD_OUTDIR=$MANUAL_COLL_OUTDIR/$NS/$DIR
			
								echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Scanning directory [$NS_POD_OUTDIR]..."
	
								if [ $KEY == "ALL" ]
								then
									local GREP_COND="ls $NS_POD_OUTDIR"
								else
									local GREP_COND="ls $NS_POD_OUTDIR | grep -E '$KEY'" 
								fi

								local FILE_MATCHED=0
							
								for POD_LOG in $(eval "$GREP_COND" | grep -E 'log$|log.prev$')
								do
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$NS_POD_OUTDIR/$POD_LOG]..."
									fi

									local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
									local HIT_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
									local MISS_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss

									grepTextFile $NS_POD_OUTDIR $POD_LOG $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_PODLOG_CTR $PRINT_PODLOG_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_POD_LOGS_OUTFILE" "$GREP_POD_LOGS_TYPE"
									local PRINT_PODLOG_HEADER="false"
									(( OVERALL_PODLOG_CTR=OVERALL_PODLOG_CTR+1 ))
									(( FILE_MATCHED=FILE_MATCHED+1 ))
								done	

								echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Total file matched in directory [$NS_POD_OUTDIR] = $FILE_MATCHED"

								if [ $FILE_MATCHED -eq 0 ]
								then
									local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
									touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
									touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss
								fi
							fi
						fi

						if [ $OC_DESC_ON == "true" ]
						then
							local NS_OUTDIR=$MANUAL_COLL_OUTDIR/$NS/$DIR

							echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Scanning directory [$NS_OUTDIR]..."

							if [ $KEY == "ALL" ]
							then
								local GREP_COND="ls $NS_OUTDIR"
							else
								local GREP_COND="ls $NS_OUTDIR | grep -E '$KEY'" 
							fi

							local FILE_MATCHED=0

							for EVENT_LOG in $(eval "$GREP_COND" | grep -E 'desc$')
							do
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$NS_OUTDIR/$EVENT_LOG]..."
								fi

								local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
								local HIT_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.hit
								local MISS_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.miss

								grepTextFile $NS_OUTDIR $EVENT_LOG $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_EVENT_CTR $PRINT_EVENT_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_EVENTS_OUTFILE" "$GREP_EVENTS_TYPE"
								local PRINT_EVENT_HEADER="false"
								(( OVERALL_EVENT_CTR=OVERALL_EVENT_CTR+1 ))
								(( FILE_MATCHED=FILE_MATCHED+1 ))
							done

							echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Total file matched in directory [$NS_OUTDIR] = $FILE_MATCHED"

							if [ $FILE_MATCHED -eq 0 ]
							then
								local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
								touch $OUTDIR/grep_EVENTS-$KEY:$PAT.hit
								touch $OUTDIR/grep_EVENTS-$KEY:$PAT.miss
							fi
						fi
					done
				done	
			fi

			if [ ${EXTRA_NAMESPACES}x != "x" ]
			then
				for NS in $(ls -l $EXTRA_NAMESPACES_OUTDIR 2> /dev/null | grep -E ^d | $AWK '{ print $NF }')
				do
					if [ $GET_POD_LOGS == "true" ]
					then
						local NS_POD_OUTDIR=$EXTRA_NAMESPACES_OUTDIR/$NS/pod
	
						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Scanning directory [$NS_POD_OUTDIR]..."
	
						if [ $KEY == "ALL" ]
						then
							local GREP_COND="ls $NS_POD_OUTDIR"
						else
							local GREP_COND="ls $NS_POD_OUTDIR | grep -E '$KEY'" 
						fi

						local FILE_MATCHED=0
							
						for POD_LOG in $(eval "$GREP_COND" | grep -E 'log$|log.prev$')
						do	
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$NS_POD_OUTDIR/$POD_LOG]..."
							fi

							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							local HIT_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							local MISS_FILE=$OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss

							grepTextFile $NS_POD_OUTDIR $POD_LOG $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_PODLOG_CTR $PRINT_PODLOG_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_POD_LOGS_OUTFILE" "$GREP_POD_LOGS_TYPE"
							local PRINT_PODLOG_HEADER="false"
							(( OVERALL_PODLOG_CTR=OVERALL_PODLOG_CTR+1 ))
							(( FILE_MATCHED=FILE_MATCHED+1 ))
						done

						echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [PODLOG] Total file matched in directory [$NS_POD_OUTDIR] = $FILE_MATCHED"

						if [ $FILE_MATCHED -eq 0 ]
						then
							local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.hit
							touch $OUTDIR/grep_POD_LOGS-$KEY:$PAT.miss
						fi
					fi

					if [ $OC_DESC_ON == "true" ]
					then
						for DIR in $(ls -l $EXTRA_NAMESPACES_OUTDIR/$NS 2> /dev/null | grep -E ^d | $AWK '{ print $NF }')
						do
							local NS_OUTDIR=$EXTRA_NAMESPACES_OUTDIR/$NS/$DIR
	
							echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Scanning directory [$NS_OUTDIR]..."

							if [ $KEY == "ALL" ]
							then
								local GREP_COND="ls $NS_OUTDIR"
							else
								local GREP_COND="ls $NS_OUTDIR | grep -E '$KEY'" 
							fi

							local FILE_MATCHED=0
	
							for EVENT_LOG in $(eval "$GREP_COND" | grep -E 'desc$')
							do
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$NS_OUTDIR/$EVENT_LOG]..."
								fi

								local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
								local HIT_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.hit
								local MISS_FILE=$OUTDIR/grep_EVENTS-$KEY:$PAT.miss

								grepTextFile $NS_OUTDIR $EVENT_LOG $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_EVENT_CTR $PRINT_EVENT_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_EVENTS_OUTFILE" "$GREP_EVENTS_TYPE"
								local PRINT_EVENT_HEADER="false"
								(( OVERALL_EVENT_CTR=OVERALL_EVENT_CTR+1 ))
								(( FILE_MATCHED=FILE_MATCHED+1 ))
							done

							echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [EVENT] Total file matched in directory [$NS_OUTDIR] = $FILE_MATCHED"

							if [ $FILE_MATCHED -eq 0 ]
							then
								local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
								touch $OUTDIR/grep_EVENTS-$KEY:$PAT.hit
								touch $OUTDIR/grep_EVENTS-$KEY:$PAT.miss
							fi
						done
					fi
				done
			fi

			if [ ${GET_NODES_DATA} == "true" ] && [ -d $CLUSTERNODES_OUTDIR ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [NODEFILE] Scanning directory [$CLUSTERNODES_OUTDIR]..."
	
				if [ $KEY == "ALL" ]
				then
					local GREP_COND="ls $CLUSTERNODES_OUTDIR"
				else
					local GREP_COND="ls $CLUSTERNODES_OUTDIR | grep -E '$KEY'" 
				fi

				local FILE_MATCHED=0

				for NODE_FILE in $(eval "$GREP_COND")
				do	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$CLUSTERNODES_OUTDIR/$NODE_FILE]..."
					fi

					local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
					local HIT_FILE=$OUTDIR/grep_NODEFILE-$KEY:$PAT.hit
					local MISS_FILE=$OUTDIR/grep_NODEFILE-$KEY:$PAT.miss

					grepTextFile $CLUSTERNODES_OUTDIR $NODE_FILE $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_NODEFILE_CTR $PRINT_NODEFILE_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_NODEFILE_OUTFILE" "$GREP_NODEFILE_TYPE"
					local PRINT_NODEFILE_HEADER="false"
					(( OVERALL_NODEFILE_CTR=OVERALL_NODEFILE_CTR+1 ))
					(( FILE_MATCHED=FILE_MATCHED+1 ))
				done

				echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [NODEFILE] Total file matched in directory [$NS_OUTDIR] = $FILE_MATCHED"

				if [ $FILE_MATCHED -eq 0 ]
				then
					local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
					touch $OUTDIR/grep_NODEFILE-$KEY:$PAT.hit
					touch $OUTDIR/grep_NODEFILE-$KEY:$PAT.miss
				fi
			fi

			if [ ${CPFILES_ENABLED} == "true" ] && [ -d $CPFILES_ROOT_OUTDIR ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [CPFILES] Scanning directory [$CPFILES_ROOT_OUTDIR]..."
	
				if [ $KEY == "ALL" ]
				then
					local GREP_COND="find $CPFILES_ROOT_OUTDIR -type f ! -name 'FINAL-CPFILES-CFG.cfg'"
				else
					local GREP_COND="find $CPFILES_ROOT_OUTDIR -type f ! -name 'FINAL-CPFILES-CFG.cfg' | $AWK -F/ '\$NF ~ /$KEY/ { print }'"
				fi

				local FILE_MATCHED=0

				for CP_FILE in $(eval "$GREP_COND")
				do	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Grepping for pattern [$PATTERN] in file [$CP_FILE]..."
					fi

					local CPFILE_DIRNAME=$(dirname $CP_FILE)
					local CPFILE_FILENAME=$(basename $CP_FILE)
	
					local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
					local HIT_FILE=$OUTDIR/grep_CPFILES-$KEY:$PAT.hit
					local MISS_FILE=$OUTDIR/grep_CPFILES-$KEY:$PAT.miss

					grepTextFile $CPFILE_DIRNAME $CPFILE_FILENAME $KEYVALUE_CTR "$KEY" "$PATTERN" $OVERALL_CPFILES_CTR $PRINT_CPFILES_HEADER "$HIT_FILE" "$MISS_FILE" "$GREP_CPFILES_OUTFILE" "$GREP_CPFILES_TYPE"
					local PRINT_CPFILES_HEADER="false"
					(( OVERALL_CPFILES_CTR=OVERALL_CPFILES_CTR+1 ))
					(( FILE_MATCHED=FILE_MATCHED+1 ))
				done

				echo "[$(date)] [${FUNCNAME[0]}] [KEY=$KEY / PATTERN=$PATTERN] [CPFILES] Total file matched in directory [$CPFILES_ROOT_OUTDIR] = $FILE_MATCHED"

				if [ $FILE_MATCHED -eq 0 ]
				then
					local PAT=$(echo "$PATTERN" | sed 's#/#~SLASH~#g')
					touch $OUTDIR/grep_CPFILES-$KEY:$PAT.hit
					touch $OUTDIR/grep_CPFILES-$KEY:$PAT.miss
				fi
			fi

			(( PATTERN_CTR=PATTERN_CTR+1 ))
		done

		(( KEYVALUE_CTR=KEYVALUE_CTR+1 ))
	done

	echo "[$(date)] [${FUNCNAME[0]}] Total KEYVALUE processed = $KEYVALUE_CTR" | tee -a $ANALYZE_OUTFILE
	echo "[$(date)] [${FUNCNAME[0]}] KEYVALUE pairs = ${KEYVALUE_ARR[@]}" | tee -a $ANALYZE_OUTFILE

	# [POD_LOGS] Process hit/miss counter files
	echo "[$(date)] [${FUNCNAME[0]}] Total PODLOG processed = $OVERALL_PODLOG_CTR [hit=$GREP_POD_LOGS_HIT / missed=$GREP_POD_LOGS_MISS]" | tee -a $ANALYZE_OUTFILE

	# IFS=$'\n'
	for PODLOGS_HIT_FILE in $(ls $OUTDIR/grep_POD_LOGS-*.hit 2> /dev/null)
	do
		local TMP_KEY_PATTERN=${PODLOGS_HIT_FILE##*-}
		local KEY_PATTERN=${TMP_KEY_PATTERN%.hit}
		local PAT=$(echo "$KEY_PATTERN" | sed 's#~SLASH~#/#g')

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Counting file $PODLOGS_HIT_FILE for KEY_PATTERN [$PAT]..."
		fi	

		local PODLOGS_HIT_CTR=$(wc -l "$PODLOGS_HIT_FILE" | $AWK '{ print $1 }')
		
		if [ -s $OUTDIR/grep_POD_LOGS-$KEY_PATTERN.miss ]
		then
			local PODLOGS_MISS_CTR=$(wc -l $OUTDIR/grep_POD_LOGS-$KEY_PATTERN.miss | $AWK '{ print $1 }')
		else
			local PODLOGS_MISS_CTR=0
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Total PODLOG hit [$PAT] = $PODLOGS_HIT_CTR [missed=$PODLOGS_MISS_CTR]" | tee -a $ANALYZE_OUTFILE

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up PODLOGS_HIT_FILE [$PODLOGS_HIT_FILE] to directory [$GREPPATTERN_DEBUG_OUTDIR]..."
			cp -p "$PODLOGS_HIT_FILE" $GREPPATTERN_DEBUG_OUTDIR
		fi

		rm "$PODLOGS_HIT_FILE"
	done

	for PODLOGS_MISS_FILE in $(ls $OUTDIR/grep_POD_LOGS-*.miss 2> /dev/null)
	do
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up PODLOGS_MISS_FILE [$PODLOGS_MISS_FILE] to directory [$GREPPATTERN_DEBUG_OUTDIR]..."
			cp -p $PODLOGS_MISS_FILE $GREPPATTERN_DEBUG_OUTDIR
		fi

		rm $PODLOGS_MISS_FILE
	done

	# [EVENTS] Process hit/miss counter files
	echo "[$(date)] [${FUNCNAME[0]}] Total EVENTFILE processed = $OVERALL_EVENT_CTR [hit=$GREP_EVENTS_HIT / missed=$GREP_EVENTS_MISS]" | tee -a $ANALYZE_OUTFILE

	for EVENTS_HIT_FILE in $(ls $OUTDIR/grep_EVENTS-*.hit 2> /dev/null)
	do
		local TMP_KEY_PATTERN=${EVENTS_HIT_FILE##*-}
		local KEY_PATTERN=${TMP_KEY_PATTERN%.hit}
		local PAT=$(echo "$KEY_PATTERN" | sed 's#~SLASH~#/#g')

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Counting file $EVENTS_HIT_FILE for KEY_PATTERN [$PAT]..."
		fi	

		local EVENTS_HIT_CTR=$(wc -l $EVENTS_HIT_FILE | $AWK '{ print $1 }')

		if [ -s $OUTDIR/grep_EVENTS-$KEY_PATTERN.miss ]
		then
			local EVENTS_MISS_CTR=$(wc -l $OUTDIR/grep_EVENTS-$KEY_PATTERN.miss | $AWK '{ print $1 }')
		else
			local EVENTS_MISS_CTR=0
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Total EVENTS hit [$PAT] = $EVENTS_HIT_CTR [missed=$EVENTS_MISS_CTR]" | tee -a $ANALYZE_OUTFILE	

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up EVENTS_HIT_FILE [$EVENTS_HIT_FILE] to directory [$GREPPATTERN_DEBUG_OUTDIR]..."
			cp -p $EVENTS_HIT_FILE $GREPPATTERN_DEBUG_OUTDIR
		fi

		rm $EVENTS_HIT_FILE
	done

	for EVENTS_MISS_FILE in $(ls $OUTDIR/grep_EVENTS-*.miss 2> /dev/null)
	do
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up EVENTS_MISS_FILE [$EVENTS_MISS_FILE] to directory [$GREPPATTERN_DEBUG_OUTDIR]..."
			cp -p $EVENTS_MISS_FILE $GREPPATTERN_DEBUG_OUTDIR
		fi

		rm $EVENTS_MISS_FILE
	done

	# [NODEFILE] Process hit/miss counter files
	echo "[$(date)] [${FUNCNAME[0]}] Total NODEFILE processed = $OVERALL_NODEFILE_CTR [hit=$GREP_NODEFILE_HIT / missed=$GREP_NODEFILE_MISS]" | tee -a $ANALYZE_OUTFILE

	for NODEFILE_HIT_FILE in $(ls $OUTDIR/grep_NODEFILE-*.hit 2> /dev/null)
	do
		local TMP_KEY_PATTERN=${NODEFILE_HIT_FILE##*-}
		local KEY_PATTERN=${TMP_KEY_PATTERN%.hit}
		local PAT=$(echo "$KEY_PATTERN" | sed 's#~SLASH~#/#g')

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Counting file $NODEFILE_HIT_FILE for KEY_PATTERN [$PAT]..."
		fi	

		local NODEFILE_HIT_CTR=$(wc -l $NODEFILE_HIT_FILE | $AWK '{ print $1 }')

		if [ -s $OUTDIR/grep_NODEFILE-$KEY_PATTERN.miss ]
		then
			local NODEFILE_MISS_CTR=$(wc -l $OUTDIR/grep_NODEFILE-$KEY_PATTERN.miss | $AWK '{ print $1 }')
		else
			local NODEFILE_MISS_CTR=0
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Total NODEFILE hit [$PAT] = $NODEFILE_HIT_CTR [missed=$NODEFILE_MISS_CTR]" | tee -a $ANALYZE_OUTFILE

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up NODEFILE_HIT_FILE [$NODEFILE_HIT_FILE] to directory [$GREPPATTERN_DEBUG_OUTDIR]..."
			cp -p $NODEFILE_HIT_FILE $GREPPATTERN_DEBUG_OUTDIR
		fi

		rm $NODEFILE_HIT_FILE
	done

	for NODEFILE_MISS_FILE in $(ls $OUTDIR/grep_NODEFILE-*.miss 2> /dev/null)
	do
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up NODEFILE_MISS_FILE [$NODEFILE_MISS_FILE] to directory [$GREPPATTERN_DEBUG_OUTDIR]..."
			cp -p "$NODEFILE_MISS_FILE" $GREPPATTERN_DEBUG_OUTDIR
		fi

		rm "$NODEFILE_MISS_FILE"
	done

	# [CPFILES] Process hit/miss counter files
	echo "[$(date)] [${FUNCNAME[0]}] Total CPFILES processed = $OVERALL_CPFILES_CTR [hit=$GREP_CPFILES_HIT / missed=$GREP_CPFILES_MISS]" | tee -a $ANALYZE_OUTFILE

	for CPFILES_HIT_FILE in $(ls $OUTDIR/grep_CPFILES-*.hit 2> /dev/null)
	do
		local TMP_KEY_PATTERN=${CPFILES_HIT_FILE##*-}
		local KEY_PATTERN=${TMP_KEY_PATTERN%.hit}
		local PAT=$(echo "$KEY_PATTERN" | sed 's#~SLASH~#/#g')

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Counting file $CPFILES_HIT_FILE for KEY_PATTERN [$PAT]..."
		fi	

		local CPFILES_HIT_CTR=$(wc -l $CPFILES_HIT_FILE | $AWK '{ print $1 }')

		if [ -s $OUTDIR/grep_CPFILES-$KEY_PATTERN.miss ]
		then
			local CPFILES_MISS_CTR=$(wc -l $OUTDIR/grep_CPFILES-$KEY_PATTERN.miss | $AWK '{ print $1 }')
		else
			local CPFILES_MISS_CTR=0
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Total CPFILES hit [$PAT] = $CPFILES_HIT_CTR [missed=$CPFILES_MISS_CTR]" | tee -a $ANALYZE_OUTFILE

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up CPFILES_HIT_FILE [$CPFILES_HIT_FILE] to directory [$GREPPATTERN_DEBUG_OUTDIR]..."
			cp -p $CPFILES_HIT_FILE $GREPPATTERN_DEBUG_OUTDIR
		fi

		rm $CPFILES_HIT_FILE
	done

	for CPFILES_MISS_FILE in $(ls $OUTDIR/grep_CPFILES-*.miss 2> /dev/null)
	do
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up CPFILES_MISS_FILE [$CPFILES_MISS_FILE] to directory [$GREPPATTERN_DEBUG_OUTDIR]..."
			cp -p $CPFILES_MISS_FILE $GREPPATTERN_DEBUG_OUTDIR
		fi

		rm $CPFILES_MISS_FILE
	done

	echo >> $ANALYZE_OUTFILE

	IFS=$'\n'	
}

grepTextFile()
{
	local GREP_OUTDIR=$1
	local TEXT_FILE=$2
	local KEYVALYE_CTR=$3
	local KEY=$4
	local PATTERN=$5
	local OVERALL_CTR=$6
	local PRINT_HEADER=$7
	local HIT_FILE=$8
	local MISS_FILE=$9
	local GREP_OUTFILE=${10}
	local GREP_TYPE=${11}

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] GREP_OUTDIR=[$GREP_OUTDIR] / TEXT_FILE=[$TEXT_FILE] / KEYVALYE_CTR=[$KEYVALYE_CTR] / KEY=[$KEY] / PATTERN=[$PATTERN] / OVERALL_CTR=[$OVERALL_CTR] / PRINT_HEADER=[$PRINT_HEADER] / HIT_FILE=[$HIT_FILE] / MISS_FILE=[$MISS_FILE] / GREP_OUTFILE=[$GREP_OUTFILE] / GREP_TYPE=[$GREP_TYPE]"
	fi

	if [ $PRINT_HEADER == "true" ]
	then
		echo "===================================================" >> $GREP_OUTFILE
		echo "GREP REPORT (patterns = $GREP_PATTERN)" >> $GREP_OUTFILE
		echo "FILE TYPE = [$GREP_TYPE] " >> $GREP_OUTFILE
		echo "IMPORTANT: By default, the grep command will be executed in ignore-case mode!" >> $GREP_OUTFILE
		echo "===================================================" >> $GREP_OUTFILE
		echo >> $GREP_OUTFILE
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] [KV=$KEYVALUE_CTR] [KEY=$KEY] Grepping for pattern [$PATTERN] in file [$GREP_OUTDIR/$TEXT_FILE] of type [$GREP_TYPE]..."
	fi
	
	if [ $(echo "$PATTERN" | $AWK -F~ '{ print NF }') -gt 1 ]
	then
		if [[ $PATTERN =~ \\~ ]]
		then
			local TMP_PATTERN1=$(echo "$PATTERN" | sed 's/~/ /g')
			local TMP_PATTERN2=$(echo "$TMP_PATTERN1" | sed 's/\\ /~/g')
			local PATTERN1=$(echo "$TMP_PATTERN2" | $AWK '{ print $1 }')
			local PATTERN2=$(echo "$TMP_PATTERN2" | $AWK '{ for (i=2; i<=NF; i++) { if (i==2) {CMD="grep -E -i '\''" $i "'\''"} else {CMD=CMD " | grep -E -i '\''" $i "'\''"}}} END { print CMD }')
	
			if [ ${#PATTERN2} -gt 0 ]
			then
				if [ $GREP_TYPE == "$GREP_EVENTS_TYPE" ]
				then
					local GREP_CMD="$AWK '/^Events:/{f=1}f' $GREP_OUTDIR/$TEXT_FILE | grep -E -ni '$PATTERN1' | $PATTERN2"
				else
					local GREP_CMD="grep -E -ni '$PATTERN1' $GREP_OUTDIR/$TEXT_FILE | $PATTERN2"
				fi
			else
				if [ $GREP_TYPE == "$GREP_EVENTS_TYPE" ]
				then
					local GREP_CMD="$AWK '/^Events:/{f=1}f' $GREP_OUTDIR/$TEXT_FILE | grep -E -ni '$PATTERN1'"
				else
					local GREP_CMD="grep -E -ni '$PATTERN1' $GREP_OUTDIR/$TEXT_FILE"
				fi
			fi
		else
			local PATTERN1=$(echo "$PATTERN" | $AWK -F~ '{ print $1 }')
			local PATTERN2=$(echo "$PATTERN" | $AWK -F~ '{ for (i=2; i<=NF; i++) { if (i==2) {CMD="grep -E -i '\''" $i "'\''"} else {CMD=CMD " | grep -E -i '\''" $i "'\''"}}} END { print CMD }')

			if [ $GREP_TYPE == "$GREP_EVENTS_TYPE" ]
			then
				local GREP_CMD="$AWK '/^Events:/{f=1}f' $GREP_OUTDIR/$TEXT_FILE | grep -E -ni '$PATTERN1' | $PATTERN2"
			else
				local GREP_CMD="grep -E -ni '$PATTERN1' $GREP_OUTDIR/$TEXT_FILE | $PATTERN2"
			fi
		fi
	else
		if [ $GREP_TYPE == "$GREP_EVENTS_TYPE" ]
		then
			local GREP_CMD="$AWK '/^Events:/{f=1}f' $GREP_OUTDIR/$TEXT_FILE | grep -E -ni '"$PATTERN"'"
		else
			local GREP_CMD="grep -E -ni '"$PATTERN"' $GREP_OUTDIR/$TEXT_FILE"
		fi
	fi
	
	if [ $MG_DEBUG == "true" ]
	then	
		echo "[$(date)] [${FUNCNAME[0]}] [KV=$KEYVALUE_CTR] [$OVERALL_CTR] GREP_CMD [$GREP_CMD] > [$GREP_OUTFILE]"
	fi
	
	local TMPFILE=$GREP_OUTDIR/${TEXT_FILE}.tmp
	eval "$GREP_CMD" > $TMPFILE

	if [ -s $TMPFILE ]
	then
		echo "[$OVERALL_CTR] TEXT_FILE [$GREP_OUTDIR/$TEXT_FILE]" >> $GREP_OUTFILE
		echo "[$OVERALL_CTR] KEY [$KEY]" >> $GREP_OUTFILE
		echo "[$OVERALL_CTR] PATTERN [$PATTERN]" >> $GREP_OUTFILE
		
		cat $TMPFILE >> $GREP_OUTFILE

		case "$GREP_TYPE" in	
			$GREP_POD_LOGS_TYPE) 	(( GREP_POD_LOGS_HIT=GREP_POD_LOGS_HIT+1 )) ;;
			$GREP_NODEFILE_TYPE) 	(( GREP_NODEFILE_HIT=GREP_NODEFILE_HIT+1 )) ;;
			$GREP_CPFILES_TYPE) 	(( GREP_CPFILES_HIT=GREP_CPFILES_HIT+1 )) ;;
			$GREP_EVENTS_TYPE) 		(( GREP_EVENTS_HIT=GREP_EVENTS_HIT+1 ))
								echo "[$OVERALL_EVENT_CTR] FULL EVENT LOG:" >> $GREP_OUTFILE
								$AWK '/^Events:/{f=1}f' $GREP_OUTDIR/$TEXT_FILE | sed '/^[ \t]*$/d' >> $GREP_OUTFILE
								;;
		esac

		echo >> $GREP_OUTFILE
		echo "===================================================" >> $GREP_OUTFILE

		echo "$GREP_OUTDIR/$TEXT_FILE" >> "$HIT_FILE"
		touch "$MISS_FILE"

		if [ $INCIDENT_REPORT_ENABLED == "true" ]
		then
			setIncident "ocp" "$TEXT_FILE" "oc_pod_logs" "" "$(cat $TMPFILE)"
		fi
	else
		case "$GREP_TYPE" in	
			$GREP_POD_LOGS_TYPE) (( GREP_POD_LOGS_MISS=GREP_POD_LOGS_MISS+1 )) ;;
			$GREP_NODEFILE_TYPE) (( GREP_NODEFILE_MISS=GREP_NODEFILE_MISS+1 )) ;;
			$GREP_CPFILES_TYPE) (( GREP_CPFILES_MISS=GREP_CPFILES_MISS+1 ));;
			$GREP_EVENTS_TYPE) (( GREP_EVENTS_MISS=GREP_EVENTS_MISS+1 ));;
		esac

		echo "$GREP_OUTDIR/$TEXT_FILE" >> "$MISS_FILE"
		touch "$HIT_FILE"
	fi

	rm $TMPFILE
}

doSnapshots()
{
	if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
	then
		while read PROD_VER_LINE
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_VER_LINE = [$PROD_VER_LINE]"
			fi

			local SNAPSHOTS_PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')

			if [ ${#RTVAR_SNAPSHOTS_PRODVER} -gt 0 ]
			then
				local SNAPSHOTS_PRODVER_VALID="false"
	
				for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
				do
					if [ $RTVAR_SNAPSHOTS_PRODVER == $VALID_PROD_VERSION ]
					then
						local SNAPSHOTS_PRODVER_VALID="true"
						break
					fi
				done	
	
				if [ $SNAPSHOTS_PRODVER_VALID == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] SNAPSHOTS_PRODVER is set to [$RTVAR_SNAPSHOTS_PRODVER]! Setting SNAPSHOTS_PROD_VER to [$RTVAR_SNAPSHOTS_PRODVER]!"
					local SNAPSHOTS_PROD_VER=$RTVAR_SNAPSHOTS_PRODVER
				else
					local SNAPSHOTS_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
					echo "[$(date)] [${FUNCNAME[0]}] SNAPSHOTS_PRODVER [$RTVAR_SNAPSHOTS_PRODVER] is invalid or not supported product version! Setting SNAPSHOTS_PROD_VER to default [$SNAPSHOTS_PROD_VER]!"
				fi
			else
				local SNAPSHOTS_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
			fi

			local INPUT_FILE="$MUSTGATHER_DIRNAME/config/snapshots/$SNAPSHOTS_PROD_VER/product.snapshots.cfg"
			local SNAPSHOTS_PROD_GROUP_NS_REFFILE=${REFFILE_OUTDIR}/${SNAPSHOTS_PROD_GROUP}.ns-ref

			local SNAPSHOTS_WORKDIR=$SNAPSHOTS_OUTDIR/PRODGRP=$SNAPSHOTS_PROD_GROUP
			local SNAPSHOTS_CURDIR=$SNAPSHOTS_WORKDIR/$MG_TIMESTAMP

			echo "[$(date)] [${FUNCNAME[0]}] SNAPSHOTS_CURDIR = [$SNAPSHOTS_CURDIR]"

			if [ ! -d $SNAPSHOTS_CURDIR ]
			then
				mkdir -p $SNAPSHOTS_CURDIR
			fi
		
			if [ -s $SNAPSHOTS_WORKDIR/.latest-snapshot ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Previous snapshot found [$(cat $SNAPSHOTS_WORKDIR/.latest-snapshot)]..." 
				mv $SNAPSHOTS_WORKDIR/.latest-snapshot $SNAPSHOTS_WORKDIR/.previous-snapshot
			else
				echo "[$(date)] [${FUNCNAME[0]}] There is no previous snapshot. Setting SNAPSHOTS_ONLY to [true]..." 
				SNAPSHOTS_ONLY="true"
			fi
		
			echo "$MG_TIMESTAMP" > $SNAPSHOTS_WORKDIR/.latest-snapshot
		
			# Housekeep SNAPSHOTS_WORKDIR
			if [ $(ls -d $SNAPSHOTS_WORKDIR/* | wc -l) -gt $MAX_SNAPSHOTS ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Initiating SNAPSHOTS_WORKDIR[$SNAPSHOTS_WORKDIR] housekeeping [limit=$MAX_SNAPSHOTS]..."
		
				local TO_REMOVE=
			
				for TO_REMOVE in $(ls -dt $SNAPSHOTS_WORKDIR/* | $AWK 'NR > '$MAX_SNAPSHOTS)
				do
					local SNAPSHOTS_TARGET_DIR=$(basename $TO_REMOVE)
					
					if [[ "$SNAPSHOTS_TARGET_DIR"  =~ ^[0-9]{8}-[0-9]{6}$ ]]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Removing directory [$TO_REMOVE]..." 
						rm -r $TO_REMOVE
					else
						echo "[$(date)] [${FUNCNAME[0]}] Directory [$TO_REMOVE] does not seem to be snapshorts directory! Skipping..." 
					fi
		
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] SNAPSHOTS_TARGET_DIR = [$SNAPSHOTS_TARGET_DIR]"
					fi
				done
			fi
	
			echo "[$(date)] [${FUNCNAME[0]}] Calling function diffSnapshots() - [INPUT_FILE=$INPUT_FILE ## SNAPSHOTS_PROD_GROUP=$SNAPSHOTS_PROD_GROUP ## SNAPSHOTS_PROD_VER=$SNAPSHOTS_PROD_VER ## SNAPSHOTS_CURDIR=$SNAPSHOTS_CURDIR ## SNAPSHOTS_PROD_GROUP_NS_REFFILE=$SNAPSHOTS_PROD_GROUP_NS_REFFILE]"
			diffSnapshots "$INPUT_FILE" "$SNAPSHOTS_PROD_GROUP" "$SNAPSHOTS_PROD_VER" "$SNAPSHOTS_CURDIR" "$SNAPSHOTS_PROD_GROUP_NS_REFFILE"
		done < $PROD_VERSIONS_REFFILE_FINAL
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product group namespace reference file [$PROD_VERSIONS_REFFILE_FINAL] does not exist or is zero-sized!"
		echo "[$(date)] [${FUNCNAME[0]}] Falling back to default 'non-product-group' execution..."

		local SNAPSHOTS_PROD_GROUP="default"
		local SNAPSHOTS_PROD_VER=$PRODUCT_VERSION
		local INPUT_FILE="$MUSTGATHER_DIRNAME/config/snapshots/config/$PRODUCT_VERSION/product.snapshots.cfg"
		local SNAPSHOTS_PROD_GROUP_NS_REFFILE=$PROD_NAMESPACES_REFFILE

		local SNAPSHOTS_WORKDIR=$SNAPSHOTS_OUTDIR/PRODGRP=$SNAPSHOTS_PROD_GROUP/$MG_TIMESTAMP
		local SNAPSHOTS_CURDIR=$SNAPSHOTS_WORKDIR/$MG_TIMESTAMP

		if [ ! -d $SNAPSHOTS_CURDIR ]
		then
			mkdir -p $SNAPSHOTS_CURDIR
		fi
	
		if [ -s $SNAPSHOTS_WORKDIR/.latest-snapshot ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Previous snapshot found [$(cat $SNAPSHOTS_WORKDIR/.latest-snapshot)]..." 
			mv $SNAPSHOTS_WORKDIR/.latest-snapshot $SNAPSHOTS_WORKDIR/.previous-snapshot
		else
			echo "[$(date)] [${FUNCNAME[0]}] There is no previous snapshot. Setting SNAPSHOTS_ONLY to [true]..." 
			SNAPSHOTS_ONLY="true"
		fi
	
		echo "$MG_TIMESTAMP" > $SNAPSHOTS_WORKDIR/.latest-snapshot
	
		# Housekeep SNAPSHOTS_WORKDIR
		if [ $(ls -d $SNAPSHOTS_WORKDIR/* | wc -l) -gt $MAX_SNAPSHOTS ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Initiating SNAPSHOTS_WORKDIR[$SNAPSHOTS_WORKDIR] housekeeping [limit=$MAX_SNAPSHOTS]..."
	
			local TO_REMOVE=
		
			for TO_REMOVE in $(ls -dt $SNAPSHOTS_WORKDIR/* | $AWK 'NR > '$MAX_SNAPSHOTS)
			do
				local SNAPSHOTS_TARGET_DIR=$(basename $TO_REMOVE)
				
				if [[ "$SNAPSHOTS_TARGET_DIR"  =~ ^[0-9]{8}-[0-9]{6}$ ]]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Removing directory [$TO_REMOVE]..." 
					rm -r $TO_REMOVE
				else
					echo "[$(date)] [${FUNCNAME[0]}] Directory [$TO_REMOVE] does not seem to be snapshorts directory! Skipping..." 
				fi
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] SNAPSHOTS_TARGET_DIR = [$SNAPSHOTS_TARGET_DIR]"
				fi
			done
		fi
	
		echo "[$(date)] [${FUNCNAME[0]}] Calling function diffSnapshots() - [INPUT_FILE=$INPUT_FILE ## SNAPSHOTS_PROD_GROUP=$SNAPSHOTS_PROD_GROUP ## SNAPSHOTS_PROD_VER=$SNAPSHOTS_PROD_VER ## SNAPSHOTS_CURDIR=$SNAPSHOTS_CURDIR ## SNAPSHOTS_PROD_GROUP_NS_REFFILE=$SNAPSHOTS_PROD_GROUP_NS_REFFILE]"
		diffSnapshots "$INPUT_FILE" "$SNAPSHOTS_PROD_GROUP" "$SNAPSHOTS_PROD_VER" "$SNAPSHOTS_CURDIR" "$SNAPSHOTS_PROD_GROUP_NS_REFFILE"
	fi
}

diffSnapshots()
{
	local SNAPSHOTS_CFGFILE_PROD=$1
	local PRODGROUP=$2
	local PRODVER=$3
	local SNAPSHOTS_CURDIR=$4
	local SNAPSHOTS_PROD_GROUP_NS_REFFILE=$5

	local SNAPSHOTS_DEBUG_WORKDIR=$SNAPSHOTS_DEBUG_OUTDIR/PRODGRP=$PRODGROUP

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] SNAPSHOTS_CFGFILE_PROD = [$SNAPSHOTS_CFGFILE_PROD] / PRODGROUP = [$PRODGROUP] / PRODVER = [$PRODVER] / SNAPSHOTS_CURDIR = [$SNAPSHOTS_CURDIR]"
	fi

	local LINECTR=0
	local GOODLINE=0
	local BADLINE=0

	local FILE=
	local CFGLINE=
	
	local DEF_ENV_ARR=()
	local SNAPSHOTS_USER_INPUT_ENV=$(compgen -A variable | grep -E '^RTVAR_SNAPSHOTS_' | tr '\n' ' ')

	if [ ${#SNAPSHOTS_USER_INPUT_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for USER_INPUT_ENV in $SNAPSHOTS_USER_INPUT_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$USER_INPUT_ENV] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$USER_INPUT_ENV"
		done	
	fi

	local GMGFVAR_ENV=$(compgen -A variable | grep -E '^RTVAR_GMGFVAR_' | tr '\n' ' ')

	if [ ${#GMGFVAR_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for GMGFVAR in $GMGFVAR_ENV
		do
			echo "[$(date)] [${FUNCNAME[0]}] Appending user provided variables [$GMGFVAR] into DEF_ENV_ARR..."
			local DEF_ENV_ARR[${#DEF_ENV_ARR[@]}]="$GMGFVAR"
		done	
	fi

	IFS=$'\n'
	for DEF_ENV in ${DEF_ENV_ARR[@]}
	do
		if [[ $DEF_ENV =~ ^-f ]]
		then
			local SNAPSHOTS_FUNCNAME=$(echo "$DEF_ENV" | $AWK '{ print $2 }')
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment function [$SNAPSHOTS_FUNCNAME]..."
			fi

			export -f $SNAPSHOTS_FUNCNAME
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$DEF_ENV = ${!DEF_ENV}]"
			fi

			export $DEF_ENV
		fi
	done

	if [ -s $SNAPSHOTS_CFGFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Taking system snapshot based on configuration file [$SNAPSHOTS_CFGFILE]..."

		while read CFGLINE
		do
			# Skip all lines that start with # and blank lines
			if [[ $(echo "$CFGLINE" | $AWK '{$1=$1};1') == "${SNAPSHOTS_CFGFILE_COMMENT}"* ]] || [[ $(echo "$CFGLINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			else
				(( LINECTR=LINECTR+1 ))

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$LINECTR] CFGLINE = [$CFGLINE]"
				fi
			fi
	
			local CFGNAME=$(echo "$CFGLINE" | $AWK -F${SNAPSHOTS_CFGFILE_DELIMITER} '{ print $1 }')
			local CFGDESC=$(echo "$CFGLINE" | $AWK -F${SNAPSHOTS_CFGFILE_DELIMITER} '{ print $2 }')
			local CFGCMD=$(echo "$CFGLINE" | $AWK -F${SNAPSHOTS_CFGFILE_DELIMITER} '{ print $3 }')
			local CFGOUTFILE=$(echo "$CFGLINE" | $AWK -F${SNAPSHOTS_CFGFILE_DELIMITER} '{ print $4 }')
			
			if [ ${#CFGNAME} -gt 0 ] && [ ${#CFGCMD} -gt 0 ] && [ ${#CFGOUTFILE} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing command [$CFGCMD] => $SNAPSHOTS_CURDIR/$CFGOUTFILE"
				echo "CFGNAME = [$CFGNAME]" > $SNAPSHOTS_CURDIR/$CFGOUTFILE
				echo "CFGDESC = [$CFGDESC]" >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
				echo "CFGCMD = [$CFGCMD]" >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
				echo >> $SNAPSHOTS_CURDIR/$CFGOUTFILE >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
				echo "============================================================" >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
					
				eval "$CFGCMD" >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
				local EXIT_STATUS=$?
	
				if [ $EXIT_STATUS -eq 0 ]
				then
					(( GOODLINE=GOODLINE+1 ))
				else
					(( BADLINE=BADLINE+1 ))
				fi
	
				echo "[$(date)] [${FUNCNAME[0]}] Exit status = [$EXIT_STATUS]"	
			else
				echo "[$(date)] [${FUNCNAME[0]}] Invalid config line [$CFGLINE]. Skipping..."
				(( BADLINE=BADLINE+1 ))
			fi	
		done < $SNAPSHOTS_CFGFILE
	
	
		if [ $MG_DEBUG == "true" ]
		then
			if [ ! -d $SNAPSHOTS_DEBUG_WORKDIR ]
			then
				mkdir -p $SNAPSHOTS_DEBUG_WORKDIR
			fi
	
			echo "[$(date)] [${FUNCNAME[0]}] Backing up cluster configuration file [$SNAPSHOTS_CFGFILE] to directory [$SNAPSHOTS_DEBUG_WORKDIR]..."
			cp -p $SNAPSHOTS_CFGFILE $SNAPSHOTS_DEBUG_WORKDIR
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Snapshot configuration file [$SNAPSHOTS_CFGFILE] does not exist or is zero-sized! Skipping..."
	fi

	if [ -s $SNAPSHOTS_CFGFILE_PROD ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Taking system snapshot based on product configuration file [$SNAPSHOTS_CFGFILE_PROD]..."

		while read CFGLINE
		do
			# Skip all lines that start with # and blank lines
			if [[ $(echo "$CFGLINE" | $AWK '{$1=$1};1') == "${SNAPSHOTS_CFGFILE_COMMENT}"* ]] || [[ $(echo "$CFGLINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			else
				(( LINECTR=LINECTR+1 ))

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [$LINECTR] CFGLINE = [$CFGLINE]"
				fi
			fi
	
			local CFGNAME=$(echo "$CFGLINE" | $AWK -F${SNAPSHOTS_CFGFILE_DELIMITER} '{ print $1 }')
			local CFGDESC=$(echo "$CFGLINE" | $AWK -F${SNAPSHOTS_CFGFILE_DELIMITER} '{ print $2 }')
			local CFGCMD=$(echo "$CFGLINE" | $AWK -F${SNAPSHOTS_CFGFILE_DELIMITER} '{ print $3 }')
			local CFGOUTFILE=$(echo "$CFGLINE" | $AWK -F${SNAPSHOTS_CFGFILE_DELIMITER} '{ print $4 }')
			
			local SNAPSHOTS_PROD_GROUP=$PRODGROUP
			local SNAPSHOTS_PROD_VERSION=$PRODVER
			local PROD_GROUP_ENV_ARR=("SNAPSHOTS_PROD_GROUP_NS_REFFILE" "SNAPSHOTS_PROD_GROUP" "SNAPSHOTS_PROD_VERSION")
			
			for DEF_ENV in ${PROD_GROUP_ENV_ARR[@]}
			do
				if [[ $DEF_ENV =~ ^-f ]]
				then
					local SNAPSHOTS_FUNCNAME=$(echo "$DEF_ENV" | $AWK '{ print $2 }')

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Exporting environment function [$SNAPSHOTS_FUNCNAME]..."
					fi

					export -f $SNAPSHOTS_FUNCNAME
				else
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$DEF_ENV = ${!DEF_ENV}]"
					fi

					export $DEF_ENV
				fi
			done

			if [ ${#CFGNAME} -gt 0 ] && [ ${#CFGCMD} -gt 0 ] && [ ${#CFGOUTFILE} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing command [$CFGCMD] => $SNAPSHOTS_CURDIR/$CFGOUTFILE"
				echo "CFGNAME = [$CFGNAME]" > $SNAPSHOTS_CURDIR/$CFGOUTFILE
				echo "CFGDESC = [$CFGDESC]" >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
				echo "CFGCMD = [$CFGCMD]" >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
				echo >> $SNAPSHOTS_CURDIR/$CFGOUTFILE >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
				echo "============================================================" >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
				
				eval "$CFGCMD" >> $SNAPSHOTS_CURDIR/$CFGOUTFILE
				local EXIT_STATUS=$?
	
				if [ $EXIT_STATUS -eq 0 ]
				then
					(( GOODLINE=GOODLINE+1 ))
				else
					(( BADLINE=BADLINE+1 ))
				fi
	
				echo "[$(date)] [${FUNCNAME[0]}] Exit status = [$EXIT_STATUS]"	
			else
				echo "[$(date)] [${FUNCNAME[0]}] Invalid config line [$CFGLINE]. Skipping..."
				(( BADLINE=BADLINE+1 ))
			fi	
		done < $SNAPSHOTS_CFGFILE_PROD

		if [ $MG_DEBUG == "true" ]
		then
			if [ ! -d $SNAPSHOTS_DEBUG_WORKDIR ]
			then
				mkdir -p $SNAPSHOTS_DEBUG_WORKDIR
			fi

			echo "[$(date)] [${FUNCNAME[0]}] Backing up product configuration file [$SNAPSHOTS_CFGFILE_PROD] to directory [$SNAPSHOTS_DEBUG_WORKDIR]..."
			cp -p $SNAPSHOTS_CFGFILE_PROD $SNAPSHOTS_DEBUG_WORKDIR
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Snapshot product configuration file [$SNAPSHOTS_CFGFILE_PROD] does not exist or is zero-sized! Skipping..."
	fi

	echo "[$(date)] [${FUNCNAME[0]}] Total config line = $LINECTR"
	echo "[$(date)] [${FUNCNAME[0]}] Total good config line = $GOODLINE"
	echo "[$(date)] [${FUNCNAME[0]}] Total bad config line = $BADLINE"

	# To proceed with snapshots comparisoon
	if [ $SNAPSHOTS_ONLY == "false" ]
	then
		if [ $GOODLINE -gt 0 ]
		then
			local FILE_CTR=0
	
			local SNAPSHOTS_WORKDIR=$(dirname $SNAPSHOTS_CURDIR)
			local PREV_DIR=$SNAPSHOTS_WORKDIR/$(cat $SNAPSHOTS_WORKDIR/.previous-snapshot)
			local PREV_DATETIME=$(cat $SNAPSHOTS_WORKDIR/.previous-snapshot)
			local CUR_DATETIME=$(echo "$SNAPSHOTS_CURDIR" | $AWK -F/ '{ print $NF }')
	
			echo "============================================================" >> $SNAPSHOTS_REPORT
			echo "[$PRODUCT_NAME: PRODUCT_GROUP = $PRODGROUP / PRODUCT_VERSION = $PRODVER] SNAPSHOTS REPORT" >> $SNAPSHOTS_REPORT
			echo "NOTE: The output is harvested using the 'diff' command." >> $SNAPSHOTS_REPORT
			echo "Symbol '<' = Current data [ddmmYYYY-HHMMSS = $CUR_DATETIME]" >> $SNAPSHOTS_REPORT
			echo "Symbol '>' = Previous data [ddmmYYYY-HHMMSS = $PREV_DATETIME]" >> $SNAPSHOTS_REPORT
			echo "============================================================" >> $SNAPSHOTS_REPORT
			echo >> $SNAPSHOTS_REPORT
	
			for FILE in $(ls $SNAPSHOTS_CURDIR)
			do
				(( FILE_CTR=FILE_CTR+1 ))
	
				local LATEST_FILE=$SNAPSHOTS_CURDIR/$FILE
				local PREV_FILE=$PREV_DIR/$FILE
	
				local STR_CFGNAME=$($AWK 'NR==1' $SNAPSHOTS_CURDIR/$FILE)
				local STR_CFGDESC=$($AWK 'NR==2' $SNAPSHOTS_CURDIR/$FILE)
				local STR_CFGCMD=$($AWK 'NR==3' $SNAPSHOTS_CURDIR/$FILE)
	
				echo "[$FILE_CTR] $STR_CFGNAME" >> $SNAPSHOTS_REPORT
				echo "[$FILE_CTR] $STR_CFGDESC" >> $SNAPSHOTS_REPORT
				echo "[$FILE_CTR] $STR_CFGCMD" >> $SNAPSHOTS_REPORT
				echo "[$FILE_CTR] FILE = [$FILE]" >> $SNAPSHOTS_REPORT
	
				if [ -f $PREV_FILE ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Comparing current file [$LATEST_FILE] against previous file [$PREV_FILE]..."
					local BEFORE_TOTAL_LINE=$(wc -l $SNAPSHOTS_REPORT | $AWK '{ print $1 }')
					
					diff $LATEST_FILE $PREV_FILE >> $SNAPSHOTS_REPORT
					local AFTER_TOTAL_LINE=$(wc -l $SNAPSHOTS_REPORT | $AWK '{ print $1 }')
	
					if [ $BEFORE_TOTAL_LINE -eq $AFTER_TOTAL_LINE ]
					then
						echo "< No difference found! >" >> $SNAPSHOTS_REPORT
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Previous snapshot of file [$FILE] is not available in directory [$PREV_DIR]!" | tee -a $SNAPSHOTS_REPORT
				fi
	
				echo >> $SNAPSHOTS_REPORT
				echo "===============================" >> $SNAPSHOTS_REPORT
			done
		else
			echo "[$(date)] [${FUNCNAME[0]}] Current snapshot failed [GOODLINE = $GOODLINE]..."
		fi
	fi
}

checkEnvVar()
{
	local ENVVAR=$1

	local ENV_OUTFILE=$ROOT_OUTDIR/checkEnvVar.$$
	local ENVLINE=

	IFS=$OLDIFS

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] User input environment variable string = [$ENVVAR]"
	fi

	if [ ! -d $ROOT_OUTDIR ]
	then
		mkdir -p $ROOT_OUTDIR

		if [ ! -d $ROOT_OUTDIR ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Error creating directory [$ROOT_OUTDIR]. Exiting..." >&2
			cleanUpDataDir
			exit 255
		fi
	fi

	if [[ "$ENVVAR" =~ ~\> ]]
	then
		# To cater for (-n) option
		echo "$ENVVAR" | sed 's/\^\^/\n/g' | sed 's/.*~>//' | $AWK -F## '{ for (i=1;i<=NF;i++) print $i }' > $ENV_OUTFILE
	else
		# For '-E', '-Z' and '-W'
		echo "$ENVVAR" | $AWK 'BEGIN{RS="##"} {$1=$1}1' > $ENV_OUTFILE
	fi

	if [ ! -f $ENV_OUTFILE ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Error creating environment variable file [$ENV_OUTFILE]. Exiting..." >&2
		cleanUpDataDir
		exit 255	
	fi

	while read ENVLINE
	do
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Environment variable = [$ENVLINE]"
		fi

		if [ $(echo "$ENVLINE" | $AWK -F= '{ print NF }') -ne 2 ]
		then
			local ENVNAME=$(echo "$ENVLINE" | $AWK -F= '{ print $1 }')
			local ENVVAL=$(echo "$ENVLINE" | $AWK -F= '{ print $2 }')
			local ENVVAL_LAST=$(echo "$ENVLINE" | $AWK -F= '{ print $NF }')

			if ( [[ "$ENVVAL" =~ ^\" ]] && [[ "$ENVVAL_LAST" =~ .+\"$ ]] ) || ( [[ "$ENVVAL" =~ ^\' ]] && [[ "$ENVVAL_LAST" =~ .+\'$ ]] )
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVLINE]: ENVNAME=[$ENVNAME] / ENVVAL=[$ENVVAL] / ENVVAL_LAST=[$ENVVAL_LAST]" 
				fi
			else
				if [ -f $ENV_OUTFILE ]
				then
					rm $ENV_OUTFILE
				fi

				echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVLINE]: ENVNAME=[$ENVNAME] / ENVVAL=[$ENVVAL] / ENVVAL_LAST=[$ENVVAL_LAST]" 

				if [ $(echo "$ENVLINE" | $AWK -F= '{ print NF }') -eq 1 ]
				then
					if [[ ! "$ENVLINE" =~ = ]]
					then
						echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVLINE] is not in the correct format (VAR1=VAL1) - does not contain equal sign(=)!" >&2
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVLINE] is not in the correct format (VAR1=VAL1) - VAL1 must be enclosed in single/double quotes if it contains equal sign(=)!" >&2
				fi

				return 1
			fi
		else
			if [[ "$ENVLINE" =~ ^.+[[:space:]]+= ]] || [[ "$ENVLINE" =~ ^.+=[[:space:]]+ ]]
			then
				if [ -f $ENV_OUTFILE ]
				then
					rm $ENV_OUTFILE
				fi

				echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVLINE] is not in the correct format (VAR1=VAL1) - no space is allowed before and after the equal sign!" >&2
				return 1
			else
				local ENVNAME=$(echo "$ENVLINE" | $AWK -F= '{ print $1 }')
				local ENVVAL=$(echo "$ENVLINE" | $AWK -F= '{ print $2 }')
				local GLOBAL_ENVNAME=

				# Checking quotes
				if [[ "$ENVVAL" =~ ^\" ]] && [[ ! "$ENVVAL" =~ \"$ ]]
				then
					echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVNAME] with value [$ENVVAL] does not end with double quote(\")!" >&2
					rm $ENV_OUTFILE
					return 1
				fi
	
				if [[ "$ENVVAL" =~ \"$ ]] && [[ ! "$ENVVAL" =~ ^\" ]]
				then
					echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVNAME] with value [$ENVVAL] does not start with double quote(\")!" >&2
					rm $ENV_OUTFILE
					return 1
				fi

				if [[ "$ENVVAL" =~ ^\' ]] && [[ ! "$ENVVAL" =~ \'$ ]]
				then
					echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVNAME] with value [$ENVVAL] does not end with single quote(')!" >&2
					rm $ENV_OUTFILE
					return 1
				fi
	
				if [[ "$ENVVAL" =~ \'$ ]] && [[ ! "$ENVVAL" =~ ^\' ]]
				then
					echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVNAME] with value [$ENVVAL] does not start with single quote(')!" >&2
					rm $ENV_OUTFILE
					return 1
				fi

				# All global variables defined in GMGF_ENV_ARR array are not allowed to be overriden unless specified in the envvar.override config file
				for GLOBAL_ENVNAME in ${GMGF_ENV_ARR[@]}
				do
					if [ "$ENVNAME" == "$GLOBAL_ENVNAME" ]
					then
						if isEnvVarOverrideable "$ENVNAME"
						then
							echo "[$(date)] [${FUNCNAME[0]}] WARNING: Global variable [$ENVNAME] will be overriden!"
						else
							if [ -f $ENV_OUTFILE ]
							then
								rm $ENV_OUTFILE
							fi
		
							echo "[$(date)] [${FUNCNAME[0]}] User variable [$ENVNAME] is not allowed, because a global variable of the same name exists!"
							return 1
						fi
					fi
				done
			fi
		fi
	done < $ENV_OUTFILE

	if [ -f $ENV_OUTFILE ]
	then
		rm $ENV_OUTFILE
	fi

	IFS=$'\n'
	return 0
}

checkGrepPattern()
{
	# [-G] To validate syntax of GREP_PATTERN

	local G_PATTERN=
	
	if [ ${#GREP_PATTERN} -gt 0 ]
	then
		IFS=$OLDIFS
	
		for G_PATTERN in $(echo "$GREP_PATTERN" | sed 's/##/ /g')
		do
			# echo "G_PATTERN = [$G_PATTERN]"
			local G_KEY=$(echo "$G_PATTERN" | $AWK -F: '{ print $1 }')
			local G_VAL=$(echo "$G_PATTERN" | $AWK -F: '{ print $2 }')
			local G_KV_CNT=$(echo "$G_PATTERN" | $AWK -F: '{ print NF }')

			if [ ${G_KV_CNT} -ne 2 ]
			then
				echo "[$(date)] [$(basename "$0")] ERROR: Invalid GREP_PATTERN [INPUT=$GREP_PATTERN / PROB=$G_PATTERN]! Specify keyvalue pair with format [FILE-REGEX:PATTERN]..."
				return 1	
			else
				if [ ${#G_KEY} -eq 0 ]
				then
					echo "[$(date)] [$(basename "$0")] ERROR: Invalid GREP_PATTERN [INPUT=$GREP_PATTERN / PROB=$G_PATTERN]! Key [FILE-REGEX] cannot be empty!"
					return 1	
				fi
			fi
		done	
	
		IFS=$'\n'
		return 0
	fi
}

checkManualCollectObjName()
{
	local OBJNAME_LIST=$1

	MANUAL_COLL_OBJNAME_REFFILE=$ROOT_OUTDIR/objname.ref.$$
	local TMP_WORKFILE=$ROOT_OUTDIR/objname.tmp.$$
	local LINE=

	IFS=$OLDIFS

	if [ ! -d $ROOT_OUTDIR ]
	then
		mkdir -p $ROOT_OUTDIR
	fi
		
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Writing user-input objname string [$OBJNAME_LIST] to file [$TMP_WORKFILE]..."
	fi

	echo "$OBJNAME_LIST" | $AWK 'BEGIN{RS="##"} {$1=$1}1' > $TMP_WORKFILE

	if ! verifyObjNameInput $TMP_WORKFILE
	then
		return 1
	fi

	while read LINE
	do
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] OBJNAME string = [$LINE]"
		fi
			
		local TAGNAME=$(echo "$LINE" | $AWK -F: '{ print $1 }')
		# local OBJNAME=$(echo "$LINE" | $AWK -F: '{ print $2 }')
		local OBJNAME=$(echo "$LINE" | cut -f 2- -d :)

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] TAGNAME = [$TAGNAME] / OBJNAME = [$OBJNAME]"
		fi

		if checkManualCollectUniqObjName $MANUAL_COLL_OBJNAME_REFFILE $TAGNAME
		then
			echo "[$(date)] [${FUNCNAME[0]}] Writing new reference line [$LINE] into file [$MANUAL_COLL_OBJNAME_REFFILE]..."
			echo "$LINE" >> $MANUAL_COLL_OBJNAME_REFFILE
		else
			echo "[$(date)] [${FUNCNAME[0]}] [LINE=$LINE] Tag [$TAGNAME] exists in reference file [$MANUAL_COLL_OBJNAME_REFFILE]!"
			return 1
		fi
	done < $TMP_WORKFILE

	rm $TMP_WORKFILE
	
	IFS=$'\n'
	return 0
}

verifyObjNameInput()
{
	local IN_FILE=$1	
	local LINE=

	while read LINE
	do
		local NUM_COL=$(echo "$LINE" | $AWK -F: '{ print NF }')

		if [ $NUM_COL -lt 2 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [LINE=$LINE] Configuration line is not in the right format of <tagname:objname>!"
			return 1
		else
			local TAGNAME=$(echo "$LINE" | $AWK -F: '{ print $1 }')
			local OBJNAME=$(echo "$LINE" | cut -f 2- -d :)

			if [ ${#TAGNAME} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [LINE=$LINE] TAGNAME is null!"
				return 1
			fi

			if [ ${#OBJNAME} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [LINE=$LINE] OBJNAME is null!"
				return 1
			fi
		fi
	done < $IN_FILE
	
	return 0
}

checkManualCollectUniqObjName()
{
	local IN_FILE=$1
	local IN_TAGNAME=$2

	local REFLINE=

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Checking uniqueness of tagname [$IN_TAGNAME] in reference file [$IN_FILE]..."
	fi
	
	if [ ! -f $IN_FILE ] 
	then
		echo "[$(date)] [${FUNCNAME[0]}] Tag [$IN_TAGNAME] passed uniqueness test!"
		return 0
	fi

	while read REFLINE
	do
		local TAGNAME=$(echo "$REFLINE" | $AWK -F: '{ print $1 }')	
		local OBJNAME=$(echo "$REFLINE" | cut -f 2- -d :)

		if [ ${#TAGNAME} -gt 0 ]
		then
			if [ $TAGNAME == $IN_TAGNAME ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Tag [$IN_TAGNAME] failed uniqueness test!"
				return 1
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] Tag [$IN_TAGNAME] failed uniqueness test!"
			return 1
		fi
	done < $IN_FILE

	echo "[$(date)] [${FUNCNAME[0]}] Tag [$IN_TAGNAME] passed uniqueness test!"
	return 0
}

getManualCollectObjName()
{
	local IN_TAGNAME=$1
	local LINE=

	while read LINE
	do
		local TAGNAME=$(echo "$LINE" | $AWK -F: '{ print $1 }')		
		# local OBJNAME=$(echo "$LINE" | $AWK -F: '{ print $2 }')
		local OBJNAME=$(echo "$LINE" | cut -f 2- -d :)

		if [ ${#TAGNAME} -gt 0 ] && [ $TAGNAME == $IN_TAGNAME ]
		then
			echo "$OBJNAME"
			return 0
		fi
	done < $MANUAL_COLL_OBJNAME_REFFILE

	echo ""
	return 1
}

checkManualCollectExecPrep()
{
	local EXECPREP_INPUT=$1
	local EXECPREP_ITEM=
	MANUAL_COLL_EXECPREP_REFFILE=$DEFAULT_TMPDIR/execprep.ref.$$

	if [[ ! "$EXECPREP_INPUT" =~ ~\> ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] EXECPREP user input [$EXECPREP_INPUT] is in invalid format! Should be [tag~><sourcefile>:<targetfile>]!"
		return 1
	else
		echo "[$(date)] [${FUNCNAME[0]}] EXECPREP_INPUT = [$EXECPREP_INPUT]"
	fi
		
	for EXECPREP_ITEM in $(echo "$EXECPREP_INPUT" | sed 's/##/\n/g')
	do
		local EXECPREP_TAG=$(echo "$EXECPREP_ITEM" | $AWK -F'~>' '{ print $1 }')
		local EXECPREP_SRC=$(echo "$EXECPREP_ITEM" | $AWK -F'~>' '{ print $2 }' | $AWK -F: '{ print $1 }')
		local EXECPREP_TGT=$(echo "$EXECPREP_ITEM" | $AWK -F'~>' '{ print $2 }' | $AWK -F: '{ print $2 }')

		echo "[$(date)] [${FUNCNAME[0]}] EXECPREP_TAG = [$EXECPREP_TAG] / EXECPREP_SRC = [$EXECPREP_SRC] / EXECPREP_TGT = [$EXECPREP_TGT]"

		if [ ${#EXECPREP_TAG} -eq 0 ] || [ ${#EXECPREP_SRC} -eq 0 ] || [ ${#EXECPREP_TGT} -eq 0 ]
		then	
			echo "[$(date)] [${FUNCNAME[0]}] EXECPREP user input [$EXECPREP_INPUT] is in invalid format! Should be [tag~><sourcefile>:<targetfile>]!"
			return 1
		else
			if [ ! "$EXECPREP_SRC" == "bash" ]
			then
				if [ ! -e $EXECPREP_SRC ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] EXECPREP source file [$EXECPREP_SRC] does not exist!"
					return 1
				fi
			fi
		fi

		echo "[$(date)] [${FUNCNAME[0]}] Writing line '${EXECPREP_TAG}##${EXECPREP_SRC}##${EXECPREP_TGT}' to [$MANUAL_COLL_EXECPREP_REFFILE]..."
		echo "${EXECPREP_TAG}##${EXECPREP_SRC}##${EXECPREP_TGT}" >> $MANUAL_COLL_EXECPREP_REFFILE
	done
}

checkCpFilesFormat()
{
	local USERINPUT=$1

	local NUM_COLUMN=$(echo "$USERINPUT" | $AWK -F${CPFILES_CFGFILE_DELIMITER} '{ print NF }')

	if [ ! $NUM_COLUMN -eq 1 ] && [ ! $NUM_COLUMN -eq 5 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] User input does not meet the right format (one or five columns)!"
		return 1
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] NUM_COLUMN = [$NUM_COLUMN]"
	fi
	
	if [ $NUM_COLUMN -eq 5 ]
	then
		local NAMESPACE=$(echo "$USERINPUT" | $AWK -F${CPFILES_CFGFILE_DELIMITER} '{ print $1 }')
		local PODNAME=$(echo "$USERINPUT" | $AWK -F${CPFILES_CFGFILE_DELIMITER} '{ print $2 }')	
		local CONTAINER=$(echo "$USERINPUT" | $AWK -F${CPFILES_CFGFILE_DELIMITER} '{ print $3 }')	
		local FILES=$(echo "$USERINPUT" | $AWK -F${CPFILES_CFGFILE_DELIMITER} '{ print $4 }')	
		local LIMITS=$(echo "$USERINPUT" | $AWK -F${CPFILES_CFGFILE_DELIMITER} '{ print $5 }')	
	
		if [ ${#NAMESPACE} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] NAMESPACE is null!"	
			return 1	
		else
			if [[ ! $NAMESPACE =~ ^NS4PROD= ]]
			then
				if ! $OC_CMD get namespace $NAMESPACE > /dev/null
				then
					echo "[$(date)] [${FUNCNAME[0]}] NAMESPACE provided [$NAMESPACE] is invalid!"
					return 1
				fi
			fi			
		fi	
	
		if [ ${#PODNAME} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] PODNAME cannot be null!"
			return 1
		fi
		
		if [ ${#FILES} -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] FILES cannot be null!"
			return 1
		fi
	fi

	return 0
}

checkProdVersion()
{
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] PRODUCT_VERSION = [$PRODUCT_VERSION]"
	fi

	local DEFAULT_PROD_VERSION_SUCC="false"
	local PROD_GROUP_REFFILE_SUCC="false"

	# [PART #1] Default product version processing
	# GMGF will not force quit if detected PRODUCT_VERSION is not a PRODUCT_SUPPORTED_VERSION
	if [ ${#PRODUCT_VERSION} -eq 0 ]
	then
		DETECTED_PRODVER=
		PRODUCT_VERSION_DEFAULT="true"
		PRODUCT_VERSION=${PRODUCT_SUPPORTED_VERSION[${#PRODUCT_SUPPORTED_VERSION[@]}-1]}
		echo "[$(date)] [${FUNCNAME[0]}] Setting default product version = [$PRODUCT_VERSION]"

		local DEFAULT_PROD_VERSION_SUCC="true"
	else
		local VALID_PROD_VERSION_FOUND="false"
		local VALID_PROD_VERSION=
		
		for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
		do
			if [ $PRODUCT_VERSION == $VALID_PROD_VERSION ]
			then
				local VALID_PROD_VERSION_FOUND="true"
				DETECTED_PRODVER=$PRODUCT_VERSION
				break
			fi
		done	

		if [ $VALID_PROD_VERSION_FOUND == "false" ]
		then
			if [ ${#DEFAULT_TO_LATEST_PRODVER} -gt 0 ] && [ $DEFAULT_TO_LATEST_PRODVER == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Detected product version [$PRODUCT_VERSION] is NOT a valid/supported product version!"
				DETECTED_PRODVER=$PRODUCT_VERSION
				PRODUCT_VERSION_DEFAULT="true"
				PRODUCT_VERSION=${PRODUCT_SUPPORTED_VERSION[${#PRODUCT_SUPPORTED_VERSION[@]}-1]}
				echo "[$(date)] [${FUNCNAME[0]}] Setting product version to latest valid/supported version [$PRODUCT_VERSION]!" 

				local DEFAULT_PROD_VERSION_SUCC="true"
			else
				echo "[$(date)] [${FUNCNAME[0]}] Detected product version [$PRODUCT_VERSION] is NOT a valid/supported product version!"

				local DEFAULT_PROD_VERSION_SUCC="false"
			fi
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Detected product version [$PRODUCT_VERSION] is a valid/supported product version!"
			fi

			local DEFAULT_PROD_VERSION_SUCC="true"
		fi
	fi

	# Likely do not need this when the "product group reference file" goes live!
	if [ $USERSET_MISSINGOBJ_VERSION -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Setting MISSINGOBJ_VERSION to [$PRODUCT_VERSION]..."
		MISSINGOBJ_VERSION=$PRODUCT_VERSION
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] USERSET_MISSINGOBJ_VERSION is set! Not setting MISSINGOBJ_VERSION!"
		fi
	fi

	if [ ! -s ${PROD_VERSIONS_REFFILE} ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] PROD_VERSIONS_REFFILE [$PROD_VERSIONS_REFFILE] does not exist or is zero-sized! Returning..."
		return 1
	else
		# Perform initial check on PROD_VERSIONS_REFFILE
		local TMP_PROD_VERSIONS_REFFILE=${PROD_VERSIONS_REFFILE}.tmp
		local PROD_GROUP_DEFAULT_PREFIX="$(echo "$PRODUCT_NAME" | $AWK '{ print tolower($0) }')_prodgrp_"
		local PROD_VER_LINE_CTR=0

		local REFFILE_UPDATED="false"
		
		while read PROD_VER_LINE
		do
			(( PROD_VER_LINE_CTR=PROD_VER_LINE_CTR+1 ))

			local PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
			local PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
			local PROD_NS=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $3 }')

			if [ ${#PROD_GROUP} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [LINE = $PROD_VER_LINE] Product group name cannot be empty! Setting to default [${PROD_GROUP_DEFAULT_PREFIX}${PROD_VER_LINE_CTR}]..."
				local FINAL_PROD_GROUP=${PROD_GROUP_DEFAULT_PREFIX}${PROD_VER_LINE_CTR}

				local REFFILE_UPDATED="true"
			else
				local FINAL_PROD_GROUP="$PROD_GROUP"
			fi
			
			if [ ${#PROD_VER} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [LINE = $PROD_VER_LINE] Product version cannot be empty! Setting to default [$PRODUCT_VERSION]..."
				local FINAL_PROD_VER="$PRODUCT_VERSION"

				local REFFILE_UPDATED="true"
			else
				local FINAL_PROD_VER="$PROD_VER"
			fi

			if [ ${#PROD_NS} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [LINE = $PROD_VER_LINE] Product namespaces cannot be empty! Returning..."
				return 1
			fi
			
			echo "${FINAL_PROD_GROUP}${PROD_REFFILE_DELIMITER}${FINAL_PROD_VER}${PROD_REFFILE_DELIMITER}${PROD_NS}" >> $TMP_PROD_VERSIONS_REFFILE
		done < $PROD_VERSIONS_REFFILE
		
		if [ $REFFILE_UPDATED == "true" ] 
		then
			if [ -s ${TMP_PROD_VERSIONS_REFFILE} ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Updating PROD_VERSIONS_REFFILE [$PROD_VERSIONS_REFFILE]..."

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] TMP_PROD_VERSIONS_REFFILE = [$(cat $TMP_PROD_VERSIONS_REFFILE)]"
				fi

				mv $TMP_PROD_VERSIONS_REFFILE $PROD_VERSIONS_REFFILE
			else
				echo "[$(date)] [${FUNCNAME[0]}] TMP_PROD_VERSIONS_REFFILE [$TMP_PROD_VERSIONS_REFFILE] does not exist or is zero-sized! Returning..."
				return 1
			fi
		else
			if [ -f ${TMP_PROD_VERSIONS_REFFILE} ]
			then
				rm $TMP_PROD_VERSIONS_REFFILE
			fi
		fi
	fi

	# Check whether product group names are unique
	local TMP_PROD_VER_REFFILE_PRODGROUPS=$($AWK 'NF > 0' $PROD_VERSIONS_REFFILE | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
	local TMP_PROD_VER_REFFILE_LINE_COUNT=$(echo "$TMP_PROD_VER_REFFILE_PRODGROUPS" | wc -l)
	local TMP_PROD_VER_REFFILE_UNIQ_COUNT=$(echo "$TMP_PROD_VER_REFFILE_PRODGROUPS" | sort -u | wc -l)

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Product group names = [$(echo $TMP_PROD_VER_REFFILE_PRODGROUPS | tr '\n' ' ' | sed 's/[ ]*$//')]"
	fi

	if [ $TMP_PROD_VER_REFFILE_LINE_COUNT -eq $TMP_PROD_VER_REFFILE_UNIQ_COUNT ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] All product group names [TOTAL=$TMP_PROD_VER_REFFILE_UNIQ_COUNT] are unique!"
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product group names are NOT unique [LINE_COUNT = $TMP_PROD_VER_REFFILE_LINE_COUNT / UNIQ_COUNT = $TMP_PROD_VER_REFFILE_UNIQ_COUNT]! Returning..."
		return 1
	fi

	# [PART #2] Product group reference file processing
	if [ -s $PROD_VERSIONS_REFFILE ]
	then
		local PROD_GROUP_COUNT=0
		local ANY_PROD_GROUP_EXCLUDED="false"

		# Check if there is user-provided "prodgroup.cfg" file
		local PRODGROUP_CFGFILE="$MUSTGATHER_DIRNAME/config/prodgroup.cfg"

		if [ -s $PRODGROUP_CFGFILE ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] PRODGROUP_CFGFILE [$PRODGROUP_CFGFILE] exists!"

			# Set RTVAR_EXCL_PROD_GROUP
			if [ ${#RTVAR_EXCL_PROD_GROUP} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] RTVAR_EXCL_PROD_GROUP [$RTVAR_EXCL_PROD_GROUP] will be reset to empty!"
				RTVAR_EXCL_PROD_GROUP=
			fi

			unset TMP_PROD_GROUP_ARR

			while read PROD_VER_LINE
			do
				local PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
				TMP_PROD_GROUP_ARR[${#TMP_PROD_GROUP_ARR[@]}]="$PROD_GROUP"
			done < $PROD_VERSIONS_REFFILE

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] TMP_PROD_GROUP_ARR = [${TMP_PROD_GROUP_ARR[@]}]"
			fi

			if [ ${#TMP_PROD_GROUP_ARR[@]} -gt 0 ]
			then
				while read USER_PRODGRP_LINE
				do
					local TRIM_USER_PRODGRP_LINE=$(echo "$USER_PRODGRP_LINE" | sed 's/^[ ]*//' | sed 's/[ ]*$//')
					local IS_VALID_PRODGROUP="false"
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] USER_PRODGRP_LINE = [$USER_PRODGRP_LINE] / TRIM_USER_PRODGRP_LINE = [$TRIM_USER_PRODGRP_LINE]"
					fi
	
					for VALID_PROD_GRP in ${TMP_PROD_GROUP_ARR[@]}
					do
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] VALID_PROD_GRP = [$VALID_PROD_GRP]"
						fi

						if [ "$TRIM_USER_PRODGRP_LINE" == "$VALID_PROD_GRP" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] User provided product group [$TRIM_USER_PRODGRP_LINE] is valid!"
							local IS_VALID_PRODGROUP="true"
							break
						fi
					done

					if [ $IS_VALID_PRODGROUP == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Removing product group [$TRIM_USER_PRODGRP_LINE] from TMP_PROD_GROUP_ARR array..."
		
						local TMP_PROD_GROUP_ARR_VAL="${TMP_PROD_GROUP_ARR[@]/$TRIM_USER_PRODGRP_LINE}"

						if [ ${#TMP_PROD_GROUP_ARR_VAL} -gt 0 ]
						then
							TMP_PROD_GROUP_ARR=( "$TMP_PROD_GROUP_ARR_VAL" )
						else
							unset TMP_PROD_GROUP_ARR
						fi

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] TMP_PROD_GROUP_ARR_VAL = [$TMP_PROD_GROUP_ARR_VAL] [LENGTH=${#TMP_PROD_GROUP_ARR_VAL}]"
							echo "[$(date)] [${FUNCNAME[0]}] Latest TMP_PROD_GROUP_ARR = [${TMP_PROD_GROUP_ARR[@]}][${#TMP_PROD_GROUP_ARR[@]}]"
						fi
					else
						printf "[$(date)] [${FUNCNAME[0]}] ${BOLD}${RED}User input product group [$TRIM_USER_PRODGRP_LINE] is an invalid product group! Returning...${NORMAL}${NEWLINE}"
						echo "[$(date)] [${FUNCNAME[0]}] User input product group [$TRIM_USER_PRODGRP_LINE] is an invalid product group! Returning..." >> $RUNTIME_LOGFILE
						return 1
					fi
				done < $PRODGROUP_CFGFILE

				if [ ${#TMP_PROD_GROUP_ARR[@]} -gt 0 ]
				then
					for PROD_GRP in ${TMP_PROD_GROUP_ARR[@]}
					do
						echo "[$(date)] [${FUNCNAME[0]}] Adding product group [$PROD_GRP] to RTVAR_EXCL_PROD_GROUP variable..."

						if [ ${#RTVAR_EXCL_PROD_GROUP} -eq 0 ]
						then
							RTVAR_EXCL_PROD_GROUP="$PROD_GRP"
						else
							RTVAR_EXCL_PROD_GROUP="${RTVAR_EXCL_PROD_GROUP},${PROD_GRP}"
						fi
					done

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Final RTVAR_EXCL_PROD_GROUP = [$RTVAR_EXCL_PROD_GROUP]"
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] TMP_PROD_GROUP_ARR array is empty! Proceeding..."
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] TMP_PROD_GROUP_ARR array is empty! Unable to process PRODGROUP_CFGFILE [$PRODGROUP_CFGFILE] file!"
			fi
		fi

		while read PROD_VER_LINE
		do
			local PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
			local PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
			local PROD_NS=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $3 }')

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_VER_LINE = [$PROD_VER_LINE]"
				echo "[$(date)] [${FUNCNAME[0]}] PROD_GROUP = [$PROD_GROUP] / PROD_VER = [$PROD_VER] / PROD_NS = [$PROD_NS]"
			fi

			if [ ${#PROD_GROUP} -eq 0 ] || [ ${#PROD_VER} -eq 0 ] || [ ${#PROD_NS} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_GROUP / PROD_VER / PROD_NS cannot be empty/null! Skipping..."
				continue
			fi

			if [[ ${PROD_GROUP} =~ / ]]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_GROUP [$PROD_GROUP] cannot contain forward slash! Skipping..."
				continue
			fi

			if [ ${#RTVAR_EXCL_PROD_GROUP} -gt 0 ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] RTVAR_EXCL_PROD_GROUP = [$RTVAR_EXCL_PROD_GROUP]"
				fi

				local TO_EXCL_PROD_GROUP="false"

				IFS=$OLDIFS
				for EXCL_PROD_GROUP in $(echo "$RTVAR_EXCL_PROD_GROUP" | sed 's/,/ /g')
				do
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] PROD_GROUP = [$PROD_GROUP] / EXCL_PROD_GROUP = [$EXCL_PROD_GROUP]"
					fi

					if [ $PROD_GROUP == "$EXCL_PROD_GROUP" ]
					then
						local TO_EXCL_PROD_GROUP="true"
						local ANY_PROD_GROUP_EXCLUDED="true"
						break
					fi
				done
				IFS=$'\n'

				if [ $TO_EXCL_PROD_GROUP == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] PROD_GROUP [$PROD_GROUP] is configured to be excluded! Skipping..."
					continue
				fi
			fi
	
			local VALID_PROD_VERSION_FOUND="false"

			for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
			do
				if [ $PROD_VER == $VALID_PROD_VERSION ]
				then
					local VALID_PROD_VERSION_FOUND="true"
					break
				fi
			done

			if [ $VALID_PROD_VERSION_FOUND == "false" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Detected product version [$PROD_VER] is NOT a valid/supported product version!"

				if [ ${#DEFAULT_TO_LATEST_PRODVER} -gt 0 ] && [ $DEFAULT_TO_LATEST_PRODVER == "true" ]
				then
					local PROD_VER=${PRODUCT_SUPPORTED_VERSION[${#PRODUCT_SUPPORTED_VERSION[@]}-1]}
					echo "[$(date)] [${FUNCNAME[0]}] Setting product version to latest valid/supported version [$PROD_VER]!" 
				else
					echo "[$(date)] [${FUNCNAME[0]}] Removing line [$PROD_VER_LINE] from product version reference file [${PROD_VERSIONS_REFFILE}]!"
					continue
				fi
			fi

			# Check for EXCL_PROD_NS
			local FINAL_PROD_NS=

			if [ ${#RTVAR_EXCL_PROD_NS} -gt 0 ]
			then
				for NS_LINE in $(echo "$PROD_NS" | $AWK -F${PROD_REFFILE_NS_DELIMITER} '{ for (i=1;i<=NF;i++) { print $i } }')
				do
					local SUB_PROD_NAME=$(echo "$NS_LINE" | $AWK -F= '{ print $1 }')
					local SUB_PROD_NS_LINE=$(echo "$NS_LINE" | $AWK -F= '{ print $2 }')
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] NS_LINE = [$NS_LINE] / SUB_PROD_NAME = [$SUB_PROD_NAME] / SUB_PROD_NS_LINE = [$SUB_PROD_NS_LINE]"
					fi
	
					local NEW_SUB_PROD_NS_LINE=
	
					IFS=$OLDIFS
					for SUB_PROD_NS in $(echo "$SUB_PROD_NS_LINE" | sed 's/,/ /g')
					do
						if toExcludeProdNamespace $SUB_PROD_NS
						then
							echo "[$(date)] [${FUNCNAME[0]}] [PROD_GROUP = $PROD_GROUP / PROD = $SUB_PROD_NAME] Namespace [$SUB_PROD_NS] to be excluded..."
						else
							if [ ${#NEW_SUB_PROD_NS_LINE} -eq 0 ]
							then
								local NEW_SUB_PROD_NS_LINE="$SUB_PROD_NS"
							else
								local NEW_SUB_PROD_NS_LINE="$NEW_SUB_PROD_NS_LINE,$SUB_PROD_NS"
							fi
						fi
					done
					IFS=$'\n'
	
					local NEW_SUB_PROD_NS_LINE="${SUB_PROD_NAME}=${NEW_SUB_PROD_NS_LINE}"
	
					if [ ${#FINAL_PROD_NS} -eq 0 ]
					then
						local FINAL_PROD_NS="$NEW_SUB_PROD_NS_LINE"
					else
						local FINAL_PROD_NS="${FINAL_PROD_NS}${PROD_REFFILE_NS_DELIMITER}${NEW_SUB_PROD_NS_LINE}"
					fi
				done
			else
				local FINAL_PROD_NS="$PROD_NS"
			fi

			local CHECK_FINAL_PROD_NS=$(echo "$FINAL_PROD_NS" | $AWK -F${PROD_REFFILE_NS_DELIMITER} 'BEGIN { FOUND=0 } { for (i=1;i<=NF;i++) { if ($i ~ /^.+=.+$/) { FOUND=1; print "OK"; break } } } END { if (FOUND == 0) { print "NOK" } }')

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] FINAL_PROD_NS = [$FINAL_PROD_NS] / CHECK_FINAL_PROD_NS = [$CHECK_FINAL_PROD_NS]"
			fi

			if [ ${#CHECK_FINAL_PROD_NS} -gt 0 ] && [ ${CHECK_FINAL_PROD_NS} == "OK" ]
			then
				# To create final product group reference file
				echo "${PROD_GROUP}${PROD_REFFILE_DELIMITER}${PROD_VER}${PROD_REFFILE_DELIMITER}${FINAL_PROD_NS}" >> $PROD_VERSIONS_REFFILE_FINAL
			else
				echo "[$(date)] [${FUNCNAME[0]}] FINAL_PROD_NS [$FINAL_PROD_NS] does not contain any namespace! Skipping..."
				continue	
			fi

			# To create product group namespace reference file
			local PROD_GROUP_NS_REFFILE=${REFFILE_OUTDIR}/${PROD_GROUP}.ns-ref
			echo "[$(date)] [${FUNCNAME[0]}] Creating product group [$PROD_GROUP] namespace reference file [$PROD_GROUP_NS_REFFILE]..."
			echo "$FINAL_PROD_NS" | $AWK -F${PROD_REFFILE_NS_DELIMITER} '{ for (i=1;i<=NF;i++) { print $i } }' > $PROD_GROUP_NS_REFFILE 	

			# Add PROD_GROUP into PROD_GROUPS_ARR array
			echo "[$(date)] [${FUNCNAME[0]}] Adding PROD_GROUP [$PROD_GROUP] into PROD_GROUPS_ARR!"
			PROD_GROUPS_ARR[${#PROD_GROUPS_ARR[@]}]="$PROD_GROUP"
	
			(( PROD_GROUP_COUNT=PROD_GROUP_COUNT+1 ))
		done < $PROD_VERSIONS_REFFILE

		if [ ! -f $PROD_VERSIONS_REFFILE_FINAL ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] PROD_VERSIONS_REFFILE_FINAL [$PROD_VERSIONS_REFFILE_FINAL] does not exist!"
			return 1
		else
			if [ ! -s $PROD_VERSIONS_REFFILE_FINAL ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Line count of PROD_VERSIONS_REFFILE_FINAL [$PROD_VERSIONS_REFFILE_FINAL] = [0]"
				return 1
			else
				echo "[$(date)] [${FUNCNAME[0]}] Line count of PROD_VERSIONS_REFFILE_FINAL [$PROD_VERSIONS_REFFILE_FINAL] = [$(wc -l $PROD_VERSIONS_REFFILE_FINAL | $AWK '{ print $1 }')]"
			fi
		fi

		# For debugging purpose, create an empty file (even if all product groups are excluded)
		touch $PROD_VERSIONS_REFFILE_FINAL

		# To build product namespaces count 
		if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Building product namespaces count and mapping..."

			if [ $BASH_V4 == "true" ]
			then
				if [ ${#PROD_NAMESPACES_LIST_ARR[@]} -gt 0 ]
				then
					unset PROD_NAMESPACES_LIST_ARR
				fi

				if [ ${#PROD_NAMESPACES_MAP_ARR[@]} -gt 0 ]
				then
					unset PROD_NAMESPACES_MAP_ARR
				fi

				declare -A PROD_NAMESPACES_LIST_ARR
				declare -A PROD_NAMESPACES_MAP_ARR
			else
				if [ ${#PROD_NAMESPACES_LIST_FILE} -gt 0 ] && [ -f $PROD_NAMESPACES_LIST_FILE ]
				then
					rm $PROD_NAMESPACES_LIST_FILE	
				fi

				if [ ${#PROD_NAMESPACES_MAP_FILE} -gt 0 ] && [ -f $PROD_NAMESPACES_MAP_FILE ]
				then
					rm $PROD_NAMESPACES_MAP_FILE	
				fi
			fi

			while read REF_LINE 
			do
				local PROD_GROUP=$(echo "$REF_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
				local PROD_VER=$(echo "$REF_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
				local PROD_NS=$(echo "$REF_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $3 }')
				
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [REFLINE = $REF_LINE] PROD_GROUP = [$PROD_GROUP] / PROD_VER = [$PROD_VER] / PROD_NS = [$PROD_NS]"
				fi

				IFS=$OLDIFS
				for PROD_NS_LINE in $(echo "$PROD_NS" | sed 's#/# #g')
				do
					local PROD_NAME=$(echo "$PROD_NS_LINE" | $AWK -F= '{ print $1 }')
					local PROD_NS_LIST=$(echo "$PROD_NS_LINE" | $AWK -F= '{ print $2 }')

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [PROD_NS_LINE = $PROD_NS_LINE] PROD_NAME = [$PROD_NAME] / PROD_NS_LIST = [$PROD_NS_LIST]"
					fi

					for PROD_NS_LIST_LINE in $(echo "$PROD_NS_LIST" | sed 's/,/ /g')
					do
						if [ $BASH_V4 == "true" ]
						then
							# Use associative array
							if [ ${PROD_NAMESPACES_LIST_ARR[$PROD_NS_LIST_LINE]+_} ]
							then
								PROD_NAMESPACES_LIST_ARR[$PROD_NS_LIST_LINE]=$((${PROD_NAMESPACES_LIST_ARR[$PROD_NS_LIST_LINE]}+1))
							else
								PROD_NAMESPACES_LIST_ARR[$PROD_NS_LIST_LINE]=1
							fi

							# Build namespace to product name mapping too
							if [ "${PROD_NAMESPACES_MAP_ARR[$PROD_NAME]+_}" ]
							then
								PROD_NAMESPACES_MAP_ARR[$PROD_NAME]="${PROD_NAMESPACES_MAP_ARR[$PROD_NAME]},$PROD_NS_LIST_LINE"
							else
								PROD_NAMESPACES_MAP_ARR[$PROD_NAME]="$PROD_NS_LIST_LINE"
							fi
						else
							# Use file
							PROD_NAMESPACES_LIST_FILE=$REFFILE_OUTDIR/prod-ns.cnt
							local TMP_PROD_NAMESPACES_LIST_FILE=${PROD_NAMESPACES_LIST_FILE}.tmp

							echo "$PROD_NS_LIST_LINE" >> $TMP_PROD_NAMESPACES_LIST_FILE

							# Build namespace to product name mapping too
							PROD_NAMESPACES_MAP_FILE=$REFFILE_OUTDIR/prod-ns.map
							local TMP_PROD_NAMESPACES_MAP_FILE=${PROD_NAMESPACES_MAP_FILE}.tmp
							echo "$PROD_NAME=$PROD_NS_LIST_LINE" >> $TMP_PROD_NAMESPACES_MAP_FILE
						fi
					done
				done
				
				IFS=$'\n'
			done < $PROD_VERSIONS_REFFILE_FINAL

			if [ ${#TMP_PROD_NAMESPACES_LIST_FILE} -gt 0 ] && [ -s $TMP_PROD_NAMESPACES_LIST_FILE ]
			then
				for UNIQ_NS in $(sort $TMP_PROD_NAMESPACES_LIST_FILE | uniq)
				do
					local CMD="$AWK '/^"$UNIQ_NS"\$/' $TMP_PROD_NAMESPACES_LIST_FILE"
					local NS_COUNT=$(eval "$CMD" | wc -l)

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] UNIQ_NS = [$UNIQ_NS] / NS_COUNT = [$NS_COUNT]"
					fi

					echo "$UNIQ_NS=$NS_COUNT" >> $PROD_NAMESPACES_LIST_FILE
				done

				rm $TMP_PROD_NAMESPACES_LIST_FILE
			fi

			if [ ${#TMP_PROD_NAMESPACES_MAP_FILE} -gt 0 ] && [ -s $TMP_PROD_NAMESPACES_MAP_FILE ]
			then
				for UNIQ_PROD in $(sort $TMP_PROD_NAMESPACES_MAP_FILE | uniq | $AWK -F= '{ print $1 }' | uniq)
				do
					local TO_PROC_LINE=$(grep -E "^$UNIQ_PROD" $TMP_PROD_NAMESPACES_MAP_FILE)
					local TO_PROC_FINAL=
	
					IFS=$'\n'
					for TO_PROC in $TO_PROC_LINE
					do
						local TO_PROC_PRODNAME=$(echo "$TO_PROC" | $AWK -F= '{ print $1 }')
						local TO_PROC_PRODNS=$(echo "$TO_PROC" | $AWK -F= '{ print $2 }')

						if [ ${#TO_PROC_FINAL} -eq 0 ]
						then
							local TO_PROC_FINAL="$TO_PROC_LINE"
						else
							local TO_PROC_FINAL="${TO_PROC_LINE},${TO_PROC_PRODNS}"
						fi	
					done	

					if [ ${#TO_PROC_FINAL} -gt 0 ]
					then
						echo "$TO_PROC_FINAL" >> $PROD_NAMESPACES_MAP_FILE	
					fi
				done

				rm $TMP_PROD_NAMESPACES_MAP_FILE
			fi

			if [ $MG_DEBUG == "true" ]
			then
				if [ $BASH_V4 == "true" ]
				then
					for KEY in "${!PROD_NAMESPACES_LIST_ARR[@]}"
					do
						echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_LIST_ARR[$KEY] = [${PROD_NAMESPACES_LIST_ARR[$KEY]}]"
					done

					for KEY in "${!PROD_NAMESPACES_MAP_ARR[@]}"
					do
						echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_MAP_ARR[$KEY] = [${PROD_NAMESPACES_MAP_ARR[$KEY]}]"
					done
				else
					if [ -f $PROD_NAMESPACES_LIST_FILE ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Content of PROD_NAMESPACES_LIST_FILE =>"
						cat $PROD_NAMESPACES_LIST_FILE
					else
						echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_LIST_FILE [$PROD_NAMESPACES_LIST_FILE] does not exist!"
					fi

					if [ -f $PROD_NAMESPACES_MAP_FILE ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Content of PROD_NAMESPACES_MAP_FILE =>"
						cat $PROD_NAMESPACES_MAP_FILE
					else
						echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_MAP_FILE [$PROD_NAMESPACES_MAP_FILE] does not exist!"
					fi
				fi
			fi

			# To crosscheck against product of function checkProdNamespace() and update if necessary
			# (1) PROD_NAMESPACES_UNIQUE array
			local ORI_PROD_NAMESPACES_UNIQUE=$(printf '%s\n' "${PROD_NAMESPACES_UNIQUE[@]}" | sed 's/^\s//' | sed 's/\s$'// | sort | uniq)
			local PROD_NAMESPACES_UNIQUE_UPDATED="false"

			if [ $BASH_V4 == "true" ]
			then
				local CUR_PROD_NAMESPACES_UNIQUE=$(printf "%s\n" "${!PROD_NAMESPACES_LIST_ARR[@]}" | sed 's/^\s//' | sed 's/\s$'// | sort | uniq)
			else
				if [ ${#PROD_NAMESPACES_LIST_FILE} -gt 0 ] && [ -s $PROD_NAMESPACES_LIST_FILE ]
				then
					local CUR_PROD_NAMESPACES_UNIQUE=$(sort $PROD_NAMESPACES_LIST_FILE | sed 's/^\s//' | sed 's/\s$'// | $AWK -F= '{ print $1 }' | uniq)
				else
					echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_LIST_FILE [$PROD_NAMESPACES_LIST_FILE] does not exist or is zero-sized!"	
					local CUR_PROD_NAMESPACES_UNIQUE=
				fi
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] ORI_PROD_NAMESPACES_UNIQUE = [$ORI_PROD_NAMESPACES_UNIQUE]"
				echo "[$(date)] [${FUNCNAME[0]}] CUR_PROD_NAMESPACES_UNIQUE = [$CUR_PROD_NAMESPACES_UNIQUE]"
			fi

			if [ "$ORI_PROD_NAMESPACES_UNIQUE" != "$CUR_PROD_NAMESPACES_UNIQUE" ]
			then
				# CUR_PROD_NAMESPACES_UNIQUE will be used to replace/construct new PROD_NAMESPACES_UNIQUE, because checkProdVersion() is executed after checkProdNamespace() (hence latest info)
				echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_UNIQUE array is outdated! To be updated..."
				unset PROD_NAMESPACES_UNIQUE

				local REMOVED_NS=$(diff <(echo "$ORI_PROD_NAMESPACES_UNIQUE") <(echo "$CUR_PROD_NAMESPACES_UNIQUE") | grep -E -v '^[0-9]+|^$' | $AWK '$1 ~ /^</ { print $2 }')
				local ADDED_NS=$(diff <(echo "$ORI_PROD_NAMESPACES_UNIQUE") <(echo "$CUR_PROD_NAMESPACES_UNIQUE") | grep -E -v '^[0-9]+|^$' | $AWK '$1 ~ /^>/ { print $2 }')
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Product namespaces removed = [$REMOVED_NS]"
					echo "[$(date)] [${FUNCNAME[0]}] Product namespaces added = [$ADDED_NS]"
				fi	

				IFS=$'\n'
				for UNIQUE_NS in $CUR_PROD_NAMESPACES_UNIQUE	
				do
					PROD_NAMESPACES_UNIQUE[${#PROD_NAMESPACES_UNIQUE[@]}]="$UNIQUE_NS"					
				done

				PROD_NAMESPACES_UNIQUE_STR="${PROD_NAMESPACES_UNIQUE[@]}"

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Updated PROD_NAMESPACES_UNIQUE = [${PROD_NAMESPACES_UNIQUE[@]}]"
					echo "[$(date)] [${FUNCNAME[0]}] Updated PROD_NAMESPACES_UNIQUE_STR = [$PROD_NAMESPACES_UNIQUE_STR]"
				fi

				local PROD_NAMESPACES_UNIQUE_UPDATED="true"
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_UNIQUE is consistent! No difference is found between getProdNamespaces() and getProdVersions()!" 
				fi
			fi

			# (2) PROD_NAMESPACES_UNIQUE_REFFILE reference file
			if [ ${PROD_NAMESPACES_UNIQUE_UPDATED} == "true" ]	
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_UNIQUE_REFFILE [$PROD_NAMESPACES_UNIQUE_REFFILE] is outdated! To be updated..."

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Original content of PROD_NAMESPACES_UNIQUE_REFFILE = [$(cat $PROD_NAMESPACES_UNIQUE_REFFILE)]"
				fi

				rm $PROD_NAMESPACES_UNIQUE_REFFILE

				for UNIQUE_NS in ${PROD_NAMESPACES_UNIQUE[@]}
				do
					echo "$UNIQUE_NS" >> $PROD_NAMESPACES_UNIQUE_REFFILE
				done

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Updated content of PROD_NAMESPACES_UNIQUE_REFFILE = [$(cat $PROD_NAMESPACES_UNIQUE_REFFILE)]"
				fi
			fi	

			# (3) PROD_NAMESPACES_REFFILE_FINAL reference file (not updating PROD_NAMESPACES_REFFILE)
			if [ ${PROD_NAMESPACES_UNIQUE_UPDATED} == "true" ]	
			then
				echo "[$(date)] [${FUNCNAME[0]}] PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL] is outdated! To be updated..."

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Original content of PROD_NAMESPACES_REFFILE_FINAL = [$(cat $PROD_NAMESPACES_REFFILE_FINAL)]"
				fi

				rm $PROD_NAMESPACES_REFFILE_FINAL

				if [ $BASH_V4 == "true" ]
				then
					for KEY in "${!PROD_NAMESPACES_MAP_ARR[@]}"	
					do
						echo "${KEY}=${PROD_NAMESPACES_MAP_ARR[$KEY]}"
					done | sort >> $PROD_NAMESPACES_REFFILE_FINAL
				else
					sort -o $PROD_NAMESPACES_REFFILE_FINAL $PROD_NAMESPACES_MAP_FILE
				fi	

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Updated content of PROD_NAMESPACES_REFFILE_FINAL = [$(cat $PROD_NAMESPACES_REFFILE_FINAL)]"
				fi
			fi
		fi	

		# If EXCL_PROD_GROUP is set, to update PROD_NAMESPACES_REFFILE_FINAL, PROD_NAMESPACES_KEYVAL_ARR, PROD_NAMESPACES_UNIQUE_REFFILE, PROD_NAMESPACES_UNIQUE, PROD_VERSIONS_UNIQUE_REFFILE and PROD_VERSIONS_UNIQUE
		if [ ${#RTVAR_EXCL_PROD_GROUP} -gt 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] RTVAR_EXCL_PROD_GROUP = [$RTVAR_EXCL_PROD_GROUP]"

			IFS=$OLDIFS
			for EXCL_PROD_GROUP in $(echo "$RTVAR_EXCL_PROD_GROUP" | sed 's/,/ /g')
			do
				local IS_VALID_PROD_GROUP="false"

				# A valid EXCL_PROD_GROUP will not be in the PROD_GROUPS_ARR
				if [ -s $PROD_VERSIONS_REFFILE ]
				then
					while read REF_LINE
					do
						local REF_PROD_GROUP=$(echo "$REF_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')

						if [ "$EXCL_PROD_GROUP" == "$REF_PROD_GROUP" ]
						then
							local IS_VALID_PROD_GROUP="true"
							break
						fi
					done < $PROD_VERSIONS_REFFILE
				else
					echo "[$(date)] [${FUNCNAME[0]}] PROD_VERSIONS_REFFILE [$PROD_VERSIONS_REFFILE] does not exist or is zero-sized! Skipping..."
				fi

				if [ $IS_VALID_PROD_GROUP == "false" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] EXCL_PROD_GROUP [$EXCL_PROD_GROUP] is not a valid product group! Skipping..."
					continue
				fi
				
				# Step 0 - obtain product namespaces to exclude
				local EXCL_NS_LIST_CMD="$AWK -F${PROD_REFFILE_DELIMITER} '\$1 ~ /^$EXCL_PROD_GROUP\$/ { print \$3 }' $PROD_VERSIONS_REFFILE | tr '${PROD_REFFILE_NS_DELIMITER}' '\n' | $AWK -F= '{ print \$2 }'"
			
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [Step #0] EXCL_NS_LIST_CMD = [$EXCL_NS_LIST_CMD]"
				fi
					
				local EXCL_NS_LIST=$(eval "$EXCL_NS_LIST_CMD")

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [Step #0] EXCL_PROD_GROUP = [$EXCL_PROD_GROUP] / EXCL_NS_LIST = [$EXCL_NS_LIST]"
				fi

				for EXCL_NS in ${EXCL_NS_LIST}
				do
					echo "[$(date)] [${FUNCNAME[0]}] [Step #0] Searching for excluded product namespace [$EXCL_NS]..."

					# Step 1 - update PROD_NAMESPACES_REFFILE_FINAL
					local TMP_WORKFILE=$(dirname $PROD_VERSIONS_REFFILE_FINAL)/$(basename $PROD_VERSIONS_REFFILE_FINAL).tmp

					while read REF_LINE
					do
						local PROD_NAMESPACES_REFFILE_FINAL_PRODNAME=$(echo "$REF_LINE" | $AWK -F= '{ print $1 }')
						local PROD_NAMESPACES_REFFILE_FINAL_PRODNS=$(echo "$REF_LINE" | $AWK -F= '{ print $2 }')
						local NS_LIST_LINE=

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [Step #1] PROD_NAMESPACES_REFFILE_FINAL_PRODNAME = [$PROD_NAMESPACES_REFFILE_FINAL_PRODNAME] / PROD_NAMESPACES_REFFILE_FINAL_PRODNS = [$PROD_NAMESPACES_REFFILE_FINAL_PRODNS]"
						fi

						IFS=$OLDIFS
						for REF_NS in $(echo "$PROD_NAMESPACES_REFFILE_FINAL_PRODNS" | sed 's/,/ /g')
						do
							if [ "$EXCL_NS" == "$REF_NS" ]
							then
								if [ $BASH_V4 == "true" ]
								then
									if [ ${#PROD_NAMESPACES_LIST_ARR[@]} -gt 0 ]
									then
										if [ ${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]+_} ]
										then
											if [ ${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]} -gt 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Excluded product namespace [$EXCL_NS] has [${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]}] active reference(s)! Keeping..."

												if [ ${#NS_LIST_LINE} -eq 0 ]
												then
													local NS_LIST_LINE="${REF_NS}"
												else
													local NS_LIST_LINE="${NS_LIST_LINE},${REF_NS}"
												fi
											else
												echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL]..."
											fi
										else
											echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL]..."
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL]..."
									fi
								else
									if [ ${#PROD_NAMESPACES_LIST_FILE} -gt 0 ] && [ -s $PROD_NAMESPACES_LIST_FILE ]
									then
										while read CNT_LINE
										do
											local CNT_NS=$(echo "$CNT_LINE" | $AWK -F= '{ print $1 }')
											local CNT_VAL=$(echo "$CNT_LINE" | $AWK -F= '{ print $2 }')
	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [Step #1] CNT_NS = [$CNT_NS] / CNT_VAL = [$CNT_VAL]"
											fi

											if [ ${#CNT_VAL} -gt 0 ] && [ $CNT_VAL -gt 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Excluded product namespace [$EXCL_NS] has [${CNT_VAL[$EXCL_NS]}] active reference(s)! Keeping..."

												if [ ${#NS_LIST_LINE} -eq 0 ]
												then
													local NS_LIST_LINE="${REF_NS}"
												else
													local NS_LIST_LINE="${NS_LIST_LINE},${REF_NS}"
												fi
											else
												echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL]..."
											fi
										done < $PROD_NAMESPACES_LIST_FILE
									else
										echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL]..."
									fi
								fi
							else
								if [ ${#NS_LIST_LINE} -eq 0 ]
								then
									local NS_LIST_LINE="${REF_NS}"
								else
									local NS_LIST_LINE="${NS_LIST_LINE},${REF_NS}"
								fi
							fi
						done
						IFS=$'\n'

						echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Writing line [${PROD_NAMESPACES_REFFILE_FINAL_PRODNAME}=${NS_LIST_LINE}] to temp file [$TMP_WORKFILE]..."
						echo "${PROD_NAMESPACES_REFFILE_FINAL_PRODNAME}=${NS_LIST_LINE}" >> $TMP_WORKFILE	
					done < $PROD_NAMESPACES_REFFILE_FINAL					

					if [ -f $TMP_WORKFILE ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Updating PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL]..."
						mv $TMP_WORKFILE $PROD_NAMESPACES_REFFILE_FINAL
					fi

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [Step #1] Content of PROD_NAMESPACES_REFFILE_FINAL =>"
						cat $PROD_NAMESPACES_REFFILE_FINAL
					fi

					# Step 2 - update PROD_NAMESPACES_KEYVAL_ARR
					if [ $BASH_V4 == "true" ]
					then
						IFS=$OLDIFS
						for PROD_NAMESPACES_KEY in ${!PROD_NAMESPACES_KEYVAL_ARR[@]}
						do
							local PROD_NAMESPACES_VAL=${PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAMESPACES_KEY]}
							local NS_LIST_LINE=
							local EXCL_NS_FOUND="false"

							for REF_NS in $(echo "$PROD_NAMESPACES_VAL" | sed 's/,/ /g')
							do
								if [ "$EXCL_NS" == "$REF_NS" ]
								then
									if [ $BASH_V4 == "true" ]
									then
										if [ ${#PROD_NAMESPACES_LIST_ARR[@]} -gt 0 ]
										then
											if [ ${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]+_} ]
											then
												if [ ${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]} -gt 0 ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] [Step #2] Excluded product namespace [$EXCL_NS] has [${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]}] active reference(s)! Keeping..."
	
													if [ ${#NS_LIST_LINE} -eq 0 ]
													then
														local NS_LIST_LINE="${REF_NS}"
													else
														local NS_LIST_LINE="${NS_LIST_LINE},${REF_NS}"
													fi
												else
													echo "[$(date)] [${FUNCNAME[0]}] [Step #2] Removing product namespace [$EXCL_NS] from array PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAMESPACES_KEY]..."
													local EXCL_NS_FOUND="true"
												fi
											else
												echo "[$(date)] [${FUNCNAME[0]}] [Step #2] Removing product namespace [$EXCL_NS] from array PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAMESPACES_KEY]..."
												local EXCL_NS_FOUND="true"
											fi
										else
											echo "[$(date)] [${FUNCNAME[0]}] [Step #2] Removing product namespace [$EXCL_NS] from array PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAMESPACES_KEY]..."
											local EXCL_NS_FOUND="true"
										fi
									else
										if [ ${#PROD_NAMESPACES_LIST_FILE} -gt 0 ] && [ -s $PROD_NAMESPACES_LIST_FILE ]
										then
											while read CNT_LINE
											do
												local CNT_NS=$(echo "$CNT_LINE" | $AWK -F= '{ print $1 }')
												local CNT_VAL=$(echo "$CNT_LINE" | $AWK -F= '{ print $2 }')
		
												if [ $MG_DEBUG == "true" ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] [Step #1] CNT_NS = [$CNT_NS] / CNT_VAL = [$CNT_VAL]"
												fi
	
												if [ ${#CNT_VAL} -gt 0 ] && [ $CNT_VAL -gt 0 ]
												then
													echo "[$(date)] [${FUNCNAME[0]}] [Step #2] Excluded product namespace [$EXCL_NS] has [${CNT_VAL[$EXCL_NS]}] active reference(s)! Keeping..."
	
													if [ ${#NS_LIST_LINE} -eq 0 ]
													then
														local NS_LIST_LINE="${REF_NS}"
													else
														local NS_LIST_LINE="${NS_LIST_LINE},${REF_NS}"
													fi
												else
													echo "[$(date)] [${FUNCNAME[0]}] [Step #2] Removing product namespace [$EXCL_NS] from array PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAMESPACES_KEY]..."
													local EXCL_NS_FOUND="true"
												fi
											done < $PROD_NAMESPACES_LIST_FILE
										else
											echo "[$(date)] [${FUNCNAME[0]}] [Step #2] Removing product namespace [$EXCL_NS] from array PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAMESPACES_KEY]..."
											local EXCL_NS_FOUND="true"
										fi
									fi
								else
									if [ ${#NS_LIST_LINE} -eq 0 ]
									then
										local NS_LIST_LINE="${REF_NS}"
									else
										local NS_LIST_LINE="${NS_LIST_LINE},${REF_NS}"
									fi
								fi
							done

							if [ $EXCL_NS_FOUND == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [Step #2] Updating PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAMESPACES_KEY] to [$NS_LIST_LINE]..."
								PROD_NAMESPACES_KEYVAL_ARR[$PROD_NAMESPACES_KEY]="$NS_LIST_LINE"
							fi
						done
						IFS=$'\n'

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [Step #2] Content of PROD_NAMESPACES_KEYVAL_ARR =>"
				
							for KEY in ${!PROD_NAMESPACES_KEYVAL_ARR[@]}
							do
								echo "PROD_NAMESPACES_KEYVAL_ARR[$KEY] = [${PROD_NAMESPACES_KEYVAL_ARR[$KEY]}]"
							done
						fi
					fi

					# Step 3 - update PROD_NAMESPACES_UNIQUE_REFFILE
					local TMP_WORKFILE=$(dirname $PROD_NAMESPACES_UNIQUE_REFFILE)/$(basename $PROD_NAMESPACES_UNIQUE_REFFILE).tmp
						
					if [ -s $PROD_NAMESPACES_UNIQUE_REFFILE ]
					then
						while read REF_LINE
						do
							if [ "$EXCL_NS" == "$REF_LINE" ]
							then
								# Check whether the excluded product namespace has no more references
								if [ $BASH_V4 == "true" ]
								then
									if [ ${#PROD_NAMESPACES_LIST_ARR[@]} -gt 0 ]
									then
										if [ ${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]+_} ]
										then
											if [ ${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]} -gt 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Excluded product namespace [$EXCL_NS] has [${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]}] active reference(s)! Keeping..."
												echo "$REF_LINE" >> $TMP_WORKFILE
											else
												echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_UNIQUE_REFFILE..."	
											fi
										else
											echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_UNIQUE_REFFILE..."	
										fi
									else
										echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_UNIQUE_REFFILE..."	
									fi
								else
									if [ ${#PROD_NAMESPACES_LIST_FILE} -gt 0 ] && [ -s $PROD_NAMESPACES_LIST_FILE ]
									then
										while read CNT_LINE
										do
											local CNT_NS=$(echo "$CNT_LINE" | $AWK -F= '{ print $1 }')
											local CNT_VAL=$(echo "$CNT_LINE" | $AWK -F= '{ print $2 }')
	
											if [ $MG_DEBUG == "true" ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [Step #3] CNT_NS = [$CNT_NS] / CNT_VAL = [$CNT_VAL]"
											fi

											if [ ${#CNT_VAL} -gt 0 ] && [ $CNT_VAL -gt 0 ]
											then
												echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Excluded product namespace [$EXCL_NS] has [${CNT_VAL[$EXCL_NS]}] active reference(s)! Keeping..."
												echo "$REF_LINE" >> $TMP_WORKFILE
											else
												echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_UNIQUE_REFFILE..."	
											fi
										done < $PROD_NAMESPACES_LIST_FILE
									else
										echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_UNIQUE_REFFILE..."	
									fi
								fi
							else
								echo "$REF_LINE" >> $TMP_WORKFILE
							fi
						done < $PROD_NAMESPACES_UNIQUE_REFFILE
					else
						 echo "[$(date)] [${FUNCNAME[0]}] [Step #3] PROD_NAMESPACES_UNIQUE_REFFILE [$PROD_NAMESPACES_UNIQUE_REFFILE] does not exist or is zero-sized!"
					fi
				
					if [ -f $TMP_WORKFILE ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Updating PROD_NAMESPACES_UNIQUE_REFFILE [$PROD_NAMESPACES_UNIQUE_REFFILE]..."
						mv $TMP_WORKFILE $PROD_NAMESPACES_UNIQUE_REFFILE

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Latest PROD_NAMESPACES_UNIQUE_REFFILE [$PROD_NAMESPACES_UNIQUE_REFFILE] => "
							cat $PROD_NAMESPACES_UNIQUE_REFFILE
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] [Step #3] TMP_WORKFILE [$TMP_WORKFILE] does not exist! Removing PROD_NAMESPACES_UNIQUE_REFFILE [$PROD_NAMESPACES_UNIQUE_REFFILE]..."
						rm $PROD_NAMESPACES_UNIQUE_REFFILE
					fi

					# Step 4 - update EXCL_PROD_NS global variable
					# Check whether the excluded product namespace has no more references
					local TO_UPDATE_EXCL_PROD_NS="true"

					if [ $BASH_V4 == "true" ]
					then
						if [ ${#PROD_NAMESPACES_LIST_ARR[@]} -gt 0 ]
						then
							if [ ${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]+_} ]
							then
								if [ ${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]} -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [Step #4] Excluded product namespace [$EXCL_NS] has [${PROD_NAMESPACES_LIST_ARR[$EXCL_NS]}] active reference(s)! Keeping..."
									local TO_UPDATE_EXCL_PROD_NS="false"
								else
									echo "[$(date)] [${FUNCNAME[0]}] [Step #4] [1] To update EXCL_PROD_NS with product namespace [$EXCL_NS]..."
								fi
							else
								echo "[$(date)] [${FUNCNAME[0]}] [Step #4] [2] To update EXCL_PROD_NS with product namespace [$EXCL_NS]..."
							fi
						else	
							echo "[$(date)] [${FUNCNAME[0]}] [Step #4] [3] To update EXCL_PROD_NS with product namespace [$EXCL_NS]..."
						fi
					else
						if [ ${#PROD_NAMESPACES_LIST_FILE} -gt 0 ] && [ -s PROD_NAMESPACES_LIST_FILE ]
						then
							while read CNT_LINE
							do
								local CNT_NS=$(echo "$CNT_LINE" | $AWK -F= '{ print $1 }')
								local CNT_VAL=$(echo "$CNT_LINE" | $AWK -F= '{ print $2 }')

								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [Step #3] CNT_NS = [$CNT_NS] / CNT_VAL = [$CNT_VAL]"
								fi

								if [ ${#CNT_VAL} -gt 0 ] && [ $CNT_VAL -gt 0 ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Excluded product namespace [$EXCL_NS] has [${CNT_VAL[$EXCL_NS]}] active reference(s)! Keeping..."
									local TO_UPDATE_EXCL_PROD_NS="false"
								else
									echo "[$(date)] [${FUNCNAME[0]}] [Step #3] Removing product namespace [$EXCL_NS] from file PROD_NAMESPACES_UNIQUE_REFFILE..."	
								fi
							done < $PROD_NAMESPACES_LIST_FILE
						else
							echo "[$(date)] [${FUNCNAME[0]}] [Step #4] [] To update EXCL_PROD_NS with product namespace [$EXCL_NS]..."
						fi
					fi

					if [ $TO_UPDATE_EXCL_PROD_NS == "true" ]
					then
						if [ ${#RTVAR_EXCL_PROD_NS} -eq 0 ]
						then
							RTVAR_EXCL_PROD_NS="$EXCL_NS"
							echo "[$(date)] [${FUNCNAME[0]}] [Step #4] Adding excluded product namespace [$EXCL_NS] into EXCL_PROD_NS global variable [$RTVAR_EXCL_PROD_NS]..."
						else
							local EXCL_PROD_NS_FOUND="false"
	
							IFS=$OLDIFS
							for EXCL_PROD_NS in $(echo "$RTVAR_EXCL_PROD_NS" | sed 's/,/ /g')
							do
								if [ "$EXCL_PROD_NS" == "$EXCL_NS" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [Step #4] Excluded product namespace [$EXCL_NS] is already in global variable EXCL_PROD_NS! Not adding..."
									local EXCL_PROD_NS_FOUND="true"
									break
								fi
							done
							IFS=$'\n'
	
							if [ $EXCL_PROD_NS_FOUND == "false" ]
							then
								RTVAR_EXCL_PROD_NS="${RTVAR_EXCL_PROD_NS},${EXCL_NS}"
								echo "[$(date)] [${FUNCNAME[0]}] [Step #4] Adding excluded product namespace [$EXCL_NS] into EXCL_PROD_NS global variable [$RTVAR_EXCL_PROD_NS]..."
							fi
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] [Step #4] TO_UPDATE_EXCL_PROD_NS = [$TO_UPDATE_EXCL_PROD_NS]"
					fi
				done
			done	
			IFS=$'\n'

			# Step 5 - update PROD_NAMESPACES_UNIQUE and PROD_NAMESPACES_UNIQUE_STR
			if [ -s $PROD_NAMESPACES_UNIQUE_REFFILE ]
			then
				# First clear and rebuild PROD_NAMESPACES_UNIQUE
				echo "[$(date)] [${FUNCNAME[0]}] [Step #5] Resetting PROD_NAMESPACES_UNIQUE array..."
				unset PROD_NAMESPACES_UNIQUE

				for VALID_NS in $(sort $PROD_NAMESPACES_UNIQUE_REFFILE | uniq)
				do
					echo "[$(date)] [${FUNCNAME[0]}] [Step #5] Adding namespace [$VALID_NS] into PROD_NAMESPACES_UNIQUE array!"
					PROD_NAMESPACES_UNIQUE[${#PROD_NAMESPACES_UNIQUE[@]}]=$VALID_NS
					# echo "$VALID_NS" >> $PROD_NAMESPACES_UNIQUE_REFFILE
				done

				if [ ${#PROD_NAMESPACES_UNIQUE} -gt 0 ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [Step #5] Setting PROD_NAMESPACES_UNIQUE_STR to [${PROD_NAMESPACES_UNIQUE[@]}..."
					PROD_NAMESPACES_UNIQUE_STR=${PROD_NAMESPACES_UNIQUE[@]}
				fi

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [Step #5] PROD_NAMESPACES_UNIQUE =>"
					for UNIQUE_NS_ITEM in ${PROD_NAMESPACES_UNIQUE[@]}
					do
						echo "$UNIQUE_NS_ITEM"
					done
				fi
			else
				echo "[$(date)] [${FUNCNAME[0]}] [Step #5] PROD_NAMESPACES_UNIQUE_REFFILE [$PROD_NAMESPACES_UNIQUE_REFFILE] does not exist or is zero-sized! PROD_NAMESPACES_UNIQUE array will be empty!"
			fi

			# Step 6 - update PRODUCT_VERSION and MISSINGOBJ_VERSION
			if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
			then	
				echo "[$(date)] [${FUNCNAME[0]}] [Step #6] Checking whether PRODUCT_VERSION and MISSINGOBJ_VERSION need to be updated..."

				local IS_PROD_VER_FOUND="false"
				local LATEST_PRODVER_FILE=
				local NEWEST_VER_IDX=

				while read REF_LINE
				do
					local PROD_GROUP=$(echo "$REF_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
					local PROD_VER=$(echo "$REF_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
					local PROD_NS=$(echo "$REF_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $3 }')
					
					if [ "$PRODUCT_VERSION" == "$PROD_VER" ]
					then
						local IS_PROD_VER_FOUND="true"
						break
					fi

					local CUR_VER_IDX=0
					local VALID_VER_FOUND="false"
					
					for VALID_PROD_VER in ${PRODUCT_SUPPORTED_VERSION[@]}
					do
						if [ $VALID_PROD_VER == $PROD_VER ]
						then
							local VALID_VER_FOUND="true"
					
							if [ ${#NEWEST_VER_IDX} -eq 0 ]
							then
								local NEWEST_VER_IDX=$CUR_VER_IDX
					
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] [Step #6] [1] Current latest version = [${PRODUCT_SUPPORTED_VERSION[$NEWEST_VER_IDX]}][$NEWEST_VER_IDX]" >&2
								fi
							else
								if [ $CUR_VER_IDX -gt $NEWEST_VER_IDX ]
								then
									local NEWEST_VER_IDX=$CUR_VER_IDX
					
									if [ $MG_DEBUG == "true" ]
									then
										echo "[$(date)] [${FUNCNAME[0]}] [Step #6] [2] Current latest version = [${PRODUCT_SUPPORTED_VERSION[$NEWEST_VER_IDX]}][$NEWEST_VER_IDX]" >&2
									fi
								fi
							fi
					
							break
						fi
					
						(( CUR_VER_IDX=CUR_VER_IDX+1 ))
					done
				done < $PROD_VERSIONS_REFFILE_FINAL

				if [ $IS_PROD_VER_FOUND == "true" ]
				then
					 echo "[$(date)] [${FUNCNAME[0]}] [Step #6] PRODUCT_VERSION [$PRODUCT_VERSION] is found in PROD_VERSIONS_REFFILE_FINAL [$PROD_VERSIONS_REFFILE_FINAL]! Keeping..."
				else
					if [ ${#NEWEST_VER_IDX} -eq 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [Step #6] NEWEST_VER_IDX is empty/null! Unable to reset PRODUCT_VERSION!"
					else
						PRODUCT_VERSION=${PRODUCT_SUPPORTED_VERSION[$NEWEST_VER_IDX]}	
						echo "[$(date)] [${FUNCNAME[0]}] [Step #6] Resetting PRODUCT_VERSION to [$PRODUCT_VERSION]..."

						if [ $USERSET_MISSINGOBJ_VERSION -eq 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [Step #6] Resetting MISSINGOBJ_VERSION to [$PRODUCT_VERSION]..."
							MISSINGOBJ_VERSION=$PRODUCT_VERSION
						fi
					fi
				fi
			fi

			# Step 7 - Updating PROD_VERSIONS_UNIQUE_REFFILE and PROD_VERSIONS_UNIQUE array
			if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [Step #5] Resetting PROD_NAMESPACES_UNIQUE array..."
				unset PROD_NAMESPACES_UNIQUE

				local TMP_PROD_VER_FILE=${PROD_VERSIONS_REFFILE_FINAL}.tmp

				while read REF_LINE
				do
					local PROD_VER=$(echo "$REF_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
					echo "$PROD_VER" >> $TMP_PROD_VER_FILE
				done	

				if [ -f $TMP_PROD_VER_FILE ]
				then
					sort $TMP_PROD_VER_FILE | uniq > $PROD_VERSIONS_UNIQUE_REFFILE

					if [ -s $PROD_VERSIONS_UNIQUE_REFFILE ]
					then
						if [ $BASH_V4 == "true" ]
						then
							mapfile -t PROD_VERSIONS_UNIQUE < $PROD_VERSIONS_UNIQUE_REFFILE
						else
							PROD_VERSIONS_UNIQUE=( $(cat $PROD_VERSIONS_UNIQUE_REFFILE) )
						fi

						if [ ${#PROD_VERSIONS_UNIQUE} -gt 0 ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [Step #7] Setting PROD_VERSIONS_UNIQUE_STR to [${PROD_VERSIONS_UNIQUE[@]}..."
							PROD_VERSIONS_UNIQUE_STR=${PROD_VERSIONS_UNIQUE[@]}
						fi

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] [Step #7] PROD_VERSIONS_UNIQUE =>"
							for UNIQUE_VER_ITEM in ${PROD_VERSIONS_UNIQUE[@]}
							do
								echo "$UNIQUE_VER_ITEM"
							done
						fi
					else
						echo "[$(date)] [${FUNCNAME[0]}] [Step #7] File PROD_VERSIONS_UNIQUE_REFFILE [$PROD_VERSIONS_UNIQUE_REFFILE] does not exist or is zero-sized!"
					fi
				else		
					echo "[$(date)] [${FUNCNAME[0]}] [Step #7] File TMP_PROD_VER_FILE [$TMP_PROD_VER_FILE] does not exist or is zero-sized!"
				fi	
			fi
		fi

		if [ $PROD_GROUP_COUNT -eq 0 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Product group count = [$PROD_GROUP_COUNT]! Setting PROD_GROUP_REFFILE_SUCC to [false]!"
			PROD_GROUP_REFFILE_SUCC="false"
		else
			if [ $PROD_GROUP_COUNT -gt 1 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] More than one(1) product groups detected! Setting PROD_VERSIONS_SINGLE_PRODGROUP to [false]!"
				PROD_VERSIONS_SINGLE_PRODGROUP="false"
			else
				# PROD_GROUP_COUNT == 1
				if [ $ANY_PROD_GROUP_EXCLUDED == "true" ]
				then
					# Set to 'false' because there are actually more than 1 product groups
					echo "[$(date)] [${FUNCNAME[0]}] Some product groups are excluded causing final count to be one(1)! Setting PROD_VERSIONS_SINGLE_PRODGROUP to [true]!"
					PROD_VERSIONS_SINGLE_PRODGROUP="true"
				fi
			fi

			echo "[$(date)] [${FUNCNAME[0]}] Product group count = [$PROD_GROUP_COUNT]! Setting PROD_GROUP_REFFILE_SUCC to [true]!"
			local PROD_GROUP_REFFILE_SUCC="true"
		fi

		# Create PROD_VERSIONS_UNIQUE_REFFILE and PROD_VERSIONS_UNIQUE array
		if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
		then	
			unset PROD_VERSIONS_UNIQUE
			local TMP_PROD_VERSIONS_UNIQUE_REFFILE=${PROD_VERSIONS_UNIQUE_REFFILE}.tmp

			while read REF_LINE
			do
				local PROD_VER=$(echo "$REF_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
				echo "$PROD_VER" >> $TMP_PROD_VERSIONS_UNIQUE_REFFILE
			done < $PROD_VERSIONS_REFFILE_FINAL	

			if [ -s $TMP_PROD_VERSIONS_UNIQUE_REFFILE ]
			then
				sort $TMP_PROD_VERSIONS_UNIQUE_REFFILE | uniq > $PROD_VERSIONS_UNIQUE_REFFILE
				
				if [ $BASH_V4 == "true" ]
				then
					mapfile -t PROD_VERSIONS_UNIQUE < $PROD_VERSIONS_UNIQUE_REFFILE
				else
					PROD_VERSIONS_UNIQUE=( $(cat $PROD_VERSIONS_UNIQUE_REFFILE) )
				fi

				if [ ${#PROD_VERSIONS_UNIQUE[@]} -gt 0 ]
				then
					PROD_VERSIONS_UNIQUE_STR="${PROD_VERSIONS_UNIQUE[@]}"
				fi

				echo "[$(date)] [${FUNCNAME[0]}] PROD_VERSIONS_UNIQUE_REFFILE [$PROD_VERSIONS_UNIQUE_REFFILE][LEN=$(wc -l < $PROD_VERSIONS_UNIQUE_REFFILE)] and PROD_VERSIONS_UNIQUE [SIZE=${#PROD_VERSIONS_UNIQUE[@]}] created!"	

				rm $TMP_PROD_VERSIONS_UNIQUE_REFFILE
			else
				echo "[$(date)] [${FUNCNAME[0]}] TMP_PROD_VERSIONS_UNIQUE_REFFILE [$TMP_PROD_VERSIONS_UNIQUE_REFFILE] does not exist or is zero-sized!"

				if [ -f $TMP_PROD_VERSIONS_UNIQUE_REFFILE ]
				then
					rm $TMP_PROD_VERSIONS_UNIQUE_REFFILE
				fi
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] [Step #7] PROD_VERSIONS_REFFILE_FINAL does not exist or is zero-sized! Unable to create PROD_VERSIONS_UNIQUE_REFFILE and PROD_VERSIONS_UNIQUE array!"
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] Product version reference file [${PROD_VERSIONS_REFFILE}] does not exist or is zero-sized!"
		local PROD_GROUP_REFFILE_SUCC="false"
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] DEFAULT_PROD_VERSION_SUCC = [$DEFAULT_PROD_VERSION_SUCC] / PROD_GROUP_REFFILE_SUCC = [$PROD_GROUP_REFFILE_SUCC]"
	fi

	if [ $DEFAULT_PROD_VERSION_SUCC == "false" ] || [ $PROD_GROUP_REFFILE_SUCC == "false" ]
	then
		return 1
	else
		return 0
	fi
}

getAllProdGroups()
{
	local INFILE=$1

	if [ ${#INFILE} -gt 0 ]
	then
		if [ -s $INFILE ]
		then
			local REFFILE=$INFILE
		else
			echo "[$(date)] [${FUNCNAME[0]}] INFILE [$INFILE] does not exist or is zero-sized! Setting INFILE to [$PROD_VERSIONS_REFFILE_FINAL]..." >&2
			local REFFILE=$PROD_VERSIONS_REFFILE_FINAL
		fi

		if [ -s $REFFILE ]
		then
			local RETVAL=
	
			while read LINE
			do
				local PRODGROUP=$(echo "$LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
				
				if [ ${#RETVAL} -eq 0 ]
				then
					local RETVAL="$PRODGROUP"
				else
					local RETVAL="$RETVAL $PRODGROUP"
				fi
			done < $REFFILE
	
			if [ ${#RETVAL} -gt 0 ]
			then
				echo "$RETVAL"
				return 0
			else
				echo "$PROD_GROUPS_INVALID_STR"
				return 1
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] REFFILE [$REFFILE] does not exist or is zero-sized!" >&2
			echo "$PROD_GROUPS_INVALID_STR"
			return 1
		fi
	else
		if [ ${#PROD_GROUPS_ARR[@]} -gt 0 ]
		then
			echo "${PROD_GROUPS_ARR[@]}"
			return 0
		else
			echo "$PROD_GROUPS_INVALID_STR"
			return 1
		fi
	fi
}

getProdGroupRefFile()
{
	local PRODGROUP=$1
	local REFFILE=$REFFILE_OUTDIR/${PRODGROUP}.ns-ref

	if [ -s "$REFFILE" ]
	then
		echo "$REFFILE"
		return 0
	else
		echo "$PROD_GROUPS_INVALID_STR"	
		return 1
	fi
}

getProdGroupThruNamespace()
{
	local PRODNAME=$1
	local NS=$2

	local RETVAL=

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] PRODNAME = [$PRODNAME] / NS = [$NS]" >&2
	fi

	if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
	then
		while read REFLINE
		do
			local IN_PROD_GROUP=$(echo "$REFLINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
			local IN_PROD_VER=$(echo "$REFLINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
			local IN_PROD_NS=$(echo "$REFLINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $3 }')
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] IN_PROD_GROUP = [$IN_PROD_GROUP] / IN_PROD_VER = [$IN_PROD_VER] / IN_PROD_NS = [$IN_PROD_NS]" >&2
			fi

			IFS=$OLDIFS
			for NS_LINE in $(echo "$IN_PROD_NS" | sed 's#'${PROD_REFFILE_NS_DELIMITER}'# #g')
			do
				local TO_CONTINUE="true"

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] NS_LINE = [$NS_LINE]" >&2
				fi

				local PROD_NAME=$(echo "$NS_LINE" | $AWK -F= '{ print $1 }')
				local PROD_NS=$(echo "$NS_LINE" | $AWK -F= '{ print $2 }')

				if [ "$PRODNAME" == "$PROD_NAME" ]
				then
					for MATCH_PROD_NS in $(echo "$PROD_NS" | sed 's/,/ /g')
					do
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] MATCH_PROD_NS = [$MATCH_PROD_NS]" >&2
						fi

						if [ "$NS" == "$MATCH_PROD_NS" ]
						then
							if [ ${#RETVAL} -eq 0 ]
							then
								local RETVAL="$IN_PROD_GROUP"
							else
								local RETVAL="$RETVAL $IN_PROD_GROUP"
							fi

							local TO_CONTINUE="false"
							break
						fi
					done
				fi

				if [ $TO_CONTINUE == "false" ]
				then
					break
				fi
			done
			IFS=$'\n'	
		done < $PROD_VERSIONS_REFFILE_FINAL

		echo "[$(date)] [${FUNCNAME[0]}] Product group returned = [$RETVAL]" >&2
		echo "$RETVAL"
	else
		echo "[$(date)] [${FUNCNAME[0]}] PROD_VERSIONS_REFFILE_FINAL [$PROD_VERSIONS_REFFILE_FINAL] does not exist or is zero-sized!" >&2
		echo
		return 1
	fi
}

getProdVersionThruProdGroup()
{
	local PRODGROUP=$1
	local IS_FOUND="false"

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] PRODGROUP = [$PRODGROUP]" >&2
	fi

	if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
	then
		while read REFLINE
		do
			local IN_PROD_GROUP=$(echo "$REFLINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
			local IN_PROD_VER=$(echo "$REFLINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] IN_PROD_GROUP = [$IN_PROD_GROUP] / IN_PROD_VER = [$IN_PROD_VER]" >&2
			fi

			if [ "$PRODGROUP" == "$IN_PROD_GROUP" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Product version returned = [$IN_PROD_VER]" >&2
				echo "$IN_PROD_VER"
				local IS_FOUND="true"
				break
			fi	
		done < $PROD_VERSIONS_REFFILE_FINAL

		if [ $IS_FOUND == "false" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Product version returned = []" >&2
			echo
			return 1
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] PROD_VERSIONS_REFFILE_FINAL [$PROD_VERSIONS_REFFILE_FINAL] does not exist or is zero-sized!" >&2
		echo
		return 1
	fi
}

getSecData()
{
	MODE=$1
	echo "[$(date)] [${FUNCNAME[0]}] Executing in mode [$MODE]..."

	local EXEC_MISS_OBJ="false"

	case "$MODE" in
		all)
			if [ ${#MISSINGOBJ_FOR_GETALL} -gt 0 ] && [ ${MISSINGOBJ_FOR_GETALL} == "true" ]
			then
				local EXEC_MISS_OBJ="true"
			fi
			;;
		comprehensive)
			if [ ${#MISSINGOBJ_FOR_GETCOMPREHENSIVE} -gt 0 ] && [ ${MISSINGOBJ_FOR_GETCOMPREHENSIVE} == "true" ]
			then
				local EXEC_MISS_OBJ="true"
			fi
			;;
		basic)
			if [ ${#MISSINGOBJ_FOR_GETBASIC} -gt 0 ] && [ ${MISSINGOBJ_FOR_GETBASIC} == "true" ]
			then
				local EXEC_MISS_OBJ="true"
			fi
			;;
		limited)
			if [ ${#MISSINGOBJ_FOR_GETLIMITED} -gt 0 ] && [ ${MISSINGOBJ_FOR_GETLIMITED} == "true" ]
			then
				local EXEC_MISS_OBJ="true"
			fi
			;;
		selective)
			if [ ${#MISSINGOBJ_FOR_GETSELECTIVE} -gt 0 ] && [ ${MISSINGOBJ_FOR_GETSELECTIVE} == "true" ]
			then
				local EXEC_MISS_OBJ="true"
			fi

			if [ ${#RTVAR_SELECTIVE_CUSTOM_DATA} -gt 0 ] && [ ${RTVAR_SELECTIVE_CUSTOM_DATA} == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Setting CUSTOM_DATA_ENABLED to [true]..."
				CUSTOM_DATA_ENABLED="true"
			fi
			;;
		modules)
			if [ ${#MISSINGOBJ_FOR_GETMODULES} -gt 0 ] && [ ${MISSINGOBJ_FOR_GETMODULES} == "true" ]
			then
				local EXEC_MISS_OBJ="false"
			fi
			;;
	esac

	# Priority is given to addres config file of executing primary mode
	if [ -s $MUSTGATHER_DIRNAME/config/addres-${MODE}.cfg ]
	then	
		local ADDRES_CFGFILE="$MUSTGATHER_DIRNAME/config/addres-${MODE}.cfg"
	else
		local ADDRES_CFGFILE="$MUSTGATHER_DIRNAME/config/addres.cfg"
	fi

	local ADDRES=

	# To collect data for additional resources if ADDRES_CFGFILE exists
	if [ -s $ADDRES_CFGFILE ]
	then
		IFS=$OLDIFS
		local LINE_CTR=0

		echo "[$(date)] [${FUNCNAME[0]}] ADDRES_CFGFILE [$ADDRES_CFGFILE] exists. To collect data for additional resources..."

		for ADDRES_LINE in $(cat $ADDRES_CFGFILE | grep -E -v '^[ ]*'${ADDRES_CFGFILE_COMMENT}'|^$|^[ ]*$')
		do
			(( LINE_CTR=LINE_CTR+1 ))

			local ADDRES=$(echo "$ADDRES_LINE" | $AWK -F"${ADDRES_CFGFILE_DELIMITER}" '{ print $1 }')
			local SCOPE=$(echo "$ADDRES_LINE" | $AWK -F"${ADDRES_CFGFILE_DELIMITER}" '{ print $2 }')

			if [ $MG_DEBUG == "true" ]
			then
				 echo "[$(date)] [${FUNCNAME[0]}] ADDRES = [$ADDRES] / SCOPE = [$SCOPE]"
			fi

			if [ ${#SCOPE} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Collecting data for resource [$ADDRES]..."
				getAddResData "$ADDRES"
			else
				echo "[$(date)] [${FUNCNAME[0]}] Collecting data for resource [$ADDRES] with scope [$SCOPE]..."
				getAddResData "$ADDRES/$SCOPE"
			fi
		done

		echo "[$(date)] [${FUNCNAME[0]}] Total additional resource processed = [$LINE_CTR]"

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up ADDRES_CFGFILE [$ADDRES_CFGFILE] to directory [$DEBUG_OUTDIR/addres]..."

			if [ ! -d $DEBUG_OUTDIR/addres ]
			then
				mkdir -p $DEBUG_OUTDIR/addres
			fi

			cp -p $ADDRES_CFGFILE $DEBUG_OUTDIR/addres
		fi
	fi

	# To collect data for additional resources provided by user dynamically during runtime (-W "ADDRES=")
	if [ ${#RTVAR_ADDRES} -gt 0 ]
	then
		IFS=$OLDIFS
		local LINE_CTR=0

		echo "[$(date)] [${FUNCNAME[0]}] RTVAR_ADDRES variable is set [$RTVAR_ADDRES] exists. To collect data for additional resources..."

		for ADDRES_LINE in $(echo "$RTVAR_ADDRES" | sed 's/,/ /g')
		do
			(( LINE_CTR=LINE_CTR+1 ))

			local ADDRES=$(echo "$ADDRES_LINE" | $AWK -F"${ADDRES_CFGFILE_DELIMITER}" '{ print $1 }')
			local SCOPE=$(echo "$ADDRES_LINE" | $AWK -F"${ADDRES_CFGFILE_DELIMITER}" '{ print $2 }')

			if [ $MG_DEBUG == "true" ]
			then
				 echo "[$(date)] [${FUNCNAME[0]}] ADDRES = [$ADDRES] / SCOPE = [$SCOPE]"
			fi

			if [ ${#SCOPE} -eq 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Collecting data for resource [$ADDRES]"
				getAddResData "$ADDRES"
			else
				echo "[$(date)] [${FUNCNAME[0]}] Collecting data for resource [$ADDRES] with scope [$SCOPE]..."
				getAddResData "$ADDRES/$SCOPE"
			fi
		done

		echo "[$(date)] [${FUNCNAME[0]}] Total additional resource processed = [$LINE_CTR]"
	fi

	if [ ${CUSTOM_DATA_ENABLED} == "true" ]
	then
		if [ ${#RTVAR_DISABLE_CUSTOM_DATA} -gt 0 ] && [ ${RTVAR_DISABLE_CUSTOM_DATA} == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] DISABLE_CUSTOM_DATA is set to [$RTVAR_DISABLE_CUSTOM_DATA]. Skipping execution of user-defined custom data collection..."
		else
			if [[ $(type -t getCustomData) == function ]]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing user-defined custom data collection..."
				getCustomData
			else
				echo "[$(date)] [${FUNCNAME[0]}] No user-defined custom data collection function [getCustomData()] detected. Skipping..."
			fi
		fi
	else
		echo "[$(date)] [${FUNCNAME[0]}] CUSTOM_DATA_ENABLED is set to [$CUSTOM_DATA_ENABLED]. Skipping execution of user-defined custom data collection..."
	fi

	if [ ${#RTVAR_DISABLE_SEC_DATA} -gt 0 ] && [ ${RTVAR_DISABLE_SEC_DATA} == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] DISABLE_SEC_DATA is set to [$RTVAR_DISABLE_SEC_DATA]. Skipping all secondary mode(s) data collection..."
	else
		if [ ${GET_NODES_DATA} == "true" ]
		then
			getNodesData
		fi
	
		if [ ${CMD_EXEC} == "true" ]
		then
			runCmdExec
		fi
		
		if [ ${MANUAL_COLL} -eq 1 ]
		then
			doManualCollection
		fi
		
		if [ ${EXTRA_NAMESPACES}x != "x" ]
		then
			getAllExtraNS $EXTRA_NAMESPACES
		fi
		
		if [ $GET_MISS_OBJ == "true" ] || [ $EXEC_MISS_OBJ == "true" ]
		then
			doMissingObjects
		fi
	
		if [ $GET_COMPLIANCE == "true" ]
		then
			doCompliance
		fi
	
		if [ ${#PLUGINS} -gt 0 ]
		then
			doPlugins
		fi
		
		if [ ${CPFILES_ENABLED} == "true" ]
		then
			doCpFiles
		fi

		if [ ${DIFF_SNAPSHOTS} == "true" ]
		then
			doSnapshots
		fi
	fi

	if [ ${#GREP_PATTERN} -gt 0 ]
	then
		grepPattern
	fi

	if [ ${GET_DEPENDENCY_DATA} == "true" ]
	then
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
		do
			getPodDependencyData $DEP_PROD_NS 
		done
	
		# Pod to pod data link data
		for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]}
		do
			getPod2PodLinkData $DEP_PROD_NS 
		done
	fi

	if [ ${INCIDENT_REPORT_ENABLED} == "true" ]
	then
		analyzeIncident
	fi

	# To check whether postDataCollect() function is implemented in config/product.sh
	if [[ $(type -t postDataCollect) == function ]]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Executing user implemented function - postDataCollect()..." 

		if [ ! -d $POST_DATA_COLLECT_OUTDIR ]
		then
			mkdir -p $POST_DATA_COLLECT_OUTDIR
		fi

		postDataCollect

		echo "[$(date)] [${FUNCNAME[0]}] User implemented function ended - postDataCollect()..."	
	else
		echo "[$(date)] [${FUNCNAME[0]}] Function postDataCollect() is not implemented! Skipping..."	
	fi
}

getAddResData()
{
	local RESOURCE=$(echo "$1" | $AWK -F/ '{ print tolower($1) }')
	local SCOPE=$(echo "$1" | $AWK -F/ '{ print tolower($2) }')

	local IS_NAMESPACED
	IS_NAMESPACED=$(isNamespaced "$RESOURCE")
	ADDRES_EXITCODE=$?

	local NS=
	unset SCOPE_ARR

	if [ ${#SCOPE} -eq 0 ]
	then
		if [ $ADDRES_EXITCODE -eq 0 ]
		then
			if [ $IS_NAMESPACED -eq 0 ]
			then
				# Default collection scope is all product namespaces
				echo "[$(date)] [${FUNCNAME[0]}] RESOURCE = [$RESOURCE] / SCOPE = [${PROD_NAMESPACES_UNIQUE[@]}]"
				local SCOPE_ARR=${PROD_NAMESPACES_UNIQUE[@]}
			else
				# Assume resource type is cluster-scoped
				echo "[$(date)] [${FUNCNAME[0]}] RESOURCE = [$RESOURCE] / SCOPE = [cluster]"
				local SCOPE_ARR=()
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] RESOURCE = [$RESOURCE]"
			local SCOPE_ARR=()
		fi
	else
		if [ $SCOPE == "allns" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] RESOURCE = [$RESOURCE] / SCOPE = [$SCOPE]"
			local SCOPE_ARR=("allns")
		else
			if ! checkUserPriv get ns all 
			then
				echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have [get] privilege on resource [namespace] at cluster scope! Assuming namespace [$SCOPE] is valid..."
				echo "[$(date)] [${FUNCNAME[0]}] RESOURCE = [$RESOURCE] / SCOPE = [$SCOPE]"

				for CUR_SCOPE in $(echo "$SCOPE" | sed 's/@@/\n/g' | sort | uniq)
				do
					if [ "$CUR_SCOPE" == "allns" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] SCOPE [allns] supersede all other namespaces! Resetting CUR_SCOPE to only [allns]!"
						local SCOPE_ARR=("allns")
					else
						local SCOPE_ARR[${#SCOPE_ARR[@]}]="$CUR_SCOPE"
					fi
				done
			else
				# SCOPE = tolower(), so NS4PROD= will become ns4prod=
				if [[ "$SCOPE" =~ ns4prod= ]]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Processing SCOPE [$SCOPE]..."

					local NEW_SCOPE=

					for CUR_SCOPE in $(echo "$SCOPE" | sed 's/@@/\n/g' | sort | uniq)
					do
						if [[ "$CUR_SCOPE" =~ ^ns4prod= ]]
						then
							local CUR_SCOPE_PROD_NAME=$(echo "$CUR_SCOPE" | $AWK -F= '{ print $2 }')
							local CUR_SCOPE_NS_LIST=$(getProdToNamespacesMapping "$CUR_SCOPE_PROD_NAME")

							if [ ${#CUR_SCOPE_NS_LIST} -gt 0 ]
							then
								if [ "${CUR_SCOPE_NS_LIST}" != "$PROD_NAMESPACES_INVALID_STR" ]
								then
									local CUR_SCOPE_NS_LIST=$(echo "$CUR_SCOPE_NS_LIST" | sed 's/ /@@/g')
								else
									local CUR_SCOPE_NS_LIST=
								fi
							fi

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] CUR_SCOPE_PROD_NAME = [$CUR_SCOPE_PROD_NAME] / CUR_SCOPE_NS_LIST = [$CUR_SCOPE_NS_LIST]"
							fi
						else
							local CUR_SCOPE_NS_LIST="$CUR_SCOPE"
						fi

						if [ ${#CUR_SCOPE_NS_LIST} -gt 0 ]
						then
							if [ ${#NEW_SCOPE} -eq 0 ]
							then
								local NEW_SCOPE="$CUR_SCOPE_NS_LIST"
							else
								local NEW_SCOPE="${NEW_SCOPE}@@${CUR_SCOPE_NS_LIST}"
							fi
						else
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] CUR_SCOPE_NS_LIST is empty/null!"
							fi
						fi
					done

					local SCOPE="$NEW_SCOPE"
					echo "[$(date)] [${FUNCNAME[0]}] Processed SCOPE variable = [$SCOPE]"
				fi

				for CUR_SCOPE in $(echo "$SCOPE" | sed 's/@@/\n/g' | sort | uniq)
				do
					if [ "$CUR_SCOPE" == "allns" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] SCOPE [allns] supersede all other namespaces! Resetting CUR_SCOPE to only [allns]!"
						local SCOPE_ARR=("allns")
						break
					else
						if $OC_CMD get namespace $CUR_SCOPE >/dev/null
						then
							echo "[$(date)] [${FUNCNAME[0]}] RESOURCE = [$RESOURCE] / SCOPE = [$CUR_SCOPE] is valid!"

							if toExcludeProdNamespace $CUR_SCOPE
							then
								echo "[$(date)] [${FUNCNAME[0]}] To exclude namespace [$CUR_SCOPE]. Skipping..."
								continue
							fi

							echo "[$(date)] [${FUNCNAME[0]}] Adding namespace [$CUR_SCOPE] into SCOPE_ARR [CUR_LEN=${#SCOPE_ARR[@]}]"
							local SCOPE_ARR[${#SCOPE_ARR[@]}]="$CUR_SCOPE"
						else
							echo "[$(date)] [${FUNCNAME[0]}] RESOURCE = [$RESOURCE] / SCOPE = [$CUR_SCOPE] is invalid!"
						fi			
					fi
				done
			fi
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] RESOURCE = [$RESOURCE] / IS_NAMESPACED = [$IS_NAMESPACED] / EXIT_STATUS = [$ADDRES_EXITCODE]"	
		echo "[$(date)] [${FUNCNAME[0]}] SCOPE_ARR = [${SCOPE_ARR[@]}]"
	fi

	if [ $ADDRES_EXITCODE -eq 0 ]
	then
		if [ $IS_NAMESPACED -eq 0 ]
		then
			if [ ${#SCOPE} -gt 0 ] 
			then
				for CUR_SCOPE in ${SCOPE_ARR[@]}
				do
					if [ $CUR_SCOPE == "allns" ]
					then
						local SCOPE_NS="all"
						local SCOPE_NS_STR="ALLNS"
						local SCOPE_NS_MSG="cluster level"
						local NS_OUTDIR="$CLUSTER_DATA_OUTDIR"
					else
						local SCOPE_NS="$CUR_SCOPE"
						local SCOPE_NS_STR="$CUR_SCOPE"
						local SCOPE_NS_MSG="namespace [$CUR_SCOPE]"

						if isProdNamespace "$CUR_SCOPE"
						then
							local NS_OUTDIR="$PRODUCT_DATA_OUTDIR/$CUR_SCOPE"
						else
							local NS_OUTDIR="$OTHER_NS_DATA_OUTDIR/$CUR_SCOPE"
						fi
					fi

					if ! checkUserPriv get,list $RESOURCE $SCOPE_NS
					then
						echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to execute '$OC_CMD get' on resource [$RESOURCE] on ${SCOPE_NS_STR}. Skipping..."	
						continue	
					fi
			
					if [ ! -d $NS_OUTDIR ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Making directory [$NS_OUTDIR]..."
						mkdir -p $NS_OUTDIR
					fi
				
					ocGet $RESOURCE $NS_OUTDIR/oc_${RESOURCE}.out "$SCOPE_NS_STR"
					ocDesc $RESOURCE $NS_OUTDIR/$RESOURCE "$SCOPE_NS_STR"
				done
			else
				for NS in ${PROD_NAMESPACES_UNIQUE[@]}
				do
					echo "[$(date)] [${FUNCNAME[0]}] CURRENT_PROD_NAMESPACE = [$NS]"

					if toExcludeProdNamespace $NS
					then
						echo "[$(date)] [${FUNCNAME[0]}] To exclude namespace [$NS]. Skipping..."
						continue
					fi

					if ! checkUserPriv get,list $RESOURCE $NS
					then
						echo "[$(date)] [${FUNCNAME[0]}] User [$OC_WHOAMI] does not have privilege to execute '$OC_CMD get' on resource [$RESOURCE] in namespace [$NS]. Skipping..."	
						continue	
					fi

					local NS_OUTDIR="$PRODUCT_DATA_OUTDIR/$NS"
			
					if [ ! -d $NS_OUTDIR ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Making directory [$NS_OUTDIR]..."
						mkdir -p $NS_OUTDIR
					fi
			
					ocGet $RESOURCE $NS_OUTDIR/oc_${RESOURCE}.out $NS
					ocDesc $RESOURCE $NS_OUTDIR/$RESOURCE $NS

					if [ $RESOURCE == "pvc" ] || [ $RESOURCE == "persistentvolumeclaim" ] || [ $RESOURCE == "persistentvolumeclaims" ]
					then
						analyzeOcPvc $NS $NS_OUTDIR/oc_${RESOURCE}.out $NS_OUTDIR/${RESOURCE}
					fi
				done
			fi
		else
			local NS_OUTDIR="$CLUSTER_DATA_OUTDIR"

			if [ ! -d $NS_OUTDIR ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Making directory [$NS_OUTDIR]..."
				mkdir -p $NS_OUTDIR
			fi

			ocGet $RESOURCE $NS_OUTDIR/oc_${RESOURCE}.out 
			ocDesc $RESOURCE $NS_OUTDIR/$RESOURCE
		fi
	else
		if [ $ADDRES_EXITCODE -eq 2 ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] File RES_LIST_PROCFILE [$RES_LIST_PROCFILE] does not exist or is zero-sized! Skipping..."
		else
			echo "[$(date)] [${FUNCNAME[0]}] Unable to determine whether resource [$RESOURCE] is namespaced. Skipping..."	
		fi
	fi
}

getGenericPodName()
{
	# EXIT_STATUS:
	# 0 = successful
	# 1 = failed
	# 2 = doubtful

     local IN_PODNAME=$1
     local IN_NS=$2

	local EXIT_STATUS=0


     # Parent resource (either replicaset or job)
     local PARENT_KIND=$($OC_CMD get -o=jsonpath='{.metadata.ownerReferences[0].kind}' -n $IN_NS po $IN_PODNAME)
     local PARENT_NAME=$($OC_CMD get -o=jsonpath='{.metadata.ownerReferences[0].name}' -n $IN_NS po $IN_PODNAME)

     if [ ${#PARENT_KIND} -gt 0 ]
     then
		case $PARENT_KIND in 
			ReplicaSet)	local GENERIC_PODNAME=$($OC_CMD get $PARENT_KIND $PARENT_NAME -n $IN_NS -o=jsonpath='{.metadata.ownerReferences[0].name}')
						;;
			StatefulSet)	local GENERIC_PODNAME="$PARENT_NAME"
						;;
			Job)			local JOB_PARENT=$($OC_CMD get $PARENT_KIND $PARENT_NAME -n $IN_NS -o=jsonpath='{.metadata.ownerReferences[0].kind}')

						if [ ${#JOB_PARENT} -gt 0 ]
						then
							if [ $JOB_PARENT == "CronJob" ]
							then
								local PARENT_NAME=$($OC_CMD get $PARENT_KIND $PARENT_NAME -n $IN_NS -o=jsonpath='{.metadata.ownerReferences[0].name}')
								local PARENT_KIND=$JOB_PARENT
								local GENERIC_PODNAME=$PARENT_NAME
							else
								local GENERIC_PODNAME="$PARENT_NAME"
							fi	
						else
							local GENERIC_PODNAME="$PARENT_NAME"
						fi
						;;	
			Cluster)		local GENERIC_PODNAME="$PARENT_NAME"
						;;
			*)			# Now, we are entering a guessing game (when owner is not a replicaset, statefulset or job)
						echo "[$(date)] [${FUNCNAME[0]}] PODNAME = [$IN_PODNAME] - Parent is not replicaset/statefulset/job/cluster => PARENT_KIND = [$PARENT_KIND] / PARENT_NAME = [$PARENT_NAME]" >> $RUNTIME_LOGFILE	
						local POD_STATUS=$($OC_CMD get pod $IN_PODNAME --no-headers | $AWK '{ print $3 }')
				
						# Assumed to be pod spawned by job (but ownerreferences were set manually!)
						if [ "$POD_STATUS" == "Completed" ] || [ "$POD_STATUS" == "Terminated" ]
						then
							local PARENT_FOUND="false"
				
							for JOB in $($OC_CMD get job -n $IN_NS --no-headers | $AWK '{ print $1 }')
							do
								# Vary dangerous assumption!
								if [[ "$IN_PODNAME" =~ ^${JOB} ]]
								then
									PARENT_FOUND="true"						
									local GENERIC_PODNAME=$JOB	
									EXIT_STATUS=2
								fi
							done
				
							if [ $PARENT_FOUND == "false" ]
							then
				              		local GENERIC_PODNAME="NULL"
								EXIT_STATUS=1
							fi
						else
							if [ "$POD_STATUS" == "Running" ]
							then
								local PARENT_FOUND="false"
				
								# Assumed to be pod spawned by statefulset
								if [[ $IN_PODNAME =~ -[0-9]+$ ]]
								then
									for STS in $($OC_CMD get sts -n $IN_NS --no-headers | $AWK '{ print $1 }')
									do
										# Vary dangerous assumption!
										if [[ "$IN_PODNAME" =~ ^${STS} ]]
										then
											PARENT_FOUND="true"						
											local GENERIC_PODNAME=$STS
											EXIT_STATUS=2
										fi
									done
				
									if [ $PARENT_FOUND == "false" ]
									then
										# Very last attempt of being more dangerous! 
										if [[ "$IN_PODNAME" =~ ^$PARENT_NAME ]]
										then
											local GENERIC_PODNAME=$PARENT_NAME
											EXIT_STATUS=2
										else
				    			       			local GENERIC_PODNAME="NULL"
											EXIT_STATUS=1
										fi
									fi
								else
									# Assumed to be pod spawned by deployment/replicaset 
									for DEPLOY in $($OC_CMD get deploy -n $IN_NS --no-headers | $AWK '{ print $1 }')
									do
										# Vary dangerous assumption!
										if [[ "$IN_PODNAME" =~ ^${DEPLOY} ]]
										then
											PARENT_FOUND="true"						
											local GENERIC_PODNAME=$DEPLOY
											EXIT_STATUS=2
										fi
									done
				
									if [ $PARENT_FOUND == "false" ]
									then
										# Very last attempt of being more dangerous! 
										if [[ "$IN_PODNAME" =~ ^$PARENT_NAME ]]
										then
											local GENERIC_PODNAME=$PARENT_NAME
											EXIT_STATUS=2
										else
				    			        			local GENERIC_PODNAME="NULL"
											EXIT_STATUS=1
										fi
									fi
								fi
							else
				               	local GENERIC_PODNAME="NULL"
								EXIT_STATUS=1
							fi
						fi
						;;
		esac
     else
		# A pod without parent! To obtain generic pod name by stripping off suffixed UUID
		local GEN_POD_NAME=$($OC_CMD get -o=jsonpath='{.metadata.generateName}' -n $IN_NS po $IN_PODNAME)

		if [ ${#GEN_POD_NAME} -gt 0 ]
		then
			local GENERIC_PODNAME=$(echo "$GEN_POD_NAME" | sed 's/-$//')
			EXIT_STATUS=2
		else
			local GENERIC_PODNAME=$(echo "$IN_PODNAME" | sed 's/-[a-zA-Z0-9]*$//')
			EXIT_STATUS=2
		fi
     fi

	if [ ${#MG_DEBUG} -gt 0 ] && [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] PODNAME = [$IN_PODNAME] / PARENT_KIND = [$PARENT_KIND] / PARENT_NAME = [$PARENT_NAME] / GENERIC_PODNAME = [$GENERIC_PODNAME]" >> $RUNTIME_LOGFILE
	fi

     echo "$GENERIC_PODNAME"
	return $EXIT_STATUS
}

getPodDependencyData()
{
	# 4 types of data:
	# (1) pod dependency data (configmap, secret, pvc)
	# (2) pod status, category and description 
	# (3) pod to pod data flow
	# (4) missing pod (only if MISSINGOBJ is enabled)

	local NAMESPACE=$1
		
	local DEP_OUTDIR=$RUNTIME_OUTDIR/dependency/$NAMESPACE
	local DEP_DEBUG_OUTDIR=$DEBUG_OUTDIR/dependency/$NAMESPACE

	local DEP_REF_FILE="$MUSTGATHER_DIRNAME/config/dependency/$PRODUCT_VERSION/$(getNamespaceToProdMapping $NAMESPACE)-pod.desc"
	local DEP_REF_FILE_BACKUP_DIR=$DEP_DEBUG_OUTDIR
	local DEP_POD_NOCAT=$DEP_DEBUG_OUTDIR/pod.nocat
	local DEP_POD_NODESC=$DEP_DEBUG_OUTDIR/pod.nodesc
	local DEP_POD_FOUND=$DEP_OUTDIR/pod.found
	local DEP_POD_MISSING=$DEP_OUTDIR/pod.missing
	local DEP_GENERIC_NAME_REF_FILE=$DEP_OUTDIR/pod-generic-name.ref

	local RAWFILE=$DEP_OUTDIR/pod.raw
	local WORKFILE=$DEP_OUTDIR/pod.wrk
	local POD_STATUS_OUTFILE=$DEP_OUTDIR/pod.status
	local NODESFILE=$DEP_OUTDIR/nodes.csv
	local LINKSFILE=$DEP_OUTDIR/links.csv
		
	local POD_COLOR="#808000"
	local SECRET_COLOR="#69b3a2"
	local CONFIGMAP_COLOR="#7FFFD4"
	local PVC_COLOR="#045F5F"
	local MISSING_COLOR="#FF0000"
		
	local NODESFILE_HEADER="namespace,name,type,category,description,status,stroke,strokewidth,color"
	local LINKSFILE_HEADER="srcnamespace,sourcename,sourcetype,tgtnamespace,targetname,targettype,relationship"

	if [ ! -d $DEP_OUTDIR ]
	then
		mkdir -p $DEP_OUTDIR
	fi
		
	if [ $MG_DEBUG == "true" ] && [ ! -d $DEP_DEBUG_OUTDIR ]
	then
		mkdir -p $DEP_DEBUG_OUTDIR
		cp -p $DEP_REF_FILE $DEP_REF_FILE_BACKUP_DIR
	fi
		
	$OC_CMD get po -n $NAMESPACE --no-headers > $POD_STATUS_OUTFILE
	echo "$NODESFILE_HEADER" > $NODESFILE

	local POD=
		
	# Construct pod nodes data
	for POD in $($OC_CMD get pod --template '{{range .items}}{{.metadata.name}}{{"\n"}}{{end}}' -n $NAMESPACE)
	do
		local TMPFILE=$DEP_OUTDIR/${POD}.tmp
		
		echo "[$(date)] [${FUNCNAME[0]}] Executing command [$OC_CMD describe pod $POD -n $NAMESPACE | $AWK '/^QoS/&&--f||f||/^Volumes:/&&f++'] to TMPFILE [$TMPFILE]"
		$OC_CMD describe pod $POD -n $NAMESPACE | $AWK '/^QoS/&&--f||f||/^Volumes:/&&f++' > $TMPFILE 
		
		if [ -s $POD_STATUS_OUTFILE ]
		then
			local SEARCH_CMD="$AWK '\$1 ~ /^$POD\$/ { print \$3 }' $POD_STATUS_OUTFILE"
			local PODSTATUS=$(eval $SEARCH_CMD)

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Pod status command = [$SEARCH_CMD]"
			fi
		else
			local PODSTATUS="Unknown"
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] POD_STATUS = [$PODSTATUS]"
		fi
		
		# Defining circle stroke
		if [ $PODSTATUS == "Running" ] || [ $PODSTATUS == "Completed" ]
		then
			local PODSTATUS_STROKE="none"
			local PODSTATUS_STROKEWIDTH=0
		else
			local PODSTATUS_STROKE="$MISSING_COLOR"
			local PODSTATUS_STROKEWIDTH="5px"
		fi

		if [ -s $DEP_REF_FILE ]
		then
			local DEP_GENERIC_PODNAME=$(getGenericPodName $POD $NAMESPACE)
			echo "${DEP_GENERIC_PODNAME}##${POD}" >> $DEP_GENERIC_NAME_REF_FILE

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] POD = [$POD] / GENERIC_PODNAME = [$DEP_GENERIC_PODNAME]"
			fi

			local CATEGORY_CMD="$AWK -F## '\$1 ~ /^$DEP_GENERIC_PODNAME\$/ { print \$2 }' $DEP_REF_FILE"
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing CATEGORY_CMD = [$CATEGORY_CMD]..."
			fi

			local POD_CATEGORY=$(eval "$CATEGORY_CMD" | sed 's/"/ /g' | sed 's/^[ ]*//' | sed 's/[ ]*$//')

			if [ ${#POD_CATEGORY} -gt 0 ]
			then
				if [[ $POD_CATEGORY =~ , ]]
				then
					local POD_CATEGORY="\"$POD_CATEGORY\""
				fi
			else
				local POD_CATEGORY="null"
				echo "$POD" >> $DEP_POD_NOCAT
			fi
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] POD_CATEGORY = [$POD_CATEGORY]..."
			fi

			local DESC_CMD="$AWK -F## '\$1 ~ /^$DEP_GENERIC_PODNAME\$/ { print \$3 }' $DEP_REF_FILE"
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing DESC_CMD = [$DESC_CMD]..."
			fi

			local POD_DESC=$(eval "$DESC_CMD" | sed 's/"/ /g' | sed 's/^[ ]*//' | sed 's/[ ]*$//')

			if [ ${#POD_DESC} -gt 0 ] 
			then
				if [[ $POD_DESC =~ , ]]
				then
					local POD_DESC="\"$POD_DESC\""
				fi

				# To prepare to find any missing resource
				local POD_DESC_FOUND_CMD="$AWK -F## '\$1 ~ /^$DEP_GENERIC_PODNAME\$/ { print }' $DEP_REF_FILE"
				eval "$POD_DESC_FOUND_CMD" >> $DEP_POD_FOUND
			else
				local POD_DESC="null"
				echo "$POD" >> $DEP_POD_NODESC
			fi
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] POD_DESC = [$POD_DESC]..."
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] Pod reference file [$DEP_REF_FILE] does not exist or is zero-sized!"
			local POD_CATEGORY="null"
			local POD_DESC="null"
		fi
		
		# Construct NODES file (not final)
		local POD_NODES_LINE="$NAMESPACE,$POD,pod,$POD_CATEGORY,$POD_DESC,$PODSTATUS,$PODSTATUS_STROKE,$PODSTATUS_STROKEWIDTH,$POD_COLOR"

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Output [$POD_NODES_LINE] to NODESFILE..."
		fi

		echo "$POD_NODES_LINE" >> $NODESFILE
		
		# Construct LINKS temp work file
		if [ -s $TMPFILE ]
		then
			$AWK -v "PODNAME=$POD" '/Type:/ { if ($2 == "PersistentVolumeClaim" || $2 == "ConfigMap" || $2 == "Secret" ) { OBJ=$2; getline; if ( OBJ == "PersistentVolumeClaim" ) { print PODNAME ":pvc:" $2 }; if ( OBJ == "ConfigMap" ) { print PODNAME ":configmap:" $2 }; if ( OBJ == "Secret" ) { print PODNAME ":secret:" $2 }; } else { if ($2 == "Projected") { while ( $0 ~ /^[ ]+.*:[ ]+.+/ ) { if ( getline <= 0 ) { exit } else { if ( $1 == "ConfigMapName:" ) { print PODNAME ":configmap:" $2 } else { if ( $1 == "SecretName:" ) { print PODNAME ":secret:" $2 } } } } } } }' $TMPFILE >> $RAWFILE
		
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Backing up temporary work file [$TMPFILE] to directory [$DEP_DEBUG_OUTDIR]..."		
				cp -p $TMPFILE $DEP_DEBUG_OUTDIR
			fi

			rm $TMPFILE
		else
			echo "[$(date)] [${FUNCNAME[0]}] TMPFILE [$TMPFILE] is not available! Skipping pod [$POD]..."
		fi
	done

	# Find missing pods
	if [ -s $DEP_POD_MISSING ]
	then
		local DEP_MISS_LINE=

		while read DEP_MISS_LINE
		do	
			# Skip all lines that start with # and blank lines
			if [[ $(echo "$DEP_MISS_LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$DEP_MISS_LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi
		
			echo "[$(date)] [${FUNCNAME[0]}] Detected missing pod [$DEP_MISS_LINE]..."

			# To remove the trailing dash (-) from regex taken from MISSINGOBJ config file
			local DEP_MISSOBJ_PROC=$(echo "$DEP_MISS_LINE" | sed 's/-$//')
			local DEP_MISSOBJ_CMD="$AWK -F## '\$1 ~ /$DEP_MISSOBJ_PROC/ { print \$1 }' $DEP_REF_FILE"
			local DEP_MISSOBJ=$(eval "$DEP_MISSOBJ_CMD")

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] DEP_MISSOBJ_PROC = [$DEP_MISSOBJ_PROC]"
				echo "[$(date)] [${FUNCNAME[0]}] Executing command [$DEP_MISSOBJ_CMD]..."
			fi

			if [ ${#DEP_MISSOBJ} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Unified missing pod name = [$DEP_MISSOBJ]"
			else
				# if [[ $DEP_MISSOBJ_PROC =~ }$ ]] || [[ $DEP_MISSOBJ_PROC =~ \]$ ]] || [[ $DEP_MISSOBJ_PROC =~ \*$ ]] || [[ $DEP_MISSOBJ_PROC =~ \+$ ]] || [[ $DEP_MISSOBJ_PROC =~ \?$ ]]
				if [[ $DEP_MISSOBJ_PROC =~ \{[0-9]*}$ ]] 
				then
					# DANGEROUS: Assumed MISSINGOBJ config line ends with regex to match UUID suffix of pod name, so remove the last portion of "Eg. -[a-z0-9]{4}"
					local DEP_MISSOBJ_PROC2=$(echo "$DEP_MISSOBJ_PROC" | sed 's/{[0-9]*}$//' | sed 's/-\[[^]]*\]$//')
					local DEP_MISSOBJ_CMD2="$AWK -F## '\$1 ~ /$DEP_MISSOBJ_PROC2/ { print \$1 }' $DEP_REF_FILE"

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] DEP_MISSOBJ_PROC2 = [$DEP_MISSOBJ_PROC2]"
						echo "[$(date)] [${FUNCNAME[0]}] DEP_MISSOBJ_CMD2 = [$DEP_MISSOBJ_CMD2]"
					fi
			
					local DEP_MISSOBJ=$(eval "$DEP_MISSOBJ_CMD2")

					if [ ${#DEP_MISSOBJ} -gt 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Unified missing pod name = [$DEP_MISSOBJ]"
					else
						echo "[$(date)] [${FUNCNAME[0]}] Unable to unify missing pod name [$DEP_MISS_LINE]! Skipping..."
						continue
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] Unable to unify missing pod name [$DEP_MISS_LINE]! Skipping..."
					continue
				fi
			fi

			local CATEGORY_CMD="$AWK -F## '\$1 ~ /^$DEP_MISSOBJ\$/ { print \$2 }' $DEP_REF_FILE"
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing CATEGORY_CMD = [$CATEGORY_CMD]..."
			fi

			local POD_CATEGORY=$(eval "$CATEGORY_CMD" | sed 's/"/ /g' | sed 's/^[ ]*//' | sed 's/[ ]*$//')

			if [ ${#POD_CATEGORY} -gt 0 ]
			then
				if [[ $POD_CATEGORY =~ , ]]
				then
					local POD_CATEGORY="\"$POD_CATEGORY\""
				fi
			else
				local POD_CATEGORY="null"
				echo "$POD" >> $DEP_POD_NOCAT
			fi
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] POD_CATEGORY = [$POD_CATEGORY]..."
			fi

			local DESC_CMD="$AWK -F## '\$1 ~ /^$DEP_MISSOBJ\$/ { print \$3 }' $DEP_REF_FILE"
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Executing DESC_CMD = [$DESC_CMD]..."
			fi

			local POD_DESC=$(eval "$DESC_CMD" | sed 's/"/ /g' | sed 's/^[ ]*//' | sed 's/[ ]*$//')

			if [ ${#POD_DESC} -gt 0 ] 
			then
				if [[ $POD_DESC =~ , ]]
				then
					local POD_DESC="\"$POD_DESC\""
				fi

				# To prepare to find any missing resource
				local POD_DESC_FOUND_CMD="$AWK -F## '\$1 ~ /^$DEP_GENERIC_PODNAME\$/ { print }' $DEP_REF_FILE"
				eval "$POD_DESC_FOUND_CMD" >> $DEP_POD_FOUND
			else
				local POD_DESC="null"
				echo "$POD" >> $DEP_POD_NODESC
			fi
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] POD_DESC = [$POD_DESC]..."
			fi

			local DEP_MISSOBJ_LINE="$NAMESPACE,$DEP_MISSOBJ,pod,$POD_CATEGORY,$POD_DESC,Missing,none,0,$MISSING_COLOR"

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Output [$DEP_MISSOBJ_LINE] to NODESFILE..."
			fi

			echo "$DEP_MISSOBJ_LINE" >> $NODESFILE
		done < $DEP_POD_MISSING
		
		if [ $MG_DEBUG == "true" ]
		then
			cp -p $DEP_POD_FOUND $DEP_DEBUG_OUTDIR
		fi

		rm $DEP_POD_FOUND
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] Backing up pod status file [$POD_STATUS_OUTFILE] to directory [$DEP_DEBUG_OUTDIR]..."		
		cp -p $POD_STATUS_OUTFILE $DEP_DEBUG_OUTDIR
	fi

	rm $POD_STATUS_OUTFILE

	# Start to process dependency data
	if [ -s $RAWFILE ]
	then
		local LINECTR=1
		local LINE=
		
		while read LINE
		do
			# Skip all lines that start with # and blank lines
			if [[ $(echo "$LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi
		
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] LINE = [$LINE]"
			fi
		
			local PODNAME=$(echo "$LINE" | $AWK -F: '{ print $1 }')
			local OBJTYPE=$(echo "$LINE" | $AWK -F: '{ print $2 }')
			local OBJNAME=$(echo "$LINE" | $AWK -F: '{ print $3 }')

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] PODNAME = [$PODNAME] / OBJTYPE = [$OBJTYPE] / OBJNAME = [$OBJNAME]"
			fi
		
			local TARGET_COLOR="$MISSING_COLOR"
		
			if [ ${#OBJTYPE} -gt 0 ]
			then
				case $OBJTYPE in
					secret) TARGET_COLOR="$SECRET_COLOR" ;;
					configmap) TARGET_COLOR="$CONFIGMAP_COLOR" ;;
					pvc) TARGET_COLOR="$PVC_COLOR" ;;
				esac
			fi
		
			if [ $OBJTYPE == "pvc" ]
			then
				local OBJSTATUS=$($OC_CMD get $OBJTYPE -n $NAMESPACE $OBJNAME --no-headers | $AWK '{ print $2 }')
		
				if [ ${#OBJSTATUS} -gt 0 ] && [ $OBJSTATUS == "Bound" ]
				then
					local OBJSTROKE="none"
					local OBJSTROKEWIDTH="0"
				else
					local OBJSTROKE="$MISSING_COLOR"
					local OBJSTROKEWIDTH="5px"
				fi
			else
				if $OC_CMD get $OBJTYPE -n $NAMESPACE $OBJNAME --no-headers > /dev/null 2>&1
				then
					local OBJSTATUS="Exists"
					local OBJSTROKE="none"
					local OBJSTROKEWIDTH="0"
				else
					local OBJSTATUS="NotFound"
					local OBJSTROKE="$MISSING_COLOR"
					local OBJSTROKEWIDTH="5px"
				fi
			fi
		
			if [ ${#OBJSTATUS} -eq 0 ]
			then
				local OBJSTATUS="Unknown"
				local OBJSTROKE="$MISSING_COLOR"
				local OBJSTROKEWIDTH="5px"
			fi
		
			# Add non-pod (supporting) resource into NODEFILE
			local NODES_LINE="$NAMESPACE,$OBJNAME,$OBJTYPE,null,null,$OBJSTATUS,$OBJSTROKE,$OBJSTROKEWIDTH,$TARGET_COLOR"

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Output [$NODES_LINE] to NODESFILE..."
			fi

			echo "$NODES_LINE" >> $NODESFILE
		
			# Construct LINKS file
			local LINK_LINE="$NAMESPACE,$PODNAME,pod,$NAMESPACE,$OBJNAME,$OBJTYPE,DependsOn"

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Output [$LINK_LINE] to WORKFILE..."
			fi

			echo "$LINK_LINE" >> $WORKFILE
		
			(( LINECTR=LINECTR+1 ))
		done < <(sort -u $RAWFILE)
		
		if [ -s $WORKFILE ]
		then
			echo "$LINKSFILE_HEADER" > $LINKSFILE
			sort -t ',' -k1,1 -k4,4 -k3,3 $WORKFILE >> $LINKSFILE

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Backing up work file [$WORKFILE] to directory [$DEP_DEBUG_OUTDIR]..."				
				cp -p $WORKFILE $DEP_DEBUG_OUTDIR
			fi

			rm $WORKFILE
		else
			echo "[$(date)] [${FUNCNAME[0]}] WORKFILE [$WORKFILE] does not exist or is zero-sized!"
		fi
		
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] Backing up raw file [$RAWFILE] to directory [$DEP_DEBUG_OUTDIR]..."		
			cp -p $RAWFILE $DEP_DEBUG_OUTDIR
		fi

		rm $RAWFILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] Raw file [$RAWFILE] does not exist or is zero-sized! Exiting..."
	fi
}

getPod2PodLinkData()
{
	local NAMESPACE=$1

	local DEP_POD2POD_REF_FILE="$MUSTGATHER_DIRNAME/config/dependency/$PRODUCT_VERSION/$(getNamespaceToProdMapping $NAMESPACE)-pod2pod.link"
	local DEP_OUTDIR=$RUNTIME_OUTDIR/dependency/$NAMESPACE
	local NODESFILE=$DEP_OUTDIR/nodes.csv
	local LINKSFILE=$DEP_OUTDIR/links.csv

	# Construct pod to pod link data
	if [ -s $DEP_POD2POD_REF_FILE ]
	then
		local POD2POD_LINE=

		while read POD2POD_LINE
		do
			# Skip all lines that start with # and blank lines
			if [[ $(echo "$POD2POD_LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$POD2POD_LINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] POD2POD_LINE = [$POD2POD_LINE]"
			fi
		
			local SRC=
			local TGT=

			local SRC_NS=$(echo "$POD2POD_LINE" | $AWK -F## '{ print $1 }')
			local SRC_POD=$(echo "$POD2POD_LINE" | $AWK -F## '{ print $2 }')
			local TGT_NS=$(echo "$POD2POD_LINE" | $AWK -F## '{ print $3 }')
			local TGT_POD=$(echo "$POD2POD_LINE" | $AWK -F## '{ print $4 }')

			if [[ $SRC_NS =~ ^NS4PROD= ]]
			then
				local SRC_PROD=$(echo "$SRC_NS" | $AWK -F= '{ print $2 }')
				echo "[$(date)] [${FUNCNAME[0]}] [$SRC_NS] Retrieving source namespace for product [$SRC_PROD]..."		
				local SRC_NAMESPACE=$(getProdToNamespacesMapping "$SRC_PROD")
				echo "[$(date)] [${FUNCNAME[0]}] [$SRC_NS] Product namespace retrieved = [$SRC_NAMESPACE]"
			else
				local SRC_NAMESPACE=$SRC_NS
			fi

			if [[ $TGT_NS =~ ^NS4PROD= ]]
			then
				local TGT_PROD=$(echo "$TGT_NS" | $AWK -F= '{ print $2 }')
				echo "[$(date)] [${FUNCNAME[0]}] [$TGT_NS] Retrieving target namespace for product [$TGT_PROD]..."		
				local TGT_NAMESPACE=$(getProdToNamespacesMapping "$TGT_PROD")
				echo "[$(date)] [${FUNCNAME[0]}] [$TGT_NS] Product namespace retrieved = [$TGT_NAMESPACE]"
			else
				local TGT_NAMESPACE=$TGT_NS
			fi

			if [ ${#SRC_NAMESPACE} -eq 0 ] || [ $SRC_NAMESPACE == "NULL" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] SRC_NAMESPACE [$SRC_NAMESPACE] is invalid. Skipping..."
				continue
			fi

			if [ ${#TGT_NAMESPACE} -eq 0 ] || [ $TGT_NAMESPACE == "NULL" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] TGT_NAMESPACE [$TGT_NAMESPACE] is invalid. Skipping..."
				continue
			fi

			# Source namespace should always be the namespace the tool is currently processing!
			if [ $SRC_NAMESPACE != $NAMESPACE ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Source namespace [$SRC_NAMESPACE] is not the current namespace [$NAMESPACE]! Skipping..."
				continue
			fi

			local SRC_DEP_OUTDIR=$RUNTIME_OUTDIR/dependency/$SRC_NAMESPACE
			local SRC_DEP_GENERIC_NAME_REF_FILE=$SRC_DEP_OUTDIR/pod-generic-name.ref

			local SRC_PODNAMES_CMD="$AWK -F## '\$1 ~ /^$SRC_POD\$/ { print \$2 }' $SRC_DEP_GENERIC_NAME_REF_FILE"
			local SRC_PODNAMES=$(eval "$SRC_PODNAMES_CMD" | tr '\n' ' ' | sed 's/[ ]*$//')

			local TGT_DEP_OUTDIR=$RUNTIME_OUTDIR/dependency/$TGT_NAMESPACE
			local TGT_DEP_GENERIC_NAME_REF_FILE=$TGT_DEP_OUTDIR/pod-generic-name.ref

			local TGT_PODNAMES_CMD="$AWK -F## '\$1 ~ /^$TGT_POD\$/ { print \$2 }' $TGT_DEP_GENERIC_NAME_REF_FILE"	
			local TGT_PODNAMES=$(eval "$TGT_PODNAMES_CMD" | tr '\n' ' ' | sed 's/[ ]*$//')

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Retrieving source pod name for pattern [$SRC_POD]..."
				echo "[$(date)] [${FUNCNAME[0]}] SRC_PODNAMES_CMD = [$SRC_PODNAMES_CMD]"
				echo "[$(date)] [${FUNCNAME[0]}] SRC_PODNAMES = [$SRC_PODNAMES]"

				echo "[$(date)] [${FUNCNAME[0]}] Retrieving target pod name for pattern [$TGT_POD]..."
				echo "[$(date)] [${FUNCNAME[0]}] TGT_PODNAMES_CMD = [$TGT_PODNAMES_CMD]"
				echo "[$(date)] [${FUNCNAME[0]}] TGT_PODNAMES = [$TGT_PODNAMES]"
			fi

			# if [ ${#SRC_PODNAMES} -gt 0 ] && [ ${#TGT_PODNAMES} -gt 0 ]
			if [ ${#SRC_PODNAMES} -gt 0 ] 
			then
				if [ ${#TGT_PODNAMES} -eq 0 ]
				then
					# Assumed target pod is missing	
					TGT_PODNAMES=$TGT_POD
				fi

				# Target pod is from another namespace. To add to nodes.csv of the source namespace.
				if [ $TGT_NAMESPACE != $NAMESPACE ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] Adding pod [$TGT_PODNAMES] into nodes.csv file of namespace [$NAMESPACE]..."
				
					local TGT_NODESFILE=$TGT_DEP_OUTDIR/nodes.csv
					local TGT_NODE_CMD="$AWK -F, '\$2 ~ /^${TGT_PODNAMES}\$/ { print }' $TGT_NODESFILE"
					local TGT_NODE=$(eval "$TGT_NODE_CMD")

					echo "[$(date)] [${FUNCNAME[0]}] Executing command [$TGT_NODE_CMD]..."	
					echo "[$(date)] [${FUNCNAME[0]}] TGT_NODE retrieved = [$TGT_NODE]"

					if [ ${#TGT_NODE} -gt 0 ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Adding TGT_NODE into NODESFILES [$NODESFILE]..."
						echo "$TGT_NODE" >> $NODESFILE
					fi
				fi				

				IFS=$OLDIFS
				for SRC in $SRC_PODNAMES
				do
					for TGT in $TGT_PODNAMES
					do
						local POD2POD_LINK_LINE="$SRC_NAMESPACE,${SRC},pod,$TGT_NAMESPACE,${TGT},pod,DependsOn"
	
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [${FUNCNAME[0]}] POD2POD_LINK_LINE = [$POD2POD_LINK_LINE]"	
						fi
	
						echo "$POD2POD_LINK_LINE" >> $LINKSFILE
					done
				done
			else
				# echo "[$(date)] [${FUNCNAME[0]}] Either SRC_PODNAMES [$SRC_PODNAMES] or TGT_PODNAMES [$TGT_PODNAMES] is empty! Skipping..."
				echo "[$(date)] [${FUNCNAME[0]}] SRC_PODNAMES [$SRC_PODNAMES] is empty! Skipping..."
			fi
		done < $DEP_POD2POD_REF_FILE
	else
		echo "[$(date)] [${FUNCNAME[0]}] DEP_POD2POD_REF_FILE [$DEP_POD2POD_REF_FILE] does not exist or is zero-sized!"
	fi
}

toExcludeProdNamespace()
{
	local NS=$1

	# Return 0 = to exclude namespace
	# Return 1 = not to exclude namespace

	if [ ${#RTVAR_EXCL_PROD_NS} -gt 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] EXCLUDE_PROD_NAMESPACES = $RTVAR_EXCL_PROD_NS [Current size of EXCL_PROD_NS_ARR = ${#EXCL_PROD_NS_ARR[@]}]"

		local EXCL_NS=
		local TO_EXCL_NS="false"
		local TO_UPDATE_RTVAR_EXCL_PROD_NS="false"
		local UPDATED_RTVAR_EXCL_PROD_NS=
		
		IFS=$OLDIFS

		if [ $BASH_V4 == "true" ]
		then
			if [ ${#EXCL_PROD_NS_ARR[@]} -gt 0 ]
			then
				if [ ${EXCL_PROD_NS_ARR[$NS]+_} ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Returning cache for [$NS] = [${EXCL_PROD_NS_ARR[$NS]}]..."
					return ${EXCL_PROD_NS_ARR[$NS]}
				fi	
			fi
		fi

		# To create an array of excluded product namespaces
		if [[ $RTVAR_EXCL_PROD_NS =~ NS4PROD= ]]
		then
			read -r -a EXCLUDE_PROD_NAMESPACES_ARR <<< $(echo "$RTVAR_EXCL_PROD_NS" | sed 's/,/ /g')
			local NS_CTR=0

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Length of EXCLUDE_PROD_NAMESPACES_ARR = [${#EXCLUDE_PROD_NAMESPACES_ARR[@]}]"
			fi
		fi

		for EXCL_NS in $(echo "$RTVAR_EXCL_PROD_NS" | sed 's/,/ /g')
		do
			local ORI_EXCL_NS="$EXCL_NS"

			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] EXCL_NS = [$EXCL_NS]"
			fi

			if [[ $EXCL_NS =~ ^NS4PROD= ]]
			then
				local NS_PRODNAME=$(echo "$EXCL_NS" | $AWK -F= '{ print $2 }')

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] NS_PRODNAME = [$NS_PRODNAME]" 
				fi

				if [ ${#NS_PRODNAME} -gt 0 ]
				then
					local FINAL_EXCL_NS=$(getProdToNamespacesMapping "$NS_PRODNAME")

					if [ "$FINAL_EXCL_NS" == $PROD_NAMESPACES_INVALID_STR ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Unable to determine product namespace [$ORI_EXCL_NS]!"
						echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] To remove [$EXCL_NS] from RTVAR_EXCL_PROD_NS..."

						# To update RTVAR_EXCL_PROD_NS
						if [ ${#UPDATED_RTVAR_EXCL_PROD_NS} -eq 0 ]
						then
							local UPDATED_RTVAR_EXCL_PROD_NS=
						else
							local UPDATED_RTVAR_EXCL_PROD_NS="$UPDATED_RTVAR_EXCL_PROD_NS"
						fi	

						local TO_UPDATE_RTVAR_EXCL_PROD_NS="true"
					else
						# To update RTVAR_EXCL_PROD_NS
						local UPDATED_FINAL_EXCL_NS=$(echo "$FINAL_EXCL_NS" | sed 's/ /,/g')

						if [ ${#UPDATED_RTVAR_EXCL_PROD_NS} -eq 0 ]
						then
							local UPDATED_RTVAR_EXCL_PROD_NS="$UPDATED_FINAL_EXCL_NS"
						else
							local UPDATED_RTVAR_EXCL_PROD_NS="$UPDATED_RTVAR_EXCL_PROD_NS,$UPDATED_FINAL_EXCL_NS"
						fi	

						local TO_UPDATE_RTVAR_EXCL_PROD_NS="true"
					fi
				else
					echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] NS_PRODNAME is empty in [$EXCL_NS]!"
					echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] To remove [$EXCL_NS] from RTVAR_EXCL_PROD_NS..."

					# To update RTVAR_EXCL_PROD_NS
					if [ ${#UPDATED_RTVAR_EXCL_PROD_NS} -eq 0 ]
					then
						local UPDATED_RTVAR_EXCL_PROD_NS=
					else
						local UPDATED_RTVAR_EXCL_PROD_NS="$UPDATED_RTVAR_EXCL_PROD_NS"
					fi	

					local TO_UPDATE_RTVAR_EXCL_PROD_NS="true"
				fi
			else
				local FINAL_EXCL_NS="$EXCL_NS"

				if [ ${#UPDATED_RTVAR_EXCL_PROD_NS} -eq 0 ]
				then
					local UPDATED_RTVAR_EXCL_PROD_NS="$FINAL_EXCL_NS"
				else
					local UPDATED_RTVAR_EXCL_PROD_NS="$UPDATED_RTVAR_EXCL_PROD_NS,$FINAL_EXCL_NS"
				fi	
			fi

			echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Product namespace retrieved = [$FINAL_EXCL_NS]"
		
			if [ $(echo "$FINAL_EXCL_NS" | $AWK '{ print NF }') -gt 1 ]
			then
				for RETRIEVED_NS in ${FINAL_EXCL_NS}
				do
					if [ $NS == "$RETRIEVED_NS" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Product namespace [$NS] is configured to be excluded!"
						local TO_EXCL_NS="true"
						break
					fi
				done
			else
				if [ $NS == "$FINAL_EXCL_NS" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Product namespace [$NS] is configured to be excluded!"
					local TO_EXCL_NS="true"
					# break
				fi
			fi	

			if [ $TO_EXCL_NS == "true" ]
			then
				if [ $TO_UPDATE_RTVAR_EXCL_PROD_NS == "true" ]
				then
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] NS_CTR = [$NS_CTR] / Length of EXCLUDE_PROD_NAMESPACES_ARR = [${#EXCLUDE_PROD_NAMESPACES_ARR[@]}]"
					fi

					if [ $((NS_CTR+1)) -ne ${#EXCLUDE_PROD_NAMESPACES_ARR[@]} ]
					then
						local CUR_CTR=0
	
						for EXCL_NS in ${EXCLUDE_PROD_NAMESPACES_ARR[@]}
						do
							if [ $CUR_CTR -gt $NS_CTR ]
							then
								echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Adding [$EXCL_NS] into variable UPDATED_RTVAR_EXCL_PROD_NS..."

								if [ ${#UPDATED_RTVAR_EXCL_PROD_NS} -eq 0 ]
								then
									local UPDATED_RTVAR_EXCL_PROD_NS="$EXCL_NS"
								else
									local UPDATED_RTVAR_EXCL_PROD_NS="$UPDATED_RTVAR_EXCL_PROD_NS,$EXCL_NS"
								fi	

								echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Latest UPDATED_RTVAR_EXCL_PROD_NS = [$UPDATED_RTVAR_EXCL_PROD_NS]"
							fi
	
							(( CUR_CTR=CUR_CTR+1 ))
						done
					fi
				fi

				break
			fi

			(( NS_CTR=NS_CTR+1 ))
		done
	
		if [ $TO_UPDATE_RTVAR_EXCL_PROD_NS == "true" ]
		then
			echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Updating RTVAR_EXCL_PROD_NS [$RTVAR_EXCL_PROD_NS] to [$UPDATED_RTVAR_EXCL_PROD_NS]..."
			RTVAR_EXCL_PROD_NS="$UPDATED_RTVAR_EXCL_PROD_NS"
		fi

		if [ $TO_EXCL_NS == "true" ]
		then
			if [ $BASH_V4 == "true" ]
			then
				if [ ! ${EXCL_PROD_NS_ARR[$NS]+_} ]
				then
					EXCL_PROD_NS_ARR[$NS]=0
					echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Adding key [$NS] with value [0] into EXCL_PROD_NS_ARR [COUNT=${#EXCL_PROD_NS_ARR[@]}]..."
				fi

				if [ $MG_DEBUG == "true" ]
				then
					for KEY in ${!EXCL_PROD_NS_ARR[@]}
					do
						echo "EXCL_PROD_NS_ARR[$KEY] = [${EXCL_PROD_NS_ARR[$KEY]}]"
					done
				fi
			fi

			echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Namespace [$NS] is to be excluded!"
			return 0	
		else
			if [ $BASH_V4 == "true" ]
			then
				if [ ! ${EXCL_PROD_NS_ARR[$NS]+_} ]
				then
					EXCL_PROD_NS_ARR[$NS]=1
					echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Adding key [$NS] with value [1] into EXCL_PROD_NS_ARR [COUNT=${#EXCL_PROD_NS_ARR[@]}]..."
				fi

				if [ $MG_DEBUG == "true" ]
				then
					for KEY in ${!EXCL_PROD_NS_ARR[@]}
					do
						echo "EXCL_PROD_NS_ARR[$KEY] = [${EXCL_PROD_NS_ARR[$KEY]}]"
					done
				fi
			fi

			echo "[$(date)] [${FUNCNAME[0]}] [INPUT=$NS] Namespace [$NS] is not to be excluded!"
			return 1
		fi
	else
		return 1
	fi
}

getFuncStartTime()
{
	if [ $IS_MACOS == "true" ]
	then
		if [ ${#GDATE} -gt 0 ]
		then
			local FUNC_START=$($GDATE +%s%3N)
		else
			local FUNC_START=$(date +%s)
		fi
	else
		local FUNC_START=$(date +%s%3N)
	fi

	echo "$FUNC_START"
}

getFuncEndTime()
{
	if [ $IS_MACOS == "true" ]
	then
		if [ ${#GDATE} -gt 0 ]
		then
			local FUNC_END=$($GDATE +%s%3N)
		else
			local FUNC_END=$(date +%s)
		fi
	else
		local FUNC_END=$(date +%s%3N)
	fi

	echo "$FUNC_END"
}

getFuncElapsedTime()
{
	local FUNC_NAME=$1
	local FUNC_START=$2
	local FUNC_END=$3
	local FUNC_MSG=$4

	if [ ${#FUNC_START} -eq 0 ] || [ ${#FUNC_END} -eq 0 ]
	then
		echo "[$(date)] [$FUNC_NAME] FUNC_START and/or FUNC_END is null/empty!" >&2
		return 1
	fi

	if [ ${#FUNC_START} -eq 10 ] && [ ${#FUNC_END} -eq 10 ]
	then
		local FUNC_MACOS="true"
	else
		local FUNC_MACOS="false"
	fi

	local FUNC_DURATION=$(( FUNC_END - FUNC_START ))

	if [ ${#FUNC_DURATION} -eq 0 ]
	then
		echo "[$(date)] [$FUNC_NAME] FUNC_DURATION is null/empty!" >&2
		return 1
	fi
	
	if [ $FUNC_MACOS == "false" ]
	then
		if [ ${#FUNC_DURATION} -eq 3 ]
		then
			local FUNC_MILISEC=${FUNC_DURATION: -3}
			local FUNC_DURATION=0
		else
			if [ ${#FUNC_DURATION} -gt 3 ]
			then
				local FUNC_MILISEC=${FUNC_DURATION: -3}
				local FUNC_DURATION=${FUNC_DURATION::$((${#FUNC_DURATION}-3))}
			else
				local FUNC_MILISEC=${FUNC_DURATION}
				local FUNC_DURATION=0
			fi
		fi

		if [[ ${FUNC_MILISEC} =~ ^0 ]]
		then
			local FUNC_MILISEC=$(echo "$FUNC_MILISEC" | sed 's/^0*//')
		fi

		if [ ${#FUNC_MILISEC} -eq 0 ]
		then
			local FUNC_MILISEC=0
		fi	

		if [ $IS_MACOS == "true" ]
		then
			local FUNC_ELAPSED=$(eval "printf '%02d hr %02d min %02d sec %03d ms' $((FUNC_DURATION/3600)) $((FUNC_DURATION%3600/60)) $((FUNC_DURATION%60)) $FUNC_MILISEC")
		else
			local FUNC_ELAPSED=$(eval "echo -n $(date -ud "@$FUNC_DURATION" +'%H hr %M min %S sec'); echo ' '$FUNC_MILISEC ms")
		fi
	else
		local FUNC_ELAPSED=$(eval "printf '%02d hr %02d min %02d sec' $((FUNC_DURATION/3600)) $((FUNC_DURATION%3600/60)) $((FUNC_DURATION%60))")
	fi

	echo "[$(date)] [$FUNC_NAME] FUNC_START = [$FUNC_START] / FUNC_END = [$FUNC_END] / FUNC_DURATION = [$FUNC_DURATION] / FUNC_MILISEC = [$FUNC_MILISEC]"

	if [ ${#FUNC_MSG} -gt 0 ]
	then
		echo "[$(date)] [$FUNC_NAME] Function took [$FUNC_ELAPSED] to execute ${FUNC_MSG}..."
	else
		echo "[$(date)] [$FUNC_NAME] Function took [$FUNC_ELAPSED] to execute..."
	fi
}

echoModeMsg()
{
	echo "[$(date)] [${FUNCNAME[0]}] Executing data collection mode [$MUSTGATHER_OPT]..."
}

checkCloudPlatform()
{
	# Try to auto-detect cloud platform
	if [ ${#CLOUD_PLATFORM} -eq 0 ]
	then
		local IS_OCP=$($OC_CMD api-resources | grep route.openshift.io | head -1 | sed -E 's/ +/ /g')

		if [ ${#IS_OCP} -gt 0 ]
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] IS_OCP = [$IS_OCP]"
			fi

			echo "[$(date)] [${FUNCNAME[0]}] Setting CLOUD_PLATFORM to [ocp]..."
			CLOUD_PLATFORM="ocp"
		else
			local IS_K3S=$($OC_CMD api-resources | grep k3s.cattle.io | head -1 | sed -E 's/ +/ /g')

			if [ ${#IS_K3S} -gt 0 ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [${FUNCNAME[0]}] IS_K3S = [$IS_K3S]"
				fi

				echo "[$(date)] [${FUNCNAME[0]}] Setting CLOUD_PLATFORM to [k3s]..."
				CLOUD_PLATFORM="k3s"
			else
				local IS_K8S=$($OC_CMD api-resources | grep networking.k8s.io | head -1 | sed -E 's/ +/ /g')

				if [ ${#IS_K8S} -gt 0 ]
				then
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] IS_K8S = [$IS_K8S]"
					fi
	
					echo "[$(date)] [${FUNCNAME[0]}] Setting CLOUD_PLATFORM to [k8s]..."
					CLOUD_PLATFORM="k8s"
				fi
			fi
		fi
	fi

	if [ ${#CLOUD_PLATFORM} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] CLOUD_PLATFORM variable is null/empty! Returning..."
		return 1
	else
		case "$CLOUD_PLATFORM" in
			ocp|OCP)	if [ ${#ALLOW_CUSTOM_CLIENT} -gt 0 ] && [ ${ALLOW_CUSTOM_CLIENT} == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Setting OC_CMD to [$OC_CMD]..."
						return 0 
					else	
						if [ $OC_CMD == "kubectl" ]
						then
							if command -v oc > /dev/null 2>&1
							then
								echo "[$(date)] [${FUNCNAME[0]}] Setting OC_CMD from [kubectl] to [oc]..."
								OC_CMD="oc"
							else
								echo "[$(date)] [${FUNCNAME[0]}] WARNING: OC_CMD is set to [kubectl] on cloud platform [ocp]!"
							fi
	
							return 0 
						else
							echo "[$(date)] [${FUNCNAME[0]}] Setting OC_CMD to [$OC_CMD]..."
							return 0 
						fi
					fi
					;;
			k3s|K3S)	if [ ${#ALLOW_CUSTOM_CLIENT} -gt 0 ] && [ ${ALLOW_CUSTOM_CLIENT} == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Setting OC_CMD to [$OC_CMD]..."
						return 0 
					else	
						if [ $OC_CMD == "oc" ]
						then
							if command -v kubectl > /dev/null 2>&1
							then
								echo "[$(date)] [${FUNCNAME[0]}] Setting OC_CMD from [oc] to [kubectl]..."
								OC_CMD="kubectl"
							else
								echo "[$(date)] [${FUNCNAME[0]}] WARNING: OC_CMD is set to [oc] on cloud platform [k3s]!"
							fi
	
							return 0
						else
							echo "[$(date)] [${FUNCNAME[0]}] Setting OC_CMD to [$OC_CMD]..."
							return 0 
						fi
					fi
					;;
			k8s|K8S)	if [ ${#ALLOW_CUSTOM_CLIENT} -gt 0 ] && [ ${ALLOW_CUSTOM_CLIENT} == "true" ]
					then
						echo "[$(date)] [${FUNCNAME[0]}] Setting OC_CMD to [$OC_CMD]..."
						return 0 
					else	
						if [ $OC_CMD == "oc" ]
						then
							if command -v kubectl > /dev/null 2>&1
							then
								echo "[$(date)] [${FUNCNAME[0]}] Setting OC_CMD from [oc] to [kubectl]..."
								OC_CMD="kubectl"
							else
								echo "[$(date)] [${FUNCNAME[0]}] WARNING: OC_CMD is set to [oc] on cloud platform [k8s]!"
							fi
	
							return 0
						else
							echo "[$(date)] [${FUNCNAME[0]}] Setting OC_CMD to [$OC_CMD]..."
							return 0 
						fi
					fi
					;;
			*)		return 1 ;;
		esac
	fi
}

isEnvVarOverrideable()
{
	local ENVVAR=$1

	if [ ${#ENVVAR} -eq 0 ]
	then
		echo "[$(date)] [${FUNCNAME[0]}] ENVVAR [$ENVVAR] is null/empty! Returning..."
		return 1
	else
		if [ -s $MUSTGATHER_DIRNAME/envvar.override ]
		then
			local ENVVAR_OVERRIDEABLE=$(sed 's/^[ ]*//' $MUSTGATHER_DIRNAME/envvar.override | sed 's/[ ]*$//' | $AWK '/^'${ENVVAR}'$/')

			if [ ${#ENVVAR_OVERRIDEABLE} -gt 0 ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] ENVVAR [$ENVVAR] is overrideable!"
				return 0
			else
				echo "[$(date)] [${FUNCNAME[0]}] ENVVAR [$ENVVAR] is NOT overrideable!"
				return 1
			fi
		else
			echo "[$(date)] [${FUNCNAME[0]}] File [$MUSTGATHER_DIRNAME/envvar.override] does not exist or is zero-sized! Returning..."
			return 1
		fi
	fi
}

# Special handling for ALIAS and VIEW modes
while true
do
	while getopts :O:V:W:Dvh OPTION 2> /dev/null
	do
		case $OPTION in
			O)	ALIAS_MODE="true" 
				ALIAS_NAME=$OPTARG
				;;
			V) 	VIEW_ONLY="true"
			   	VIEW_MODULE_OPTARG=$OPTARG
			   	VIEW_MODULE=$(echo "$VIEW_MODULE_OPTARG" | $AWK '{ print $1 }')
				;;
			W)	RUNTIME_VAR=$OPTARG
				;;
			D)	MG_DEBUG="true"
				;;	
			v)	echoVersion; exit 0
				;;	
			h)	echoUsage; exit 0
				;;
			\?)	;;
		esac
	done		

	((OPTIND++))
	[ $OPTIND -gt $# ] && break
done

OPTIND=0

ALIAS_MODE_ONLY_ORIG=$ALIAS_MODE_ONLY

if [ $ALIAS_MODE_ONLY == "true" ]
then
	if [ ${#NON_CLOUD} -gt 0 ] && [ $NON_CLOUD == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] Executing in NON_CLOUD mode, flag ALIAS_MODE_ONLY [$ALIAS_MODE_ONLY] is ignored! To proceed..." | tee -a $TMP_LOGFILE
		DEFER_EXEC_MODE_CHECK="false"
	else	
		if [ $ALIAS_MODE == "true" ]
		then
			if [ ${#RUNTIME_VAR} -gt 0 ]
			then
				# Just in case user override ALIAS_MODE_ONLY variable
				echo "[$(date)] [$(basename "$0")] User provided runtime variable detected! To proceed with execution mode check..." | tee -a $TMP_LOGFILE
				DEFER_EXEC_MODE_CHECK="true"
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] ALIAS_MODE_ONLY = [$ALIAS_MODE_ONLY] / ALIAS_MODE = [$ALIAS_MODE] and no user provided runtime variable is detected!" | tee -a $TMP_LOGFILE
				fi

				DEFER_EXEC_MODE_CHECK="false"
			fi
		else
			if [ ${#RUNTIME_VAR} -gt 0 ]
			then
				# Just in case user override ALIAS_MODE_ONLY variable
				echo "[$(date)] [$(basename "$0")] User provided runtime variable detected! Deferring exit..." | tee -a $TMP_LOGFILE
				DEFER_EXEC_MODE_CHECK="true"
			else
				echo "[$(date)] [$(basename "$0")] Execution can only proceed with ALIAS mode [-O]! To list supported aliases, execute '-O .listalias'! Exiting..."
				cleanUpDataDir
				exit 1
			fi
		fi
	fi
else
	if [ ${#RUNTIME_VAR} -gt 0 ]
	then
		if [ $VIEW_ONLY != "true" ] || [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] User provided runtime variable detected! To proceed with execution mode check..." | tee -a $TMP_LOGFILE
		fi

		DEFER_EXEC_MODE_CHECK="true"
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] ALIAS_MODE_ONLY = [$ALIAS_MODE_ONLY] and no user provided runtime variable is detected!" | tee -a $TMP_LOGFILE
		fi

		DEFER_EXEC_MODE_CHECK="false"
	fi
fi

if [ $MG_DEBUG == "true" ]
then
	echo "[$(date)] [$(basename "$0")] DEFER_EXEC_MODE_CHECK = [$DEFER_EXEC_MODE_CHECK]" | tee -a $TMP_LOGFILE
fi

if [ ${#NON_CLOUD} -gt 0 ] && [ $NON_CLOUD == "true" ]
then
	echo "[$(date)] [$(basename "$0")] Executing in 'non-cloud' mode - only initSetup() will be executed..." | tee -a $TMP_LOGFILE
fi

# To check whether initSetup() function is implemented in config/product.sh
if [[ $(type -t initSetup) == function ]]
then
	if ( [ $VIEW_ONLY == "true" ] && [ ! $MG_DEBUG == "true" ] ) || [ ! $MG_DEBUG == "true" ]
	then
		checkOSArch > /dev/null
		checkTty > /dev/null
		checkBashVersion > /dev/null

		if [ ${#BASH_V4} -gt 0 ] && [ $BASH_V4 == "true" ]
		then
			if [[ $(checkAssociativeArray) ]]
			then
				BASH_V4="true"
			else
				BASH_V4="false"
			fi
		fi
	else
		checkOSArch > >(tee -a $TMP_LOGFILE) 2>&1
		checkTty > >(tee -a $TMP_LOGFILE) 2>&1
		checkBashVersion > >(tee -a $TMP_LOGFILE) 2>&1

		if [ ${#BASH_V4} -gt 0 ] && [ $BASH_V4 == "true" ]
		then
			if [[ $(checkAssociativeArray) ]]
			then
				echo "[$(date)] [$(basename "$0")] Associative array test passed! BASH_V4 remains [true]..." | tee -a $TMP_LOGFILE
				BASH_V4="true"
			else
				echo "[$(date)] [$(basename "$0")] Associative array test failed! Resetting BASH_V4 to [false]..." | tee -a $TMP_LOGFILE
				BASH_V4="false"
			fi
		fi
	fi

	if ! checkOcCmd 
	then
		cleanUpDataDir
		exit 1
	else
		if [ $OC_CMD == "oc" ]
		then
			OC_WHOAMI=$($OC_CMD whoami)
		else
			OC_WHOAMI=$($OC_CMD config current-context | $AWK -F/ '{ print $NF }')
		fi
	fi

	setupDeferRtvarStruc > >(tee -a $TMP_LOGFILE) 2>&1

	OPTIND=0

	while true
	do
		while getopts :W:Do:Y INIT_OPTION 2> /dev/null
		do
			case $INIT_OPTION in
				D)	if [ ! $VIEW_ONLY == "true" ]	
					then
						MG_DEBUG="true"
					fi
					;;	
				W)	RUNTIME_VAR=$OPTARG
					# echo "[$(date)] [$(basename "$0")] [INIT] Processing and exporting user-defined variables..."
		
					if [ $VIEW_ONLY == "true" ]
					then
						if ! checkEnvVar $RUNTIME_VAR > /dev/null
						then
							cleanUpDataDir
							exit 1
						fi
			
						processRuntimeVar > /dev/null
					else
						if ! checkEnvVar $RUNTIME_VAR > >(tee -a $TMP_LOGFILE) 2>&1
						then
							cleanUpDataDir
							exit 1
						fi
			
						processRuntimeVar > >(tee -a $TMP_LOGFILE) 2>&1
					fi
					;;	
				o) 	ROOT_OUTDIR=$OPTARG
					if [[ $OPTARG == "." ]]
					then
						ROOT_OUTDIR=$PWD
				   	fi
	
					if [[ ! "$ROOT_OUTDIR" =~ ^/ ]]
					then
						echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] must be full path (e.g. /tmp/output)!"
						cleanUpDataDir
						exit 1
					fi
	
					if [ $ROOT_OUTDIR == $MUSTGATHER_DIRNAME ]
					then
						echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] to MUSTGATHER_DIRNAME [$MUSTGATHER_DIRNAME] is NOT allowed!"
						cleanUpDataDir
						exit 1
					fi	
	
					if [[ "$ROOT_OUTDIR" =~ ^$MUSTGATHER_DIRNAME ]]
					then
						echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] to a sub-directory MUSTGATHER_DIRNAME [$MUSTGATHER_DIRNAME] is NOT allowed!"
						cleanUpDataDir
						exit 1
					fi	
					;;
				Y)	AUTO_YES="true"
					;;
				\?)	;;
			esac
		done
		
		((OPTIND++))
		[ $OPTIND -gt $# ] && break
	done
	
	OPTIND=0

	if ( [ $VIEW_ONLY == "true" ] && [ ! $MG_DEBUG == "true" ] ) || [ ! $MG_DEBUG == "true" ]
	then
		checkBashVersionAgain > /dev/null
	else
		checkBashVersionAgain > >(tee -a $TMP_LOGFILE) 2>&1
	fi

	if [ ${#NON_CLOUD} -gt 0 ] && [ $NON_CLOUD == "true" ]
	then
		MUSTGATHER_OPT="noncloud"
		setupDataDir 
		# getOutFile

		if [[ $(type -t getOutFileName) == function ]]
		then
			# To set GZIP_OUTFILE variable
			GZIP_OUTFILE=$(getOutFileName) 

			if [ ${#GZIP_OUTFILE} -eq 0 ]
			then
				GZIP_OUTFILE="$ROOT_OUTDIR/$(getOutFileNameDef).tar.gz"
				echo "[$(date)] [$(basename "$0")] User-defined function 'getOutFileName' returns empty/null string! Setting variable GZIP_OUTFILE to default [$GZIP_OUTFILE]..." | tee -a $RUNTIME_LOGFILE
			else
				GZIP_OUTFILE="$ROOT_OUTDIR/${GZIP_OUTFILE}.tar.gz"
				echo "[$(date)] [$(basename "$0")] Setting variable GZIP_OUTFILE to user-defined [$GZIP_OUTFILE]..." | tee -a $RUNTIME_LOGFILE
			fi
		else
			# Default implementation in product.sh.def
			GZIP_OUTFILE="$ROOT_OUTDIR/$(getOutFileNameDef).tar.gz"
			echo "[$(date)] [$(basename "$0")] Setting variable GZIP_OUTFILE to default [$GZIP_OUTFILE]..." | tee -a $RUNTIME_LOGFILE
		fi

		INITSETUP_DEF_ENV_ARR="ANALYZE_OUTFILE"

		IFS=$OLDIFS
		for INITSETUP_DEF_ENV in $INITSETUP_DEF_ENV_ARR
		do
			echo "[$(date)] [$(basename "$0")] Appending additional variables [$INITSETUP_DEF_ENV] into GMGF_ENV_ARR..." | tee -a $RUNTIME_LOGFILE
			GMGF_ENV_ARR[${#GMGF_ENV_ARR[@]}]="$INITSETUP_DEF_ENV"
		done	

		# Export global variables and functions
		IFS=$'\n'
		for GMGF_ENV in ${GMGF_ENV_ARR[@]}
		do
			if [[ $GMGF_ENV =~ ^-f ]]
			then
				GMGF_ENV_FUNCNAME=$(echo "$GMGF_ENV" | $AWK '{ print $2 }')
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] Exporting environment function [$GMGF_ENV_FUNCNAME]..." | tee -a $RUNTIME_LOGFILE
				fi

				export -f $GMGF_ENV_FUNCNAME
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] Exporting environment variable [$GMGF_ENV = ${!GMGF_ENV}]" | tee -a $RUNTIME_LOGFILE
				fi

				export $GMGF_ENV
			fi
		done

		deferRuntimeVar

		IFS=$OLDIFS
		RTVAR_ENV_ARR=$(compgen -A variable | grep -E '^RTVAR_' | tr '\n' ' ')
	
		if [ ${#RTVAR_ENV_ARR} -gt 0 ]
		then
			IFS=$OLDIFS
			for RTVAR_ENV in $RTVAR_ENV_ARR
			do
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] Exporting environment variable [$RTVAR_ENV = ${!RTVAR_ENV}]" | tee -a $RUNTIME_LOGFILE
				fi

				export $RTVAR_ENV
			done	
		fi
	else
		if [ $DEFER_EXEC_MODE_CHECK == "true" ]
		then
			# Deferred ALIAS_MODE_ONLY handling due to user provided runtime variable (-W)
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] ALIAS_MODE_ONLY_ORIG = [$ALIAS_MODE_ONLY_ORIG] / ALIAS_MODE_ONLY = [$ALIAS_MODE_ONLY]" | tee -a $TMP_LOGFILE
			fi

			if [ $ALIAS_MODE_ONLY_ORIG == "true" ] && [ $ALIAS_MODE_ONLY == "true" ]
			then
				# ALIAS_MODE_ONLY did not change, all good!
				if [ $ALIAS_MODE == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] [1] Deferred execution mode check completed! To proceed in ALIAS mode..." | tee -a $TMP_LOGFILE
				else
					if [ $VIEW_ONLY != "true" ] || [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [$(basename "$0")] [1] Deferred execution mode check completed! To proceed normally..." | tee -a $TMP_LOGFILE
					fi
				fi
			else
				if [ $ALIAS_MODE_ONLY_ORIG == "true" ] && [ $ALIAS_MODE_ONLY == "false" ]
				then
					# User overrode ALIAS_MODE_ONLY to 'false'
					printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: ALIAS_MODE_ONLY was overridden [true -> false]! Proceeding...${NORMAL}${NEWLINE}"
					echo "[$(date)] [$(basename "$0")] WARNING: ALIAS_MODE_ONLY was overridden [true -> false]! Proceeding..." >> $TMP_LOGFILE
					sleep $DEFAULT_SLEEP_SEC
				else
					if [ $ALIAS_MODE_ONLY_ORIG == "false" ] && [ $ALIAS_MODE_ONLY == "true" ]
					then
						# User overrode ALIAS_MODE_ONLY to 'true' - no idea why the user would do that!?
						if [ $ALIAS_MODE == "true" ]
						then
							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [$(basename "$0")] ALIAS_MODE_ONLY was overridden [false -> true]! ALIAS_MODE is set to [$ALIAS_MODE]! Proceeding..." | tee -a $TMP_LOGFILE
							fi
						else
							echo "[$(date)] [$(basename "$0")] Execution can only proceed with ALIAS mode [-O]! To list supported aliases, execute '-O .listalias'! Exiting..."
							cleanUpDataDir
							exit 1
						fi
					else
						# ALIAS_MODE_ONLY remains 'false', all good!
						if [ $ALIAS_MODE == "true" ]
						then
							echo "[$(date)] [$(basename "$0")] [2] Deferred execution mode check completed! To proceed in ALIAS mode..." | tee -a $TMP_LOGFILE
						else
							if [ $VIEW_ONLY != "true" ] || [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [$(basename "$0")] [2] Deferred execution mode check completed! To proceed normally..." | tee -a $TMP_LOGFILE
							fi
						fi
					fi
				fi
			fi
		else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] No deferred execution mode check is needed!" | tee -a $TMP_LOGFILE
			fi
		fi
	fi

	if [ ${#NON_CLOUD} -eq 0 ] || [ $NON_CLOUD != "true" ]
	then
		if ( [ $VIEW_ONLY == "true" ] && [ ! $MG_DEBUG == "true" ] ) || [ ! $MG_DEBUG == "true" ]
		then
			if checkCloudPlatform > /dev/null
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is supported!"
				fi

				getOcVersion > /dev/null
			else
				echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is NOT supported!" >&2
				cleanUpDataDir
				exit 1
			fi
		else
			if checkCloudPlatform > >(tee -a $TMP_LOGFILE) 2>&1 
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is supported!" | tee -a $TMP_LOGFILE
				fi

				getOcVersion > >(tee -a $TMP_LOGFILE) 2>&1
			else
				echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is NOT supported!" >&2
				cleanUpDataDir
				exit 1
			fi
		fi
	fi

	if ( [ $VIEW_ONLY == "true" ] && [ ! $MG_DEBUG == "true" ] ) || [ ! $MG_DEBUG == "true" ]
	then
		initSetup > /dev/null
		INITSETUP_EXITCODE=$?
	else
		echo "[$(date)] [$(basename "$0")] Executing user implemented function - initSetup()..." | tee -a $TMP_LOGFILE	
		initSetup > >(tee -a $TMP_LOGFILE) 2>&1
		INITSETUP_EXITCODE=$?
		echo "[$(date)] [$(basename "$0")] User implemented function ended - initSetup()..." | tee -a $TMP_LOGFILE
	fi

	if [ ${#NON_CLOUD} -gt 0 ] && [ $NON_CLOUD == "true" ]
	then
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		exit $INITSETUP_EXITCODE
	fi
else
	if [ ${#NON_CLOUD} -gt 0 ] && [ $NON_CLOUD == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] initSetup() is not defined! Exiting..."
		cleanUpDataDir
		exit 1
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] initSetup() is not defined!" | tee -a $TMP_LOGFILE
		fi
	fi
fi

if [ $ALIAS_MODE == "true" ] && [ $VIEW_ONLY == "true" ]
then
	echo "[$(date)] [$(basename "$0")] ALIAS mode cannot be used together with VIEW-ONLY mode! Exiting..."
	cleanUpDataDir
	exit 1
fi

if [ $ALIAS_MODE == "true" ]
then
	if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] Entering ALIAS mode..." | tee -a $TMP_LOGFILE
		echo "[$(date)] [$(basename "$0")] Expanding alias [$ALIAS_NAME]..." | tee -a $TMP_LOGFILE
	fi

	MUSTGATHER_ALL_OPT_ORI=$@
	OPTIND=0

	# Init - to provide product info support 
	MUSTGATHER_OPT="alias"

	if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]
	then
		checkOSArch > >(tee -a $TMP_LOGFILE) 2>&1
		checkTty > >(tee -a $TMP_LOGFILE) 2>&1
		checkBashVersion > >(tee -a $TMP_LOGFILE) 2>&1
	else
		checkOSArch > /dev/null
		checkTty > /dev/null
		checkBashVersion > /dev/null
	fi

	if [ ${#BASH_V4} -gt 0 ] && [ $BASH_V4 == "true" ]
	then
		if [[ $(checkAssociativeArray) ]]
		then
			if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] Associative array test passed! BASH_V4 remains [true]..." | tee -a $TMP_LOGFILE
			fi

			BASH_V4="true"
		else
			if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]	
			then
				echo "[$(date)] [$(basename "$0")] Associative array test failed! Resetting BASH_V4 to [false]..." | tee -a $TMP_LOGFILE
			fi

			BASH_V4="false"
		fi
	fi

	if ! checkOcCmd 
	then
		cleanUpDataDir
		exit 1
	else
		if [ $OC_CMD == "oc" ]
		then
			OC_WHOAMI=$($OC_CMD whoami)
		else
			OC_WHOAMI=$($OC_CMD config current-context | $AWK -F/ '{ print $NF }')
		fi
	fi

	if [[ $(type -t initSetup) != function ]]
	then
		setupDeferRtvarStruc > >(tee -a $TMP_LOGFILE) 2>&1
	fi

	while true
	do
		while getopts :O:o:W:YD ALIAS_OPTION 2> /dev/null
		do
			case $ALIAS_OPTION in
				O)	;;
				# [GLOBAL] Unless reset by expanded alias
				o) 	ROOT_OUTDIR=$OPTARG
					if [[ $OPTARG == "." ]]
					then
						ROOT_OUTDIR=$PWD
				   	fi
	
					if [[ ! "$ROOT_OUTDIR" =~ ^/ ]]
					then
						echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] must be full path (e.g. /tmp/output)!"
						cleanUpDataDir
						exit 1
					fi
	
					if [ $ROOT_OUTDIR == $MUSTGATHER_DIRNAME ]
					then
						echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] to MUSTGATHER_DIRNAME [$MUSTGATHER_DIRNAME] is NOT allowed!"
						cleanUpDataDir
						exit 1
					fi	
	
					if [[ "$ROOT_OUTDIR" =~ ^$MUSTGATHER_DIRNAME ]]
					then
						echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] to a sub-directory MUSTGATHER_DIRNAME [$MUSTGATHER_DIRNAME] is NOT allowed!"
						cleanUpDataDir
						exit 1
					fi	
	
					ALIAS_MODE_ROOT_OUTDIR=$ROOT_OUTDIR
					;;
				# [ALIAS only] Expanded alias can have its own [-W]
				W)	if [[ $(type -t initSetup) != function ]]	
					then
						# echo "[$(date)] [$(basename "$0")] [ALIAS] Processing and exporting user-defined variables..."
						RUNTIME_VAR=$OPTARG
		
						if ! checkEnvVar $RUNTIME_VAR > >(tee -a $TMP_LOGFILE) 2>&1
						then
							cleanUpDataDir
							exit 1
						fi
		
						processRuntimeVar > >(tee -a $TMP_LOGFILE) 2>&1
					fi
					;;	
				# [ALIAS only] Expanded alias can have its own [-Y]
				Y) 	AUTO_YES="true"
					;;
				# [ALIAS only] Expanded alias can have its own [-D]
				D) 	MG_DEBUG="true"
					;;
				\?)	;;
		
				# If new options are added here, please remember to reset it after ALIAS is expanded!
				# NOTE: Added getopts for -W, -Y and -D, so that user can control interaction with functions like getProdNamespaces(), checkProdNamespace() and getProdVersions() called by the ALIAS mode!
			esac
		done		

		((OPTIND++))
		[ $OPTIND -gt $# ] && break
	done

	checkBashVersionAgain > >(tee -a $TMP_LOGFILE) 2>&1

	if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]
	then
		if checkCloudPlatform > >(tee -a $TMP_LOGFILE) 2>&1
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is supported!" | tee -a $TMP_LOGFILE
			fi
			
			getOcVersion > >(tee -a $TMP_LOGFILE) 2>&1
		else
			echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is NOT supported!" >&2
			cleanUpDataDir
			exit 1
		fi
	else
		if checkCloudPlatform > /dev/null
		then
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is supported!" | tee -a $TMP_LOGFILE
			fi

			getOcVersion > /dev/null
		else
			echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is NOT supported!" >&2
			cleanUpDataDir
			exit 1
		fi
	fi

	if [ -d $ROOT_OUTDIR ]
	then
		if ! touch $ROOT_OUTDIR/testmg-$$
		then
			echo "[$(date)] [$(basename "$0")] FATAL: Unable to write to ROOT_OUTDIR [$ROOT_OUTDIR]!"
			cleanUpDataDir
			exit 1
		else
			rm $ROOT_OUTDIR/testmg-$$
		fi
	else
		if ! mkdir $ROOT_OUTDIR
		then
			echo "[$(date)] [$(basename "$0")] FATAL: Unable to create ROOT_OUTDIR [$ROOT_OUTDIR]!"
			cleanUpDataDir
			exit 1	
		fi
	fi

	ORI_POS_PARAM_CTR=0
	for ORI_POS_PARAM in $@
	do
		(( ORI_POS_PARAM_CTR=ORI_POS_PARAM_CTR+1 ))

		if [ ${#MUSTGATHER_ALL_OPT_ORI_POS_PARAM} -eq 0 ]
		then
			MUSTGATHER_ALL_OPT_ORI_POS_PARAM="[$ORI_POS_PARAM_CTR] $ORI_POS_PARAM"
		else
			MUSTGATHER_ALL_OPT_ORI_POS_PARAM="$MUSTGATHER_ALL_OPT_ORI_POS_PARAM / [$ORI_POS_PARAM_CTR] $ORI_POS_PARAM"
		fi
	done
		
	if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]
	then
		setupDataDir 
	else
		setupDataDir > /dev/null
	fi

	if [ $BASH_V4 == "true" ]
	then
		declare -gA PROD_NAMESPACES_KEYVAL_ARR
		declare -gA USER_PRIV_ARR
		declare -gA EXCL_PROD_NS_ARR
	fi

	if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]
	then
		getProdNamespaces $PROD_NAMESPACES_REFFILE > >(tee -a $RUNTIME_LOGFILE) 2>&1

		if ! checkProdNamespace > >(tee -a $RUNTIME_LOGFILE) 2>&1
		then
		   	echo "[$(date)] [$(basename "$0")] ERROR: Unable to determine product namespaces!" > >(tee -a $RUNTIME_LOGFILE)
			cleanUpDataDir
			exit 1
		fi

		PRODUCT_VERSION=$(getProdVersions $PROD_VERSIONS_REFFILE 2> >(tee -a $RUNTIME_LOGFILE >&2))
	else
		getProdNamespaces $PROD_NAMESPACES_REFFILE > /dev/null 2>&1

		if ! checkProdNamespace > /dev/null
		then
		   	echo "[$(date)] [$(basename "$0")] ERROR: Unable to determine product namespaces!" > >(tee -a $RUNTIME_LOGFILE)
			cleanUpDataDir
			exit 1
		fi

		PRODUCT_VERSION=$(getProdVersions $PROD_VERSIONS_REFFILE 2> /dev/null)
	fi

	if [ ${#RTVAR_ALIAS_PRODVER} -gt 0 ]
	then
		if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] ALIAS_PRODVER is set to [$RTVAR_ALIAS_PRODVER]! Resetting PRODUCT_VERSION to [$RTVAR_ALIAS_PRODVER]!" > >(tee -a $RUNTIME_LOGFILE)
		else
			echo "[$(date)] [$(basename "$0")] ALIAS_PRODVER is set to [$RTVAR_ALIAS_PRODVER]! Resetting PRODUCT_VERSION to [$RTVAR_ALIAS_PRODVER]!" > /dev/null
		fi

		PRODUCT_VERSION=$RTVAR_ALIAS_PRODVER
	fi

	if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]
	then
		if ! checkProdVersion > >(tee -a $RUNTIME_LOGFILE) 2>&1
		then
			echo "[$(date)] [$(basename "$0")] ERROR: Unable to determine product version!" > >(tee -a $RUNTIME_LOGFILE)
			cleanUpDataDir
			exit 1
		else
			if [ ${ALIAS_NAME} == ".listalias" ]
			then
				ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/config/alias/$PRODUCT_VERSION/alias.cfg
			else
				if [ ${ALIAS_NAME} == ".listalias_custom" ]
				then
					ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/data/alias/$PRODUCT_VERSION/alias.cfg

					if [ ! -s $ALIAS_CFGFILE ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [$(basename "$0")] ALIAS configuration file [$ALIAS_CFGFILE] does not exist or is zero-sized!" > >(tee -a $RUNTIME_LOGFILE)
						fi	

						ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/data/alias/alias.cfg
		
						echo "[$(date)] [$(basename "$0")] Setting ALIAS configuration file to [$ALIAS_CFGFILE]..." > >(tee -a $RUNTIME_LOGFILE)
					fi
				else
					ALIAS_CFGFILE=

					if [ -s $MUSTGATHER_DIRNAME/config/alias/$PRODUCT_VERSION/alias.cfg ]
					then
						ALIAS_FOUND=$(grep -E "^${ALIAS_NAME}${ALIAS_CFGFILE_DELIMITER}" $MUSTGATHER_DIRNAME/config/alias/$PRODUCT_VERSION/alias.cfg)
					else
						ALIAS_FOUND=
					fi

					if [ ${#ALIAS_FOUND} -gt 0 ]
					then
						ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/config/alias/$PRODUCT_VERSION/alias.cfg
					else
						if [ ${#ALIAS_MODE_ONLY} -gt 0 ] && [ ${ALIAS_MODE_ONLY} == "true" ]
						then
							echo "[$(date)] [$(basename "$0")] ALIAS_MODE_ONLY is set to [$ALIAS_MODE_ONLY]! Not considering user defined aliases!"	> >(tee -a $RUNTIME_LOGFILE)
							ALIAS_CFGFILE=
							ALIAS_FOUND=
						else
							if [ -s $MUSTGATHER_DIRNAME/data/alias/$PRODUCT_VERSION/alias.cfg ]
							then
								ALIAS_FOUND=$(grep -E "^${ALIAS_NAME}${ALIAS_CFGFILE_DELIMITER}" $MUSTGATHER_DIRNAME/data/alias/$PRODUCT_VERSION/alias.cfg)
							else
								ALIAS_FOUND=
							fi
	
							if [ ${#ALIAS_FOUND} -gt 0 ]
							then
								ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/data/alias/$PRODUCT_VERSION/alias.cfg
							else
								if [ -s $MUSTGATHER_DIRNAME/data/alias/alias.cfg ]
								then
									ALIAS_FOUND=$(grep -E "^${ALIAS_NAME}${ALIAS_CFGFILE_DELIMITER}" $MUSTGATHER_DIRNAME/data/alias/alias.cfg)
								else
									ALIAS_FOUND=
								fi
	
								if [ ${#ALIAS_FOUND} -gt 0 ]
								then
									ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/data/alias/alias.cfg
								else
									ALIAS_CFGFILE=
									ALIAS_FOUND=
								fi
							fi
						fi
					fi
				fi
			fi
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] ALIAS_CFGFILE = [$ALIAS_CFGFILE] / ALIAS_FOUND = [$ALIAS_FOUND]" > >(tee -a $RUNTIME_LOGFILE)
		fi
	else
		if ! checkProdVersion > /dev/null
		then
			echo "[$(date)] [$(basename "$0")] ERROR: Unable to determine product version!" > >(tee -a $RUNTIME_LOGFILE)
			cleanUpDataDir
			exit 1
		else
			if [ ${ALIAS_NAME} == ".listalias" ]
			then
				ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/config/alias/$PRODUCT_VERSION/alias.cfg
			else
				if [ ${ALIAS_NAME} == ".listalias_custom" ]
				then
					ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/data/alias/$PRODUCT_VERSION/alias.cfg

					if [ ! -s $ALIAS_CFGFILE ]
					then
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [$(basename "$0")] ALIAS configuration file [$ALIAS_CFGFILE] does not exist or is zero-sized!" > >(tee -a $RUNTIME_LOGFILE)
						fi	

						ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/data/alias/alias.cfg

						echo "[$(date)] [$(basename "$0")] Setting ALIAS configuration file to [$ALIAS_CFGFILE]..." > >(tee -a $RUNTIME_LOGFILE)
					fi
				else
					ALIAS_CFGFILE=

					if [ -s $MUSTGATHER_DIRNAME/config/alias/$PRODUCT_VERSION/alias.cfg ]
					then
						ALIAS_FOUND=$(grep -E "^${ALIAS_NAME}${ALIAS_CFGFILE_DELIMITER}" $MUSTGATHER_DIRNAME/config/alias/$PRODUCT_VERSION/alias.cfg)
					else
						ALIAS_FOUND=
					fi

					if [ ${#ALIAS_FOUND} -gt 0 ]
					then
						ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/config/alias/$PRODUCT_VERSION/alias.cfg
					else
						if [ -s $MUSTGATHER_DIRNAME/data/alias/$PRODUCT_VERSION/alias.cfg ]
						then
							ALIAS_FOUND=$(grep -E "^${ALIAS_NAME}${ALIAS_CFGFILE_DELIMITER}" $MUSTGATHER_DIRNAME/data/alias/$PRODUCT_VERSION/alias.cfg)
						else
							ALIAS_FOUND=
						fi

						if [ ${#ALIAS_FOUND} -gt 0 ]
						then
							ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/data/alias/$PRODUCT_VERSION/alias.cfg
						else
							if [ -s $MUSTGATHER_DIRNAME/data/alias/alias.cfg ]
							then
								ALIAS_FOUND=$(grep -E "^${ALIAS_NAME}${ALIAS_CFGFILE_DELIMITER}" $MUSTGATHER_DIRNAME/data/alias/alias.cfg)
							else
								ALIAS_FOUND=
							fi

							if [ ${#ALIAS_FOUND} -gt 0 ]
							then
								ALIAS_CFGFILE=$MUSTGATHER_DIRNAME/data/alias/alias.cfg
							else
								ALIAS_CFGFILE=
								ALIAS_FOUND=
							fi
						fi
					fi
				fi
			fi
		fi	

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] ALIAS_CFGFILE = [$ALIAS_CFGFILE] / ALIAS_FOUND = [$ALIAS_FOUND]" > >(tee -a $RUNTIME_LOGFILE)
		fi
	fi
	
	TO_EXPORT_GMGF_ENV="false"
	
	if [ $BASH_V4 == "true" ]
	then
		if [ ${#DEFER_RTVAR_ARR[@]} -gt 0 ]
		then
			TO_EXPORT_GMGF_ENV="true"
		fi
	else
		if [ -s $DEFER_RTVAR_INFILE ]
		then
			TO_EXPORT_GMGF_ENV="true"
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] TO_EXPORT_GMGF_ENV = [$TO_EXPORT_GMGF_ENV]" | tee -a $RUNTIME_LOGFILE
	fi

	if [ $TO_EXPORT_GMGF_ENV == "true" ]
	then	
		# Export global variables and functions
		IFS=$'\n'
		for GMGF_ENV in ${GMGF_ENV_ARR[@]}
		do
			if [[ $GMGF_ENV =~ ^-f ]]
			then
				GMGF_ENV_FUNCNAME=$(echo "$GMGF_ENV" | $AWK '{ print $2 }')
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] Exporting environment function [$GMGF_ENV_FUNCNAME]..." | tee -a $RUNTIME_LOGFILE
				fi

				export -f $GMGF_ENV_FUNCNAME
			else
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] Exporting environment variable [$GMGF_ENV = ${!GMGF_ENV}]" | tee -a $RUNTIME_LOGFILE
				fi

				export $GMGF_ENV
			fi
		done
	fi

	deferRuntimeVar

	if [ ${#ALIAS_CFGFILE} -gt 0 ] && [ -s $ALIAS_CFGFILE ]
	then
		if ( [ ${ALIAS_NAME} != ".listalias" ] && [ ${ALIAS_NAME} != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] ALIAS configuration file = [$ALIAS_CFGFILE]" > >(tee -a $RUNTIME_LOGFILE)
		else
			echo "[$(date)] [$(basename "$0")] ALIAS configuration file = [$ALIAS_CFGFILE]" > /dev/null
		fi

		ALIAS_LIST_HEADER="true"

		while read ALIAS_CFGLINE
		do
			if [[ $(echo "$ALIAS_CFGLINE" | $AWK '{$1=$1};1') == "$ALIAS_CFGFILE_COMMENT"* ]] || [[ $(echo "$ALIAS_CFGLINE" | $AWK '{ print NF }') -eq 0 ]]
			then
				continue
			fi

			TMP_ALIAS_NAME=$(echo "$ALIAS_CFGLINE" | $AWK -F$ALIAS_CFGFILE_DELIMITER '{ print substr($1, 0, 25) }')
			TMP_ALIAS_DESC=$(echo "$ALIAS_CFGLINE" | $AWK -F$ALIAS_CFGFILE_DELIMITER '{ print substr($2, 0, 80) }')
			TMP_ALIAS_CMD=$(echo "$ALIAS_CFGLINE" | $AWK -F$ALIAS_CFGFILE_DELIMITER '{ print $3 }')

			if [ ${ALIAS_NAME} == ".listalias" ] || [ ${ALIAS_NAME} == ".listalias_custom" ]
			then
				if [ $ALIAS_LIST_HEADER == "true" ]
				then
					echo
					echo "========================================================================================================================================================================================="
					printf "%-27s %-82s %-120s \n" "ALIAS_NAME" "DESCRIPTION" "COMMAND"
					echo "========================================================================================================================================================================================="
					ALIAS_LIST_HEADER="false"
				fi

				printf "%-27s %-82s %-120s\n" "$TMP_ALIAS_NAME" "$TMP_ALIAS_DESC" "$MUSTGATHER_SCRIPTNAME $TMP_ALIAS_CMD"
			else
				if [ ${#ALIAS_NAME} -gt 0 ]
				then
					if [ ${ALIAS_NAME} == ${TMP_ALIAS_NAME} ]
					then
						# Reset $@
						if [ ${#TMP_ALIAS_CMD} -gt 0 ]
						then
							echo "[$(date)] [$(basename "$0")] Resetting input positional parameters to [$TMP_ALIAS_CMD]..." | tee -a $RUNTIME_LOGFILE

							ALIAS_EVAL_CMD="set -- $TMP_ALIAS_CMD"
							eval "$ALIAS_EVAL_CMD"
		
							if [ $? -ne 0 ]
							then
								echo "[$(date)] [$(basename "$0")] Unable to expand ALIAS_CMD for ALIAS[$ALIAS_NAME]! Exiting..." | tee -a $RUNTIME_LOGFILE
								cleanUpDataDir
								exit 1
							else
								ALIAS_EXPANDED="true"
								OPTIND=0

								MUSTGATHER_ALL_OPT_MOD=$@
		
								MOD_POS_PARAM_CTR=0
								for MOD_POS_PARAM in $@
								do
									(( MOD_POS_PARAM_CTR=MOD_POS_PARAM_CTR+1 ))
							
									if [ ${#MUSTGATHER_ALL_OPT_MOD_POS_PARAM} -eq 0 ]
									then
										MUSTGATHER_ALL_OPT_MOD_POS_PARAM="[$MOD_POS_PARAM_CTR] $MOD_POS_PARAM"
									else
										MUSTGATHER_ALL_OPT_MOD_POS_PARAM="$MUSTGATHER_ALL_OPT_MOD_POS_PARAM / [$MOD_POS_PARAM_CTR] $MOD_POS_PARAM"
									fi
								done

								# Backup important files to be re-used
								ALIAS_MODE_TMP_OUTDIR=$OUTDIR

								# Reset some variables
								echo "[$(date)] [$(basename "$0")] Resetting variables [RUNTIME_VAR] to default values..." | tee -a $RUNTIME_LOGFILE
								echo "[$(date)] [$(basename "$0")] INFO: All runtime variables (-W) set in ALIAS mode will be available to expanded command as well!" | tee -a $RUNTIME_LOGFILE
								RUNTIME_VAR=
								# AUTO_YES="false"
								# MG_DEBUG="false"

								# Manually check whether alias is expanded with AUTO_YES and MG_DEBUG
								while true
								do
									while getopts YD EXPANDED_ALIAS_OPTION 2> /dev/null
									do
										case $EXPANDED_ALIAS_OPTION in
											Y) ALIAS_EXPANDED_WITH_AUTO_YES="true" ;;
											D) ALIAS_EXPANDED_WITH_MG_DEBUG="true" ;;	
											\?)	;;
										esac
									done

									((OPTIND++))
									[ $OPTIND -gt $# ] && break
								done

								OPTIND=0

								if [ ${#ALIAS_EXPANDED_WITH_AUTO_YES} -eq 0 ]
								then
									if [ ${#AUTO_YES} -gt 0 ] && [ $AUTO_YES == "true" ]
									then
										ALIAS_EXPANDED_WITH_WARNING="AUTO_YES(-Y)"
									fi
								else
									printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: Alias [$ALIAS_NAME] is expanded into a command with AUTO_YES (-Y) enabled! All prompts will be auto-answered with 'yes'!${NORMAL}${NEWLINE}"
									echo "[$(date)] [$(basename "$0")] WARNING: Alias [$ALIAS_NAME] is expanded into a command with AUTO_YES (-Y) enabled! All prompts will be auto-answered with 'yes'!" >> $RUNTIME_LOGFILE
									sleep $DEFAULT_SLEEP_SEC
								fi

								if [ ${#ALIAS_EXPANDED_WITH_MG_DEBUG} -eq 0 ]
								then
									if [ ${#MG_DEBUG} -gt 0 ] && [ $MG_DEBUG == "true" ]
									then
										if [ ${#ALIAS_EXPANDED_WITH_WARNING} -eq 0 ]
										then
											ALIAS_EXPANDED_WITH_WARNING="MG_DEBUG(-D)"
										else
											ALIAS_EXPANDED_WITH_WARNING="${ALIAS_EXPANDED_WITH_WARNING}, MG_DEBUG(-D)"
										fi
									fi
								fi

								if [ ${#ALIAS_EXPANDED_WITH_WARNING} -gt 0 ]
								then
									printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: Flags [$ALIAS_EXPANDED_WITH_WARNING] are appended to expanded alias [$MUSTGATHER_ALL_OPT_MOD]...${NORMAL}${NEWLINE}"
									echo "[$(date)] [$(basename "$0")] WARNING: Flags [$ALIAS_EXPANDED_WITH_WARNING] are appended to expanded alias [$MUSTGATHER_ALL_OPT_MOD]..." >> $RUNTIME_LOGFILE
									sleep $DEFAULT_SLEEP_SEC
								fi

								break
							fi
						else
							echo "[$(date)] [$(basename "$0")] ERROR: ALIAS_CMD for ALIAS_NAME[$ALIAS_NAME] is empty/null! Exiting..." | tee -a $RUNTIME_LOGFILE
							cleanUpDataDir
							exit 1
						fi	
					fi
				else
					echo "[$(date)] [$(basename "$0")] ERROR: ALIAS_NAME is empty/null! Exiting..." | tee -a $RUNTIME_LOGFILE
					cleanUpDataDir
					exit 1
				fi
			fi
		done	< <(sort $ALIAS_CFGFILE)

		if [ $ALIAS_EXPANDED == "false" ]
		then
			if [ $ALIAS_NAME != ".listalias" ] && [ $ALIAS_NAME != ".listalias_custom" ]
			then
				printf "[$(date)] [$(basename "$0")] ${BOLD}${RED} ERROR: Unable to find ALIAS_NAME[$ALIAS_NAME] in config file [$ALIAS_CFGFILE]! Exiting...${NORMAL}${NEWLINE}"
				echo "[$(date)] [$(basename "$0")] ERROR: Unable to find ALIAS_NAME[$ALIAS_NAME] in config file [$ALIAS_CFGFILE]! Exiting..." >> $RUNTIME_LOGFILE
			else
				echo
			fi

			if ( [ ${ALIAS_NAME} != ".listalias" ] && [ $ALIAS_NAME != ".listalias_custom" ] ) || [ $MG_DEBUG == "true" ]	
			then
				cleanUpDataDir
			else
				cleanUpDataDir > /dev/null
			fi

			exit 1
		fi

		if [ $BASH_V4 == "true" ]
		then
			if [ ${#DEFER_RTVAR_ARR[@]} -gt 0 ]
			then
				echo "[$(date)] [$(basename "$0")] Unsetting DEFER_RTVAR_ARR..." | tee -a $RUNTIME_LOGFILE
				unset DEFER_RTVAR_ARR
			fi
		else
			if [ -f $DEFER_RTVAR_INFILE ]
			then
				echo "[$(date)] [$(basename "$0")] Removing DEFER_RTVAR_INFILE [$DEFER_RTVAR_INFILE]..." | tee -a $RUNTIME_LOGFILE
				rm $DEFER_RTVAR_INFILE
			fi
		fi
	else
		if [ ${#ALIAS_FOUND} -eq 0 ]
		then
			if [ $ALIAS_NAME == ".listalias" ] || [ $ALIAS_NAME == ".listalias_custom" ]
			then
				echo "[$(date)] [$(basename "$0")] ALIAS configuration file [$ALIAS_CFGFILE] does not exist or is zero-sized! Exiting..." | tee -a $RUNTIME_LOGFILE
			else
				echo "[$(date)] [$(basename "$0")] ERROR: Unable to find ALIAS_NAME[$ALIAS_NAME] in all config files! Exiting..." | tee -a $RUNTIME_LOGFILE
			fi
		else
			echo "[$(date)] [$(basename "$0")] ALIAS configuration file [$ALIAS_CFGFILE] does not exist or is zero-sized! Exiting..." | tee -a $RUNTIME_LOGFILE
		fi

		cleanUpDataDir
		exit 1
	fi
fi

if [ $VIEW_ONLY == "true" ]
then
	OPTIND=0

	# Init - to provide product info support 
	MUSTGATHER_OPT="view"

	if [ $MG_DEBUG == "true" ]
	then
		checkOSArch 
		checkBashVersion 

		if [ ${#BASH_V4} -gt 0 ] && [ $BASH_V4 == "true" ]
		then
			if [[ $(checkAssociativeArray) ]]
			then
				echo "[$(date)] [$(basename "$0")] Associative array test passed! BASH_V4 remains [true]..."
				BASH_V4="true"
			else
				echo "[$(date)] [$(basename "$0")] Associative array test failed! Resetting BASH_V4 to [false]..."
				BASH_V4="false"
			fi
		fi
	else
		checkOSArch > /dev/null
		checkBashVersion > /dev/null

		if [ ${#BASH_V4} -gt 0 ] && [ $BASH_V4 == "true" ]
		then
			if [[ $(checkAssociativeArray) ]]
			then
				BASH_V4="true"
			else
				BASH_V4="false"
			fi
		fi
	fi

	# [Hacking] Set MG_TTY to "false" to disable any user prompt
	MG_TTY="false"

	if ! checkOcCmd 
	then
		cleanUpDataDir
		exit 1
	else
		if [ $OC_CMD == "oc" ]
		then
			OC_WHOAMI=$($OC_CMD whoami)
		else
			OC_WHOAMI=$($OC_CMD config current-context | $AWK -F/ '{ print $NF }')
		fi
	fi

	if [[ $(type -t initSetup) != function ]]
	then
		setupDeferRtvarStruc > /dev/null
	fi

	while true
	do
		while getopts :V:W:Yo:D VIEW_OPTION 2> /dev/null
		do
			case $VIEW_OPTION in
				V)	;;
				W)	if [[ $(type -t initSetup) != function ]]	
					then
						# echo "[$(date)] [$(basename "$0")] [VIEW] Processing and exporting user-defined variables..."
						RUNTIME_VAR=$OPTARG
			
						if ! checkEnvVar $RUNTIME_VAR > >(tee -a $TMP_LOGFILE) 2>&1
						then
							cleanUpDataDir
							exit 1
						fi
			
						processRuntimeVar > /dev/null
					fi
					;;	
				Y) 	AUTO_YES="true"
					;;
				o) 	ROOT_OUTDIR=$OPTARG
					if [[ $OPTARG == "." ]]
					then
						ROOT_OUTDIR=$PWD
				   	fi
	
					if [[ ! "$ROOT_OUTDIR" =~ ^/ ]]
					then
						echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] must be full path (e.g. /tmp/output)!"
						cleanUpDataDir
						exit 1
					fi
	
					if [ $ROOT_OUTDIR == $MUSTGATHER_DIRNAME ]
					then
						echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] to MUSTGATHER_DIRNAME [$MUSTGATHER_DIRNAME] is NOT allowed!"
						cleanUpDataDir
						exit 1
					fi	
	
					if [[ "$ROOT_OUTDIR" =~ ^$MUSTGATHER_DIRNAME ]]
					then
						echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] to a sub-directory MUSTGATHER_DIRNAME [$MUSTGATHER_DIRNAME] is NOT allowed!"
						cleanUpDataDir
						exit 1
					fi	
					;;
				D) 	MG_DEBUG="true"
					;;
				\?)	;;
			esac
		done		

		((OPTIND++))
		[ $OPTIND -gt $# ] && break
	done

	if [ $MG_DEBUG == "true" ]
	then
		checkBashVersionAgain
	else
		checkBashVersionAgain > /dev/null
	fi

	if [ $MG_DEBUG == "true" ]
	then
		if checkCloudPlatform
		then
			echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is supported!"
			getOcVersion
		else
			echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is NOT supported!" >&2
			cleanUpDataDir
			exit 1
		fi
	else
		if checkCloudPlatform > /dev/null
		then
			getOcVersion > /dev/null
		else
			echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is NOT supported!" >&2
			cleanUpDataDir
			exit 1
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then
		setupDataDir
	else
		setupDataDir > /dev/null 
	fi

	if [ $BASH_V4 == "true" ]
	then
		declare -gA PROD_NAMESPACES_KEYVAL_ARR
		declare -gA USER_PRIV_ARR
		declare -gA EXCL_PROD_NS_ARR
	fi

	if [ $MG_DEBUG == "true" ]
	then
		getProdNamespaces $PROD_NAMESPACES_REFFILE 

		if ! checkProdNamespace
		then
		   	echo "[$(date)] [$(basename "$0")] ERROR: Unable to determine product namespaces!" | tee -a $RUNTIME_LOGFILE
		   
		   	if ! toContinue
		   	then 
		   		cleanUpDataDir
		   		exit 1
		   	fi
		fi
	else
		getProdNamespaces $PROD_NAMESPACES_REFFILE > /dev/null 2>&1

		if ! checkProdNamespace > /dev/null 2>&1
		then
		   	echo "[$(date)] [$(basename "$0")] ERROR: Unable to determine product namespaces!" | tee -a $RUNTIME_LOGFILE
		   
		   	if ! toContinue
		   	then 
		   		cleanUpDataDir
		   		exit 1
		   	fi
		fi
	fi

	if [ ${#PRODUCT_VERSION} -eq 0 ]
	then
		if [ $MG_DEBUG == "true" ]
		then
			PRODUCT_VERSION=$(getProdVersions $PROD_VERSIONS_REFFILE 2> >(tee -a $RUNTIME_LOGFILE >&2))
		else
			PRODUCT_VERSION=$(getProdVersions $PROD_VERSIONS_REFFILE 2> /dev/null)
		fi

		if [ ${#RTVAR_VIEW_PRODVER} -gt 0 ]
		then
			echo "[$(date)] [$(basename "$0")] VIEW_PRODVER is set to [$RTVAR_VIEW_PRODVER]! Resetting PRODUCT_VERSION to [$RTVAR_VIEW_PRODVER]!"
			PRODUCT_VERSION=$RTVAR_VIEW_PRODVER
		fi

		if [ $MG_DEBUG == "true" ]
		then
		   	if ! checkProdVersion 
			then
				cleanUpDataDir
				exit 1
			fi
		else
		   	if ! checkProdVersion > /dev/null 2>&1
			then
				cleanUpDataDir
				exit 1
			fi
		fi
	else
		if [ ${#RTVAR_VIEW_PRODVER} -gt 0 ]
		then
			echo "[$(date)] [$(basename "$0")] VIEW_PRODVER is set to [$RTVAR_VIEW_PRODVER]! Resetting PRODUCT_VERSION to [$RTVAR_VIEW_PRODVER]!"
			PRODUCT_VERSION=$RTVAR_VIEW_PRODVER

			if [ $MG_DEBUG == "true" ]
			then
			   	if ! checkProdVersion 
				then
					cleanUpDataDir
					exit 1
				fi
			else
			   	if ! checkProdVersion > /dev/null 2>&1
				then
					cleanUpDataDir
					exit 1
				fi
			fi
		fi
	fi

	IFS=$'\n'
	for GMGF_ENV in ${GMGF_ENV_ARR[@]}
	do
	   	if [[ $GMGF_ENV =~ ^-f ]]
	   	then
	   		VIEW_FUNCNAME=$(echo "$GMGF_ENV" | $AWK '{ print $2 }')
			
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment function [$VIEW_FUNCNAME]..."
			fi

	   		export -f $VIEW_FUNCNAME
	   	else
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$GMGF_ENV = ${!GMGF_ENV}]"
			fi

	   		export $GMGF_ENV
	   	fi
	done

	if [ $MG_DEBUG == "true" ]
	then
		deferRuntimeVar
	else
		deferRuntimeVar > /dev/null 2>&1
	fi

	VIEWMODE_USER_INPUT_ENV=$(compgen -A variable | grep -E '^RTVAR_VIEWMODE_' | tr '\n' ' ')

	if [ ${#VIEWMODE_USER_INPUT_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for USER_INPUT_ENV in $VIEWMODE_USER_INPUT_ENV
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$USER_INPUT_ENV = ${!USER_INPUT_ENV}]"
			fi

	   		export $USER_INPUT_ENV
		done	
	fi

	GMGFVAR_ENV=$(compgen -A variable | grep -E '^RTVAR_GMGFVAR_' | tr '\n' ' ')

	if [ ${#GMGFVAR_ENV} -gt 0 ]
	then
		IFS=$OLDIFS
		for GMGFVAR in $GMGFVAR_ENV
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [${FUNCNAME[0]}] Exporting environment variable [$GMGFVAR = ${!GMGFVAR}]"
			fi

			export $GMGFVAR
		done	
	fi

	VIEW_MODULE_CLUSTER_DIR=$MUSTGATHER_DIRNAME/views
	VIEW_MODULE_CLUSTER_SCRIPT=$VIEW_MODULE_CLUSTER_DIR/$VIEW_MODULE

	VIEW_MODULE_PRODUCT_ROOTDIR=$MUSTGATHER_DIRNAME/config/views
	VIEW_MODULE_PRODUCT_ROOT_SCRIPT=$VIEW_MODULE_PRODUCT_ROOTDIR/$VIEW_MODULE
	VIEW_MODULE_PRODUCT_DIR=$MUSTGATHER_DIRNAME/config/views/${PRODUCT_VERSION}
	VIEW_MODULE_PRODUCT_SCRIPT=$VIEW_MODULE_PRODUCT_DIR/$VIEW_MODULE

	VIEW_MODULE_CUSTOM_ROOTDIR=$MUSTGATHER_DIRNAME/data/views
	VIEW_MODULE_CUSTOM_ROOT_SCRIPT=$VIEW_MODULE_CUSTOM_ROOTDIR/$VIEW_MODULE
	VIEW_MODULE_CUSTOM_DIR=$MUSTGATHER_DIRNAME/data/views/${PRODUCT_VERSION}
	VIEW_MODULE_CUSTOM_SCRIPT=$VIEW_MODULE_CUSTOM_DIR/$VIEW_MODULE

	if [ "$VIEW_MODULE_OPTARG" == ".listviews" ] || [ "$VIEW_MODULE_OPTARG" == ".listviews_custom" ]
	then
		VIEW_MODULE_AVAIL="false"
		LIST_VIEW_HEADER="true"

		if [ "$VIEW_MODULE_OPTARG" == ".listviews_custom" ]
		then
			VIEW_MODULE_PRODUCT_ROOTDIR=$VIEW_MODULE_CUSTOM_ROOTDIR
			VIEW_MODULE_PRODUCT_DIR=$VIEW_MODULE_CUSTOM_DIR
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] VIEW_MODULE_PRODUCT_ROOTDIR = [$VIEW_MODULE_PRODUCT_ROOTDIR] / VIEW_MODULE_PRODUCT_DIR = [$VIEW_MODULE_PRODUCT_DIR]"	
		fi

		if [ -s $VIEW_MODULE_PRODUCT_DIR/.views.desc ]
		then
			VIEW_MODULE_AVAIL="true"	
			PRODUCT_VIEW_MODULE_WITH_DESC=()

			if [ $LIST_VIEW_HEADER == "true" ]
			then
				echo "===================================================================================================================================================================================="
				printf "%-15s %-38s %-130s \n" "SCOPE" "MODULE_NAME" "DESCRIPTION"
				echo "===================================================================================================================================================================================="
				LIST_VIEW_HEADER="false"
			fi

			while read VIEW_LINE
			do
				if [[ $(echo "$VIEW_LINE" | $AWK '{$1=$1};1') == "$VIEW_CFGFILE_COMMENT"* ]] || [[ $(echo "$VIEW_LINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi

				if [ "$VIEW_MODULE_OPTARG" == ".listviews_custom" ]
				then
					LIST_VIEW_MODULE_SCOPE="custom"
				else
					LIST_VIEW_MODULE_SCOPE="product"
				fi

				LIST_VIEW_MODULE_NAME=$(echo "$VIEW_LINE" | $AWK -F${VIEW_CFGFILE_DELIMITER} '{ print substr($1, 0, 40) }')
				LIST_VIEW_MODULE_DESC=$(echo "$VIEW_LINE" | $AWK -F${VIEW_CFGFILE_DELIMITER} '{ print $2 }')

				if [ -s $VIEW_MODULE_PRODUCT_DIR/$LIST_VIEW_MODULE_NAME ]
				then
					printf "%-15s %-38s %-130s \n" "$LIST_VIEW_MODULE_SCOPE" "$LIST_VIEW_MODULE_NAME" "$LIST_VIEW_MODULE_DESC"
					PRODUCT_VIEW_MODULE_WITH_DESC[${#PRODUCT_VIEW_MODULE_WITH_DESC[@]}]="$LIST_VIEW_MODULE_NAME"
				fi
			done < <(sort $VIEW_MODULE_PRODUCT_DIR/.views.desc)

			for LS_VIEW_MODULE in $(ls $VIEW_MODULE_PRODUCT_DIR)
			do
				VIEW_FOUND="false"

				for PRODUCT_VIEW in "${PRODUCT_VIEW_MODULE_WITH_DESC[@]}"
				do
					if [ "$PRODUCT_VIEW" == "$LS_VIEW_MODULE" ]
					then
						VIEW_FOUND="true"
						break
					fi
				done

				if [ $VIEW_FOUND == "false" ]
				then
					printf "%-15s %-38s %-130s \n" "$LIST_VIEW_MODULE_SCOPE" "$LS_VIEW_MODULE" "N/A"
				fi
			done
		fi

		if [ -s $VIEW_MODULE_PRODUCT_ROOTDIR/.views.desc ]
		then
			VIEW_MODULE_AVAIL="true"	
			PRODUCT_VIEW_MODULE_WITH_DESC=()

			if [ $LIST_VIEW_HEADER == "true" ]
			then
				printf "%-15s %-38s %-130s \n" "SCOPE" "MODULE_NAME" "DESCRIPTION"
				echo "===================================================================================================================================================================================="
				LIST_VIEW_HEADER="false"
			fi

			while read VIEW_LINE
			do
				if [[ $(echo "$VIEW_LINE" | $AWK '{$1=$1};1') == "$VIEW_CFGFILE_COMMENT"* ]] || [[ $(echo "$VIEW_LINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi

				if [ "$VIEW_MODULE_OPTARG" == ".listviews_custom" ]
				then
					LIST_VIEW_MODULE_SCOPE="custom"
				else
					LIST_VIEW_MODULE_SCOPE="product"
				fi

				LIST_VIEW_MODULE_NAME=$(echo "$VIEW_LINE" | $AWK -F${VIEW_CFGFILE_DELIMITER} '{ print substr($1, 0, 40) }')
				LIST_VIEW_MODULE_DESC=$(echo "$VIEW_LINE" | $AWK -F${VIEW_CFGFILE_DELIMITER} '{ print $2 }')

				if [ -s $VIEW_MODULE_PRODUCT_ROOTDIR/$LIST_VIEW_MODULE_NAME ]
				then
					printf "%-15s %-38s %-130s \n" "$LIST_VIEW_MODULE_SCOPE" "$LIST_VIEW_MODULE_NAME" "$LIST_VIEW_MODULE_DESC"
					PRODUCT_VIEW_MODULE_WITH_DESC[${#PRODUCT_VIEW_MODULE_WITH_DESC[@]}]="$LIST_VIEW_MODULE_NAME"
				fi
			done < <(sort $VIEW_MODULE_PRODUCT_ROOTDIR/.views.desc)

			for LS_VIEW_MODULE in $(ls -l $VIEW_MODULE_PRODUCT_ROOTDIR | grep -E -v '^d|^l|^total' | $AWK '{ print $NF }')
			do
				VIEW_FOUND="false"

				for PRODUCT_VIEW in "${PRODUCT_VIEW_MODULE_WITH_DESC[@]}"
				do
					if [ "$PRODUCT_VIEW" == "$LS_VIEW_MODULE" ]
					then
						VIEW_FOUND="true"
						break
					fi
				done

				if [ $VIEW_FOUND == "false" ]
				then
					printf "%-15s %-38s %-130s \n" "$LIST_VIEW_MODULE_SCOPE" "$LS_VIEW_MODULE" "N/A"
				fi
			done
		fi

		if [ -s $VIEW_MODULE_CLUSTER_DIR/.views.desc ] && [ "$VIEW_MODULE_OPTARG" != ".listviews_custom" ]
		then
			VIEW_MODULE_AVAIL="true"	
			CLUSTER_VIEW_MODULE_WITH_DESC=()

			if [ $LIST_VIEW_HEADER == "true" ]
			then
				printf "%-15s %-38s %-130s \n" "SCOPE" "MODULE_NAME" "DESCRIPTION"
				echo "===================================================================================================================================================================================="
				LIST_VIEW_HEADER="false"
			fi
				
			while read VIEW_LINE
			do
				if [[ $(echo "$VIEW_LINE" | $AWK '{$1=$1};1') == "$VIEW_CFGFILE_COMMENT"* ]] || [[ $(echo "$VIEW_LINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi

				LIST_VIEW_MODULE_SCOPE="cluster"
				LIST_VIEW_MODULE_NAME=$(echo "$VIEW_LINE" | $AWK -F${VIEW_CFGFILE_DELIMITER} '{ print substr($1, 0, 40) }')
				LIST_VIEW_MODULE_DESC=$(echo "$VIEW_LINE" | $AWK -F${VIEW_CFGFILE_DELIMITER} '{ print $2 }')

				if [ -s $VIEW_MODULE_CLUSTER_DIR/$LIST_VIEW_MODULE_NAME ]
				then
					printf "%-15s %-38s %-130s \n" "$LIST_VIEW_MODULE_SCOPE" "$LIST_VIEW_MODULE_NAME" "$LIST_VIEW_MODULE_DESC"
					CLUSTER_VIEW_MODULE_WITH_DESC[${#CLUSTER_VIEW_MODULE_WITH_DESC[@]}]="$LIST_VIEW_MODULE_NAME"
				fi
			done < $VIEW_MODULE_CLUSTER_DIR/.views.desc

			for LS_VIEW_MODULE in $(ls $VIEW_MODULE_CLUSTER_DIR)
			do
				VIEW_FOUND="false"

				for CLUSTER_VIEW in "${CLUSTER_VIEW_MODULE_WITH_DESC[@]}"
				do
					if [ "$CLUSTER_VIEW" == "$LS_VIEW_MODULE" ]
					then
						VIEW_FOUND="true"
						break
					fi
				done

				if [ $VIEW_FOUND == "false" ]
				then
					printf "%-15s %-38s %-130s \n" "$LIST_VIEW_MODULE_SCOPE" "$LS_VIEW_MODULE" "N/A"
				fi
			done
		fi

		if [ $VIEW_MODULE_AVAIL == "false" ]
		then
			echo

			if [ "$VIEW_MODULE_OPTARG" == ".listviews_custom" ]
			then
				echo "ERROR: No custom VIEW-ONLY module is available!"
			else
				echo "ERROR: No VIEW-ONLY module is available!"
			fi
		fi

	   	cleanUpDataDir > /dev/null
		exit 0
	fi

	# If 2 scripts of the same name are found, product script takes precedence
	if [ -s $VIEW_MODULE_PRODUCT_SCRIPT ]
	then
		VIEW_MODULE_SCRIPT=$VIEW_MODULE_PRODUCT_DIR/$VIEW_MODULE
		VIEW_MODULE_CMD=$VIEW_MODULE_PRODUCT_DIR/$VIEW_MODULE_OPTARG
	else
		if [ -s $VIEW_MODULE_PRODUCT_ROOT_SCRIPT ]
		then
			VIEW_MODULE_SCRIPT=$VIEW_MODULE_PRODUCT_ROOTDIR/$VIEW_MODULE
			VIEW_MODULE_CMD=$VIEW_MODULE_PRODUCT_ROOTDIR/$VIEW_MODULE_OPTARG
		else
			if [ -s $VIEW_MODULE_CLUSTER_SCRIPT ]
			then
				VIEW_MODULE_SCRIPT=$VIEW_MODULE_CLUSTER_DIR/$VIEW_MODULE
				VIEW_MODULE_CMD=$VIEW_MODULE_CLUSTER_DIR/$VIEW_MODULE_OPTARG
			else
				if [ -s $VIEW_MODULE_CUSTOM_SCRIPT ]
				then
					VIEW_MODULE_SCRIPT=$VIEW_MODULE_CUSTOM_DIR/$VIEW_MODULE
					VIEW_MODULE_CMD=$VIEW_MODULE_CUSTOM_DIR/$VIEW_MODULE_OPTARG
				else
					if [ -s $VIEW_MODULE_CUSTOM_ROOT_SCRIPT ]
					then
						VIEW_MODULE_SCRIPT=$VIEW_MODULE_CUSTOM_ROOTDIR/$VIEW_MODULE
						VIEW_MODULE_CMD=$VIEW_MODULE_CUSTOM_ROOTDIR/$VIEW_MODULE_OPTARG
					else
						echo "[$(date)] [$(basename "$0")] View module [$VIEW_MODULE] is not available. Exiting..."
			   			cleanUpDataDir > /dev/null
						exit 1
					fi
				fi
			fi
		fi
	fi

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] VIEW_MODULE_SCRIPT = [$VIEW_MODULE_SCRIPT] / VIEW_MODULE_CMD = [$VIEW_MODULE_CMD]"
	fi
	 
	if [ -s $VIEW_MODULE_SCRIPT ]
	then
		if [ ${#TIMEOUT} -eq 0 ]
		then
			VIEW_MODULE_TO_EXEC="$TIMEOUT $VIEW_TVALUE /bin/bash $VIEW_MODULE_CMD"
		else
			VIEW_MODULE_TO_EXEC="/bin/bash $VIEW_MODULE_CMD"
		fi

		eval $VIEW_MODULE_TO_EXEC
	else
		echo "[$(date)] [$(basename "$0")] View module [$VIEW_MODULE] is not available at [$VIEW_MODULE_SCRIPT]. Exiting..."
	fi 
	
	cleanUpDataDir > /dev/null
	exit 0
fi

# Handling for PRIMARY/SECONDARY modes
if [ ! $ALIAS_MODE == "true" ] && [ ! $VIEW_ONLY == "true" ]
then
	MUSTGATHER_ALL_OPT_MOD=$@

	ORI_POS_PARAM_CTR=0
	for ORI_POS_PARAM in $@
	do
		(( ORI_POS_PARAM_CTR=ORI_POS_PARAM_CTR+1 ))

		if [ ${#MUSTGATHER_ALL_OPT_ORI_POS_PARAM} -eq 0 ]
		then
			MUSTGATHER_ALL_OPT_ORI_POS_PARAM="[$ORI_POS_PARAM_CTR] $ORI_POS_PARAM"
		else
			MUSTGATHER_ALL_OPT_ORI_POS_PARAM="$MUSTGATHER_ALL_OPT_ORI_POS_PARAM / [$ORI_POS_PARAM_CTR] $ORI_POS_PARAM"
		fi
	done

	MOD_POS_PARAM_CTR=0
	for MOD_POS_PARAM in $@
	do
		(( MOD_POS_PARAM_CTR=MOD_POS_PARAM_CTR+1 ))

		if [ ${#MUSTGATHER_ALL_OPT_MOD_POS_PARAM} -eq 0 ]
		then
			MUSTGATHER_ALL_OPT_MOD_POS_PARAM="[$MOD_POS_PARAM_CTR] $MOD_POS_PARAM"
		else
			MUSTGATHER_ALL_OPT_MOD_POS_PARAM="$MUSTGATHER_ALL_OPT_MOD_POS_PARAM / [$MOD_POS_PARAM_CTR] $MOD_POS_PARAM"
		fi
	done
		
	OPTIND=0
fi

if [[ $(type -t initSetup) == function ]] 
then 
	if [ $ALIAS_MODE == "true" ]
	then	
		setupDeferRtvarStruc > >(tee -a $TMP_LOGFILE) 2>&1
	fi
else
	checkOSArch > >(tee -a $TMP_LOGFILE) 2>&1
	checkTty > >(tee -a $TMP_LOGFILE) 2>&1
	checkBashVersion > >(tee -a $TMP_LOGFILE) 2>&1

	if [ ${#BASH_V4} -gt 0 ] && [ $BASH_V4 == "true" ]
	then
		if [[ $(checkAssociativeArray) ]]
		then
			echo "[$(date)] [$(basename "$0")] Associative array test passed! BASH_V4 remains [true]..." | tee -a $TMP_LOGFILE
			BASH_V4="true"
		else
			echo "[$(date)] [$(basename "$0")] Associative array test failed! Resetting BASH_V4 to [false]..." | tee -a $TMP_LOGFILE
			BASH_V4="false"
		fi
	fi

	setupDeferRtvarStruc > >(tee -a $TMP_LOGFILE) 2>&1
fi

while true
do
	while getopts ":abcdk:li:e:fgm:n:j:B:o:pstu:w:x:yz:vhC:E:F:KT:L:P:Z:Q:A:RSG:W:NIJXYHUMD" opt 2> /dev/null
	do
		case $opt in
			# PRIMARY data collection modes
			# [ALL]
			a) MUSTGATHER_OPT="all"	
			   PRIMARY_MODE_ARRAY[${#PRIMARY_MODE_ARRAY[@]}]="-a"
			   GET_NODES_DATA="true"
			   OPTSET=1
				;;
			# [COMPREHENSIVE]
			c) MUSTGATHER_OPT="comprehensive"
			   PRIMARY_MODE_ARRAY[${#PRIMARY_MODE_ARRAY[@]}]="-c"
			   OPTSET=1
				;;
			# [BASIC]
			b) MUSTGATHER_OPT="basic"	
			   PRIMARY_MODE_ARRAY[${#PRIMARY_MODE_ARRAY[@]}]="-b"
			   OPTSET=1
				;;
			# [LIMITED]
			l) MUSTGATHER_OPT="limited"
			   PRIMARY_MODE_ARRAY[${#PRIMARY_MODE_ARRAY[@]}]="-l"
			   # OC_DESC_ON="false"
			   OPTSET=1
				;;
			# [MODULES]
			z) MUSTGATHER_OPT="modules"
			   PRIMARY_MODE_ARRAY[${#PRIMARY_MODE_ARRAY[@]}]="-z"
			   MODULES=$OPTARG
			   OPTSET=1
	
			   if [ $MODULES == ".listmodules" ]
			   then
			   	if [ ! -d $MUSTGATHER_DIRNAME/config/modules ]
			   	then
					MODULES_LISTING_SYSTEM_HELPFILE=$MUSTGATHER_DIRNAME/modules.help
	
					if [ -s $MUSTGATHER_DIRNAME/config/modules.help ]
					then
						MODULES_LISTING_HELPFILE=$MUSTGATHER_DIRNAME/config/modules.help
						MODULES_LISTING_HELPFILE_TYPE="product"
					else
						MODULES_LISTING_HELPFILE=$MODULES_LISTING_SYSTEM_HELPFILE
						MODULES_LISTING_HELPFILE_TYPE="system"
					fi
	
					VMOD_CTR=1
		
					echo "==================================================================================================================================================" 
					printf "%-25s %-70s %-30s \n" "MODULE" "DESCRIPTION" "EXAMPLE"
					echo "==================================================================================================================================================" 
	
					for VMOD in $(sort <<<"${VALID_MODULES[*]}")
					do
						if [ -s $MODULES_LISTING_HELPFILE ]
						then
							MODULES_LISTING_DESC=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $2 }')
							MODULES_LISTING_EXAMPLE=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $3 }')
						
							if [ ${#MODULES_LISTING_DESC} -eq 0 ]
							then
								if [ $MODULES_LISTING_HELPFILE_TYPE == "product" ]
								then
									MODULES_LISTING_DESC=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_SYSTEM_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $2 }')
	
									if [ ${#MODULES_LISTING_DESC} -eq 0 ]
									then
										MODULES_LISTING_DESC="N/A"
									fi
								else
									MODULES_LISTING_DESC="N/A"
								fi
							fi	
	
							if [ ${#MODULES_LISTING_EXAMPLE} -eq 0 ]
							then
								if [ $MODULES_LISTING_HELPFILE_TYPE == "product" ]
								then
									MODULES_LISTING_EXAMPLE=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_SYSTEM_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $3 }')
	
									if [ ${#MODULES_LISTING_EXAMPLE} -eq 0 ]
									then
										MODULES_LISTING_EXAMPLE="N/A"
									fi
								else
									MODULES_LISTING_EXAMPLE="N/A"
								fi
							fi	
						else
							MODULES_LISTING_DESC="N/A"
							MODULES_LISTING_EXAMPLE="N/A"
						fi
	
						printf "%-25s %-70s %-30s \n" "[$VMOD_CTR] $VMOD" "$MODULES_LISTING_DESC" "$MODULES_LISTING_EXAMPLE"
	
						(( VMOD_CTR=VMOD_CTR+1 ))
					done
		
					exit 0
				else
					MODULES_LISTING="true"
				fi
			   fi
				;;
			k) MUSTGATHER_OPT="selective"
			   PRIMARY_MODE_ARRAY[${#PRIMARY_MODE_ARRAY[@]}]="-k"
			   SELECTIVE_RESOURCES=$OPTARG
			   OPTSET=1
	
			   CUSTOM_DATA_ENABLED="false"
				;;
			# SECONDARY data collection modes
			# [CLUSTERNODES]
			d) SECONDARY_MODE_ARRAY[${#PRIMARY_MODE_ARRAY[@]}]="-d"
			   GET_NODES_DATA="true"
				;;
			# [CMDEXEC]
			C) SECONDARY_MODE_ARRAY[${#SECONDARY_MODE_ARRAY[@]}]="-C"
			   CMD_EXEC_INPUT=$OPTARG
			   CMD_EXEC_CMD=$(echo "$CMD_EXEC_INPUT" | $AWK -F'##' '{ print $1 }')
			   CMD_EXEC_FILE=$(echo "$CMD_EXEC_CMD" | $AWK '{ print $1 }')
			   CMD_EXEC_PARAM=$(echo "$CMD_EXEC_CMD" | $AWK '{$1=""}1' | $AWK '{$1=$1}1')
			   CMD_EXEC_ENVFILE=$(echo "$CMD_EXEC_INPUT" | $AWK -F'##' '{ print $2 }')
				;;
			# [MANUALCOLLECT]
			m) SECONDARY_MODE_ARRAY[${#SECONDARY_MODE_ARRAY[@]}]="-m"
			   MANUAL_COLL_INPUT=$OPTARG
			   MANUAL_COLL=1
	
			   MANUAL_COLL_INPUT_COLS=$(echo "$MANUAL_COLL_INPUT" | $AWK -F: '{ print NF }')

			   if [ $MANUAL_COLL_INPUT_COLS -eq 2 ]
			   then
				MANUAL_COLL_INPUTTAG=$(echo "$MANUAL_COLL_INPUT" | $AWK -F: '{ print $1 }')
				MANUAL_COLL_INPUTFILE=$(echo "$MANUAL_COLL_INPUT" | $AWK -F: '{ print $2 }')
			   else
				if [ $MANUAL_COLL_INPUT_COLS -eq 1 ]
				then
					# If user only provides one argument to '-m' option, it will be assumed to be an input file
					MANUAL_COLL_INPUTTAG="ALL"
					MANUAL_COLL_INPUTFILE=$MANUAL_COLL_INPUT
				else
					echo "[$(date)] [$(basename "$0")] ERROR: Input of MANUALCOLLECT mode (-m) is invalid [$MANUAL_COLL_INPUT]! Exiting..."
					cleanUpDataDir
					exit 1
				fi
			   fi
	
			   if [[ $MANUAL_COLL_INPUTFILE =~ ^/ ]] || [[ $MANUAL_COLL_INPUTFILE =~ ^./ ]]
			   then
				if ! checkInputFile $MANUAL_COLL_INPUTFILE
			 	then
					echo "[$(date)] [$(basename "$0")] Input file for function getManualCollection() [$MANUAL_COLL_INPUTFILE] is a directory or unavailable or zero-sized. Exiting..."
					cleanUpDataDir
					exit 1
				fi
		
				if ! validateManualCollection $MANUAL_COLL_INPUTFILE
				then
					echo "[$(date)] [$(basename "$0")] Input file for function getManualCollection() [$MANUAL_COLL_INPUTFILE] does not contain any configuration. Exiting..."
					cleanUpDataDir
					exit 1
				fi

				# MANUAL_COLL_CUSTOM_DATA is a flag to indicate whether GMGF should try to locate MANUALCOLLECT config file in the 'data' directory
				MANUAL_COLL_CUSTOM_DATA="false"
			   else
				case "$MANUAL_COLL_INPUTFILE" in
					mc.cfg)			MANUAL_COLL_CUSTOM_DATA="false"
									;;
					.listmc)			MANUAL_COLL_CUSTOM_DATA="false"
									;;
					mc_custom.cfg)		MANUAL_COLL_CUSTOM_DATA="true"
									;;
					.listmc_custom)	MANUAL_COLL_CUSTOM_DATA="true"
									;;
					*)				echo "[$(date)] [$(basename "$0")] Cannot provide custom MANUALCOLLECT (-m) input file using just the filename [$MANUAL_COLL_INPUTFILE]! Please use full/absolute path! Exiting..."
									cleanUpDataDir
									exit 1
									;;
				esac
			   fi
				;;
			# [EXTRA_NAMESPACES]
			e) SECONDARY_MODE_ARRAY[${#SECONDARY_MODE_ARRAY[@]}]="-e"		
			   EXTRA_NAMESPACES=$OPTARG
				;;
			# [MISSINGOBJ]
			x) SECONDARY_MODE_ARRAY[${#SECONDARY_MODE_ARRAY[@]}]="-x"		
			   MISSINGOBJ_VERSION=$OPTARG
		
			   if [ $MISSINGOBJ_VERSION != "X" ]
			   then
				if [[ $MISSINGOBJ_VERSION =~ ^/ ]] || [[ $MISSINGOBJ_VERSION =~ ^\. ]]
				then
					if [ -s $MISSINGOBJ_VERSION ]
					then
						if [[ $MISSINGOBJ_VERSION =~ ^\. ]]
						then
							MISSINGOBJ_CUR_DIR=$PWD
							MISSINGOBJ_INPUTFILE_DIR=$(dirname $MISSINGOBJ_VERSION)
							
							if [ -d $INPUTFILE_DIR ]
							then
								cd $MISSINGOBJ_INPUTFILE_DIR
								MISSINGOBJ_INPUTFILE_DIR=$PWD
								cd $MISSINGOBJ_CUR_DIR
							else
								echo "[$(date)] [$(basename "$0")] MISSINGOBJ input file [$MISSINGOBJ_VERSION] does not exist or is zero-sized! Exiting..."
								cleanUpDataDir
								exit 1
							fi
	
							MISSINGOBJ_INPUTFILE=$MISSINGOBJ_INPUTFILE_DIR/$(basename $MISSINGOBJ_VERSION)
						else
							MISSINGOBJ_INPUTFILE=$MISSINGOBJ_VERSION
						fi
					else
						echo "[$(date)] [$(basename "$0")] MISSINGOBJ input file [$MISSINGOBJ_VERSION] does not exist or is zero-sized! Exiting..."
						cleanUpDataDir
						exit 1
					fi
				else
					if [[ "$MISSINGOBJ_VERSION" =~ ^[0-9] ]]
					then
						USERSET_MISSINGOBJ_VERSION=1
			
						if ! checkMissingObjVersion
						then
					   		echo "[$(date)] [$(basename "$0")] Product '${PRODUCT_NAME}' version $OPTARG is not supported"
							echoProductSupportedVersions
							echoProductCorrectiveActions
							cleanUpDataDir
						   	exit 1
						fi
					else
						# Custom MISSINGOBJ configuration file should NOT start with a number (to not get mixed up with version - see above)
						# Search sequence (priority is given to configuration file tagged against a product version):
						# (1) $MUSTGATHER_DIRNAME/data/missingobj/<PROD_VER>
						# (2) $MUSTGATHER_DIRNAME/data/missingobj
						USERSET_MISSINGOBJ_CFGFILE=$MISSINGOBJ_VERSION
					fi
				fi
			   else
				if [ ${#ALIAS_MODE} -gt 0 ] && [ ${ALIAS_MODE} == "true" ]
				then
					if [ ${#PRODUCT_VERSION} -gt 0 ]
					then
						echo "[$(date)] [$(basename "$0")] Auto-expand [-x $OPTARG] => Setting MISSINGOBJ_VERSION to [${PRODUCT_VERSION}]..."
						MISSINGOBJ_VERSION=${PRODUCT_VERSION}
					else
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [$(basename "$0")] PRODUCT_VERSION is null! Unable to set MISSINGOBJ_VERSION!"
						fi
					fi
				fi
			   fi
	
			   GET_MISS_OBJ="true"
				;;
			# [COMPLIANCE] 
			A) SECONDARY_MODE_ARRAY[${#SECONDARY_MODE_ARRAY[@]}]="-A"
			   COMPLIANCE_USERINPUT=$OPTARG
	
			   COMPLIANCE_INPUTTAG=$(echo "$COMPLIANCE_USERINPUT" | $AWK -F: '{ print $1 }')
			   COMPLIANCE_INPUTFILE=$(echo "$COMPLIANCE_USERINPUT" | $AWK -F: '{ print $2 }')
	
			   if [ ${#COMPLIANCE_INPUTFILE} -gt 0 ]
			   then
				if [ $COMPLIANCE_INPUTFILE != "custom" ]
				then
					if [ ! -s $COMPLIANCE_INPUTFILE ]
					then
						echo "[$(date)] [$(basename "$0")] User input compliance file [$COMPLIANCE_INPUTFILE] does not exist or is zero-sized! Setting to default..."
						COMPLIANCE_INPUTFILE=""
					else
						COMPLIANCE_CUSTOM_INPUTFILE="true"
					fi
				fi
			   fi
				
			   GET_COMPLIANCE="true"
				;;
			# [PLUGINS]
			P) SECONDARY_MODE_ARRAY[${#SECONDARY_MODE_ARRAY[@]}]="-P"
			   PLUGINS_USERINPUT=$OPTARG
			   PLUGINS=$(echo "$PLUGINS_USERINPUT" | $AWK '{ print $1 }')
	
			   if ! checkPlugins
			   then
				cleanUpDataDir
				exit 1
			   fi
				;;
			# [CPFILES]
			F) SECONDARY_MODE_ARRAY[${#SECONDARY_MODE_ARRAY[@]}]="-F"
			   CPFILES_FILES=$OPTARG
	
			   if ! checkCpFilesFormat $CPFILES_FILES
			   then
				echo "[$(date)] [$(basename "$0")] User input [$CPFILES_FILES] for "cpfiles" collection mode is invalid!"
				cleanUpDataDir
				exit 1
			   else
				CPFILES_ENABLED="true"
			   fi
				;;
			# [SNAPSHOTS]
			K) SECONDARY_MODE_ARRAY[${#SECONDARY_MODE_ARRAY[@]}]="-K"	
			   DIFF_SNAPSHOTS="true"
				;;
			# Supporting options for PRIMARY/SECONDARY data collection modes
			W) if [[ $(type -t initSetup) != function ]]	|| [ $ALIAS_MODE == "true" ]
			   then
				# echo "[$(date)] [$(basename "$0")] [NORMAL] Processing and exporting user-defined variables..."
				RUNTIME_VAR=$OPTARG
		
				if ! checkEnvVar $RUNTIME_VAR > >(tee -a $TMP_LOGFILE) 2>&1
				then
					# echo "[$(date)] [$(basename "$0")] User input [$RUNTIME_VAR] is invalid or not in the right format [VAR1=VALUE1##VAR2=VALUE2xi##,...]"
					cleanUpDataDir
					exit 1
				fi
		
				processRuntimeVar > >(tee -a $TMP_LOGFILE) 2>&1
			   fi
				;;	
			# Supporting options for SECONDARY data collection modes
			# [CLUSTERNODES] Journal size (number of lines)
			L) JOURNAL_SIZE=$OPTARG
			   JOURNAL_SIZE_CUSTOM="true"
				;;
			# [CLUSTERNODES] SSH key [experimental]
			i) SSHKEY=$OPTARG
			   echoSSHWarning
				;;
			# [CLUSTERNODES] Cluster node admin username
			u) NODE_ADMIN_USER=$OPTARG
			   ADMUSERSET=1
			   USE_OC_DEBUG=0
				;;
			# [CLUSTERNODES] To use SSH
			s) USE_OC_DEBUG=0
				;;
			# [CMDEXEC] Environment variables
			E) CMD_EXEC_ENV=$OPTARG
	
			   if ! checkEnvVar $CMD_EXEC_ENV
			   then
				# echo "[$(date)] [$(basename "$0")] User input [$CMD_EXEC_ENV] is invalid or not in the right format [VAR1=VALUE1##VAR2=VALUE2##...]"
				cleanUpDataDir
				exit 1
			   fi
				;;	
			# [CMDEXEC] Execution timeout value
			T) IN_CMD_EXEC_TVALUE=$OPTARG
				;;
			# [MANUALCOLLECT] Environment variables
			n) MANUAL_COLL_ENV=$OPTARG
	
			   if ! checkEnvVar $MANUAL_COLL_ENV
			   then
				# echo "[$(date)] [$(basename "$0")] User input [$MANUAL_COLL_ENV] is invalid or not in the right format [VAR1=VALUE1##VAR2=VALUE2xi##,...]"
				cleanUpDataDir
				exit 1
			   fi
				;;
			# [MANUALCOLLECT] OBJNAME value dynamic substitution
			j) MANUAL_COLL_OBJNAME=$OPTARG
			
			   if [ ${#MANUAL_COLL_OBJNAME} -eq 0 ]
			   then
				echo "[$(date)] [$(basename "$0")] User input MANUAL_COLL_OBJNAME is blank or null! Exiting..."
				cleanUpDataDir
				exit 1
			   fi
			   
			   if ! checkManualCollectObjName $MANUAL_COLL_OBJNAME
			   then
				echo "[$(date)] [$(basename "$0")] User input [$MANUAL_COLL_OBJNAME] is invalid! Exiting..."
				cleanUpDataDir
				exit 1
			   fi
				;;
			# [MANUALCOLLECT] EXECPREP value dynamic substitution
			B) MANUAL_COLL_EXECPREP=$OPTARG
	
			   if [ ${#MANUAL_COLL_EXECPREP} -eq 0 ]
			   then
				echo "[$(date)] [$(basename "$0")] User input MANUAL_COLL_EXECPREP is blank or null! Exiting..."
				cleanUpDataDir
				exit 1
			   fi
			   
			   if ! checkManualCollectExecPrep $MANUAL_COLL_EXECPREP
			   then
				echo "[$(date)] [$(basename "$0")] User input [$MANUAL_COLL_EXECPREP] is invalid! Exiting..."
				cleanUpDataDir
				exit 1
			   fi
				;;
			# [MANUALCOLLECT] EXECCMD timeout value
			w) IN_MANUAL_COLLECT_EXEC_TVALUE=$OPTARG
				;;
			# [PLUGINS] Environment variables
			Z) PLUGINS_ENV=$OPTARG
	
			   if ! checkEnvVar $PLUGINS_ENV
			   then
				# echo "[$(date)] [$(basename "$0")] User input [$PLUGINS_ENV] is invalid or not in the right format [VAR1=VALUE1##VAR2=VALUE2##...]"
				cleanUpDataDir
				exit 1
			   fi
				;;	
			# [PLUGINS] Execution timeout value
			Q) IN_PLUGINS_TIMEOUT=$OPTARG
				;;
			# General supporting options both PRIMARY and SECONDARY data collection modes
			t) OC_DESC_ON="false"
				;;
			g) GET_POD_LOGS="false"
				;;
			p) COLL_PREV_LOGS="true"
				;;
			y) COLLECT_YAML="true"
				;;
			J) COLLECT_JSON="true"
				;;
			f) GET_PVC_USAGE="true"
				;;
			G) GREP_PATTERN=$OPTARG
	
			   if ! checkGrepPattern "$GREP_PATTERN"
			   then
				cleanUpDataDir
				exit 1
			   fi
				;;
			N) ALLNS_DATA="true"
				;;
			S) IS_SENSITIVE_DATA_ALLOWED="true"
				;;
			I) INCIDENT_REPORT_ENABLED="true"
				;;
			X) CUSTOM_DATA_ENABLED="false"
				;;
			# View modes - display SUMMARY.log on screen
			R) REPORT_ON_SCREEN="true"
				;;
			# Miscellaneous
			o) ROOT_OUTDIR=$OPTARG
			   if [[ $OPTARG == "." ]]
			   then
				ROOT_OUTDIR=$PWD
			   fi
	
			   if [[ ! "$ROOT_OUTDIR" =~ ^/ ]]
			   then
				echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] must be full path (e.g. /tmp/output)!"
				cleanUpDataDir
				exit 1
			   fi
	
			   if [ $ROOT_OUTDIR == $MUSTGATHER_DIRNAME ]
			   then
				echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] to MUSTGATHER_DIRNAME [$MUSTGATHER_DIRNAME] is NOT allowed!"
				cleanUpDataDir
				exit 1
			   fi	
	
			   if [[ "$ROOT_OUTDIR" =~ ^$MUSTGATHER_DIRNAME ]]
			   then
				echo "[$(date)] [$(basename "$0")] FATAL: Setting of ROOT_OUTDIR [$ROOT_OUTDIR] to a sub-directory MUSTGATHER_DIRNAME [$MUSTGATHER_DIRNAME] is NOT allowed!"
				cleanUpDataDir
				exit 1
			   fi	
				;;
			Y) AUTO_YES="true"
				;;
			H) GET_DEPENDENCY_DATA="true"
				;;
			v) echoVersion; exit 0
				;;
			h) echoUsage; exit 0
				;;
			U) CHECK_FOR_UPDATE="true"
				;;
			M) AUTO_CHECK_UPDATE="false"
				;;
			D) MG_DEBUG="true"
				;;
			\?) echo "[ERROR] Invalid option = -$OPTARG [OPTIND=$OPTIND]"
			    echo; echoUsage; cleanUpDataDir; exit 1
				;;
		esac
	done

	((OPTIND++))
	[ $OPTIND -gt $# ] && break
done

if [[ $(type -t initSetup) != function ]] 
then 
	checkBashVersionAgain > >(tee -a $TMP_LOGFILE) 2>&1

	if [ $DEFER_EXEC_MODE_CHECK == "true" ]
	then
		# Deferred ALIAS_MODE_ONLY handling due to user provided runtime variable (-W)
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] ALIAS_MODE_ONLY_ORIG = [$ALIAS_MODE_ONLY_ORIG] / ALIAS_MODE_ONLY = [$ALIAS_MODE_ONLY]" | tee -a $TMP_LOGFILE
		fi
	
		if [ $ALIAS_MODE_ONLY_ORIG == "true" ] && [ $ALIAS_MODE_ONLY == "true" ]
		then
			# ALIAS_MODE_ONLY did not change, all good!
			if [ $ALIAS_MODE == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] [1] Deferred execution mode check completed! To proceed in ALIAS mode..." | tee -a $TMP_LOGFILE
			else
				echo "[$(date)] [$(basename "$0")] [1] Deferred execution mode check completed! To proceed normally..." | tee -a $TMP_LOGFILE
			fi
		else
			if [ $ALIAS_MODE_ONLY_ORIG == "true" ] && [ $ALIAS_MODE_ONLY == "false" ]
			then
				# User overrode ALIAS_MODE_ONLY to 'false'
				printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: ALIAS_MODE_ONLY was overridden [true -> false]! Proceeding...${NORMAL}${NEWLINE}"
				echo "[$(date)] [$(basename "$0")] WARNING: ALIAS_MODE_ONLY was overridden [true -> false]! Proceeding..." >> $TMP_LOGFILE
				sleep $DEFAULT_SLEEP_SEC
			else
				if [ $ALIAS_MODE_ONLY_ORIG == "false" ] && [ $ALIAS_MODE_ONLY == "true" ]
				then
					# User overrode ALIAS_MODE_ONLY to 'true' - no idea why the user would do that!?
					echo "[$(date)] [$(basename "$0")] Execution can only proceed with ALIAS mode [-O]! To list supported aliases, execute '-O .listalias'! Exiting..."
					cleanUpDataDir
					exit 1
				else
					# ALIAS_MODE_ONLY remains 'false', all good!
					if [ $ALIAS_MODE == "true" ]
					then
						echo "[$(date)] [$(basename "$0")] [2] Deferred execution mode check completed! To proceed in ALIAS mode..." | tee -a $TMP_LOGFILE
					else
						echo "[$(date)] [$(basename "$0")] [2] Deferred execution mode check completed! To proceed normally..." | tee -a $TMP_LOGFILE
					fi
				fi
			fi
		fi
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] No deferred execution mode check is needed!" | tee -a $TMP_LOGFILE
		fi
	fi

	if checkCloudPlatform > >(tee -a $TMP_LOGFILE) 2>&1
	then
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is supported!" | tee -a $TMP_LOGFILE
		fi
	
		getOcVersion > >(tee -a $TMP_LOGFILE) 2>&1
	else
		echo "[$(date)] [$(basename "$0")] CLOUD_PLATFORM [$CLOUD_PLATFORM] is NOT supported!" >&2
		cleanUpDataDir
		exit 1
	fi
fi

if [ $VIEW_ONLY == "true" ]
then
	echo "[$(date)] [$(basename "$0")] INFO: Entering VIEW-ONLY mode. Setting OC_DESC_ON, COLLECT_YAML, COLLECT_JSON, GET_POD_LOGS and COLL_PREV_LOGS to [false]!"
	OC_DESC_ON="false"
	COLLECT_YAML="false" 
	COLLECT_JSON="false" 
	GET_POD_LOGS="false"
	COLL_PREV_LOGS="false"

	echo "[$(date)] [$(basename "$0")] INFO: Entering VIEW-ONLY mode. Setting REPORT_ON_SCREEN to [true]!"
	REPORT_ON_SCREEN="true"
fi

if [ -d $ROOT_OUTDIR ]
then
	if ! touch $ROOT_OUTDIR/testmg-$$
	then
		echo "[$(date)] [$(basename "$0")] FATAL: Unable to write to ROOT_OUTDIR [$ROOT_OUTDIR]!"
		cleanUpDataDir
		exit 1
	else
		rm $ROOT_OUTDIR/testmg-$$
	fi
else
	if ! mkdir $ROOT_OUTDIR
	then
		echo "[$(date)] [$(basename "$0")] FATAL: Unable to create ROOT_OUTDIR [$ROOT_OUTDIR]!"
		cleanUpDataDir
		exit 1	
	fi
fi

# If CHECK_FOR_UPDATE (option -U) is true
if [ $CHECK_FOR_UPDATE == "true" ] 
then
	if [[ $(type -t checkForUpdate) == function ]]
	then
		UPDATE_TO_PROCEED="true"

		if [ ${#UPDATE_PING_CHECK} -gt 0 ]
		then
			if [ ${UPDATE_PING_CHECK} == "true" ]
			then
				# To make sure there's proper network connection
				echo "[$(date)] [$(basename "$0")] INFO: Testing network connection [$MG_PING_CHECK_URL]..."
		
				if ! ping -c2 -W2 $MG_PING_CHECK_URL > /dev/null
				then
					printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}ERROR: Ping test failed! Skipping manual-upgrade...${NORMAL}${NEWLINE}"
					UPDATE_TO_PROCEED="false"
				fi
			else
				echo "[$(date)] [$(basename "$0")] System variable UPDATE_PING_CHECK is set to [$UPDATE_PING_CHECK]! Skipping network connection test..."
			fi
		else
			echo "[$(date)] [$(basename "$0")] System variable UPDATE_PING_CHECK is not set! Not checking network connection..."
		fi

		if [ ${UPDATE_TO_PROCEED} == "true" ]
		then
			if checkForUpdate 
			then
				echo "[$(date)] [$(basename "$0")] INFO: Function checkForUpdate() is executed! Please rerun the mustgather command without the '-U' option!"
				cleanUpDataDir
				exit 0
			else
				if [ $? == $MG_LATEST_VER_CODE ]
				then
					cleanUpDataDir
					exit 0
				else
					printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}ERROR: Function checkForUpdate() failed! Please refer to any error messages printed above!${NORMAL}${NEWLINE}"
					cleanUpDataDir
					exit 1
				fi
			fi
		fi
	else
		echo "[$(date)] [$(basename "$0")] ERROR: Function checkForUpdate() is not implemented!. Exiting..."
		cleanUpDataDir
		exit 1
	fi
else
	# Auto update if AUTO_CHECK_UPDATE is set to "true" in config/product.cfg
	if [ ${#AUTO_CHECK_UPDATE} -gt 0 ]
	then
		if [ $(echo "$AUTO_CHECK_UPDATE" | $AWK '{ print tolower($0) }') == "true" ]	
		then
			UPDATE_TO_PROCEED="true"
	
			if [ ${#UPDATE_PING_CHECK} -gt 0 ]
			then
				if [ ${UPDATE_PING_CHECK} == "true" ]
				then
					# To make sure there's proper network connection
					echo "[$(date)] [$(basename "$0")] INFO: Testing network connection [$MG_PING_CHECK_URL]..." | tee -a $TMP_LOGFILE
			
					if ! ping -c2 -W2 $MG_PING_CHECK_URL > /dev/null
					then
						printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}ERROR: Ping test failed! Skipping manual-upgrade...${NORMAL}${NEWLINE}"
						echo "[$(date)] [$(basename "$0")] ERROR: Ping test failed! Skipping manual-upgrade..." >> $TMP_LOGFILE
						UPDATE_TO_PROCEED="false"
					fi
				else
					echo "[$(date)] [$(basename "$0")] System variable UPDATE_PING_CHECK is set to [$UPDATE_PING_CHECK]! Skipping network connection test..." | tee -a $TMP_LOGFILE
				fi
			else
				echo "[$(date)] [$(basename "$0")] System variable UPDATE_PING_CHECK is not set! Not checking network connection..." | tee -a $TMP_LOGFILE
			fi

			if [ ${UPDATE_TO_PROCEED} == "true" ]
			then
				if [[ $(type -t checkForUpdate) == function ]]
				then
					if checkForUpdate > >(tee -a $TMP_LOGFILE) 2>&1
					then
						MG_ALL_INPUT="$@"
						printf "[$(date)] [$(basename "$0")] INFO: Function checkForUpdate() is executed! Please rerun the mustgather command [${BOLD}${GREEN}$(basename "$0") ${MG_ALL_INPUT}${NORMAL}]...${NEWLINE}"
						echo "[$(date)] [$(basename "$0")] INFO: Please check the printed command above for any missing single quotes!"
						cleanUpDataDir
						exit 0
					else
						if [ $? == 1 ]
						then
							printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}ERROR: Function checkForUpdate() failed! Please refer to any error messages printed above!${NORMAL}${NEWLINE}"
							echo "[$(date)] [$(basename "$0")] ERROR: Function checkForUpdate() failed! Please refer to any error messages printed above!" >> $TMP_LOGFILE
	
							if [ ${#AUTO_CHECK_FAILED_EXIT} -gt 0 ] 
							then
								if [ $(echo "$AUTO_CHECK_FAILED_EXIT" | $AWK '{ print tolower($0) }') == "true" ]
								then
									echo "[$(date)] [$(basename "$0")] ERROR: If the update problem persists, please disable AUTO_CHECK_UPDATE function by setting the variable to 'false' in config/product.cfg file!"
									cleanUpDataDir
									exit 1
								else
									if [ $MG_DEBUG == "true" ]
									then
										if [ $(echo "$AUTO_CHECK_FAILED_EXIT" | $AWK '{ print tolower($0) }') == "false" ]
										then
											echo "[$(date)] [$(basename "$0")] INFO: AUTO_CHECK_FAILED_EXIT is set to [false]..." | tee -a $TMP_LOGFILE
										else
											echo "[$(date)] [$(basename "$0")] INFO: AUTO_CHECK_FAILED_EXIT is set to invalid value [$AUTO_CHECK_FAILED_EXIT]..." | tee -a $TMP_LOGFILE
										fi
									fi
								fi
							fi
						else
							if [ $? == $MG_LATEST_VER_CODE ]
							then
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [$(basename "$0")] INFO: MustGather tool '$(basename "$0")' is up-to-date at version [$MG_VERSION]!" | tee -a $TMP_LOGFILE
								fi
							fi
						fi
						
					fi
				else
					printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}ERROR: Function checkForUpdate() is not implemented!${NORMAL}${NEWLINE}"
					echo "[$(date)] [$(basename "$0")] ERROR: Function checkForUpdate() is not implemented!" >> $TMP_LOGFILE
	
					if [ ${#AUTO_CHECK_FAILED_EXIT} -gt 0 ] 
					then
						if [ $(echo "$AUTO_CHECK_FAILED_EXIT" | $AWK '{ print tolower($0) }') == "true" ]
						then
							cleanUpDataDir
							exit 1
						fi
					fi
				fi	
			fi	
		else
			if [ $(echo "$AUTO_CHECK_UPDATE" | $AWK '{ print tolower($0) }') == "false" ]
			then
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] INFO: AUTO_CHECK_UPDATE is set to [false]!" | tee -a $TMP_LOGFILE
				fi
			else
				echo "[$(date)] [$(basename "$0")] INFO: AUTO_CHECK_UPDATE is set to an invalid value [$AUTO_CHECK_UPDATE]!" | tee -a $TMP_LOGFILE
			fi
		fi
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] INFO: AUTO_CHECK_UPDATE is not set!" | tee -a $TMP_LOGFILE
		fi
	fi
fi

if [ $IS_SENSITIVE_DATA_ALLOWED == "true" ]
then
	if [ $COLLECT_YAML == "true" ] || [ $COLLECT_JSON == "true" ]
	then
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: Sensitive data collection (secrets, certs, etc) [-S] is enabled/allowed explicitly! If this is not your intention, press Ctrl-C to abort!${NORMAL}${NEWLINE}"
		echo "[$(date)] [$(basename "$0")] WARNING: Sensitive data collection (secrets, certs, etc) [-S] is enabled/allowed explicitly! If this is not your intention, press Ctrl-C to abort!" >> $TMP_LOGFILE
	else
		if [ $COLLECT_YAML == "false" ] && [ $COLLECT_JSON == "false" ]
		then
			if [ $GET_NODES_DATA == "true" ]	
			then
				printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}INFO: Sensitive data collection (secrets, certs, etc) [-S] is enabled/allowed explicitly! If this is not your intention, press Ctrl-C to abort!${NORMAL}${NEWLINE}"
				echo "[$(date)] [$(basename "$0")] INFO: Sensitive data collection (secrets, certs, etc) [-S] is enabled/allowed explicitly! If this is not your intention, press Ctrl-C to abort!" >> $TMP_LOGFILE
			else
				printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}INFO: Sensitive data collection (secrets, certs, etc) [-S] is enabled/allowed explicitly! However, option [-y] or [-J] options not provided!${NORMAL}${NEWLINE}"
				echo "[$(date)] [$(basename "$0")] INFO: Sensitive data collection (secrets, certs, etc) [-S] is enabled/allowed explicitly! However, option [-y] or [-J] options not provided!" >> $TMP_LOGFILE
			fi
		fi
	fi

	sleep $DEFAULT_SLEEP_SEC
fi

checkMustGatherOpt > >(tee -a $TMP_LOGFILE) 2>&1

if [ $OPTSET -eq 0 ]
then
	echo "[ERROR] Script option (-a | -c | -b | -l | -z | -d | -C | -m | -e | -x | -F) is not set. Exiting..."
	echo ""
	echoUsage
	cleanUpDataDir
	exit 1
fi

if ! checkOcCmd 
then
	cleanUpDataDir
	exit 1
else
	if [ $OC_CMD == "oc" ]
	then
		OC_WHOAMI=$($OC_CMD whoami)
	else
		OC_WHOAMI=$($OC_CMD config current-context | $AWK -F/ '{ print $NF }')
	fi
fi

setupDataDir 

if [ ${#MODULES} -gt 0 ] && [ $MODULES_LISTING != "true" ]
then
	if [[ ${MODULES} =~ ^/ ]] || [[ ${MODULES} =~ ^./ ]]
	then
		if [ -s ${MODULES} ]
		then
			echo "[$(date)] [$(basename "$0")] Custom module = [$MODULES]" | tee -a $RUNTIME_LOGFILE
			MODULES_CUSTOM="true"				
			MODULES_CUSTOM_VERIFIED="true"				
			MODULES_CUSTOM_DEFERRED="false"
		else
			echo "[$(date)] [$(basename "$0")] ERROR: Custom module [$MODULES] does not exist or is zero-sized!"
			cleanUpDataDir
			exit 1
		fi
	else
		if [[ ${MODULES} =~ ^CUSTOM: ]]
		then
			echo "[$(date)] [$(basename "$0")] Deferring verification of custom module [$MODULES]..." | tee -a $RUNTIME_LOGFILE
			MODULES_CUSTOM="true"				
			MODULES_CUSTOM_VERIFIED="false"				
			MODULES_CUSTOM_DEFERRED="true"
		else
			if ! checkModules > >(tee -a $RUNTIME_LOGFILE) 2>&1
			then
				echo "[$(date)] [$(basename "$0")] User-input modules [$MODULES] are all invalid! Exiting..."
				cleanUpDataDir
				echo
				echoUsage
				exit 1
			fi
		fi
	fi
fi

if [ $MODULES_CUSTOM == "true" ] && [ $MODULES_CUSTOM_VERIFIED == "true" ]
then
	getCustomModuleAgreement

	if [ $? -eq 0 ]
	then
		MODULES_CUSTOM_AGREEMENT='true'
	fi
fi

if [ $ALIAS_MODE == "true" ]
then
	if [ ${#ALIAS_MODE_TMP_OUTDIR} -gt 0 ] && [ -d $ALIAS_MODE_TMP_OUTDIR ]
	then
		echo "[$(date)] [$(basename "$0")] Copying important files from ALIAS mode output directory [$ALIAS_MODE_TMP_OUTDIR]..." > >(tee -a $RUNTIME_LOGFILE) 2>&1
		cp -p $ALIAS_MODE_TMP_OUTDIR/1-RUNTIME-DATA/runtime.log ${RUNTIME_LOGFILE}.alias
		cp -rp $ALIAS_MODE_TMP_OUTDIR/1-RUNTIME-DATA/reffile ${RUNTIME_OUTDIR}

		if [ ${#PROD_NAMESPACES_LIST_FILE} -gt 0 ] 
		then
			cp -p $ALIAS_MODE_TMP_OUTDIR/PROD_NAMESPACES/$(basename $PROD_NAMESPACES_LIST_FILE) $PRODUCT_DATA_OUTDIR
		fi

		cat ${RUNTIME_LOGFILE}.alias > ${RUNTIME_LOGFILE}.tmp
		cat ${RUNTIME_LOGFILE} >> ${RUNTIME_LOGFILE}.tmp
		rm ${RUNTIME_LOGFILE}.alias
		mv ${RUNTIME_LOGFILE}.tmp ${RUNTIME_LOGFILE}
		echo "[$(date)] [$(basename "$0")] Old and latest runtime logfiles merged..." > >(tee -a $RUNTIME_LOGFILE) 2>&1

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] Content of directory [$OUTDIR/1-RUNTIME-DATA]..." > >(tee -a $RUNTIME_LOGFILE) 2>&1
			ls -l $OUTDIR/1-RUNTIME-DATA | tee -a $RUNTIME_LOGFILE	
			# echo "[$(date)] [$(basename "$0")] Content of directory [$OUTDIR/PROD_NAMESPACES]..." > >(tee -a $RUNTIME_LOGFILE) 2>&1
			# ls -l $OUTDIR/PROD_NAMESPACES | tee -a $RUNTIME_LOGFILE
		fi

		echo "[$(date)] [$(basename "$0")] Removing temporary ALIAS mode directory [$ALIAS_MODE_TMP_OUTDIR]..." > >(tee -a $RUNTIME_LOGFILE) 2>&1
		rm -r $ALIAS_MODE_TMP_OUTDIR
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] Directory ALIAS_MODE_TMP_OUTDIR [$ALIAS_MODE_TMP_OUTDIR] does not exist! Exiting..." > >(tee -a $RUNTIME_LOGFILE) 2>&1
			cleanUpDataDir
			exit 1
		fi
	fi
fi

checkOcClientCompat > >(tee -a $RUNTIME_LOGFILE) 2>&1

if ! checkApiCallSpeed 
then
	APICALL_ASK_USER_AGREEMENT=1

	while [ $APICALL_ASK_USER_AGREEMENT -eq 1 ]
	do
		echo -n "[$(date)] [$(basename "$0")] '$OC_CMD' command is either executing too slowly or the speed test has failed. Do you want to proceed? (y/n) " >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}'$OC_CMD' command is either executing too slowly or the speed test has failed. Do you want to proceed? (y/n) ${NORMAL}" 
	
		if [ $AUTO_YES == "true" ]
		then
			APICALL_TO_PROCEED="y"
			echo "$APICALL_TO_PROCEED" | tee -a $RUNTIME_LOGFILE
			echo "[$(date)] [$(basename "$0")] Option [-Y] is set! Auto answering [y]..." | tee -a $RUNTIME_LOGFILE
		else
			if [ $MG_TTY == "false" ]
			then
				APICALL_TO_PROCEED="n"
				echo "$APICALL_TO_PROCEED" | tee -a $RUNTIME_LOGFILE
				echo "[$(date)] [$(basename "$0")] In non-TTY mode, auto answering [n]..." | tee -a $RUNTIME_LOGFILE
			else
				read -t $DEFAULT_USERINPUT_TIMEOUT APICALL_TO_PROCEED
				APICALL_EXIT_STATUS=$?
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] APICALL_EXIT_STATUS = [$APICALL_EXIT_STATUS]"
				fi
	
				if [ $APICALL_EXIT_STATUS -gt 128 ]
				then
					echo | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [$(basename "$0")] Timeout waiting for user input. Auto answer [N]..." | tee -a $RUNTIME_LOGFILE
					APICALL_TO_PROCEED="N"
				else
					echo "$APICALL_TO_PROCEED" >> $RUNTIME_LOGFILE
				fi
			fi
		fi
	
		if [ ${#APICALL_TO_PROCEED} -gt 0 ]
		then
			if [ ${APICALL_TO_PROCEED} == "n" ] || [ ${APICALL_TO_PROCEED} == "N" ]
			then
				echo "User input [$APICALL_TO_PROCEED]. To exit..." | tee -a $RUNTIME_LOGFILE
				cleanUpDataDir	
				exit 1	
			else
				if [ ${APICALL_TO_PROCEED} == "y" ] || [ ${APICALL_TO_PROCEED} == "Y" ]
				then
					echo "User input [$APICALL_TO_PROCEED]. To proceed..." | tee -a $RUNTIME_LOGFILE
					APICALL_ASK_USER_AGREEMENT=0
	
					echo "WARNING: If the MustGather does not complete in one(1) hour, please terminate it (Ctrl-C) and contact IBM Support!" >> $RUNTIME_LOGFILE
					printf "${BOLD}${RED}WARNING: If the MustGather does not complete in one(1) hour, please terminate it (Ctrl-C) and contact IBM Support!${NORMAL}${NEWLINE}" 
					sleep $DEFAULT_SLEEP_SEC
				else
					echo "Invalid user input [$APICALL_TO_PROCEED]! Please retry..." | tee -a $RUNTIME_LOGFILE
				fi
			fi
		else
			echo "User input [$APICALL_TO_PROCEED] is blank! Please retry..." | tee -a $RUNTIME_LOGFILE
		fi
	done
fi

# Fast OC (direct connection to API server) is only available to PRIMARY data collection modes, EXTRA mode and MANUALCOLLECT mode
if [ ${#PRIMARY_MODE_ARRAY[@]} -gt 0 ] || [ ${EXTRA_NAMESPACES}x != "x" ] || [ ${MANUAL_COLL} -eq 1 ]
then
	if [ ${#FORCE_SLOW_OC} -gt 0 ] && [ $FORCE_SLOW_OC == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] FORCE_SLOW_OC = [$FORCE_SLOW_OC]! To operate in all '$OC_CMD' command mode..."
		FAST_OC="false"
	else
		if [ ${#CURL} -eq 0 ]
		then
			echo "[$(date)] [$(basename "$0")] Command 'curl' is unavailable! To operate in all '$OC_CMD' command mode..." | tee -a $RUNTIME_LOGFILE
			FAST_OC="false"
		else
			# Let's try proxy
			OC_PROXY_RANDOM_PORT=$($AWK -v min=25000 -v max=30000 'BEGIN { srand(); print int(min+rand()*(max-min+1)) }')
			OC_PROXY_PORT_LIST[${#OC_PROXY_PORT_LIST[@]}]=$OC_PROXY_RANDOM_PORT
		
			for OC_PROXY_PORT in ${OC_PROXY_PORT_LIST[@]}
			do
				echo "[$(date)] [$(basename "$0")] Trying to start '$OC_CMD proxy' at port [$OC_PROXY_PORT]..." | tee -a $RUNTIME_LOGFILE
				$OC_CMD proxy --port=$OC_PROXY_PORT > >(tee -a $RUNTIME_LOGFILE) 2>&1 &
				OC_PROXY_PID=$!
				sleep 1
					
				OC_PROXY_PS_EF=$(ps -ef | $AWK '$2 ~ /^'$OC_PROXY_PID'$/ { print $0 }')	
		
				if [ ${#OC_PROXY_PS_EF} -gt 0 ]
				then
					OC_PROXY_SUCC="true"
					OC_HEADER=""
					OC_HEADER_FOR_ECHO=""
					OC_APISVR="http://localhost:$OC_PROXY_PORT"
					break
				else
					printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Unable to start proxy at port [$OC_PROXY_PORT]...${NORMAL}${NEWLINE}"
					echo "[$(date)] [$(basename "$0")] Unable to start proxy at port [$OC_PROXY_PORT]..." >> $RUNTIME_LOGFILE

				 	OC_PROXY_DANGLING_PID=$(ps -ef | grep "$OC_CMD proxy" | grep "${OC_PROXY_PORT}")

					if [ ${#OC_PROXY_DANGLING_PID} -gt 0 ]
					then
						printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Please check the following process:${NORMAL}${NEWLINE}"
						echo "[$(date)] [$(basename "$0")] Please check the following process:" >> $RUNTIME_LOGFILE
	
						echo ">>> $OC_PROXY_DANGLING_PID" | tee -a $RUNTIME_LOGFILE
						sleep 1
		
						if [ ${#OC_PROXY_DANGLING_PID} -gt 0 ]
						then
							if [ $(echo "$OC_PROXY_DANGLING_PID" | $AWK '{ print $3 }') -eq 1 ]
							then
								# Orphaned proxy!!
								OC_PROXY_ORPHAN_PROXY_PID=$(echo "$OC_PROXY_DANGLING_PID" | $AWK '{ print $2 }')
		
								if [ ${#OC_PROXY_ORPHAN_PROXY_PID} -gt 0 ]
								then
									printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Orphaned proxy process detected [PID = $OC_PROXY_ORPHAN_PROXY_PID]${NORMAL}${NEWLINE}"
									printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Terminating orphaned proxy process [PID = $OC_PROXY_ORPHAN_PROXY_PID]${NORMAL}${NEWLINE}"
									echo "[$(date)] [$(basename "$0")] Orphaned proxy process detected [PID = $OC_PROXY_ORPHAN_PROXY_PID]" >> $RUNTIME_LOGFILE
									echo "[$(date)] [$(basename "$0")] Terminating orphaned proxy process [PID = $OC_PROXY_ORPHAN_PROXY_PID]" >> $RUNTIME_LOGFILE
	
									kill -9 $OC_PROXY_ORPHAN_PROXY_PID 
									sleep 1
								fi
		
					 			OC_PROXY_DANGLING_PID=$(ps -ef | grep "$OC_CMD proxy" | grep "${OC_PROXY_PORT}")
								
								if [ ${#OC_PROXY_DANGLING_PID} -eq 0 ]
								then
									printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Orphaned proxy process terminated [PID = $OC_PROXY_ORPHAN_PROXY_PID]. Retrying proxy at port [$OC_PROXY_PORT]...${NORMAL}${NEWLINE}"
									echo "[$(date)] [$(basename "$0")] Orphaned proxy process terminated [PID = $OC_PROXY_ORPHAN_PROXY_PID]. Retrying proxy at port [$OC_PROXY_PORT]..." >> $RUNTIME_LOGFILE
		
									$OC_CMD proxy --port=$OC_PROXY_PORT > >(tee -a $RUNTIME_LOGFILE) 2>&1 &
									OC_PROXY_PID=$!
									sleep 1
		
									OC_PROXY_PS_EF=$(ps -ef | $AWK '$2 ~ /^'$OC_PROXY_PID'$/ { print $0 }')	
		
									if [ ${#OC_PROXY_PS_EF} -gt 0 ]
									then
										OC_PROXY_SUCC="true"
										OC_HEADER=""
										OC_HEADER_FOR_ECHO=""
										OC_APISVR="http://localhost:$OC_PROXY_PORT"
										break
									else
										printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Unable to start proxy at port [$OC_PROXY_PORT]...${NORMAL}${NEWLINE}"
										printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Please check the following process:${NORMAL}${NEWLINE}"
										echo "[$(date)] [$(basename "$0")] Unable to start proxy at port [$OC_PROXY_PORT]..." >> $RUNTIME_LOGFILE
										echo "[$(date)] [$(basename "$0")] Please check the following process:" >> $RUNTIME_LOGFILE
	
					 					OC_PROXY_DANGLING_PID=$(ps -ef | grep "$OC_CMD proxy" | grep "${OC_PROXY_PORT}")
										echo ">>> $OC_PROXY_DANGLING_PID" | tee -a $RUNTIME_LOGFILE
										sleep 1
									fi
								else
									printf "[$(date)] [$(basename "$0")] ${BOLD}${RED} Termination of orphaned proxy process [PID - $OC_PROXY_ORPHAN_PROXY_PID] failed!${NORMAL}${NEWLINE}"
									echo "[$(date)] [$(basename "$0")] Termination of orphaned proxy process [PID - $OC_PROXY_ORPHAN_PROXY_PID] failed!" >> $RUNTIME_LOGFILE
								fi
							fi
						fi
					else
						echo "[$(date)] [$(basename "$0")] There isn't another proxy process running at port [${OC_PROXY_PORT}]!" | tee -a $RUNTIME_LOGFILE
					fi
				fi
			done

			if [ ${#CURL_TIMEOUT} -eq 0 ]
			then
				CURL_TIMEOUT=$CURL_DEFAULT_TIMEOUT
			fi

			if [ $OC_PROXY_SUCC == "true" ]
			then
				# Try an API call firt before setting FAST_OC to true
				OC_PROXY_TEST_CMD="$CURL -s -m $CURL_TIMEOUT $OC_APISVR/api"

				echo "[$(date)] [$(basename "$0")] Testing connection to API server [$OC_APISVR][PID=$OC_PROXY_PID]..." | tee -a $RUNTIME_LOGFILE

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] OC_PROXY_TEST_CMD = [$OC_PROXY_TEST_CMD]" | tee -a $RUNTIME_LOGFILE
					eval "$OC_PROXY_TEST_CMD" > $MAIN_ROOT_DEBUG_OUTDIR/oc_proxy_test.out 2>&1
					OC_PROXY_TEST_CONN=$(grep -E 'kind.*APIVersions|serverAddressByClientCIDRs' $MAIN_ROOT_DEBUG_OUTDIR/oc_proxy_test.out)
				else
					OC_PROXY_TEST_CONN=$(eval "$OC_PROXY_TEST_CMD" | grep -E 'kind.*APIVersions|serverAddressByClientCIDRs')
				fi
			
				if [ ${#OC_PROXY_TEST_CONN} -gt 0 ]
				then
					echo "[$(date)] [$(basename "$0")] Connection test to API server [$OC_APISVR][PID=$OC_PROXY_PID] is successful!" | tee -a $RUNTIME_LOGFILE
					FAST_OC="true"
				else
					echo "[$(date)] [$(basename "$0")] API call possibly blocked by firewall. To revert to [$OC_CMD] command execution..." | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [$(basename "$0")] Stopping proxy server at [$OC_APISVR][PID=$OC_PROXY_PID]..." | tee -a $RUNTIME_LOGFILE

					kill -9 $OC_PROXY_PID 
					wait $OC_PROXY_PID 2> /dev/null

					OC_PROXY_SUCC="false"
					FAST_OC="false"
					OC_POSSIBLE_FIREWALL="true"
				fi
			else
				echo "[$(date)] [$(basename "$0")] Giving up on starting proxy server! Failing back to token authentication method..." | tee -a $RUNTIME_LOGFILE

				if [ $OC_CMD == "oc" ]
				then
					OC_TOKEN=$($OC_CMD whoami -t)
					OC_APISVR=$($OC_CMD cluster-info | grep -E 'running' | $AWK -F'at' '{ print $2 }' | sed 's/^[ ]*//' | sed -e $'s/\x1b\[[0-9;]*m//g')
			
					if [ ${#OC_APISVR} -eq 0 ]
					then
						OC_APISVR=$($OC_CMD config view --minify | grep -E server | cut -f 2- -d ":" | tr -d " ")
					fi
				else
					OC_TOKEN=
					OC_APISVR=
				fi
		
				if [ ${#OC_TOKEN} -gt 0 ] && [ ${#OC_APISVR} -gt 0 ] && [ ${#CURL} -gt 0 ]
				then
					# Try an API call firt before setting FAST_OC to true
					OC_HEADER="-H 'Authorization: Bearer $OC_TOKEN'"
					OC_HEADER_FOR_ECHO="-H 'Authorization: Bearer <token>'"

					OC_TOKEN_TEST_CMD="$CURL -s -k -m $CURL_TIMEOUT $OC_HEADER $OC_APISVR/api"

					if [ $MG_DEBUG == "true" ]
					then
						eval "$OC_TOKEN_TEST_CMD" > $MAIN_ROOT_DEBUG_OUTDIR/oc_token_test.out
						OC_TOKEN_TEST_CONN=$(grep -E 'kind.*APIVersions|serverAddressByClientCIDRs' $MAIN_ROOT_DEBUG_OUTDIR/oc_token_test.out)
					else
						OC_TOKEN_TEST_CONN=$(eval "$OC_TOKEN_TEST_CMD" | grep -E 'kind.*APIVersions|serverAddressByClientCIDRs')
					fi
			
					if [ ${#OC_TOKEN_TEST_CONN} -gt 0 ]
					then
						echo "[$(date)] [$(basename "$0")] Setup of token authentication method is successful!" | tee -a $RUNTIME_LOGFILE
						FAST_OC="true"
					else
						echo "[$(date)] [$(basename "$0")] API call possibly blocked by firewall. To revert to [$OC_CMD] command execution..." | tee -a $RUNTIME_LOGFILE
						FAST_OC="false"
						OC_POSSIBLE_FIREWALL="true"
					fi
				else
					echo "[$(date)] [$(basename "$0")] Setup of token authentication method failed! To revert to [$OC_CMD] command execution..." | tee -a $RUNTIME_LOGFILE
					FAST_OC="false"
				fi
			fi
		fi
	fi
fi

if [ $FAST_OC == "true" ]
then
	if [ $OC_PROXY_SUCC == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] Enabling fast OC to API server [$OC_APISVR][PID=$OC_PROXY_PID]..." | tee -a $RUNTIME_LOGFILE
	else
		echo "[$(date)] [$(basename "$0")] Enabling fast OC to API server [$OC_APISVR]..." | tee -a $RUNTIME_LOGFILE
	fi

	if [ ${#FAST_OC_DESC} -eq 0 ]
	then
		# FAST_OC_DESC is turned OFF by default
		FAST_OC_DESC="false"
	fi
else
	# echo "[$(date)] [$(basename "$0")] FAST_OC is disabled! FAST_OC_DESC will be disabled too..." | tee -a $RUNTIME_LOGFILE
	# FAST_OC_DESC="false"
	echo "[$(date)] [$(basename "$0")] FAST_OC is disabled!" | tee -a $RUNTIME_LOGFILE
fi

echo "[$(date)] [$(basename "$0")] Starting data collection for product '${PRODUCT_NAME}' in [$MUSTGATHER_OPT] mode [tool version = $MG_VERSION / gmgf version = $GMGF_VERSION]" | tee -a $RUNTIME_LOGFILE
echo "[$(date)] [$(basename "$0")] Openshift user = [$OC_WHOAMI]" | tee -a $RUNTIME_LOGFILE

backupMainScripts | tee -a $RUNTIME_LOGFILE
echoVersionToFile

if [ $ALIAS_MODE != "true" ] && [ ! -f $PROD_NAMESPACES_REFFILE ]
then
	if [ $BASH_V4 == "true" ]
	then
		declare -gA PROD_NAMESPACES_KEYVAL_ARR
		declare -gA USER_PRIV_ARR
		declare -gA EXCL_PROD_NS_ARR
	fi

	getProdNamespaces $PROD_NAMESPACES_REFFILE > >(tee -a $RUNTIME_LOGFILE) 2>&1
	
	if ! checkProdNamespace > >(tee -a $RUNTIME_LOGFILE) 2>&1
	then
		echo "[$(date)] [$(basename "$0")] ERROR: Unable to determine product namespaces!" | tee -a $RUNTIME_LOGFILE
	
		if ! toContinue
		then 
			cleanUpDataDir
			exit 1
		fi
	fi
	
	if [ ${#PRODUCT_VERSION} -eq 0 ]
	then
		echo "[$(date)] [$(basename "$0")] Getting version for product [$PRODUCT_NAME]..." | tee -a $RUNTIME_LOGFILE
		PRODUCT_VERSION=$(getProdVersions $PROD_VERSIONS_REFFILE 2> >(tee -a $RUNTIME_LOGFILE >&2))
	
		if [ ${#RTVAR_PRODVER} -gt 0 ]
		then
			echo "[$(date)] [$(basename "$0")] PRODVER is set to [$RTVAR_PRODVER]! Resetting PRODUCT_VERSION to [$RTVAR_PRODVER]!"
			PRODUCT_VERSION=$RTVAR_PRODVER
		fi

		if ! checkProdVersion > >(tee -a $RUNTIME_LOGFILE) 2>&1
		then
			cleanUpDataDir
			exit 1
		fi
	fi
else
	# Likely ALIAS mode has been executed!
	# To update PROD_NAMESPACES_REFFILE_FINAL, PROD_NAMESPACES_KEYVAL_ARR, PROD_NAMESPACES_UNIQUE_REFFILE, PROD_NAMESPACES_UNIQUE, PROD_VERSIONS_UNIQUE_REFFILE and PROD_VERSIONS_UNIQUE

	if [ ${#RTVAR_EXCL_PROD_GROUP} -gt 0 ] || [ ${#RTVAR_EXCL_PROD_NS} -gt 0 ]
	then
		echo "[$(date)] [$(basename "$0")] RTVAR_EXCL_PROD_GROUP [$RTVAR_EXCL_PROD_GROUP] and/or RTVAR_EXCL_PROD_NS [$RTVAR_EXCL_PROD_NS] are set! Updating product namespaces and versions data..." | tee -a $RUNTIME_LOGFILE

		# Let's clean up first!
		if [ -f $PROD_NAMESPACES_REFFILE_FINAL ]
		then
			echo "[$(date)] [$(basename "$0")] Removing PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL]..." | tee -a $RUNTIME_LOGFILE
			rm $PROD_NAMESPACES_REFFILE_FINAL
		else
			echo "[$(date)] [$(basename "$0")] PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL] does not exist or is zero-sized!" | tee -a $RUNTIME_LOGFILE
		fi

		if [ -f $PROD_NAMESPACES_UNIQUE_REFFILE ]
		then
			echo "[$(date)] [$(basename "$0")] Removing PROD_NAMESPACES_UNIQUE_REFFILE [$PROD_NAMESPACES_UNIQUE_REFFILE]..." | tee -a $RUNTIME_LOGFILE
			rm $PROD_NAMESPACES_UNIQUE_REFFILE
		else
			echo "[$(date)] [$(basename "$0")] PROD_NAMESPACES_UNIQUE_REFFILE [$PROD_NAMESPACES_UNIQUE_REFFILE] does not exist or is zero-sized!" | tee -a $RUNTIME_LOGFILE
		fi

		if [ -f $PROD_VERSIONS_REFFILE_FINAL ]
		then
			echo "[$(date)] [$(basename "$0")] Removing PROD_VERSIONS_REFFILE_FINAL [$PROD_VERSIONS_REFFILE_FINAL]..." | tee -a $RUNTIME_LOGFILE
			rm $PROD_VERSIONS_REFFILE_FINAL
		else
			echo "[$(date)] [$(basename "$0")] PROD_NAMESPACES_REFFILE_FINAL [$PROD_NAMESPACES_REFFILE_FINAL] does not exist or is zero-sized!" | tee -a $RUNTIME_LOGFILE
		fi

		if [ -f $PROD_VERSIONS_UNIQUE_REFFILE ]
		then
			echo "[$(date)] [$(basename "$0")] Removing PROD_VERSIONS_UNIQUE_REFFILE [$PROD_VERSIONS_UNIQUE_REFFILE]..." | tee -a $RUNTIME_LOGFILE
			rm $PROD_VERSIONS_UNIQUE_REFFILE
		else
			echo "[$(date)] [$(basename "$0")] PROD_VERSIONS_UNIQUE_REFFILE [$PROD_VERSIONS_UNIQUE_REFFILE] does not exist or is zero-sized!" | tee -a $RUNTIME_LOGFILE
		fi

		if [ ${#PROD_NAMESPACES_KEYVAL_ARR[@]} -gt 0 ]	
		then
			echo "[$(date)] [$(basename "$0")] Resetting PROD_NAMESPACES_KEYVAL_ARR array..."
			unset PROD_NAMESPACES_KEYVAL_ARR

			if [ $BASH_V4 == "true" ]
			then
				declare -gA PROD_NAMESPACES_KEYVAL_ARR
			fi
		else
			echo "[$(date)] [$(basename "$0")] Size of PROD_NAMESPACES_KEYVAL_ARR = [${#PROD_NAMESPACES_KEYVAL_ARR[@]}]"
		fi

		if [ ${#PROD_NAMESPACES_UNIQUE[@]} -gt 0 ]
		then
			echo "[$(date)] [$(basename "$0")] Resetting PROD_NAMESPACES_UNIQUE array..."
			unset PROD_NAMESPACES_UNIQUE
		else
			echo "[$(date)] [$(basename "$0")] Size of PROD_NAMESPACES_UNIQUE = [${#PROD_NAMESPACES_UNIQUE[@]}]"
		fi

		if [ ${#PROD_VERSIONS_UNIQUE[@]} -gt 0 ]
		then
			echo "[$(date)] [$(basename "$0")] Resetting PROD_VERSIONS_UNIQUE array..."
			unset PROD_VERSIONS_UNIQUE
		else
			echo "[$(date)] [$(basename "$0")] Size of PROD_VERSIONS_UNIQUE = [${#PROD_VERSIONS_UNIQUE[@]}]"
		fi

		if [ ${#EXCL_PROD_NS_ARR[@]} -gt 0 ]
		then
			echo "[$(date)] [$(basename "$0")] Resetting EXCL_PROD_NS_ARR array..."
			unset EXCL_PROD_NS_ARR

			if [ $BASH_V4 == "true" ]
			then
				declare -gA EXCL_PROD_NS_ARR
			fi
		else
			echo "[$(date)] [$(basename "$0")] Size of EXCL_PROD_NS_ARR = [${#EXCL_PROD_NS_ARR[@]}]"
		fi

		if [ ${#PROD_GROUPS_ARR[@]} -gt 0 ]
		then
			echo "[$(date)] [$(basename "$0")] Resetting PROD_GROUPS_ARR array..."
			unset PROD_GROUPS_ARR
		else
			echo "[$(date)] [$(basename "$0")] Size of PROD_GROUPS_ARR = [${#PROD_GROUPS_ARR[@]}]"
		fi

		if ! checkProdNamespace > >(tee -a $RUNTIME_LOGFILE) 2>&1
		then
			echo "[$(date)] [$(basename "$0")] ERROR: Unable to determine product namespaces!" | tee -a $RUNTIME_LOGFILE
		
			if ! toContinue
			then 
				cleanUpDataDir
				exit 1
			fi
		fi

		if ! checkProdVersion > >(tee -a $RUNTIME_LOGFILE) 2>&1
		then
			cleanUpDataDir
			exit 1
		fi
	fi
fi

createProdNamespaceDir
echoProdVersion | tee -a $RUNTIME_LOGFILE
echoProdInfoToFile
# getOutFile

if [[ $(type -t getOutFileName) == function ]]
then
	# To set GZIP_OUTFILE variable
	GZIP_OUTFILE=$(getOutFileName) 

	if [ ${#GZIP_OUTFILE} -eq 0 ]
	then
		GZIP_OUTFILE="$ROOT_OUTDIR/$(getOutFileNameDef).tar.gz"
		echo "[$(date)] [$(basename "$0")] User-defined function 'getOutFileName' returns empty/null string! Setting variable GZIP_OUTFILE to default [$GZIP_OUTFILE]..." | tee -a $RUNTIME_LOGFILE
	else
		GZIP_OUTFILE="$ROOT_OUTDIR/${GZIP_OUTFILE}.tar.gz"
		echo "[$(date)] [$(basename "$0")] Setting variable GZIP_OUTFILE to user-defined [$GZIP_OUTFILE]..." | tee -a $RUNTIME_LOGFILE
	fi
else
	# Default implementation in product.sh.def
	GZIP_OUTFILE="$ROOT_OUTDIR/$(getOutFileNameDef).tar.gz"
	echo "[$(date)] [$(basename "$0")] Setting variable GZIP_OUTFILE to default [$GZIP_OUTFILE]..." | tee -a $RUNTIME_LOGFILE
fi

if [ ${#MODULES_LISTING} -gt 0 ] && [ $MODULES_LISTING == "true" ]
then
	VMOD_CTR=1

	if [ -d $MUSTGATHER_DIRNAME/config/modules/$PRODUCT_VERSION ]
	then
		MODULES_LISTING_CMD="( echo \${VALID_MODULES[*]} | tr ' ' '\n'; ls $MUSTGATHER_DIRNAME/config/modules/$PRODUCT_VERSION | grep -v 'modules.help' ) | sort | uniq"
	else
		MODULES_LISTING_CMD="sort <<<\"\${VALID_MODULES[*]}\""
	fi

	MODULES_LISTING_SYSTEM_HELPFILE=$MUSTGATHER_DIRNAME/modules.help
	MODULES_LISTING_PRODUCT_HELPFILE=$MUSTGATHER_DIRNAME/config/modules.help

	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] MODULES_LISTING_CMD = [$MODULES_LISTING_CMD]"
	fi

	echo "==================================================================================================================================================" 
	printf "%-25s %-70s %-30s \n" "MODULE" "DESCRIPTION" "EXAMPLE"
	echo "==================================================================================================================================================" 

	for VMOD in $(eval "$MODULES_LISTING_CMD")
	do
		if [ -s $MUSTGATHER_DIRNAME/config/modules/$PRODUCT_VERSION/modules.help ]
		then
			MODULES_LISTING_HELPFILE=$MUSTGATHER_DIRNAME/config/modules/$PRODUCT_VERSION/modules.help
			MODULES_LISTING_HELPFILE_TYPE="prodver"
		else
			if [ -s $MODULES_LISTING_PRODUCT_HELPFILE ]
			then
				MODULES_LISTING_HELPFILE=$MODULES_LISTING_PRODUCT_HELPFILE
				MODULES_LISTING_HELPFILE_TYPE="product"
			else
				MODULES_LISTING_HELPFILE=$MODULES_LISTING_SYSTEM_HELPFILE
				MODULES_LISTING_HELPFILE_TYPE="system"
			fi
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] VMOD = [$VMOD] / MODULES_LISTING_HELPFILE = [$MODULES_LISTING_HELPFILE] / MODULES_LISTING_HELPFILE_TYPE = [$MODULES_LISTING_HELPFILE_TYPE]"
		fi

		if [ -s $MODULES_LISTING_HELPFILE ]
		then
			MODULES_LISTING_DESC=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $2 }')
			MODULES_LISTING_EXAMPLE=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $3 }')
		
			if [ ${#MODULES_LISTING_DESC} -eq 0 ]
			then
				if [ $MODULES_LISTING_HELPFILE_TYPE == "prodver" ]
				then
					MODULES_LISTING_HELPFILE=$MODULES_LISTING_PRODUCT_HELPFILE

					if [ -s $MODULES_LISTING_HELPFILE ]
					then
						MODULES_LISTING_DESC=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $2 }')
						MODULES_LISTING_EXAMPLE=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $3 }')
						MODULES_LISTING_HELPFILE_TYPE="product"
					else
						MODULES_LISTING_HELPFILE=$MODULES_LISTING_SYSTEM_HELPFILE

						if [ -s $MODULES_LISTING_HELPFILE ]
						then
							MODULES_LISTING_DESC=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $2 }')
							MODULES_LISTING_EXAMPLE=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $3 }')
							MODULES_LISTING_HELPFILE_TYPE="system"
						fi
					fi

					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [$(basename "$0")] VMOD = [$VMOD] / MODULES_LISTING_HELPFILE = [$MODULES_LISTING_HELPFILE] / MODULES_LISTING_HELPFILE_TYPE = [$MODULES_LISTING_HELPFILE_TYPE]"
					fi
			
					if [ ${#MODULES_LISTING_DESC} -eq 0 ]
					then
						if [ $MODULES_LISTING_HELPFILE_TYPE == "product" ]
						then
							MODULES_LISTING_HELPFILE=$MODULES_LISTING_SYSTEM_HELPFILE

							MODULES_LISTING_DESC=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $2 }')
							MODULES_LISTING_EXAMPLE=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $3 }')
							MODULES_LISTING_HELPFILE_TYPE="system"

							if [ $MG_DEBUG == "true" ]
							then
								echo "[$(date)] [$(basename "$0")] VMOD = [$VMOD] / MODULES_LISTING_HELPFILE = [$MODULES_LISTING_HELPFILE] / MODULES_LISTING_HELPFILE_TYPE = [$MODULES_LISTING_HELPFILE_TYPE]"
							fi
			
							if [ ${#MODULES_LISTING_DESC} -eq 0 ]
							then
								MODULES_LISTING_DESC="N/A"
							fi

							if [ ${#MODULES_LISTING_EXAMPLE} -eq 0 ]
							then
								MODULES_LISTING_EXAMPLE="N/A"
							fi
						else
							MODULES_LISTING_DESC="N/A"
							MODULES_LISTING_EXAMPLE="N/A"
						fi
					fi
				else
					if [ $MODULES_LISTING_HELPFILE_TYPE == "product" ]
					then
						MODULES_LISTING_DESC=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_SYSTEM_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $2 }')
						MODULES_LISTING_EXAMPLE=$(grep -E -v '^[ ]*'${MODULES_HELPFILE_COMMENT} $MODULES_LISTING_SYSTEM_HELPFILE | $AWK -F${MODULES_HELPFILE_DELIMITER} '$1 ~ /^'$VMOD'$/ { print $3 }')

						if [ ${#MODULES_LISTING_DESC} -eq 0 ]
						then
							MODULES_LISTING_DESC="N/A"
						fi

						if [ ${#MODULES_LISTING_EXAMPLE} -eq 0 ]
						then
							MODULES_LISTING_EXAMPLE="N/A"
						fi
					else
						MODULES_LISTING_DESC="N/A"
						MODULES_LISTING_EXAMPLE="N/A"
					fi
				fi
			fi	
		else
			MODULES_LISTING_DESC="N/A"
			MODULES_LISTING_EXAMPLE="N/A"
		fi

		printf "%-25s %-70s %-30s \n" "[$VMOD_CTR] $VMOD" "$MODULES_LISTING_DESC" "$MODULES_LISTING_EXAMPLE"

		(( VMOD_CTR=VMOD_CTR+1 ))
	done

	echo

	cleanUpDataDir > /dev/null
	exit 0
fi

# Export global variables and functions
IFS=$'\n'
for GMGF_ENV in ${GMGF_ENV_ARR[@]}
do
	if [[ $GMGF_ENV =~ ^-f ]]
	then
		GMGF_ENV_FUNCNAME=$(echo "$GMGF_ENV" | $AWK '{ print $2 }')

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] Exporting environment function [$GMGF_ENV_FUNCNAME]..." | tee -a $RUNTIME_LOGFILE
		fi

		export -f $GMGF_ENV_FUNCNAME
	else
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] Exporting environment variable [$GMGF_ENV = ${!GMGF_ENV}]" | tee -a $RUNTIME_LOGFILE
		fi

		export $GMGF_ENV
	fi
done

deferRuntimeVar
checkUserPriv
createApiList > >(tee -a $RUNTIME_LOGFILE) 2> >(tee -a $RUNTIME_LOGFILE >&2)
createResourceList > >(tee -a $RUNTIME_LOGFILE) 2> >(tee -a $RUNTIME_LOGFILE >&2)
createSensitiveDataArr > >(tee -a $RUNTIME_LOGFILE) 2> >(tee -a $RUNTIME_LOGFILE >&2)
createRestrictedDataArr > >(tee -a $RUNTIME_LOGFILE) 2> >(tee -a $RUNTIME_LOGFILE >&2)

if [ $MODULES_CUSTOM == "true" ] && [ $MODULES_CUSTOM_VERIFIED == "false" ]
then
	MODULES_INPUT_NAME=$(echo "${MODULES}" | cut -f 2- -d ":")

	if [ ${#MODULES_INPUT_NAME} -gt 0 ]
	then
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] MODULES = [$MODULES] / MODULES_INPUT_NAME = [$MODULES_INPUT_NAME]" | tee -a $RUNTIME_LOGFILE
		fi
	
		# MODULES mode only support single product group for now!
		if [ ${#RTVAR_MODULES_PRODVER} -gt 0 ]
		then
			MODULES_PRODVER_VALID="false"
	
			for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
			do
				if [ $RTVAR_MODULES_PRODVER == $VALID_PROD_VERSION ]
				then
					MODULES_PRODVER_VALID="true"
					break
				fi
			done	
	
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] RTVAR_MODULES_PRODVER = [$RTVAR_MODULES_PRODVER] / MODULES_PRODVER_VALID = [$MODULES_PRODVER_VALID]" | tee -a $RUNTIME_LOGFILE
			fi
	
			if [ $MODULES_PRODVER_VALID == "true" ]
			then
				MODULES_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/modules/$RTVAR_MODULES_PRODVER
			else
				MODULES_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/modules/$PRODUCT_VERSION
			fi
		else
			MODULES_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/modules/$PRODUCT_VERSION
		fi
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] MODULES_DEFAULT_DIR = [$MODULES_DEFAULT_DIR]" | tee -a $RUNTIME_LOGFILE
		fi
	
		if [ -s ${MODULES_DEFAULT_DIR}/${MODULES_INPUT_NAME} ]
		then
			echo "[$(date)] [$(basename "$0")] Custom module = [${MODULES_DEFAULT_DIR}/${MODULES_INPUT_NAME}]" | tee -a $RUNTIME_LOGFILE
			MODULES="${MODULES_DEFAULT_DIR}/${MODULES_INPUT_NAME}"
			MODULES_CUSTOM="true"
			MODULES_CUSTOM_VERIFIED="true"
		else
			echo "[$(date)] [$(basename "$0")] ERROR: Custom module [$MODULES] does not exist or is zero-sized!" | tee -a $RUNTIME_LOGFILE
			cleanUpDataDir
			exit 1
		fi
	else
		echo "[$(date)] [$(basename "$0")] ERROR: Custom module [$MODULES] is empty/null!" | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		exit 1
	fi
fi

if [ $MODULES_CUSTOM == "true" ] && [ $MODULES_CUSTOM_VERIFIED == "true" ] && [ $MODULES_CUSTOM_DEFERRED == "true" ]
then
	getCustomModuleAgreement

	if [ $? -eq 0 ]
	then
		MODULES_CUSTOM_AGREEMENT='true'
	fi
fi

# [CMDEXEC] To verify CMD_EXEC_FILE and CMD_EXEC_ENVFILE
if [ ${#CMD_EXEC_CMD} -gt 0 ] && ( [ ${CMD_EXEC_CMD} == ".listcmd" ] || [ ${CMD_EXEC_CMD} == ".listcmd_custom" ] )
then
	echo "[$(date)] [$(basename "$0")] To list all available CMDEXEC scripts and their help/usage information..." | tee -a $RUNTIME_LOGFILE
	CMD_EXEC="true"
else
	if [ ${#CMD_EXEC_FILE} -gt 0 ]
	then
		if [ ${#RTVAR_CMDEXEC_FORCE_DEFAULT} -gt 0 ] && [ ${RTVAR_CMDEXEC_FORCE_DEFAULT} == "true" ]
		then
			CMDEXEC_DEFAULT_DIR=$MUSTGATHER_DIRNAME/cmdexec
			CMDEXEC_PROD_VERSION=$PRODUCT_VERSION
		else
			# CMDEXEC mode only support single product group for now!
			if [ ${#RTVAR_CMDEXEC_PRODVER} -gt 0 ]
			then
				CMD_EXEC_PRODVER_VALID="false"

				for VALID_PROD_VERSION in ${PRODUCT_SUPPORTED_VERSION[@]}
				do
					if [ $RTVAR_CMDEXEC_PRODVER == $VALID_PROD_VERSION ]
					then
						CMD_EXEC_PRODVER_VALID="true"
						break
					fi
				done	

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] RTVAR_CMDEXEC_PRODVER = [$RTVAR_CMDEXEC_PRODVER] / CMD_EXEC_PRODVER_VALID = [$CMD_EXEC_PRODVER_VALID]" | tee -a $RUNTIME_LOGFILE
				fi

				if [ $CMD_EXEC_PRODVER_VALID == "true" ]
				then
					CMDEXEC_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/cmdexec/$RTVAR_CMDEXEC_PRODVER
					CMDEXEC_PROD_VERSION=$RTVAR_CMDEXEC_PRODVER
				else
					CMDEXEC_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION
					CMDEXEC_PROD_VERSION=$PRODUCT_VERSION
				fi
			else
				CMDEXEC_DEFAULT_DIR=$MUSTGATHER_DIRNAME/config/cmdexec/$PRODUCT_VERSION
				CMDEXEC_PROD_VERSION=$PRODUCT_VERSION
			fi
		fi
		
		if [[ ! $CMD_EXEC_FILE =~ ^/ ]] && [[ ! $CMD_EXEC_FILE =~ ^./ ]]
		then
			echo "[$(date)] [$(basename "$0")] Input file for function getCmdExec() [$CMD_EXEC_FILE] is relative and will be set to default [$CMDEXEC_DEFAULT_DIR/$CMD_EXEC_FILE]..." | tee -a $RUNTIME_LOGFILE
			CMD_EXEC_FILE=$CMDEXEC_DEFAULT_DIR/$CMD_EXEC_FILE
		
			if [ ${#CMD_EXEC_PARAM} -gt 0 ]
			then
				CMD_EXEC_CMD="$CMD_EXEC_FILE $CMD_EXEC_PARAM"
			else
				CMD_EXEC_CMD="$CMD_EXEC_FILE"
			fi
		fi
	
		if ! checkInputFile $CMD_EXEC_FILE
		then
			echo "[$(date)] [$(basename "$0")] Input file for function getCmdExec() [$CMD_EXEC_FILE] is a directory or unavailable or zero-sized!" | tee -a $RUNTIME_LOGFILE
			echo "[$(date)] [$(basename "$0")] Attempting to check under system CMDEXEC directory [$MUSTGATHER_DIRNAME/cmdexec] for file [$(basename $CMD_EXEC_FILE)]..." | tee -a $RUNTIME_LOGFILE
		
			if ! checkInputFile $MUSTGATHER_DIRNAME/cmdexec/$(basename $CMD_EXEC_FILE)
			then
				echo "[$(date)] [$(basename "$0")] Input file for function getCmdExec() [$MUSTGATHER_DIRNAME/cmdexec/$(basename $CMD_EXEC_FILE)] is a directory or unavailable or zero-sized!" | tee -a $RUNTIME_LOGFILE
				echo "[$(date)] [$(basename "$0")] Attempting to check under custom CMDEXEC directory [$MUSTGATHER_DIRNAME/data/cmdexec/$CMDEXEC_PROD_VERSION] for file [$(basename $CMD_EXEC_FILE)]..." | tee -a $RUNTIME_LOGFILE

				if ! checkInputFile $MUSTGATHER_DIRNAME/data/cmdexec/$CMDEXEC_PROD_VERSION/$(basename $CMD_EXEC_FILE)
				then
					echo "[$(date)] [$(basename "$0")] Input file for function getCmdExec() [$MUSTGATHER_DIRNAME/data/cmdexec/$CMDEXEC_PROD_VERSION/$(basename $CMD_EXEC_FILE)] is a directory or unavailable or zero-sized!" | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [$(basename "$0")] Attempting to check under custom CMDEXEC directory [$MUSTGATHER_DIRNAME/data/cmdexec] for file [$(basename $CMD_EXEC_FILE)]..." | tee -a $RUNTIME_LOGFILE

					if ! checkInputFile $MUSTGATHER_DIRNAME/data/cmdexec/$(basename $CMD_EXEC_FILE)
					then
						echo "[$(date)] [$(basename "$0")] Input file for function getCmdExec() [$MUSTGATHER_DIRNAME/data/cmdexec/$(basename $CMD_EXEC_FILE)] is a directory or unavailable or zero-sized!" | tee -a $RUNTIME_LOGFILE
						CMD_EXEC="false"
					else
						CMDEXEC_DEFAULT_DIR=$MUSTGATHER_DIRNAME/data/cmdexec
				   		CMD_EXEC_CMD="$MUSTGATHER_DIRNAME/data/cmdexec/$(basename $CMD_EXEC_FILE) $CMD_EXEC_PARAM"
						CMD_EXEC_FILE=$MUSTGATHER_DIRNAME/data/cmdexec/$(basename $CMD_EXEC_FILE)
				   		CMD_EXEC_PARAM=$(echo "$CMD_EXEC_CMD" | $AWK '{$1=""}1' | $AWK '{$1=$1}1')
				   		# CMD_EXEC_ENVFILE=$(echo "$CMD_EXEC_INPUT" | $AWK -F'##' '{ print $2 }')
				
						echo "[$(date)] [$(basename "$0")] Script file [$CMD_EXEC_FILE] found! Setting CMDEXEC_DEFAULT_DIR to [$CMDEXEC_DEFAULT_DIR] and CMD_EXEC_FILE to [$CMD_EXEC_FILE]..." | tee -a $RUNTIME_LOGFILE
		
						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [$(basename "$0")] CMD_EXEC_CMD = [$CMD_EXEC_CMD]" | tee -a $RUNTIME_LOGFILE
							echo "[$(date)] [$(basename "$0")] CMD_EXEC_FILE = [$CMD_EXEC_FILE]" | tee -a $RUNTIME_LOGFILE
							echo "[$(date)] [$(basename "$0")] CMD_EXEC_PARAM = [$CMD_EXEC_PARAM]" | tee -a $RUNTIME_LOGFILE
							echo "[$(date)] [$(basename "$0")] CMD_EXEC_ENVFILE = [$CMD_EXEC_ENVFILE]" | tee -a $RUNTIME_LOGFILE
						fi
		
						CMD_EXEC="true"
					fi
				else
					CMDEXEC_DEFAULT_DIR=$MUSTGATHER_DIRNAME/data/cmdexec/$CMDEXEC_PROD_VERSION
			   		CMD_EXEC_CMD="$MUSTGATHER_DIRNAME/data/cmdexec/$CMDEXEC_PROD_VERSION/$(basename $CMD_EXEC_FILE) $CMD_EXEC_PARAM"
					CMD_EXEC_FILE=$MUSTGATHER_DIRNAME/data/cmdexec/$CMDEXEC_PROD_VERSION/$(basename $CMD_EXEC_FILE)
			   		CMD_EXEC_PARAM=$(echo "$CMD_EXEC_CMD" | $AWK '{$1=""}1' | $AWK '{$1=$1}1')
			   		# CMD_EXEC_ENVFILE=$(echo "$CMD_EXEC_INPUT" | $AWK -F'##' '{ print $2 }')
			
					echo "[$(date)] [$(basename "$0")] Script file [$CMD_EXEC_FILE] found! Setting CMDEXEC_DEFAULT_DIR to [$CMDEXEC_DEFAULT_DIR] and CMD_EXEC_FILE to [$CMD_EXEC_FILE]..." | tee -a $RUNTIME_LOGFILE
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [$(basename "$0")] CMD_EXEC_CMD = [$CMD_EXEC_CMD]" | tee -a $RUNTIME_LOGFILE
						echo "[$(date)] [$(basename "$0")] CMD_EXEC_FILE = [$CMD_EXEC_FILE]" | tee -a $RUNTIME_LOGFILE
						echo "[$(date)] [$(basename "$0")] CMD_EXEC_PARAM = [$CMD_EXEC_PARAM]" | tee -a $RUNTIME_LOGFILE
						echo "[$(date)] [$(basename "$0")] CMD_EXEC_ENVFILE = [$CMD_EXEC_ENVFILE]" | tee -a $RUNTIME_LOGFILE
					fi
	
					CMD_EXEC="true"
				fi
			else
				CMDEXEC_DEFAULT_DIR=$MUSTGATHER_DIRNAME/cmdexec
		   		CMD_EXEC_CMD="$MUSTGATHER_DIRNAME/cmdexec/$(basename $CMD_EXEC_FILE) $CMD_EXEC_PARAM"
				CMD_EXEC_FILE=$MUSTGATHER_DIRNAME/cmdexec/$(basename $CMD_EXEC_FILE)
		   		CMD_EXEC_PARAM=$(echo "$CMD_EXEC_CMD" | $AWK '{$1=""}1' | $AWK '{$1=$1}1')
		   		# CMD_EXEC_ENVFILE=$(echo "$CMD_EXEC_INPUT" | $AWK -F'##' '{ print $2 }')
		
				echo "[$(date)] [$(basename "$0")] Script file [$CMD_EXEC_FILE] found! Setting CMDEXEC_DEFAULT_DIR to [$CMDEXEC_DEFAULT_DIR] and CMD_EXEC_FILE to [$CMD_EXEC_FILE]..." | tee -a $RUNTIME_LOGFILE

				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] CMD_EXEC_CMD = [$CMD_EXEC_CMD]" | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [$(basename "$0")] CMD_EXEC_FILE = [$CMD_EXEC_FILE]" | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [$(basename "$0")] CMD_EXEC_PARAM = [$CMD_EXEC_PARAM]" | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [$(basename "$0")] CMD_EXEC_ENVFILE = [$CMD_EXEC_ENVFILE]" | tee -a $RUNTIME_LOGFILE
				fi

				CMD_EXEC="true"
			fi
		else
			CMD_EXEC="true"
		fi
	
		if [ $CMD_EXEC == "true" ]
		then
			if [ ${#CMD_EXEC_ENVFILE} -gt 0 ] 
			then
				if [[ ! $CMD_EXEC_ENVFILE =~ ^/ ]] && [[ ! $CMD_EXEC_ENVFILE =~ ^./ ]]
				then
					echo "[$(date)] [$(basename "$0")] Input environment file for function getCmdExec() [$CMD_EXEC_ENVFILE] is relative and will be set to default [$CMDEXEC_DEFAULT_DIR/$CMD_EXEC_ENVFILE]..." | tee -a $RUNTIME_LOGFILE
					CMD_EXEC_ENVFILE=$CMDEXEC_DEFAULT_DIR/$CMD_EXEC_ENVFILE
				fi
			
				if ! checkInputFile $CMD_EXEC_ENVFILE
				then
					echo "[$(date)] [$(basename "$0")] Input environment file for function getCmdExec() [$CMD_EXEC_ENVFILE] is a directory or unavailable or zero-sized!" | tee -a $RUNTIME_LOGFILE
					CMD_EXEC="false"
				else
					CMD_EXEC_IN_LINE=
					CMD_EXEC_ENVFILE_VAR=
				
					while read CMD_EXEC_IN_LINE
					do
						# Skip all lines that start with # and blank lines
						if [[ $(echo "$CMD_EXEC_IN_LINE" | $AWK '{$1=$1};1') == "#"* ]] || [[ $(echo "$CMD_EXEC_IN_LINE" | $AWK '{ print NF }') -eq 0 ]]
						then
							continue
						fi
						
						if [ ${#CMD_EXEC_ENVFILE_VAR} -eq 0 ]
						then
							CMD_EXEC_ENVFILE_VAR=$CMD_EXEC_IN_LINE
						else
							CMD_EXEC_ENVFILE_VAR="${CMD_EXEC_ENVFILE_VAR}##${CMD_EXEC_IN_LINE}"
						fi	
					done < $CMD_EXEC_ENVFILE
					
					if [ ${#CMD_EXEC_ENVFILE_VAR} -gt 0 ]
					then
						if ! checkEnvVar "$CMD_EXEC_ENVFILE_VAR"
						then
							echo "[$(date)] [$(basename "$0")] User input [$CMD_EXEC_ENVFILE_VAR] is invalid!" | tee -a $RUNTIME_LOGFILE
							CMD_EXEC="false"
						else
							CMD_EXEC="true"
				   		fi
					else
						echo "[$(date)] [$(basename "$0")] Unable to determine environment variable from input environment file [$CMD_EXEC_ENVFILE]..." | tee -a $RUNTIME_LOGFILE
						CMD_EXEC="false"
					fi
				fi
			else
				CMD_EXEC="true"
			fi
		fi
	fi
fi

# [CMDEXEC] To get user agreement before executing CMDEXEC custom script
if [ ${#CMD_EXEC_FILE} -gt 0 ] && [ ${CMD_EXEC} == "true" ] && ( [ ${CMD_EXEC_CMD} != ".listcmd" ] && [ ${CMD_EXEC_CMD} != ".listcmd_custom" ] )
then
	getCmdExecAgreement 

	if [ $? -gt 0 ]
	then
		CMD_EXEC_AGREEMENT='no'	
		CMD_EXEC="false"
	else
		CMD_EXEC_AGREEMENT='yes'
		CMD_EXEC="true"
	fi
fi

if [ ${#CMD_EXEC_FILE} -gt 0 ] && [ ${CMD_EXEC} == "false" ]
then
	printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}Skipping CMDEXEC execution...${NORMAL}${NEWLINE}"
	echo "[$(date)] [$(basename "$0")] Skipping CMDEXEC execution..." >> $RUNTIME_LOGFILE
fi

# [POD LOGS] 
if [ ${#POD_LOG_TAILLINES} -gt 0 ] && [ $POD_LOG_TAILLINES != -1 ]
then
	if [[ "$POD_LOG_TAILLINES" =~ ^[0-9]+[0-9]*$ ]]
	then
		POD_LOG_TAILLINES_CURL_STR="&tailLines=$POD_LOG_TAILLINES"
		POD_LOG_TAILLINES_OC_STR="--tail=${POD_LOG_TAILLINES}"
	else
		echo "[$(date)] [$(basename "$0")] POD_LOG_TAILLINES is invalid [$POD_LOG_TAILLINES]! Ignoring..." >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: POD_LOG_TAILLINES is invalid [$POD_LOG_TAILLINES]! Ignoring...${NORMAL}${NEWLINE}"

		POD_LOG_TAILLINES_CURL_STR=
		POD_LOG_TAILLINES_OC_STR=

		OPT_WARN="true"
	fi
else
	POD_LOG_TAILLINES_CURL_STR=
	POD_LOG_TAILLINES_OC_STR=
fi

# [-m] [MANUALCOLLECT] For security purpose, to backup and validate config file to ensure no changes before execution!
if [ ${#MANUAL_COLL_INPUTFILE} -gt 0 ] 
then
	if [ $MANUAL_COLL_INPUTFILE == ".listmc" ] || [ $MANUAL_COLL_INPUTFILE == ".listmc_custom" ]
	then
		if [ $REPORT_ON_SCREEN == "false" ]
		then
			echo "[$(date)] [$(basename "$0")] Setting REPORT_ON_SCREEN to [true]..." | tee -a $RUNTIME_LOGFILE

			REPORT_ON_SCREEN="true" 
			REPORT_ON_SCREEN_SUMMARY_FILE=$ROOT_OUTDIR/${ANALYZE_OUTFILE##*/}.$$
		fi
	else
		# Assumed to be product provided MANUALCOLLECT configuration file
		if [[ ! $MANUAL_COLL_INPUTFILE =~ ^/ ]] && [[ ! $MANUAL_COLL_INPUTFILE =~ ^./ ]]
		then
			MANUALCOLLECT_DEFAULT_DIR=$MUSTGATHER_DIRNAME
		
			while read MC_PROD_VER_LINE
			do
				MC_PROD_GROUP=$(echo "$MC_PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
				MC_PROD_VER=$(echo "$MC_PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
				
				if [ $MANUAL_COLL_CUSTOM_DATA == "false" ]
				then
					MANUAL_COLL_INPUTFILE_FINAL=$MANUALCOLLECT_DEFAULT_DIR/config/manualcollect/$MC_PROD_VER/config/${MANUAL_COLL_INPUTFILE}
				else
					MANUAL_COLL_INPUTFILE_FINAL=$MANUALCOLLECT_DEFAULT_DIR/data/manualcollect/$MC_PROD_VER/config/${MANUAL_COLL_INPUTFILE}
	
					if [ ! -s $MANUAL_COLL_INPUTFILE_FINAL ]
					then
						echo "[$(date)] [$(basename "$0")] Input file [$MANUAL_COLL_INPUTFILE_FINAL] does not exist or is zero-sized!" | tee -a $RUNTIME_LOGFILE
	
						MANUAL_COLL_INPUTFILE_FINAL=$MANUALCOLLECT_DEFAULT_DIR/data/manualcollect/config/${MANUAL_COLL_INPUTFILE}
	
						if [ ! -s $MANUAL_COLL_INPUTFILE_FINAL ]
						then
							echo "[$(date)] [$(basename "$0")] Input file [$MANUAL_COLL_INPUTFILE_FINAL] does not exist or is zero-sized!" | tee -a $RUNTIME_LOGFILE
							MANUAL_COLL_INPUTFILE_FINAL=""
						else
							echo "[$(date)] [$(basename "$0")] Setting MANUAL_COLL_CUSTOM_DATADIR to [$MANUALCOLLECT_DEFAULT_DIR/data/manualcollect/config]..."
						fi
					else
						echo "[$(date)] [$(basename "$0")] Setting MANUAL_COLL_CUSTOM_DATADIR to [$MANUALCOLLECT_DEFAULT_DIR/data/manualcollect/$MC_PROD_VER/config]..."
					fi
				fi
	
				if [ ${#MANUAL_COLL_INPUTFILE_FINAL} -gt 0 ]
				then
					echo "[$(date)] [$(basename "$0")] Input file for function getManualCollection() [$MANUAL_COLL_INPUTFILE] is relative and will be set to default [$MANUAL_COLL_INPUTFILE_FINAL]..." | tee -a $RUNTIME_LOGFILE
					MANUAL_COLL_INPUTFILE_ARR[${MANUAL_COLL_INPUTFILE_ARR[@]}]=$MANUAL_COLL_INPUTFILE_FINAL
				fi
			done < $PROD_VERSIONS_REFFILE_FINAL
		
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] MANUAL_COLL_INPUTFILE_ARR = [${MANUAL_COLL_INPUTFILE_ARR[@]}]" | tee -a $RUNTIME_LOGFILE
			fi
		else
			MANUAL_COLL_INPUTFILE_ARR[${MANUAL_COLL_INPUTFILE_ARR[@]}]=$MANUAL_COLL_INPUTFILE
		fi
	
		if [ ${#MANUAL_COLL_INPUTFILE_ARR[@]} -gt 0 ]
		then
			for MC_INFILE in ${MANUAL_COLL_INPUTFILE_ARR[@]}
			do
				if [ -s ${MC_INFILE} ]
				then
					if [ $(basename $MC_INFILE) != "mc.help" ] && [ $(basename $MC_INFILE) != "mc_custom.help" ]
					then
						checkManualCollection "$MC_INFILE" 
					
						if [ $? -gt 0 ]
						then
							echo "[$(date)] [$(basename "$0")] Setting MANUAL_COLL_SECRET to [false]..." | tee -a $RUNTIME_LOGFILE
							MANUAL_COLL_SECRET="false"
						else
							echo "[$(date)] [$(basename "$0")] Setting MANUAL_COLL_SECRET to [true]..." | tee -a $RUNTIME_LOGFILE
							MANUAL_COLL_SECRET="true"
						fi
					fi
				else
					echo "[$(date)] [$(basename "$0")] WARNING: MANUAL_COLL_INPUTFILE [$MC_INFILE] does not exists or is zero-sized!" >> $RUNTIME_LOGFILE
					printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: MANUAL_COLL_INPUTFILE [$MC_INFILE] does not exists or is zero-sized!${NORMAL}${NEWLINE}" 
					OPT_WARN="true"
				fi
			done
		else
			echo "[$(date)] [$(basename "$0")] MANUAL_COLL_INPUTFILE_ARR is empty! Disabling MANUALCOLLECT mode..." | tee -a $RUNTIME_LOGFILE
			MANUAL_COLL=0	
		fi
	fi
fi

# [-A] [COMPLIANCE] Set default input file
if [ ${GET_COMPLIANCE} == "true" ]
then
	if [ ${#COMPLIANCE_INPUTFILE} -eq 0 ]
	then
		if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
		then
			while read PROD_VER_LINE
			do
				TMP_COMPLIANCE_PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
				TMP_COMPLIANCE_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
				TMP_COMPLIANCE_PROD_GROUP_NS_REFFILE=${REFFILE_OUTDIR}/${COMPLIANCE_PROD_GROUP}.ns-ref
		
				echo "[$(date)] [$(basename "$0")] Adding item [$MUSTGATHER_DIRNAME/config/compliance/$TMP_COMPLIANCE_PROD_VER/config/compliance.cfg] into array COMPLIANCE_INPUTFILE_ARR!" | tee -a $RUNTIME_LOGFILE
				COMPLIANCE_INPUTFILE_ARR[${#COMPLIANCE_INPUTFILE_ARR[@]}]=$MUSTGATHER_DIRNAME/config/compliance/$TMP_COMPLIANCE_PROD_VER/config/compliance.cfg
			done < $PROD_VERSIONS_REFFILE_FINAL
		else
			echo "[$(date)] [$(basename "$0")] Product group namespace reference file [$PROD_VERSIONS_REFFILE_FINAL] does not exist or is zero-sized!" | tee -a $RUNTIME_LOGFILE
		fi
	else
		if [ ${COMPLIANCE_INPUTFILE} == "custom" ]
		then
			if [ -s $PROD_VERSIONS_REFFILE_FINAL ]
			then
				while read PROD_VER_LINE
				do
					TMP_COMPLIANCE_PROD_GROUP=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $1 }')
					TMP_COMPLIANCE_PROD_VER=$(echo "$PROD_VER_LINE" | $AWK -F${PROD_REFFILE_DELIMITER} '{ print $2 }')
					TMP_COMPLIANCE_PROD_GROUP_NS_REFFILE=${REFFILE_OUTDIR}/${COMPLIANCE_PROD_GROUP}.ns-ref
			
					TMP_COMPLIANCE_INPUTFILE=$MUSTGATHER_DIRNAME/data/compliance/$TMP_COMPLIANCE_PROD_VER/config/compliance.cfg

					if [ ! -s $TMP_COMPLIANCE_INPUTFILE ]
					then
						TMP_COMPLIANCE_INPUTFILE=$MUSTGATHER_DIRNAME/data/compliance/config/compliance.cfg
						
						if [ ! -s $TMP_COMPLIANCE_INPUTFILE ]
						then
							echo "[$(date)] [$(basename "$0")] Unable to locate custom COMPLIANCE configuration file! Skipping..."
							continue
						else
							echo "[$(date)] [$(basename "$0")] Adding item [$MUSTGATHER_DIRNAME/data/compliance/config/compliance.cfg] into array COMPLIANCE_INPUTFILE_ARR!" | tee -a $RUNTIME_LOGFILE
							COMPLIANCE_INPUTFILE_ARR[${#COMPLIANCE_INPUTFILE_ARR[@]}]=$MUSTGATHER_DIRNAME/data/compliance/config/compliance.cfg
						fi
					else
						echo "[$(date)] [$(basename "$0")] Adding item [$MUSTGATHER_DIRNAME/data/compliance/$TMP_COMPLIANCE_PROD_VER/config/compliance.cfg] into array COMPLIANCE_INPUTFILE_ARR!" | tee -a $RUNTIME_LOGFILE
						COMPLIANCE_INPUTFILE_ARR[${#COMPLIANCE_INPUTFILE_ARR[@]}]=$MUSTGATHER_DIRNAME/data/compliance/$TMP_COMPLIANCE_PROD_VER/config/compliance.cfg
					fi
				done < $PROD_VERSIONS_REFFILE_FINAL
			else
				echo "[$(date)] [$(basename "$0")] Product group namespace reference file [$PROD_VERSIONS_REFFILE_FINAL] does not exist or is zero-sized!" | tee -a $RUNTIME_LOGFILE
			fi
		else
			COMPLIANCE_INPUTFILE_ARR[${#COMPLIANCE_INPUTFILE_ARR[@]}]=${COMPLIANCE_INPUTFILE}
		fi
	fi
fi

# [-L] [CLUSTERNODES] To validate journal size setting
if [ $JOURNAL_SIZE_CUSTOM == "true" ]
then
 	checkJournalSize 
 
 	if [ $? -gt 0 ]
 	then
 		JOURNAL_SIZE=$JOURNAL_SIZE_DEFAULT
 	fi
fi

# [-i] [CLUSTERNODES] To validate SSH key option
if [ ${#SSHKEY} -gt 0 ]
then
	if [ $GET_NODES_DATA == "false" ]
	then
		echo "[$(date)] [$(basename "$0")] WARNING: GET_NODES_DATA is set to 'false'. Ignoring user input [-i] SSHKEY [$SSHKEY]..." >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: GET_NODES_DATA is set to 'false'. Ignoring user input [-i] SSHKEY [$SSHKEY]...${NORMAL}${NEWLINE}"
		OPT_WARN="true"
	else
		if [ -s $SSHKEY ]
		then
			SSHKEY="-i $SSHKEY"
			USE_OC_DEBUG=0
		else
			echo "[$(date)] [$(basename "$0")] WARNING: User input SSHKEY [$SSHKEY] does not exist or is zero-sized! Ignoring..." | tee -a $RUNTIME_LOGFILE
			USE_OC_DEBUG=1
			OPT_WARN="true"
		fi
	fi
fi

# [-u] [CLUSTERNODES] To validate cluster node admin username
if [ ${#NODE_ADMIN_USER} -gt 0 ]
then
	if [ $GET_NODES_DATA == "false" ]
	then
		echo "[$(date)] [$(basename "$0")] WARNING: GET_NODES_DATA is set to 'false'. Ignoring user input [-u] NODE_ADMIN_USER [$NODE_ADMIN_USER]..." >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: GET_NODES_DATA is set to 'false'. Ignoring user input [-u] NODE_ADMIN_USER [$NODE_ADMIN_USER]...${NORMAL}${NEWLINE}" 
		OPT_WARN="true"
	fi
fi

# [-s] [CLUSTERNODES] To validate USE_OC_DEBUG
if [ $USE_OC_DEBUG -eq 0 ] 
then
	if [ $GET_NODES_DATA == "false" ]
	then
		echo "[$(date)] [$(basename "$0")] WARNING: GET_NODES_DATA is set to 'false'. Ignoring [-s] USE_OC_DEBUG [$USE_OC_DEBUG]..." >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: GET_NODES_DATA is set to 'false'. Ignoring [-s] USE_OC_DEBUG [$USE_OC_DEBUG]...${NORMAL}${NEWLINE}" 
		OPT_WARN="true"
	fi
fi

# [-E] [CMDEXEC] To validate CMDEXEC environment variables
if [ ${#CMD_EXEC_ENV} -gt 0 ]
then
	if [ $CMD_EXEC == "false" ]
	then
		if [ ${#CMD_EXEC_FILE} -gt 0 ]
		then
			echo "[$(date)] [$(basename "$0")] WARNING: User chose to abort 'cmdexec' module. Ignoring user input [-E] CMD_EXEC_ENV [$CMD_EXEC_ENV]..." >> $RUNTIME_LOGFILE
			printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: User chose to abort 'cmdexec' module. Ignoring user input [-E] CMD_EXEC_ENV [$CMD_EXEC_ENV]...${NORMAL}${NEWLINE}"
		else
			echo "[$(date)] [$(basename "$0")] WARNING: CMDEXEC mode [-C] is NOT set. Ignoring user input [-E] CMD_EXEC_ENV [$CMD_EXEC_ENV]..." >> $RUNTIME_LOGFILE
			printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: CMDEXEC mode [-C] is NOT set. Ignoring user input [-E] CMD_EXEC_ENV [$CMD_EXEC_ENV]...${NORMAL}${NEWLINE}"
		fi

		OPT_WARN="true"
	fi
fi

# [-T] [CMDEXEC] To validate CMDEXEC timeout value
if [ ${#IN_CMD_EXEC_TVALUE} -gt 0 ]
then
	if [ $CMD_EXEC == "true" ]
	then
		if [ ${#TIMEOUT} -eq 0 ]
		then
			echo "[$(date)] [$(basename "$0")] INFO: Command [timeout] is unavailable. Ignoring user input CMD_EXEC_TVALUE [$IN_CMD_EXEC_TVALUE]..." | tee -a $RUNTIME_LOGFILE
		else
		  	if [ $(echo "$IN_CMD_EXEC_TVALUE" | $AWK '{ if ($0 ~ /^[0-9]+[smh]$/) { print "OK" } else { print "NOK" }}') == "OK" ]
			then
				echo "[$(date)] [$(basename "$0")] Setting CMD_EXEC_TVALUE to user input [$IN_CMD_EXEC_TVALUE]..." | tee -a $RUNTIME_LOGFILE
				CMD_EXEC_TVALUE=$IN_CMD_EXEC_TVALUE	
			else
				echo "[$(date)] [$(basename "$0")] Invalid CMD_EXEC_TVALUE [$IN_CMD_EXEC_TVALUE]. Maintain CMD_EXEC_TVALUE at [default = $CMD_EXEC_TVALUE]..." | tee -a $RUNTIME_LOGFILE
			fi
		fi
	else
		if [ ${#CMD_EXEC_FILE} -gt 0 ]
		then
			echo "[$(date)] [$(basename "$0")] WARNING: User chose to abort 'cmdexec' module. Ignoring user input [-T] CMD_EXEC_TVALUE [$IN_CMD_EXEC_TVALUE]..." >> $RUNTIME_LOGFILE
			printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: User chose to abort 'cmdexec' module. Ignoring user input [-T] CMD_EXEC_TVALUE [$IN_CMD_EXEC_TVALUE]...${NORMAL}${NEWLINE}"
		else
			echo "[$(date)] [$(basename "$0")] WARNING: CMDEXEC mode [-C] is NOT set. Ignoring user input [-T] CMD_EXEC_TVALUE [$IN_CMD_EXEC_TVALUE]..." >> $RUNTIME_LOGFILE
			printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: CMDEXEC mode [-C] is NOT set. Ignoring user input [-T] CMD_EXEC_TVALUE [$IN_CMD_EXEC_TVALUE]...${NORMAL}${NEWLINE}"
		fi

		OPT_WARN="true"
	fi
else
	if [ $CMD_EXEC == "true" ]
	then
		if [ ${#TIMEOUT} -eq 0 ]
		then
			echo "[$(date)] [$(basename "$0")] INFO: Command [timeout] is unavailable. Script file [$CMD_EXEC_FILE] will be executed without timeout!" | tee -a $RUNTIME_LOGFILE
		fi
	fi
fi

# [-n] [MANUALCOLLECT] To validate MANUALCOLLECT environment variables
if [ ${#MANUAL_COLL_ENV} -gt 0 ]
then
	if [ $MANUAL_COLL -eq 0 ]
	then
		echo "[$(date)] [$(basename "$0")] WARNING: MANUALCOLLECT mode [-m] is NOT set. Ignoring user input [-n] MANUAL_COLL_ENV [$MANUAL_COLL_ENV]..." >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: MANUALCOLLECT mode [-m] is NOT set. Ignoring user input [-n] MANUAL_COLL_ENV [$MANUAL_COLL_ENV]...${NORMAL}${NEWLINE}"
		OPT_WARN="true"
	fi
fi

# [-w] [MANUALCOLLECT] To validate EXECCMD timeout value
if [ ${#IN_MANUAL_COLLECT_EXEC_TVALUE} -gt 0 ]
then
	if [ $MANUAL_COLL -eq 1 ]
	then
		if [ ${#TIMEOUT} -eq 0 ]
		then
			echo "[$(date)] [$(basename "$0")] INFO: Command [timeout] is unavailable. Ignoring user input MANUAL_COLL_EXEC_TIMEOUT [$IN_MANUAL_COLLECT_EXEC_TVALUE]..." | tee -a $RUNTIME_LOGFILE
		else
		  	if [ $(echo "$IN_MANUAL_COLLECT_EXEC_TVALUE" | $AWK '{ if ($0 ~ /^[0-9]+[smh]$/) { print "OK" } else { print "NOK" }}') == "OK" ]
			then
				echo "[$(date)] [$(basename "$0")] Setting MANUAL_COLL_EXEC_TIMEOUT to user input [$IN_MANUAL_COLLECT_EXEC_TVALUE]..." | tee -a $RUNTIME_LOGFILE
				MANUAL_COLL_EXEC_TIMEOUT=$IN_MANUAL_COLLECT_EXEC_TVALUE
			else
				echo "[$(date)] [$(basename "$0")] Invalid MANUAL_COLL_EXEC_TIMEOUT [$IN_MANUAL_COLLECT_EXEC_TVALUE]. Maintain MANUAL_COLL_EXEC_TIMEOUT at [default = $MANUAL_COLL_DEFAULT_EXEC_TIMEOUT]..." | tee -a $RUNTIME_LOGFILE
			fi
		fi
	else
		echo "[$(date)] [$(basename "$0")] WARNING: MANUALCOLLECT mode [-m] is NOT set. Ignoring user input [-w] MANUAL_COLL_EXEC_TIMEOUT [$IN_MANUAL_COLLECT_EXEC_TVALUE]..." >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: MANUALCOLLECT mode [-m] is NOT set. Ignoring user input [-w] MANUAL_COLL_EXEC_TIMEOUT [$IN_MANUAL_COLLECT_EXEC_TVALUE]...${NORMAL}${NEWLINE}"
		OPT_WARN="true"
	fi
fi

# [-A] [COMPLIANCE] To prompt for user acceptance if ACTIONSCRIPT is detected
if [ ${GET_COMPLIANCE} == "true" ]
then
	for COMPLIANCE_FILE in $(echo "${COMPLIANCE_INPUTFILE_ARR[@]}" | tr ' ' '\n' | sort -u | tr '\n' ' ')
	do
		if [ -s $COMPLIANCE_FILE ]
		then
			if [ $COMPLIANCE_CUSTOM_INPUTFILE == "false" ]
			then
				COMPLIANCE_FILE_PROD_VER=$(echo "$COMPLIANCE_FILE" | sed 's#'$MUSTGATHER_DIRNAME'##' | $AWK -F/ '{ print $3 }')
			fi

			PRECHECK_COMPLIANCE_ACTION_ARR=()
	
			while read COMPLIANCE_CFGLINE
			do
				if [[ $(echo "$COMPLIANCE_CFGLINE" | $AWK '{$1=$1};1') == "$COMPLIANCE_CFGFILE_COMMENT"* ]] || [[ $(echo "$COMPLIANCE_CFGLINE" | $AWK '{ print NF }') -eq 0 ]]
				then
					continue
				fi
	
				PRECHECK_COMPLIANCE_TAG=$(echo "$COMPLIANCE_CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $1 }')
				PRECHECK_COMPLIANCE_ACTIONWHEN=$(echo "$COMPLIANCE_CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $13 }' | $AWK '{ if ($0 == 0) { print "PASSED" } else { if ($0 == 1) { print "FAILED" } else { print "UNKNOWN" } } }')
				PRECHECK_COMPLIANCE_ACTIONSCRIPT=$(echo "$COMPLIANCE_CFGLINE" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $14 }')
	
				if [ $COMPLIANCE_INPUTTAG != "ALL" ]
				then
					PRECHECK_TAG_MATCHED="false"
		
					IFS=$OLDIFS
					PRECHECK_PROC_COMPLIANCE_INPUTTAG=$(echo "$COMPLIANCE_INPUTTAG" | sed 's/,/ /g')
		
					for C_TAG in $(echo "$PRECHECK_PROC_COMPLIANCE_INPUTTAG")
					do
						if [ $PRECHECK_COMPLIANCE_TAG == "$C_TAG" ]
						then
							if [ ${#PRECHECK_COMPLIANCE_ACTIONSCRIPT} -gt 0 ]	
							then
								PRECHECK_COMPLIANCE_ACTION_ARR[${#PRECHECK_COMPLIANCE_ACTION_ARR[@]}]="$PRECHECK_COMPLIANCE_TAG$COMPLIANCE_CFGFILE_DELIMITER$PRECHECK_COMPLIANCE_ACTIONWHEN$COMPLIANCE_CFGFILE_DELIMITER$PRECHECK_COMPLIANCE_ACTIONSCRIPT"	
							fi
	
							break
						fi
					done
					IFS=$'\n'
				else
					if [ ${#PRECHECK_COMPLIANCE_ACTIONSCRIPT} -gt 0 ]
					then
						PRECHECK_COMPLIANCE_ACTION_ARR[${#PRECHECK_COMPLIANCE_ACTION_ARR[@]}]="$PRECHECK_COMPLIANCE_TAG$COMPLIANCE_CFGFILE_DELIMITER$PRECHECK_COMPLIANCE_ACTIONWHEN$COMPLIANCE_CFGFILE_DELIMITER$PRECHECK_COMPLIANCE_ACTIONSCRIPT"	
					fi
				fi
			done < $COMPLIANCE_FILE
	
			if [ ${#PRECHECK_COMPLIANCE_ACTION_ARR[@]} -gt 0 ]
			then
				PRECHECK_ACTION_CTR=0
	
				echo "[$(date)] [$(basename "$0")] WARNING: The following ACTIONSCRIPT will be executed depending on the result of the compliance rule:" >> $RUNTIME_LOGFILE
				printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: The following ACTIONSCRIPT will be executed depending on the result of the compliance rule:${NORMAL}${NEWLINE}"
				
				for PRECHECK_ACTION in ${PRECHECK_COMPLIANCE_ACTION_ARR[@]}
				do
					(( PRECHECK_ACTION_CTR=PRECHECK_ACTION_CTR+1 ))

					PRECHECK_ACTION_TAG=$(echo "$PRECHECK_ACTION" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $1 }')
					PRECHECK_ACTION_WHEN=$(echo "$PRECHECK_ACTION" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $2 }')
					PRECHECK_ACTION_SCRIPT=$(echo "$PRECHECK_ACTION" | $AWK -F$COMPLIANCE_CFGFILE_DELIMITER '{ print $3 }')
	
					if [[ $PRECHECK_ACTION_SCRIPT =~ ^/ ]]
					then
						echo "($PRECHECK_ACTION_CTR) [TAG=$PRECHECK_ACTION_TAG] [EXEC_WHEN=$PRECHECK_ACTION_WHEN] $PRECHECK_ACTION_SCRIPT" >> $RUNTIME_LOGFILE
						printf "${BOLD}${RED}($PRECHECK_ACTION_CTR) [TAG=$PRECHECK_ACTION_TAG] [EXEC_WHEN=$PRECHECK_ACTION_WHEN] $PRECHECK_ACTION_SCRIPT${NORMAL}${NEWLINE}" 
					else
						echo "($PRECHECK_ACTION_CTR) [TAG=$PRECHECK_ACTION_TAG] [EXEC_WHEN=$PRECHECK_ACTION_WHEN] $MUSTGATHER_DIRNAME/config/compliance/$COMPLIANCE_FILE_PROD_VER/scripts/$PRECHECK_COMPLIANCE_ACTIONSCRIPT" >> $RUNTIME_LOGFILE
						printf "${BOLD}${RED}($PRECHECK_ACTION_CTR) [TAG=$PRECHECK_ACTION_TAG] [EXEC_WHEN=$PRECHECK_ACTION_WHEN] $MUSTGATHER_DIRNAME/config/compliance/$COMPLIANCE_FILE_PROD_VER/scripts/$PRECHECK_COMPLIANCE_ACTIONSCRIPT${NORMAL}${NEWLINE}" 
					fi
				done
	
				OPT_WARN="true"
			fi
		fi	
	done
fi

# [-Z] [PLUGINS] To validate PLUGINS environment variables
if [ ${#PLUGINS_ENV} -gt 0 ]
then
	if [ ${#PLUGINS} -eq 0 ]
	then
		echo "[$(date)] [$(basename "$0")] WARNING: PLUGINS mode [-P] is NOT set. Ignoring user input [-Z] PLUGINS_ENV [$PLUGINS_ENV]..." >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: PLUGINS mode [-P] is NOT set. Ignoring user input [-Z] PLUGINS_ENV [$PLUGINS_ENV]...${NORMAL}${NEWLINE}"
		OPT_WARN="true"
	fi
fi

# [PLUGINS] To create user environment file [-Z] and to check whether data dump is enabled
if [ ${#PLUGINS} -gt 0 ]
then
	# To create environment file for each plugins
	XPLUGIN_COUNT=$(echo "$PLUGINS" | $AWK -F, '{ print NF }')
	XPLUGIN_ENV_COUNT=$(echo "$PLUGINS_ENV" | $AWK -F'\\^\\^' '{ print NF }')
	
	if [ $MG_DEBUG == "true" ]
	then
		echo "[$(date)] [$(basename "$0")] Total plugin = [$XPLUGIN_COUNT]" | tee -a $RUNTIME_LOGFILE
		echo "[$(date)] [$(basename "$0")] Total plugin envvar pair = [$XPLUGIN_ENV_COUNT]" | tee -a $RUNTIME_LOGFILE
	fi

	if [ $XPLUGIN_ENV_COUNT -gt 0 ]
	then
		echo "[$(date)] [$(basename "$0")] Creating user environment file..." | tee -a $RUNTIME_LOGFILE

		XPLUGINS_ARR=()
		IFS=$'\n'
		for XPLUGINS_ENV_PAIRS in $(echo "$PLUGINS_ENV" | sed 's/\^\^/\n/g')
		do
			if [ $MG_DEBUG == "true" ]
			then
				echo "[$(date)] [$(basename "$0")] XPLUGINS_ENV_PAIRS = [$XPLUGINS_ENV_PAIRS]" | tee -a $RUNTIME_LOGFILE
			fi

			XPLG_PROC_FLAG="false"

			if [ $(echo "$XPLUGINS_ENV_PAIRS" | $AWK -F'~>' '{ print NF} ') -eq 1 ]
			then
				if [ $XPLUGIN_COUNT -eq 1 ]
				then
					XPLUGIN_NAME=$PLUGINS
					XPLUGIN_ENVVAR=$XPLUGINS_ENV_PAIRS

					for XPLG_PROC in ${XPLUGINS_ARR[@]}
					do
						if [ $XPLG_PROC == $XPLUGIN_NAME ]
						then
							echo "[$(date)] [$(basename "$0")] Plugin name is empty [$XPLUGINS_ENV_PAIRS]! Skipping..." | tee -a $RUNTIME_LOGFILE
							XPLG_PROC_FLAG="true"
							break
						fi
					done	
				else
					echo "[$(date)] [$(basename "$0")] There are more than one PLUGINS [$PLUGINS], but there is no PLUGIN_NAME provide in PLUGINS_ENV [$XPLUGINS_ENV_PAIRS]!" | tee -a $RUNTIME_LOGFILE
					continue
				fi
			else
				XPLUGIN_NAME=$(echo "$XPLUGINS_ENV_PAIRS" | $AWK -F'~>' '{ print $1 }')
				XPLUGIN_ENVVAR=$(echo "$XPLUGINS_ENV_PAIRS" | $AWK -F'~>' '{ print $2 }')
			fi

			if [ $XPLG_PROC_FLAG == "true" ]
			then
				continue
			fi

			XPLUGINS_ARR[${#XPLUGINS_ARR[@]}]=$XPLUGIN_NAME

			for XPLG in $(echo "$PLUGINS" | sed 's/,/\n/g' | sort | uniq)	
			do
				XPLG_NAME=$(echo "$XPLG" | $AWK -F: '{ print $1 }')	
				XPLG_ACTION=$(echo "$XPLG" | $AWK -F: '{ print $2 }')

				if [ ${#XPLG_ACTION} -eq 0 ]
				then
					XPLG_ACTION=$PLUGINS_DEFAULT_ACTION
				fi

				if [ $XPLUGIN_NAME == $XPLG_NAME ]
				then
					XPLUGIN_ACTION=$XPLG_ACTION	
					break
				fi
			done

			if [ $XPLUGIN_ACTION == "data" ]
			then
				if [ ${#XPLUGIN_ACTION} -eq 0 ]
				then
					echo "[$(date)] [$(basename "$0")] Unable to determine plugin action for plugin [$XPLUGIN_NAME]! Skipping..." | tee -a $RUNTIME_LOGFILE
					continue
				fi
	
				if [ ! -d $PLUGINS_ROOT_OUTDIR ]
				then
					mkdir -p $PLUGINS_ROOT_OUTDIR
				fi
	
				XPLUGIN_ENVFILE=$PLUGINS_ROOT_OUTDIR/$XPLUGIN_NAME.$XPLUGIN_ACTION.userenv
		
				echo "[$(date)] [$(basename "$0")] Environment variables for plugin [$XPLUGIN_NAME] = [$XPLUGIN_ENVVAR]" | tee -a $RUNTIME_LOGFILE
	
				for XPLUGIN_ENVVAR_KEYVAL in $(echo "$XPLUGIN_ENVVAR" | $AWK -F## '{ for (i=1;i<=NF;i++) { print $i } }')
				do
					XPLUGIN_ENV_KEY=$(echo "$XPLUGIN_ENVVAR_KEYVAL" | $AWK -F= '{ print $1 }')
					# XPLUGIN_ENV_VAL=$(echo "$XPLUGIN_ENVVAR_KEYVAL" | $AWK -F= '{ print $2 }')
					XPLUGIN_ENV_VAL=$(echo "$XPLUGIN_ENVVAR_KEYVAL" | cut -f 2- -d =)
	
					if [ $MG_DEBUG == "true" ]
					then
						echo "[$(date)] [$(basename "$0")] XPLUGIN_ENV_KEY = [$XPLUGIN_ENV_KEY]" | tee -a $RUNTIME_LOGFILE
						echo "[$(date)] [$(basename "$0")] XPLUGIN_ENV_VAL = [$XPLUGIN_ENV_VAL]" | tee -a $RUNTIME_LOGFILE
					fi
	
					if [[ "$XPLUGIN_ENV_VAL" =~ ^\" ]] && [[ "$XPLUGIN_ENV_VAL" =~ \"$ ]]
					then
						# XPLUGIN_ENV_VAL starts and ends with double quote [remove start/end double quotes for further processing]
						TMP_XPLUGIN_ENV_VAL=$(echo "$XPLUGIN_ENV_VAL" | sed 's/^"//' | sed 's/"$//')
						echo "[$(date)] [$(basename "$0")] Removing start/end double quotes => TMP_XPLUGIN_ENV_VAL = [$TMP_XPLUGIN_ENV_VAL]" | tee -a $RUNTIME_LOGFILE
					else
						# XPLUGIN_ENV_VAL starts and ends with single quote [remove start/end single quotes for further processing]
						if [[ "$XPLUGIN_ENV_VAL" =~ ^\' ]] && [[ "$XPLUGIN_ENV_VAL" =~ \'$ ]]
						then
							TMP_XPLUGIN_ENV_VAL=$(echo "$XPLUGIN_ENV_VAL" | sed "s/^'//" | sed "s/'$//")
							echo "[$(date)] [$(basename "$0")] Removing start/end single quotes => TMP_XPLUGIN_ENV_VAL = [$TMP_XPLUGIN_ENV_VAL]" | tee -a $RUNTIME_LOGFILE
						else
							TMP_XPLUGIN_ENV_VAL="$XPLUGIN_ENV_VAL"
						fi
					fi
	
					# Check whether there's any single/double quotes within the string value
					if echo "$TMP_XPLUGIN_ENV_VAL" | grep '"' > /dev/null
					then
						FINAL_XPLUGIN_ENV_VAL="$XPLUGIN_ENV_KEY='$TMP_XPLUGIN_ENV_VAL'"
						echo "[$(date)] [$(basename "$0")] Quoting environment variable [$XPLUGIN_ENV_KEY] => [$FINAL_XPLUGIN_ENV_VAL]" | tee -a $RUNTIME_LOGFILE
					else
						if echo "$TMP_XPLUGIN_ENV_VAL" | grep "'" > /dev/null
						then
							# PROC_XPLUGIN_ENV_VAL=$(echo "$TMP_XPLUGIN_ENV_VAL" | sed "s/'/'\"'\"'/g")
							FINAL_XPLUGIN_ENV_VAL="$XPLUGIN_ENV_KEY=\"$XPLUGIN_ENV_VAL\""
							echo "[$(date)] [$(basename "$0")] Quoting environment variable [$XPLUGIN_ENV_KEY] => [$FINAL_XPLUGIN_ENV_VAL]" | tee -a $RUNTIME_LOGFILE
						else
							FINAL_XPLUGIN_ENV_VAL="$XPLUGIN_ENV_KEY=\"$TMP_XPLUGIN_ENV_VAL\""
							echo "[$(date)] [$(basename "$0")] Quoting environment variable [$XPLUGIN_ENV_KEY] => [$FINAL_XPLUGIN_ENV_VAL]" | tee -a $RUNTIME_LOGFILE
						fi
					fi
	
					echo "[$(date)] [$(basename "$0")] Writing envvar [$FINAL_XPLUGIN_ENV_VAL] to file [$XPLUGIN_ENVFILE]..." | tee -a $RUNTIME_LOGFILE
					echo "$FINAL_XPLUGIN_ENV_VAL" >> $XPLUGIN_ENVFILE 
				done
			fi
		done
	fi

	for XPLG in $(echo "$PLUGINS" | sed 's/,/\n/g' | sort | uniq)	
	do
		echo "[$(date)] [$(basename "$0")] Creating complete subshell environment for plugin [$XPLG]..." | tee -a $RUNTIME_LOGFILE

		XPLG_NAME=$(echo "$XPLG" | $AWK -F: '{ print $1 }')	
		XPLG_ACTION=$(echo "$XPLG" | $AWK -F: '{ print $2 }')

		if [ ${#XPLG_ACTION} -eq 0 ]
		then
			XPLG_ACTION=$PLUGINS_DEFAULT_ACTION
		fi

		# Create complete subshell environment (parameter file + -Z userinput) to determine whether data dump is enabled for plugin
		XPROD_VER=$(echo "$PRODUCT_VERSION" | sed 's/\.//g')
		XPLUGINS_PARAM_FILE="$MUSTGATHER_DIRNAME/config/plugins/$XPLG_NAME/$XPLG_ACTION/plugin-$XPLG_NAME-$XPLG_ACTION-${XPROD_VER}.param"	
		XPLUGIN_ENVFILE="$PLUGINS_ROOT_OUTDIR/$XPLG_NAME.$XPLG_ACTION.userenv"
	
		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] XPLUGINS_PARAM_FILE = [$XPLUGINS_PARAM_FILE]" | tee -a $RUNTIME_LOGFILE
			echo "[$(date)] [$(basename "$0")] XPLUGIN_ENVFILE = [$XPLUGIN_ENVFILE]" | tee -a $RUNTIME_LOGFILE
		fi
	
		# Execute in a subshell to NOT interfere with the current shell
		if [ -f $XPLUGINS_PARAM_FILE ] && [ -f $XPLUGIN_ENVFILE ]
		then
			XPLUGIN_ENV_CMD="bash -c '. $XPLUGINS_PARAM_FILE; . $XPLUGIN_ENVFILE; isDataDumpEnabled'"
		else
			if [ -f $XPLUGINS_PARAM_FILE ]
			then
				XPLUGIN_ENV_CMD="bash -c '. $XPLUGINS_PARAM_FILE; isDataDumpEnabled'"
			else
				echo "[$(date)] [$(basename "$0")] Parameter file [$XPLUGINS_PARAM_FILE] of plugin [$XPLG_NAME] does not exist! Skipping..." | tee -a $RUNTIME_LOGFILE
				continue
			fi
		fi

		if [ $MG_DEBUG == "true" ]
		then
			echo "[$(date)] [$(basename "$0")] XPLUGIN_ENV_CMD = [$XPLUGIN_ENV_CMD]" | tee -a $RUNTIME_LOGFILE
		fi

		if [ -f $XPLUGINS_PARAM_FILE ]
		then
			XPLUGIN_ENV_RES=$(eval "$XPLUGIN_ENV_CMD")
			echo "[$(date)] [$(basename "$0")] XPLUGIN_ENV_RES = [$XPLUGIN_ENV_RES]" | tee -a $RUNTIME_LOGFILE
	
			if [ ${#XPLUGIN_ENV_RES} -gt 0 ]
			then
				if [ $(echo "$XPLUGIN_ENV_RES" | $AWK '{ print tolower($0) }') == "true" ]
				then
					# To prompt for user agreement for data dump!
					XPLUGIN_ASK_USER_AGREEMENT=1
				
					while [ $XPLUGIN_ASK_USER_AGREEMENT -eq 1 ]
					do
						echo -n "[$(date)] [$(basename "$0")] WARNING: Data dump is enabled for plugin [$XPLG_NAME]. Do you want to continue? (y/n) " >> $RUNTIME_LOGFILE
						printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: Data dump is enabled for plugin [$XPLG_NAME]. Do you want to continue? (y/n) ${NORMAL}"
					
						if [ $AUTO_YES == "true" ]
						then
							XPLUGIN_TO_PROCEED="y"
							echo "$XPLUGIN_TO_PROCEED" | tee -a $RUNTIME_LOGFILE
							echo "[$(date)] [$(basename "$0")] Option [-Y] is set! Auto answering [y]..." | tee -a $RUNTIME_LOGFILE
						else
							if [ $MG_TTY == "false" ]
							then
								XPLUGIN_TO_PROCEED="n"
								echo "$XPLUGIN_TO_PROCEED" | tee -a $RUNTIME_LOGFILE
								echo "[$(date)] [$(basename "$0")] In non-TTY mode, auto answering [n]..." | tee -a $RUNTIME_LOGFILE
							else
								read -t $DEFAULT_USERINPUT_TIMEOUT XPLUGIN_TO_PROCEED
								XPLUGIN_EXIT_STATUS=$?
	
								if [ $MG_DEBUG == "true" ]
								then
									echo "[$(date)] [${FUNCNAME[0]}] XPLUGIN_EXIT_STATUS = [$XPLUGIN_EXIT_STATUS]"
								fi
					
								if [ $XPLUGIN_EXIT_STATUS -gt 128 ]
								then
									echo | tee -a $RUNTIME_LOGFILE
									echo "[$(date)] [${FUNCNAME[0]}] Timeout waiting for user input. Auto answer [N]..." | tee -a $RUNTIME_LOGFILE
									XPLUGIN_TO_PROCEED="N"
								else
									echo "$XPLUGIN_TO_PROCEED" >> $RUNTIME_LOGFILE
								fi
							fi
						fi
					
						if [ ${#XPLUGIN_TO_PROCEED} -gt 0 ]
						then
							if [ ${XPLUGIN_TO_PROCEED} == "n" ] || [ ${XPLUGIN_TO_PROCEED} == "N" ]
							then
								echo "User input [$XPLUGIN_TO_PROCEED]. To exit..." | tee -a $RUNTIME_LOGFILE
								cleanUpDataDir	
								exit 1	
							else
								if [ ${XPLUGIN_TO_PROCEED} == "y" ] || [ ${XPLUGIN_TO_PROCEED} == "Y" ]
								then
									echo "User input [$XPLUGIN_TO_PROCEED]. To proceed..." | tee -a $RUNTIME_LOGFILE
									XPLUGIN_ASK_USER_AGREEMENT=0
								else
									echo "Invalid user input [$XPLUGIN_TO_PROCEED]! Please retry..." | tee -a $RUNTIME_LOGFILE
								fi
							fi
						else
							echo "Invalid user input [$XPLUGIN_TO_PROCEED]! Please retry..." | tee -a $RUNTIME_LOGFILE
						fi
					done
				else
					echo "[$(date)] [$(basename "$0")] No data dump is enabled for plugin [$XPLG_NAME]..." | tee -a $RUNTIME_LOGFILE
					continue
				fi
			else
				echo "[$(date)] [$(basename "$0")] XPLUGIN_ENV_CMD failed to execute! Skipping..." | tee -a $RUNTIME_LOGFILE
				continue
			fi
		else
			echo "[$(date)] [$(basename "$0")] Parameter file [$XPLUGINS_PARAM_FILE] of plugin [$XPLG_ACTION] does not exist!" | tee -a $RUNTIME_LOGFILE
			continue
		fi
	done
fi

# [-Q] [PLUGINS] To validate PLUGINS timeout value
if [ ${#IN_PLUGINS_TIMEOUT} -gt 0 ]
then
	if [ ${#PLUGINS} -gt 0 ]
	then
		if [ ${#TIMEOUT} -eq 0 ]
		then
			echo "[$(date)] [$(basename "$0")] INFO: Command [timeout] is unavailable. Ignoring user input PLUGINS_TIMEOUT [$IN_PLUGINS_TIMEOUT]..." | tee -a $RUNTIME_LOGFILE
		else
		  	if [ $(echo "$IN_PLUGINS_TIMEOUT" | $AWK '{ if ($0 ~ /^[0-9]+[smh]$/) { print "OK" } else { print "NOK" }}') == "OK" ]
			then
				echo "[$(date)] [$(basename "$0")] Setting PLUGINS_TIMEOUT to user input [$IN_PLUGINS_TIMEOUT]..." | tee -a $RUNTIME_LOGFILE
				PLUGINS_TIMEOUT=$IN_PLUGINS_TIMEOUT
			else
				echo "[$(date)] [$(basename "$0")] Invalid PLUGINS_TIMEOUT [$IN_PLUGINS_TIMEOUT]. Maintain PLUGINS_TIMEOUT at [default = $PLUGINS_DEFAULT_TIMEOUT]..." | tee -a $RUNTIME_LOGFILE
			fi
		fi
	else
		echo "[$(date)] [$(basename "$0")] WARNING: PLUGINS mode [-P] is NOT set. Ignoring user input [-Q] PLUGINS_TIMEOUT [$IN_PLUGINS_TIMEOUT]..." >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: PLUGINS mode [-P] is NOT set. Ignoring user input [-Q] PLUGINS_TIMEOUT [$IN_PLUGINS_TIMEOUT]...${NORMAL}${NEWLINE}"
		OPT_WARN="true"
	fi
fi

# [-K] [SNAPSHOTS] To set SNAPSHOTS_CFGFILE_PROD
# if [ $DIFF_SNAPSHOTS == "true" ]
# then
#	SNAPSHOTS_CFGFILE_PROD=$MUSTGATHER_DIRNAME/config/snapshots/$PRODUCT_VERSION/product.snapshots.cfg
# fi

# [-f] To validate GET_PVC_USAGE 
if [ $GET_PVC_USAGE == "true" ]
then
	if [ ! $MUSTGATHER_OPT == "all" ] && [ ! $MUSTGATHER_OPT == "comprehensive" ] && [ ! $MUSTGATHER_OPT == "basic" ] && [ ! $MUSTGATHER_OPT == "limited" ] && [ ! $MUSTGATHER_OPT == "selective" ] && [ ! $MUSTGATHER_OPT == "modules" ] && [ ! $MUSTGATHER_OPT == "extra" ]
	then
		echo "[$(date)] [$(basename "$0")] WARNING: GET_PVC_USAGE is only applicable to collection mode [-a, -c, -b, -l, z and -e]. Selected mode is [$MUSTGATHER_OPT]. Ignoring user input [-f] GET_PVC_USAGE [$GET_PVC_USAGE]..." >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}WARNING: GET_PVC_USAGE is only applicable to collection mode [-a, -c, -b, -l, z and -e]. Selected mode is [$MUSTGATHER_OPT]. Ignoring user input [-f] GET_PVC_USAGE [$GET_PVC_USAGE]...${NORMAL}${NEWLINE}" 
		OPT_WARN="true"
	fi
fi

if [ $OPT_WARN == "true" ]
then
	OPTWARN_ASK_USER_AGREEMENT=1

	while [ $OPTWARN_ASK_USER_AGREEMENT -eq 1 ]
	do
		echo -n "[$(date)] [$(basename "$0")] There are some WARNINGS! Are you sure you want to proceed (y/n)? " >> $RUNTIME_LOGFILE
		printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}There are some WARNINGS! Are you sure you want to proceed (y/n)? ${NORMAL}"

		if [ $AUTO_YES == "true" ]
		then
			OPT_WARN_AGREEMENT="y"
			echo "$OPT_WARN_AGREEMENT" | tee -a $RUNTIME_LOGFILE
			echo "[$(date)] [$(basename "$0")] Option [-Y] is set! Auto answering [y]..." | tee -a $RUNTIME_LOGFILE
		else
			if [ $MG_TTY == "false" ]
			then
				OPT_WARN_AGREEMENT="n"
				echo "$OPT_WARN_AGREEMENT" | tee -a $RUNTIME_LOGFILE
				echo "[$(date)] [$(basename "$0")] In non-TTY mode, auto answering [n]..." | tee -a $RUNTIME_LOGFILE
			else
				read -t $DEFAULT_USERINPUT_TIMEOUT OPT_WARN_AGREEMENT
				OPT_WARN_EXIT_STATUS=$?
	
				if [ $MG_DEBUG == "true" ]
				then
					echo "[$(date)] [$(basename "$0")] OPT_WARN_EXIT_STATUS = [$OPT_WARN_EXIT_STATUS]" | tee -a $RUNTIME_LOGFILE
				fi
	
				if [ $OPT_WARN_EXIT_STATUS -gt 128 ]
				then
					echo | tee -a $RUNTIME_LOGFILE
					echo "[$(date)] [$(basename "$0")] Timeout waiting for user input. Auto answer [N]..." | tee -a $RUNTIME_LOGFILE
					OPT_WARN_AGREEMENT="N"
				else
					echo "$OPT_WARN_AGREEMENT" >> $RUNTIME_LOGFILE
				fi
			fi
		fi
	
		if [ ${#OPT_WARN_AGREEMENT} -gt 0 ]
		then
			if [ ${OPT_WARN_AGREEMENT} == "n" ] || [ ${OPT_WARN_AGREEMENT} == "N" ]
			then
				echo "User input [$OPT_WARN_AGREEMENT]. To exit..."  | tee -a $RUNTIME_LOGFILE
				cleanUpDataDir
				exit 1	
			else
				if [ ${OPT_WARN_AGREEMENT} == "y" ] || [ ${OPT_WARN_AGREEMENT} == "Y" ]
				then
					echo "User input [$OPT_WARN_AGREEMENT]. To proceed..." | tee -a $RUNTIME_LOGFILE
					OPTWARN_ASK_USER_AGREEMENT=0
				else
					echo "Invalid user input [$OPT_WARN_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
				fi
			fi
		else
			echo "Invalid user input [$OPT_WARN_AGREEMENT]! Please retry..." | tee -a $RUNTIME_LOGFILE
		fi
	done
fi

# [-H] To create directories 
if [ ${GET_DEPENDENCY_DATA} == "true" ]
then
	for DEP_PROD_NS in ${PROD_NAMESPACES_UNIQUE[@]} 
	do
		mkdir -p $RUNTIME_OUTDIR/dependency/$DEP_PROD_NS	
	done
fi

logUserInput >> $RUNTIME_OUTDIR/userinput.log 2>&1
logUserEnv >> $RUNTIME_OUTDIR/userenv.log 2>&1
logUserScriptDir >> $RUNTIME_OUTDIR/userscriptdir.log 2>&1

# To check whether preDataCollect() function is implemented in config/product.sh
if [[ $(type -t preDataCollect) == function ]]
then
	echo "[$(date)] [$(basename "$0")] Executing user implemented function - preDataCollect()..." | tee -a $RUNTIME_LOGFILE	

	if [ ! -d $PRE_DATA_COLLECT_OUTDIR ]
	then
		mkdir -p $PRE_DATA_COLLECT_OUTDIR
	fi

	preDataCollect > >(tee -a $RUNTIME_LOGFILE) 2>&1

	echo "[$(date)] [$(basename "$0")] User implemented function ended - preDataCollect()..." | tee -a $RUNTIME_LOGFILE
else
	echo "[$(date)] [$(basename "$0")] Function preDataCollect() is not implemented! Skipping..." | tee -a $RUNTIME_LOGFILE
fi

if [ $MG_DEBUG == "true" ]
then
	INIT_END_TIME=$(date +%s)
	INIT_EXEC_TIME=$(( INIT_END_TIME - START_TIME ))

	if [ $IS_MACOS == "true" ]
	then
		INIT_ELAPSED=$(eval "printf '%02d hr %02d min %02d sec' $((INIT_EXEC_TIME/3600)) $((INIT_EXEC_TIME%3600/60)) $((INIT_EXEC_TIME%60))")
	else
		INIT_ELAPSED=$(eval "echo $(date -ud "@$INIT_EXEC_TIME" +'%H hr %M min %S sec')")
	fi

	echo "[$(date)] [$(basename "$0")] START_TIME = [$START_TIME] / INIT_END_TIME = [$INIT_END_TIME]" | tee -a $RUNTIME_LOGFILE
	echo "[$(date)] [$(basename "$0")] The mustgather initialization took [$INIT_ELAPSED] to execute..." | tee -a $RUNTIME_LOGFILE
fi
	
case $MUSTGATHER_OPT in
	# PRIMARY modes
	all)
		echoModeMsg 2>&1 | tee -a $RUNTIME_LOGFILE
		if [[ $(type -t getAll) == function ]]
		then
			echo "[$(date)] [$(basename "$0")] Executing user-defined [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getAll > >(tee -a $RUNTIME_LOGFILE) 2>&1
		else
			echo "[$(date)] [$(basename "$0")] Executing default [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getAllDef > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		if [ $ALL_NODES_ONLINE == "true" ]
		then
			getSecData all > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir 
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	basic)
		echoModeMsg 2>&1 | tee -a $RUNTIME_LOGFILE
		if [[ $(type -t getBasic) == function ]]
		then
			echo "[$(date)] [$(basename "$0")] Executing user-defined [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getBasic > >(tee -a $RUNTIME_LOGFILE) 2>&1
			# getTest > >(tee -a $RUNTIME_LOGFILE) 2>&1
		else
			echo "[$(date)] [$(basename "$0")] Executing default [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getBasicDef > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		if [ $ALL_NODES_ONLINE == "true" ]
		then
			getSecData basic > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	comprehensive)
		echoModeMsg 2>&1 | tee -a $RUNTIME_LOGFILE
		if [[ $(type -t getComprehensive) == function ]]
		then
			echo "[$(date)] [$(basename "$0")] Executing user-defined [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getComprehensive > >(tee -a $RUNTIME_LOGFILE) 2>&1
		else
			echo "[$(date)] [$(basename "$0")] Executing default [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getComprehensiveDef > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		if [ $ALL_NODES_ONLINE == "true" ]
		then
			getSecData comprehensive > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir 
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	limited)
		echoModeMsg 2>&1 | tee -a $RUNTIME_LOGFILE
		if [[ $(type -t getLimited) == function ]]
		then
			echo "[$(date)] [$(basename "$0")] Executing user-defined [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getLimited > >(tee -a $RUNTIME_LOGFILE) 2>&1
		else
			echo "[$(date)] [$(basename "$0")] Executing default [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getLimitedDef > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		if [ $ALL_NODES_ONLINE == "true" ]
		then
			getSecData limited > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	selective)
		echoModeMsg 2>&1 | tee -a $RUNTIME_LOGFILE
		if [[ $(type -t getSelective) == function ]]
		then
			echo "[$(date)] [$(basename "$0")] Executing user-defined [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getSelective > >(tee -a $RUNTIME_LOGFILE) 2>&1
		else
			echo "[$(date)] [$(basename "$0")] Executing default [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
			getSelectiveDef > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		if [ $ALL_NODES_ONLINE == "true" ]
		then
			getSecData selective > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	modules)
		echoModeMsg 2>&1 | tee -a $RUNTIME_LOGFILE

		if [ ${MODULES_CUSTOM} == "false" ]
		then
			if [[ $(type -t getModules) == function ]]
			then
				echo "[$(date)] [$(basename "$0")] Executing user-defined [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
				getModules > >(tee -a $RUNTIME_LOGFILE) 2>&1
			else
				echo "[$(date)] [$(basename "$0")] Executing default [$MUSTGATHER_OPT] data collection mode..." | tee -a $RUNTIME_LOGFILE
				getModulesDef > >(tee -a $RUNTIME_LOGFILE) 2>&1
			fi
		else
			if [ $MODULES_CUSTOM_AGREEMENT == "true" ]
			then
				MODULES_CUSTOM_TO_EXEC="true"
				. ${MODULES}
	
				if [ ${#CHECK_USER_FUNC} -gt 0 ] && [ ${CHECK_USER_FUNC} == "true" ]
				then
					GMGF_CMOD_FUNC=$(grep -E '^[[:space:]]*[a-zA-Z0-9]+\()|^[[:space:]]*function' $MODULES | sed -E 's/[[:space:]]+\{.*$//' | sed -E 's/^[[:space:]]*function[[:space:]]+//' | sed -E 's/[(|)]//g' | sed -E 's/^[[:space:]]*//')
	
					if [ ${#GMGF_CMOD_FUNC} -gt 0 ]
					then
						GMGF_SYSTEM_FUNC_PROC=$(echo "$GMGF_SYSTEM_FUNC" | grep -E -v $(echo "$RESERVED_FUNC_NAME" | tr ' ' '|'))
						GMGF_ALL_FUNC=$(echo -e "${GMGF_SYSTEM_FUNC_PROC}\n${GMGF_USER_FUNC}" | sort | uniq)

						if [ $MG_DEBUG == "true" ]
						then
							echo "[$(date)] [$(basename "$0")] GMGF_ALL_FUNC = [$GMGF_ALL_FUNC]" | tee -a $RUNTIME_LOGFILE
							echo "[$(date)] [$(basename "$0")] GMGF_CMOD_FUNC = [$GMGF_CMOD_FUNC]" | tee -a $RUNTIME_LOGFILE
						fi
	
						IFS=$'\n'

						for CMOD_FUNC in ${GMGF_CMOD_FUNC}
						do
							for ALL_FUNC in ${GMGF_ALL_FUNC}
							do
								if [ "${CMOD_FUNC}" == "$ALL_FUNC" ]
								then
									printf "[$(date)] [$(basename "$0")] ${BOLD}${RED}User-defined function [$CMOD_FUNC] in custom module script [$MODULES] is a reserved system function and is not allowed! Skipping custom module execution...${NORMAL}${NEWLINE}"
									echo "[$(date)] [$(basename "$0")] User-defined function [$CMOD_FUNC] in custom module script [$MODULES] is a reserved system function and is not allowed! Skipping custom module execution..." >> $RUNTIME_LOGFILE
									MODULES_CUSTOM_TO_EXEC="false"
								fi
							done
						done
					fi
				fi

				if [ ${MODULES_CUSTOM_TO_EXEC} == "true" ]
				then
					if [[ $(type -t getCustomModule) == function ]]
					then
						echo "[$(date)] [$(basename "$0")] Executing user-defined custom module [$MODULES]..." | tee -a $RUNTIME_LOGFILE
						getCustomModule > >(tee -a $RUNTIME_LOGFILE) 2>&1
					else
						echo "[$(date)] [$(basename "$0")] User-defined custom module [$MODULES] does not contain function [getCustomModule]..." | tee -a $RUNTIME_LOGFILE
					fi
				fi
			else
				echo "[$(date)] [$(basename "$0")] MODULES_CUSTOM_AGREEMENT = [$MODULES_CUSTOM_AGREEMENT] - User did not agree to execute custom module script [$MODULES]..." | tee -a $RUNTIME_LOGFILE
			fi
		fi
		
		if [ $ALL_NODES_ONLINE == "true" ]
		then
			getSecData modules > >(tee -a $RUNTIME_LOGFILE) 2>&1
		fi

		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	# SECONDARY modes
	clusternodes)
		echoModeMsg > >(tee -a $RUNTIME_LOGFILE) 2>&1
		getNodeLogs > >(tee -a $RUNTIME_LOGFILE) 2>&1
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir 
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	manualcollect)
		echoModeMsg > >(tee -a $RUNTIME_LOGFILE) 2>&1
		getManual > >(tee -a $RUNTIME_LOGFILE) 2>&1
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	extra)
		echoModeMsg > >(tee -a $RUNTIME_LOGFILE) 2>&1
		getExtra > >(tee -a $RUNTIME_LOGFILE) 2>&1
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	cmdexec)
		echoModeMsg > >(tee -a $RUNTIME_LOGFILE) 2>&1
		getCmdExec > >(tee -a $RUNTIME_LOGFILE) 2>&1
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	missingobj)
		echoModeMsg > >(tee -a $RUNTIME_LOGFILE) 2>&1
		getMissingObj > >(tee -a $RUNTIME_LOGFILE) 2>&1
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	compliance)
		echoModeMsg > >(tee -a $RUNTIME_LOGFILE) 2>&1
		getCompliance > >(tee -a $RUNTIME_LOGFILE) 2>&1
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	plugins)
		echoModeMsg > >(tee -a $RUNTIME_LOGFILE) 2>&1
		getPluginExec > >(tee -a $RUNTIME_LOGFILE) 2>&1
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	cpfiles)
		echoModeMsg > >(tee -a $RUNTIME_LOGFILE) 2>&1
		getCpFiles > >(tee -a $RUNTIME_LOGFILE) 2>&1
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
	snapshots)
		echoModeMsg > >(tee -a $RUNTIME_LOGFILE) 2>&1
		getSnapshots > >(tee -a $RUNTIME_LOGFILE) 2>&1
		gzipData 2>&1 | tee -a $RUNTIME_LOGFILE
		cleanUpDataDir
		if [[ $(type -t echoEndMsg) == function ]]
		then
			echoEndMsg $GZIP_OUTFILE
		fi
		printSummaryLog
		;;
esac
